(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    277035,       5154]
NotebookOptionsPosition[    274158,       5059]
NotebookOutlinePosition[    274666,       5078]
CellTagsIndexPosition[    274623,       5075]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Effect of Phase Noise on Squeezed State", "Title",
 CellChangeTimes->{{3.4554612358110437`*^9, 3.455461248382044*^9}, {
  3.455467025486044*^9, 3.455467028364044*^9}, {3.455470101803244*^9, 
  3.455470102864044*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$TextStyle", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
     RowBox[{"FontSize", "\[Rule]", "13"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotopt", "=", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.1", ",", "0.7", ",", "0.2"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.5", ",", "0.5", ",", "0.2"}], "]"}]}], "}"}]}], "}"}]}]}],
   ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Using Takeno's 2007 Optics Express Paper", "Subsubtitle",
 CellChangeTimes->{{3.455469733846044*^9, 3.455469755717244*^9}}],

Cell[CellGroupData[{

Cell["\<\
Assume 70mW Pump, 140mW threshold value, escape efficiency set to 0.947 = 
next gen value, current OPO is 0.925\
\>", "Subsection",
 CellChangeTimes->{{3.455467114985044*^9, 3.455467147105044*^9}, 
   3.4554697268416443`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Lin", "[", "x_", "]"}], ":=", 
  SuperscriptBox["10", 
   FractionBox["x", "10"]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dB", "[", "x_", "]"}], ":=", 
   RowBox[{"10", "*", 
    RowBox[{"Log", "[", 
     RowBox[{"10", ",", "x"}], "]"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"thresh", " ", "=", " ", "140"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Threshold", " ", "power"}], ",", " ", 
    RowBox[{"in", " ", "mW"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"op", " ", "=", " ", "70"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Operating", " ", "power"}], ",", " ", 
    RowBox[{"in", " ", "mW"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Eta]esc", " ", "=", " ", "0.947"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Escape", " ", "efficiency", " ", "of", " ", "new", " ", "BT", " ", 
     "cavity"}], ",", " ", 
    RowBox[{"calculated", " ", "0.947"}], ",", " ", 
    RowBox[{"current", " ", "BT", " ", "has", " ", "0.924"}]}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sqzcav", " ", ":=", 
   RowBox[{"1", "-", 
    RowBox[{"\[Eta]prop", "*", "\[Eta]esc", 
     FractionBox[
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"op", "/", "thresh"}]]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SqrtBox[
          RowBox[{"op", "/", "thresh"}]]}], ")"}], "2"]]}]}]}], "  ", 
  RowBox[{"(*", 
   RowBox[{"Squeezing", " ", "without", " ", "phase", " ", "fluctuations"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ASqzcav", " ", ":=", " ", 
   RowBox[{"1", "+", 
    RowBox[{"\[Eta]prop", "*", "\[Eta]esc", 
     FractionBox[
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"op", "/", "thresh"}]]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SqrtBox[
          RowBox[{"op", "/", "thresh"}]]}], ")"}], "2"]]}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Anti", "-", 
    RowBox[{
    "Squeezing", " ", "without", " ", "phase", " ", "fluctuations"}]}], 
   "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sqzfluc", " ", ":=", " ", 
   RowBox[{
    RowBox[{"Sqzcav", "*", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "*", 
        FractionBox["\[Pi]", "180"]}], "]"}], "2"]}], "+", 
    RowBox[{"ASqzcav", "*", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "*", 
        FractionBox["\[Pi]", "180"]}], "]"}], "2"]}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "Observed", " ", "squeezing", " ", "with", " ", "phase", " ", 
    "fluctuations"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ASqzfluc", " ", ":=", " ", 
   RowBox[{
    RowBox[{"ASqzcav", "*", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "*", 
        FractionBox["\[Pi]", "180"]}], "]"}], "2"]}], "+", 
    RowBox[{"Sqzcav", "*", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "*", 
        FractionBox["\[Pi]", "180"]}], "]"}], "2"]}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Observfed", " ", "Anti"}], "-", 
    RowBox[{"Squeezing", " ", "with", " ", "phase", " ", "fluctuations"}]}], 
   "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"dB", "[", "Sqzfluc", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Theta]", ",", "0", ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Eta]prop", ",", "0.5", ",", "1"}], "}"}], ",", 
    RowBox[{"Contours", "\[Rule]", 
     RowBox[{"Range", "[", 
      RowBox[{"0", ",", "10"}], "]"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<RMS Fluctuation angle, \[Theta] (\[Degree])\>\"", ",", " ", 
       "\"\<Propogation Efficiency, \[Eta]prop\>\""}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "Large"}], ",", 
    RowBox[{"ContourShading", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"11", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"10", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"9", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"8", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"7", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"6", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"5", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"4", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"3", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"2", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"1", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"0", "/", "11"}]}], "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"Style", "[", 
      RowBox[{
      "\"\<Expected squeezing level, white region is 0dB, darkest region \
between 10 and 11dB, 1dB contours\>\"", ",", "Medium", ",", "Bold"}], 
      "]"}]}]}], "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"dB", "[", 
     RowBox[{"(", 
      RowBox[{"Sqzfluc", "/.", 
       RowBox[{"\[Eta]prop", "\[Rule]", "0.75"}]}], ")"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<Squeezing level as a function of \[Theta], for given propogation \
efficiency of 75%\>\"", ",", "Medium", ",", "Bold"}], "]"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<RMS fluctuation angle, \[Theta] (\[Degree])\>\"", ",", 
      "\"\<Squeezing relative to SNL\>\""}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "5.1", "}"}], ",", 
      RowBox[{"{", "3", "}"}]}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4554612516010437`*^9, 3.455461307621044*^9}, {
   3.455461376109044*^9, 3.455461385106044*^9}, {3.455461418521044*^9, 
   3.455461456326044*^9}, {3.455461583504044*^9, 3.455461736221044*^9}, {
   3.455462135826044*^9, 3.455462138474044*^9}, {3.455462181886044*^9, 
   3.455462251408044*^9}, {3.455462337787044*^9, 3.455462358054044*^9}, {
   3.4554623963440437`*^9, 3.455462401548044*^9}, {3.4554624492960443`*^9, 
   3.455462484740044*^9}, {3.455462556280044*^9, 3.455462566698044*^9}, {
   3.455463313743044*^9, 3.455463367074044*^9}, {3.455463413914044*^9, 
   3.455463481039044*^9}, {3.455463618396044*^9, 3.4554636704100437`*^9}, {
   3.455463759519044*^9, 3.455463864114044*^9}, {3.455463898248044*^9, 
   3.4554639001340437`*^9}, {3.455463947505044*^9, 3.455463947539044*^9}, {
   3.455463987772044*^9, 3.455463996906044*^9}, {3.4554668429500437`*^9, 
   3.455466895026044*^9}, {3.455466942595044*^9, 3.455466985898044*^9}, {
   3.455467029647044*^9, 3.455467089972044*^9}, {3.455467150007044*^9, 
   3.455467223427044*^9}, {3.4554672567450438`*^9, 3.4554673857960443`*^9}, {
   3.455467428320044*^9, 3.455467453697044*^9}, {3.455467883136644*^9, 
   3.455468003023644*^9}, {3.455468091208844*^9, 3.455468287735244*^9}, {
   3.455468329034844*^9, 3.455468365367244*^9}, {3.4554683954596443`*^9, 
   3.455468493646044*^9}, {3.455468527638444*^9, 3.4554685289020443`*^9}, {
   3.455468564345244*^9, 3.455468657898444*^9}, {3.455468698442844*^9, 
   3.455468773759644*^9}, {3.4554688111478443`*^9, 3.455469007349044*^9}, {
   3.455469130527644*^9, 3.455469147172844*^9}, {3.455469274468844*^9, 
   3.4554693638100443`*^9}, {3.4554694020144444`*^9, 
   3.4554694983444443`*^9}, {3.455469552180044*^9, 3.455469639168844*^9}, {
   3.455469767604444*^9, 3.455470077529644*^9}, {3.4554704310694437`*^9, 
   3.455470630234644*^9}, {3.4554706817302437`*^9, 3.455470683368244*^9}, {
   3.455470725332244*^9, 3.455470740791844*^9}, {3.4554710482660437`*^9, 
   3.455471122958844*^9}, {3.455471296096244*^9, 3.455471319870644*^9}, {
   3.4556402131927156`*^9, 3.455640278416316*^9}, {3.455640568435916*^9, 
   3.455640572148716*^9}, {3.4556407008175163`*^9, 3.4556407250443163`*^9}, {
   3.455640770221916*^9, 3.455640873852716*^9}, {3.455640910231916*^9, 
   3.4556412789067163`*^9}, {3.4556413441927156`*^9, 3.455641426108316*^9}, 
   3.455641473797516*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1fQVY1M/z/4GAoCjdHTbYhTVrYrfY2N1+vsrZ2GIrih0oiopgY2Bgi60o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   "], {{
     {RGBColor[1, 1, 1], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtVUtvjVEUPfe77fnOvcLtw6OqGoSOiLSCRIiJiZiIkTCQGGhEokNSUzRe
fXmlJISkQrzjUfWIgX8gITHwKBERMVGq9aq1stZg5+yzv33O2Xvttfc3f3vH
pt1ZCOEJpAhZh81EIYQt0IdgeABZif2MFMIw9OlY38FnNmQc9psxhEboP2F/
i7UBMgZ7N9Y78E/Qb0T5j8HnepTPD+jXoM+C/h36Zuh74Buhv8lsx34O1vWQ
nUGxDDseSidkMSQl6Vtwx4GqEPZD9mJ/K+r8eNJ9KyBLgvzoX5OHcBX6TNhH
k/Jg/sz9kXNfB79yKYS/WE/C925RebVif6+oPfX2aul8d1FUfLtw/1piA30D
7jyMuAawbyvINmb7PtjqIc+Dcp7lOBkTY6uJ8iVuq4Pwok9tVK3GXa9VxLUg
n514exT7aqwtWPdAnsFeQYz3HTNzY41HYF9jnXHXJ/nUYc1LirUHb03BHZ8h
Zb/z3W8R19GCYq5JwqU2yfbN9k/wmQeJkD5Ib6bcmNMq50UMd1QL31c4fwh4
5Yj/A743Qf7hrstRWNWVhPch13p5QXVv83rA+sEq4U69y3b6cz1oO9/kGXJ1
EPdXiG1JtRqDHIdUsM+xnsf3qlx3vUSMp7CfxLkp+H4iiifkS69rk6AfjcIr
Qu+OwpO4jmTi3K+C3mC9lkE/HIVdNXxeJMVZzMXJI1Xi5bmoeBjXGehF6FOh
vzauxH0I9gXQJ5P6hP1FjrEXyUty73YUthPwuQO9GfrvpD6kf56UA3Ppw/d7
UXX8mxQf4zwC2+MonhVgewh9IYdKSbgQn9OwhVxc35rEgaWQZph7MvGSnPyY
KYYMUsLZ38QGZy+YfzWwpVxnn8LWkcl+F/e8z9TvfwrCgpicdX4bIXvhUzaO
c/G9P+p+vkNOfSWvIP2Z+ERufMmUyzTznngOBs0y4ljvWr025syjx7mRQ+TS
pah5R67XRfXrbONPHIlnY1TcczzrOLOozzB33ngeTsvFy0oubo6an8xjxFzq
dK1Zc2K5GdIVxLu3ns/spSZjwtq+8zzvNwcrQX3BnmS/1Bsb8oe8++Re5nuN
npn83uI5Qx5Qb47CbqFrxJp8dH0/G8+yuUKfuZ6x7Z4D/N5uzNk/xOKYe/SL
6/LTs3t6VB+zduxl3tfhd9kzQ57n7NH35gl7g280mV9l+5Nn3F90f3/w/Fnj
fw+xXW/cWa/o+XYqqEeH/f+oOEZi0u9aEd/MPGdd2G/UG6K40+2+YC47jD+x
oM68cmM/aDwzv8seZk1nmte/HBvzZtyc84xxm/15J99qNV/2ub78XrRPnXvj
StQ/pOJcWJPcMZDrfZ47X80BcmHA+bKP6NPjvJabZ+QYz/S6d9iT7M2GJFuf
/bt9lnGyj1k/8pbrH+uT5jTxPO4e5rvk/qTt/wGWfgaD
         "]], PolygonBox[CompressedData["
1:eJwlk1uIzVEUxvc5Z6z/H3HOzJkZx2BCLo+Sorx4mZQ3KcyQpoaaNDKPI56R
M+7XUEQRuceQS3n04klMUe5pEh40MUkuv6/v4avv22vtvdde69uzevpXbS2m
lJaDBlDOUjrJQh0xHv44UlqAbgVX4JUwfw1WE3+GXgafCq7DS6ztYu9O8DxP
6SlrS4nVwLXwmTpbOS+ID4Pd8G2FlLqIv0IPoh+WUppAbgb2oO+gy7lzlKu1
l+g68XLJNebwCthOfAmYG96jvUOgAm8K1/IWrCX3CXoxfAq4Cm8M8zdgDfEx
dD98DngA/wsG4PPAI3gzZ94vuWbVfoK1f9zdSXwEPghGC75Dd23kzC/wMriA
3oT+Bq+CS+hJ6EXkj6I3w7eAn0XPZDK8E7yD/yLnIPnjMucqR7ld4D38N/HD
xNejPxZd03H0OvQH9B/0UfQG9Cd0CZwK90S9GSO+P9wD9eIHei+6iTfeLbnn
6n0vWFjwWpVYX+beqyct6B70Z/ZPBOdUD2s74APqEXoYdKDbwI2wp+Qt9ayO
7kaPoDNwRv4AK+DTwE14New99US92ReuVZ6T9xpzz141qtbvrPUSmw3uwU+H
394NvsLPhu9SjnLPh2uXB+SFi+HZyQPywvTwWXqj3toSrk09Vq9blVP0DDSL
Grq96J6r91nuXsizOfxYeDYrdQb8SHiWerPefiA8G/05/b1a7r/Swdr8sOfk
Pd1xO/wmvW0mGAqfqbNV0y14WzimHqvX7WFvy5Py5oyw9+VZefdQ2HuamWan
P66/rj/cQLw5PEt5UF68HPa2Zp7Q/wE0kIyj
         "]]}]}, 
     {RGBColor[0.9545454545454546, 
       NCache[
        Rational[10, 11], 0.9090909090909091], 0.9545454545454546], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmWuMlsUVx5/33feZ5+G23BbEcllXQWxVUm1FWJB+MhHTxKa6LOtCETBi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         "]], PolygonBox[CompressedData["
1:eJwllUloV1cUxu/75/+/7yVRM6pRE5OIcQJBpWit4NpFV4JYqqh1IQ7QLoQu
unCAGqc4JraaNo7VKm2dtSMU3QoiiFGhVm0dkarRaJxi+/v6LQ6c757vnHvf
mV7j/E+mf5wLIXyG5JHK4hBGFFCSEA7GECqQu8CLGLuzEH4FT0F/D2kBl4Nv
Y78AfiqM/zD8X3G2B1tZGsJaLliJ9EMfAWcytk+LQhiJ/hOcSfhORNaC94KH
JY6hWNvA/cEDwCXgCXCu4TuDs3Ho65F38e1D/H1wh0a//RVnCfwD4CbwcPwr
wK3gKnA1uLjYPvKdAP9zYi3kjU/AM5E72DI4lXAfEHZz9Bv1Vt35M/gN/B28
px3pRd+C/QLcqdi3opfiX4N/F2dfwF+lHBF7F/zmzG/S23qx78fehX4mOMcb
sD8nZivcNqQHfShnZ9Gn8Q216GX4N+DTg89O/J9zdhXfMuyHwQ+xHQ/O8Tps
Kfxyzu5zthF7AzG/5z2l2OdiLyD7iH8dexn2Avw+Bdd4HbgTfRp6B/ybcGs4
6wbfA78GB/g9edfwF2zjkPPEW4rcSF0T1UY1+Q3bl8igxDlSrr4C1+rbwH3B
bZlzWc0bW9HnY38feytn18CXkYPgQ8S/gj44OhcPsfdmjqFYemM7tkvI9sTf
3Ji6p9XbpTqL7gn1xj/wt4JXZ75bOVmjXkN2wp2JTNS3wR0T/I1N2Gqje7+b
mP+C66Jrq5woN52cdRBvBZLn/shZv4JnrAXuLqQ+cU1V2xT+t8Q+gETVD5/V
Oce4Cv4munfVg+rFQupZ244sSu0j3wKcD6JrpFop5yfAHaox3AXIY/SbqWul
GQ3gF/Cv5z0zR8Gzsd+Cm+gOcDX2FvRnSH/lKjp3f+DTA94RzZ2DPNAsI4+C
Yyr2BnDfxDlQLlRT1fb/nHI2h/vu5PzGr+F+BL6HPh7ObvBL+H/lvSOOgUdH
z8ZypB7bpuhZUM+r9/WN+tZG5HT0jGvW65Dj0W/UW+uRk+i/qyfwXwPONN/a
iYl3gnZDLvMsa+ZLo2dCs6EeU69VgLtyrlk5+jzkzyL30GLsb1PvDs28Zl85
U+50xxHsszLXbhQ4wK1Rzoi1GW5dsUW6alCCfVD025Uz5a4qendpJ2g3aIdq
l6oGbdE5VC61Y7RrDkXfpX+A/gWbMu967ayN6MMz51YzOBbuktS1b0eatMuj
Z0MzORnukOhcq2bz4JZkntUBqg+2Z+DOvHvgh+gdpF2kHT8evTJ6V4kjrv4x
+teoJt9hK099d8rZh7oLac55h2uXr4+ebe0w7bKi1LOnf9IlYr1IvVu1I7Ur
KzPXWjWrQh8Y3RvqefW+/jn696iG72TeMdo12lmn4J4jxrLEO7oOW0P0t+pN
zal3gnaDZvxH2aL/Deph9fLfqf+N2rFJ9Dfp27QDMuz/AS4d648=
         "]]}]}, 
     {RGBColor[0.9090909090909092, 
       NCache[
        Rational[9, 11], 0.8181818181818182], 0.9090909090909092], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFl1uMVlcVx/d85zv7bMCmEtPgTKUFkU4bb6htqSm2tcSZMA9QmxRiY1pa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         "]], PolygonBox[CompressedData["
1:eJwllWtolmUYx+/32fvez23z+EFkWx6mmQQec2iRRyQFPzgT8tSHzFTIPBQe
gpS+6Ka5nFNLFBQKxIn0JRFJxEAUQZ2kgik4llOaVOoy1CSc+vvz//Dnvc7X
/Vynt3rx6jmrshDC56AInuYhSNAN/Af9O/isLIRx6F6UQrgDNkF3IpuaQpgP
bhRCWA1qYwhrQG8CzUR/Gt+30N+G7o5sOboJYGHBNkvQFUAfco2Fr4e+gr4R
fTOySvxHwrfgfwEMQV8FfoGegU0F9EjwPu/5Ctko6HbsD6E7jv9w/N9D9hzd
MOJ/Cb0hmdab9fae3UIYwDc9JsZ+fLug9+B7EJ9e8G+AM/oW8Cr2K+F74X8H
/m34n8jRQaxV+FUQ611ku4jVhH469CjsL5W5hm3YvomsFXoeNmP0NmTrydcD
dEGPj47dDsajv0/cH7A9Rc5O+Hno15NvNPwm+D/w2YDtRtAB/b9k6PphcxTb
u/A/Fl0T1eZKyb38Dlkbuh1gAvRQ8n8DXYPNtTLHVOzXkf0K3YD/ZXwz+O/L
3DP17qPcs/KUmIugdyKbrFoje4R9G1gS/Aa95WD0t/4FNsOfjM6tGmyH/zr6
2z4lx03ijUW2LLhmNdCD0JdDP8J+OfrzxN9Y8ExUoo/I6jLb1EMPSO5dOTH6
Q88GXfCf4DMLelL0LG8DnblrrFq3oH+C7mcwJPNObEueQc3iRTAiuufqvXoy
F/5x7t6rZwn+z9yzqRpk8E2av8w12gU9ETQXvBPvoF8MthQ885r97sSvJP6/
+O+Fv4l9o/oLfwH5h8jqsK8Hfcn1DP3f6Cvhj0X3TL1bS7wQ/Y361gbwD/Sl
kmM14dOK775oX+VU7nXIBhdds9rkndZu6wboFryC7Aj8Zt0M6Ibk3qpmJ4g1
O/o2aEcWJNdctddOzoEuJe9aX+yL0NXRs/uMnBn5K3Lfgh3IlkbvhHZDN2Uc
fBX6w+gngaslQ/QX6Avapdx0Lf63oa/jv7XoHdYuHwD9C74BugW/8Tstc0zF
HpR7VyWrzv2N+lbFuJE845p17UQ5sT5Ovj3q6Qr4I+AB/BTsd6N7LXl2EvwH
6BYl30bNuGZdM6/ZXwFaodtz924W8W5BTwYtmXui3miHtcu6mbqdd3PfAt3E
ayXXVLWtwWYr9LfJb9EMahZVY9VaO6Pd6Rc9a7ohuiXaAe2Cck5B/zD37OjG
dRC/Gf29zDekEfuK6FuqGdQsVkXfhofwz3UvomdVN1G3cVl0b3VzdHtkI1v1
5Hh0z9Q73aBh6EZH10I7MhS+Lvm/Q2/QW3QTdBs0kwOja6xa64YPxPZs9H+H
dki7pJnX7GuHzmn3kmulnql3LwFfTupk
         "]]}]}, 
     {RGBColor[0.8636363636363636, 
       NCache[
        Rational[8, 11], 0.7272727272727273], 0.8636363636363636], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNV1uIVVUY3uecvdbeIxRWjqD2Yo4TmBfIGZrRMS0ds8TRGc0aSMJbWHQh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         "]], PolygonBox[CompressedData["
1:eJwllEtslVUUhc/9773/f2yigQBKcaCVh4a2mhgIllsemhQIBNveFggmKC3F
CAEMjxEkGGBASMDHRKoSnmJMGAADEhjYTmgFtKIDE1uwTYwBpZRXdKAQ4Fus
wU72Omvv89h7nV3V/mF5QxJCWIcVsE1pCMtzIZwBDMcQ/s1C+CwfQhtr/+BP
he8F92Avwv8MrmeDb7AO/Grse7idxK/Af56Y78Ckhgn4Jex4zmfUaS+IMvxJ
+JvFEH7ERgefURW9Ju4+eDH4AbgPfJ773QNPJf8MZz8NbgO3R/s6Q2d1wnfj
f0De+KdCOMxaE/wJcl6Au4ud1V2xO/h93KkEdxwbD75MXh3+Rs5/hH+dtf3E
lrFrehT7Hcj7ThXkrgWPK/hMnf0LObPI/xp7DvwX1go3QM5rxLaRsxicEZfn
fqfhS3C17LEbbhn2MrgAfof4MvwV9rqKteLXw9+Ev4HVwzdj3dzlAbiM/zf7
fgo+R/4IeC85o8Cj4Pfh/wG/A3wLPDe6pqrtbe6UwM9Kze3GRjJr4IkWwPOI
XZi6N59j/8G9Au7Ou+eV0Wfq7C5ybsP9qf6D2zmzn7Pvq57EdoHvgN9PXdsK
/AL1eDW6Vqr5r6zVgn8Dt4Cr8evI70lc8zXgJdF7qSdLo3uu3ncQ36DeEt9L
/GrsRtEal9ZVA9VCb9bbVeMW/AHWFuB/xH4J+auIf4b4zcRXw19gbQb8UexZ
cBM4D5/DlhG7EjyF2CO6Y+YaqVZ68/+ZNSFtSGPSmvbQXm9gl1L/Kf2tZvY7
yn6rwMcSa/Qn/HdZqyi4JjX421mrKvhP6W91srYAfIj4sZk1JC1JY0uJfSn6
ry7CalL3SL1STWdm/gP6C/rjl3V29F3eAh+SVlh7PXHP1fvN2MmcNdkRrUlp
cxgrwf2Q+m16g96iHqvXDdRoNXgPdjdnze+KnjGaNZopmi0TM2vnbfIn4Vdm
ztUfm4D/kL3mF/xmvf33zG/T2n7wJ5m1rxnzceY/pr+mni2Hn5daK6rhluge
q9eN7F+DP1i0fwqbDN5GTFLwn9sqvcOvT6wxaa0/tValeWl/DmungmPm6n9F
10aaWkdsU/TfVUyj/m9m7WlmaHZIs9KuZnIkfijzbNIMGcx8J91NmpV2x4AP
Ju7RpaI1KW3qzo2pZ6BmoTQkLWkGaRZJs9LuF6xNg18E/xX+e6m1PF1vlP6w
w4n/wMXUGpPWlNMD/jI6VzGKnZ161kojb8L1Fb2X7qi7SlPSlmb0Efyh1L3W
jP8WfCvzLNJMK8I1RM8izfBr7PUYhFLYPg==
         "]]}]}, 
     {RGBColor[0.8181818181818181, 
       NCache[
        Rational[7, 11], 0.6363636363636364], 0.8181818181818181], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1l1lsV1UQxi/9/++CDyYaJDy4ABojS6EtJooGBNewqriABrAoCUIrRWNE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         "]], PolygonBox[CompressedData["
1:eJwtlGloz3Ecx7/7H7/fbx4owgNHDGkXOaZYEXO1ZZaJ0JYjtTna3LMHrlDE
KMu5zZgHjkTyxFEUxphzW7bFzLVhRSKlEV7vPnvw7vd5fz/H9/v7XHFLC7ML
Qs65PBABkz3nFsc4txpyK3DuGliJfBOjMb5zV+E5ITu7jjwVfA+bTxryV2x2
w3PgX5BnctYJz4OnE/urZ7FncnYb/Sz4QOS/xNwAP419FvoS7KuQ74EieC36
iejro3x551HOWtHd4SwT/7voxyFXc7YqZD73kd9gX4j9ZfhneP9Y53Zwtof4
T7i7Hp/F+D/C5hDya86q0J3Hvh376fA+6H+BdHgbOBMxmxZ07+FV8EX4NxH3
mWdvT0HuzV1L0X/Edw36Jci1nt09En0v9DXw0ei2w/vBc+Bx8EJ4X3gT/HiM
3aG72uAX4FfgHfBG7LKwr4S/gztQwX0F2Pzz7Uw6xWhULPhO5AzOypA3gWER
q4FqcRKe7awGp5BvgOshq3kH+gPE7KlcEGOvb2/W2xXzAfpWsADf+eAMvom+
/bvOzqoe6BciXyLeUHS7QCzxXmLTHd2rqOVSOVaudYfu6oFNCfI+3+R4cET9
gM8kYp0DJ5Qf/HND1oNRz3KsXCvHD+ETPOvNi2AS9hnwfORakBlYT6m3ZsPz
0MXDnxOrHoyGjwJ1YTuTTj2sXlYPqhfHom9GbgRJ6FPhn5DbQSr8WGC5H8x7
qtF95m3LeO8tkIL/eFDp7CwV+Q/6zchNIAueDV45O5vjW4+oVzJ4b65nNrIt
Bj+i1tPqbeX4sG8zpFkaxBvW8ZYWeAG6GpCM/xDfajMDNEdt5jX7vbDPDyym
YqvHunn2Zr1dOW/r6nn1fhp3PkX/Fnmrsx4agW0R+BeymatDHuBb7Up5f4Ny
53XdHbZcamdod7wApdjODWxRNcK/Ra3H1es6m4cuH/vYiNUoAb4CJIQtp8sD
q4FqoZkc79nO0e7RmzYil4OksO2sg9JFrVbK0RF8awLbNdoxP/F/hH5bjM3E
fux/+/Y29VQn8uDAcquZ1mwXBfYvmrniwGqgWujOMt9yrFxrp04JbAdpF2mH
tXDX8MB6SzOaHNhO0m7SP04j/hbPelk7az26tZ71unpQvZgYWC9rh2qXPvas
VtqJ2o3lgfW+ZqoisBnWLGtmNbuJnvWa/jlO8wzKIraDGqK2Y7VrtaM+eLaj
tKvUA+oF1Vi1lo98/wOH1OCc
         "]]}]}, 
     {RGBColor[0.7727272727272727, 
       NCache[
        Rational[6, 11], 0.5454545454545454], 0.7727272727272727], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVk1oXVUQvi/3vnMPgm7cVVyICVYRQcXSjWLUBmzfi21Si5BaQdEmkhcX
9rUpmCJKXRQjWFM3aRIhIhjzEiXR2tQgVK2SLtQmoUVbE00rmkJojW4U0e/L
94mLw5k7Z+ac+flm5t705HMtXXVJkvyFlWKNxyR5IkuSMeyNOBjB6iskSRn7
JNZwQd/3F5OkGfIb8yR5CvzPci3SJ7HPQ2Ye9Bz2XsiuS0VvAq+GtQu6JewT
WF2g2/Hmx6Db/E6r36JOFfQoZLZg/wBrCLxb8EYneAu4uwm8Max+8CewDoDf
i7Wayp4B0FPw51m+gb0CnX9Ad0J2Gqs5lUwLZI/R54LsoD09iWw5Xqd7KXuq
IPlfcM9R7Btgy1bwH0ll50ydvknvxVmFPmA/BPmr4L9q2WbLNPub934J+/bC
ti+w12ey8xPI7MTqhszjiexjzHrMYy7IvxAU00vQnQXvdcjdBvpikA+/gn4e
qwbZ+3LF4fZUuToblJufcL4fqwHv7sPejvUa5O/OFZud4G/Dngf5zhiMRvHf
w34+KE/rIX/OuVkC/3vz3wF9GWeP4c13o+4iXUmEkRtS+ftGLvph6E06r8zp
lVTfpPeDLmXCIWPQaEyST5qxYc6oy1hVnYtm3DkQpXsU+x6/8XTU/ddn+h7E
dxn0bBCOpp135qea6Zt3lG3DSeN/BfJzqewoJ7KFNGWY+6lMsetzPbAWGHfS
Z4vyhWfM6ee0D/K/B73Hd0edd2KC95eMj7ZEOKI8sbQxKLaM92RRdjP3d4G/
Ffz1UVghZs7j/HBBfN7HWiq5Nrsz6fL9VuwtWJvrdCdrmzZ9i3texP5NVN20
uHZYw62uHeKW+WauB3JhbxD7PdBZAL0B+0RRddKRqU80OT6sv+2+pzNTLdcK
6h9l20ld8olXYn/O8SfuacMizu/Idc+PoP8O6i1fR/UU+sQ4sm/RF55tcb9h
r6EdtUx5GctEV0yPZ5JhvMfM5/mY+TOZfGL+WXvMw6kofm8qPN+bq3f0BOWP
OFnrXdhPGDPXQLYDa6UgTHXbR9o64z455XcGjIuScXIG91+E3r5c9cw4HY/q
nSX3T9oyY33au2affaH/9Is9qd79c8g47XSdtTnvjOWOgt5vNKa7XbvTdZJd
DsrlCdgwV9S8WQT9UdQ8OIb9jyD8fRU1izZ5HrHnMh6XobcUhLcaZJYKsus0
zn7L5c9qrvMR9wFinPhgTJaj8HAJd/Tl0j8YhKMOY6w+FZ937g7SXYBetag+
WXE/HnEfoz7lx3HfnqJiTt0Gx439jXNtnXvdvOcc6QeiZsRDUXOBNcecDrpe
toN/XRAODuaqP9Yh8TRu+18Jkr05092s3UnX6UuQyXH2suug5nnJmNE22jnt
OTzhfjNnG+hH1b5wJwa/A304ly9Hsa8auy8E3U3sHHBNVf0/8KBnCmcL5/lm
11jNtUI8fYiz3bQ7Cm/zjg/7xFsFYYt2UqbN2K24Rlk/rIUzvr/V/Yp+M5en
XUcr9odzbZvx0eWeyd45bLx0uW9fdU19GvVv0RgUk4ZU9/R6thOXa7Gvk93U
W7Uuexv7FP2n/BXX/qL/t+bC/32Tcbs1qi+3O6ec2czVtUGx/7MoHeremGte
cm6WomzK7S+xSizWu1exL9FPYrJqPmPK2HKOsIfzP5B183ZUz0+DZgbr586g
+qA/9Jk4IRb/w3WvMVlyvZXdN2j/vPvCDr/FXkwsLvsfbcL9//1c+Xo0KIaH
HLc3c8X8SK7eP+z6Y4+c8uzjjGddduPOn6PkfgDvQlE0eUd8z2wuzLGvED+5
88n4tkbFuwzdfvdt/kPxn4az6ZxjT13O9yZjcZfrhTGvGJv9tpN10eG+yj7C
fsL/NWK0xXlgPqi71nOi/kmeifp/4kzifxZtHnIsKVv1W/8CC8eZYQ==
         "]], PolygonBox[CompressedData["
1:eJwllEtIVVEUhrfX4z6boCbNekEPK6OCjKJJkL0GdS31WgQFQVFmmRbotaCB
9JoVZNEkjQY1yLpaZKmZNFGLJpUaSmYGGoSBVLdGEfT9rMHi/Gv9a6+91+ss
PFRTVp1wzpUiETKe51wV3zaUb8G5U965LhxSyCR4LTKU69y1HOcqwB34HMN3
P/wTcG/s3G74EqQPXI5tJbgK/xT4HdKA/wf8d8DPR4rAu7hzHrgbvgo+g/9p
4l/EVgfOJ8ZN8Fv4uoTFeA/+y3sr4WYgs/DfgywBx8h5/AdjOztJjAFwA/wL
7pqL7Tr6VmL8BF/FtgVcA9+ZsJyeBctBubzBthH8GtsZuB7i1eO7HNvOhNVs
GbgQ6UFvh6+F/8T7kuityCK4L3lWy3akAH0V0gEuQybwn0Lfy9ky7rjLXU1I
EnxWOcDleuNSyD24S7HlrhqpVqqhalkMfzuYj3wfE38p3DTnD4OznHkJdxl9
Isdq9gi+FdvByGqgWqgH6kU5+mr4B/AHInuz3j7o7S69sRmu2FuvFfMG/IXY
evGRN82EGyX/O3Dj2NYpP/g54Az8LfAw/DZityAL0Otj691JJA0eIcZ2uAxS
6a0H6oVy2gDfSczjkc3QlLeaqXaaWc1uJlitlWMb+Ku33DTjmvU+bOnIevwH
/bPy02wjJ8At8KUJq8FDzUKwt+WrR+Aib7XVTG0OdkZnNQNj3nqu3ivmGLlm
0a/g20T+sbeclJtqMOytBqqFdmQI/+955tvNfdPE/41PbWQ7p91rx1YR2Qxq
FpPBZl01boxtR7Wr8nkKPsf5/hyL0YveFWwXVMPn4P5gvVFNXgX7J+jfsI8z
1ZxdEexfUIIUoqfRF0e2883cNxBsd7Sz/+A3IT9yLedf8EfhZ0dmE3ck2O7I
VgFe4y12I1KAXh+s1tph7bJqoFooh6y3GdesaydHve2cdk8zM0Lt7gd7u3qo
XuofpH+R3qy3rw82m9pB7eJ/6civDw==
         "]]}]}, 
     {RGBColor[0.7272727272727273, 
       NCache[
        Rational[5, 11], 0.45454545454545453`], 0.7272727272727273], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFlktoXVUUhs+959yztwMHceAsLVJQEQUVFCNotaNSqQO1xhpy2wasNoU0
gSioBZtUjC8cObHiQLCDmKSmqSZgqrTm1fpsnYh2YNGCVamCdar1//xXyOCw
11177bXX4//Xvtf17XtooFkUxXf6Sn1bk2QpRnNR/FoXxeOSb5NurFUUL+ub
aBTFHq3/VkWxW/Jp7e/VN6Gz3aX1yPck65e0TstuQmeel3639p+o7Ke3st/X
CuvGwv82yY/qe1dyl3y29H0umzrk7wvbcmb17McNyx8o7rZ+T2kdlu5Sw/a7
mrZ5W/Kizi60HNOKdMcbjrmvaRmbmZZjfV3yp/K1T/InWk82LeNvMnw8J5sD
iuuRyvJh2e2lnrVzQc/vqZZ/k9cfsumXj9+l26CzPzWcI/f3Rz2J4ZXIE789
2ntW6/amZXRz2pvV19bvkeQa/aD12quK4n7JtWI4IfudkT+9oA+v6uvQucGW
82Ufe/wsR8zkNCP9eMMx35D8+0atQy2fxceTyuUa+qr1jdJ13NFw7B3RG2pO
vfCD78moG+tU6KkNMvubSsezGjcr/aW34BDs0Av6QPyTurtHuvez4+oLPT2c
iRqCZfInd2JDT3/p4XTUEww/Vhrbw7X3b1e+P0veL/mW5PiWo6fUazZwOFpa
xv/1yfuHIx7qRU1uTd7/Rb/Xy3ahuYbBpcAeua1Uvm8xePS37j9YWs891KAd
PAIPOytjAt7QI+qJfU/42SI/81rPgOXa545Ivqk0n8kXv72RC3lybiK7loMR
P/zeE7xBXgnuTASnwBbreOAMXDNPzmt9MGYLM+Zits2PYbsQGPhNeyOK487s
s+eDF9TgVNw1nZ1vpTxGtL5Qee//uVX5TG9pPTnPZPeeeXaudl/oT7u0HfbU
7mjwCywPBXbBDVgBgx9l4+mY1l2VY6D2HWEDVqajH2DpbHYM32idza45taee
n8WsAS9zgRlqsBh1mAx5dUYthD3+iJl8wSV3fijfi9mzeH9tDtD38Wx+nAgO
MVdOx2wBO72Bjfmm8yFuMHgyuEMflmMOHIvc57T+ST20v1n3Z+09VXrOvli7
Z5PSb66Nqa9kv077N1fuIzXfUfr8VMwE+MRd3NMv/VvJuDyU3A/01PO+2hjc
na1jD/sDMfeYf3PJc4P5d3Xt+A5Kty7mBfltyY6NGOF6d8TTWTpW4oRn8If6
DGafH9L6ZrLN1to8IM7V/nRW9o9ufbWmXwp+XyjtE14sR85gcTY4De9OBXaJ
J0ddh0PXDj3vxV3lGj/YA+f/BB++VZyp9iy+nPyG3l3aD+9nV8j0pCvyHajN
Q3gJ9uEAtX4m2zfz41D05YHg7oXIhZxGQ95YeyYOyfZe2V2SfqPWI8kxTyXP
rrGY4fC1HRzEBzzAD+eOBi/PJmPmTDJWt8ccJ8aOeKPh93zowTp6MHxHNkbO
6b6HJV/hnSau2tw4zjzM7t1Adn2G4z/D5dqc4a2+GP+FmCXTyfV8qTZ26Bl9
uRL46YyPnKjdaLLPbbJ/OupDnZgB/cFrbDujF7x17fg/81dyH8A+93Af/P0i
Gbtfan0vG0vMzpXgNbWE95viDWVWd8e79nX2WXyQ74a49514I+j5Urw7vD//
Af9BXgY=
         "]], PolygonBox[CompressedData["
1:eJwlk02IzVEYxs+9/3v//7OxsZ+RLEgKixlDIUqJWDAjmbpjplyayVwjrEZj
7mAhWdlYsJKa5lsYGeSzKF9jIx+lmKJmJmVsKI3f41m89Tznec55z3nf9yxu
q+zqzIcQthAF4lMawh5AE3EthnCAWAg+j3YMbWUWwgQb9hHf4X3wmKDlQqiC
PxAp/D3+38UQpuF98CmiAf8Ua2N4Z+EbOLsHvZh4zylwgqeDvb3wq+gjrK0F
r+AOZ9DesDaB3gOfBPcTzQXnUK55PFX4O+63Ez6A3h3sGQR/Jn8/+a+jL0W/
Ef22MvpNcIH9+8GtxBi8Hs8jvG16L3vXwB+DF6EfRX8NLyXOqdwniIfotfAj
6PeISsFr0mbwN+ecYxTtLtGat+e+zot+Wy/xF38d/gd5e2bhw+gD7C+hj4Bf
oO8l/x3e8IP7DUVrevNX/HPoF9Bb2PMTPEh8ATewNgyuj651O/468En2PEPv
IN969EbW5tFriCvwanRtdcZp9YO1lsQ1UC22Zr6L1iYz11C11MxodlRD1VJ3
ylL3VL2thV/MPHOaPc3Ax9Q5lVs9vwzuRK8puAfqxUt4OecavAKvzjyb5/Cv
Apej364ZPhjdM/VuOf5L6IfhT3M+swKe5n7tefdcvf8/s4lnphO8MXp21UP1
cihzLZcQjehNqf/COvgo2tnUWDOsWR6PnjX18Bb4V+paPyeewFP4Jrybidv4
Z1gbx1/CfxytKzOWZzxzTuXWH9Jf2pG6lurZbvZ+K7oWOkNnbY9+u2q2Dbws
81/Qn9ff7059F9VgDvyH/YcS//EFqe+ku2kmNZtvo2dVM6PZ6YqefdVUtf0H
ubKVsQ==
         "]]}]}, 
     {RGBColor[0.6818181818181819, 
       NCache[
        Rational[4, 11], 0.36363636363636365`], 0.6818181818181819], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVEtIVVEUvb533z3XcYMsm+SwBtXAmhWkhBU0iCZNNcioLH0WRqRWL0h0
0CxtFtVA+6hNUvqoRX7KysdzUA2EIKiBEQQVWlBrtZY0OJx9993ftfbZ6+tP
7G/KRFF0HSeL8zqNovY4il7hflYWRcch90Nfibs7F0UPoWvAGYTcB/2pJIpG
8b0I+x7ommLZULcqKxvqGOca5GXYtyDhTCodYzL+mqzytuJfHroKfBcRoxZ3
DU4jfRyHdfFQx/jTuI9kFGckKE/CPLCd8r9f+M7jHsP/LOJtw8mXqS/mY65l
52Bs1jjtmJdgOw19gX7wH2BPqP85/CZx7pepR/bP+haDfHa4xxn3nnXOt5Dr
Y8XsgrwxVj0zkL8ixkHIs4ixBPkw5PeQO4N8O3BXQbcV5wP5QY518G9OhQe5
ISbEftn4PEvVy1lgcDIVP6ch/8Fpg/5NEAb9OfUWZ1Ur6zwK+wnYtyXihDyN
Qv8kVc+PcJ9JZENbzgVr6IVNA/4P59Qra2R84s3YVe6X3BBv4ky/CfvSZygn
mX55+z4I6qsZ970g3O4E8UA+Bs3JkHnhPWy52zGYaw9qXYLvXuPGGWswvsT5
AHpaXS59OeQviTisxv+WVDhxFjhftZ7PUkZ4luD/ORG3m2BTA/knbI6Zq0q/
kaFUc8J5+YF7LfRXI9U86N5Zc4/fXV1Os8T+iQlj/avDfBHPiVRz/zQVtlPG
d9zf38xj3lyTo0Ox8GGN37PKy/6Jw92g/N2e7Qnb9XonFFe4i8UZe+Y7oUyb
Jc8McxYcnz3OZfTG6M+55Hy+RI27gv7NQu6Avgj5VtDbpS1nbzhVnti757n5
3Qy7R7DbEpTnh3OR/wb3WOV3Q6w2QDef8XcsfMkx+170O+VeY45P+HcR+RYg
30D8fUFc8w0x/6jfHd80OWV9o0HzwzlqD3pX73DXpaptZ6J9V3JfrKPk2piD
uS4k4rDRPPZ5/3AGt+Nchvwxpz4W7F9w35fd+5DfIP8tOBd3DOeV+Ykx8aW+
6N3X717qvfe4r6lfSsRnq+0LifbXBfzvTIXp+VQ5Jz3Hg36bxId7h7P8OBVH
Bc9Sm3fIFfT3ItUMcBbGg+rrMPZF5632nh/xrmUc9ss+5jwr7JccEU/OBTni
DPBNdnmO3pjHuSCfiux/LubNzc0geTfu20G7dyDo3TAuY455Rn+jznPmmpyf
8Jvnnl5e4ZA4B+Ffh7s20e5pCZ4H5/0LW1IdBQ==
         "]], PolygonBox[CompressedData["
1:eJwlkz1I1lEUxs/r//X+r7MQKS412mIQuUiCCr0VNuTUqkEI8ZqvBSYqagq2
teZsg1YiLuInvjmUH4VSQzoITRUYguBnDf4ezvDAc+5zvu45915p7XiQLzGz
GyAL3qdmtYnZNYzhYNaJfY5DOWf1sqNZFdpCxuwp/JCzdvTPYBV7EFSj/0Sf
IPY6WER7xNkffG+jH5HrBDRij6Ffhk9S+w38V6nZXMZjarC3QDf8G9iGD4J9
9C4wAF+K3kue/MvwTbCFbxf4F7ymareBGbQn0WsXiXmBFtQDtXPUvVRm9gW9
H98KfHJo9dgj8FF8bik/NR9iPyP/BrwOfIIXiCmi51LvVT4HpT4zzU53eh68
hmppprP4NoM18zveh79Ovbc20IT/PXKeJT4jzUo1VVs9fkW7g/29xGc+EP2O
uusrcv4mfhf9ceIz0+x0J91NOe/i+zF679rhCnwj+i4L4BzffPTdaOcd8Lfk
2EbbI99L9AZwnPhOtduz4LHawTp2D3Zl1n1y2EPBY9XzOLl6QYKWBX3wndT5
D2qeMqdC6rNo1AzhZcF5E5iXb/C7akfT5P8ffPfqcQV9EtxEuwpagr9JvU2d
vUv9TJp6UC/KqdzaqXb7IfW3pj8xpbcc/a3pzfwldij6X9EOtcsL5M51bA==

         "]]}]}, 
     {RGBColor[0.6363636363636364, 
       NCache[
        Rational[3, 11], 0.2727272727272727], 0.6363636363636364], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFUz1PVFEQvbvv7b3P3qCWW1oJRjoawcgarfwqoNsEY4JR2LVhWVDhD+gv
MBp1V/0BfkWDaKKyLiQ0akH8AXZU6lp4jucYipeZN/fM3DNn5lbr185eLYcQ
LuPL8J2uhNDLQxgguFkKYQ62g/jTFMIoAI9hl4sQDgNzA/YD/reAuwM7j9h5
YLrAL8QQDuH/CjB9nE0jvgR/A98i4r+isO+R+wz4LjDH8N9Jup88WKeaKf4d
uBPI2Q//NjAXMuUzt5SJW6Ok84E5vwHuJP5fJ/XRqCi+A9wsvufwryf5d5Pq
sS77Jt+pTGc998X4GnA1+H+i6kzC34ZdyuWzZhOYGcRewfbL4sD7eV4zfigX
5lEQL57z/wFyRoBZQf1N60b92NsPfF+CtBhG/CP8M1Ec2UfVOjG+jXpHMnE8
bh7jsOVMerFODbNYx3kLNdYKzW8dtpWrd87maKa7yPkA4gdzaUj+5D1jDXas
J++lT3zJM+Fd56L8J+DQrahWx7OrupcJYOqsV4jvnHeQe0Q8z0bNn/hh98u7
Lnp23Ady2rK2Lfe8mJRP3oz/329yIB/2wjPWHHF9alN3He47e+N9zOVOMP9+
ks73YAdRe/C5EJcFY9q5NKWetNx/akWNW/bfIacJfzeKKzl/9U7yLr6Ftvfg
n5YV8SZ/zq3p+i+S+DVg3xbKG4O/GjXLh/BfJsX3ka9rsjZ1Z7/jUXp3rclP
2EvI/Zb0/jmDW8B+StJ9wzznzeFmIf1OJc+nvLc/Q57jZNSc+FaYM+XZUbO+
Z8PYtOPcO75t9jvrM+r2O0rfHu6cSMLugm+7EI7vY8z9su+/Q4Gnww==
         "]], PolygonBox[CompressedData["
1:eJwlkskuhFEQhevvbv//20uwtLQyhAcwRBM7CRs7CRti3Gi08QV4AvMQHgAx
DwvdpqQ3WIgHsLMxLnwntTjJqapTt26deyt6hjoGE2ZWBVKgMTTrCcwuQWts
1kFckTQLQCYyS4MCDZWIp6n3g1J4Ocig/QOtaNPgDO0JaIHf09MAv0Q/gnaH
WRfwGfSFwHvOqd+Sm6J+TW6S2iK5Empl5MaJ24hv6K0htwGfD51Xg3XiLfBG
bx3xDnwVVCX9zrr7C+gjfkczDd+OXKsdtesd87PMOmBGC7VnkKD2RPxZZLZL
PEpvPbm9yM/QWcpl4cWh79aOtrTYbJNcbdJ31K5HxL3wYe5zDM8yr5t6P7mp
2D2Td7rDL/oV4tfAd1iDf5AbS7mH5+iXI++VRtqZ2N9GHsgLeSbv9EZ6K3kq
b3XGFXEeTRdn73PnJvhA7G+pP9CEdi72XeX5bOwey2vttBD6DtpFb3wqb8Bv
wt+sOfQ/o78jDyfgjZH/hQwzvqh/FPlsefAQuefyfpJ6nnlLxI+Be5YOvUe9
nbpT5BDXDjn4d+i9EyAX+xvoLXSnw8hzqumP/aD9By3zZVA=
         "]]}]}, 
     {RGBColor[0.5909090909090909, 
       NCache[
        Rational[2, 11], 0.18181818181818182`], 0.5909090909090909], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFkztPVVEQhTfncM++CTRWNjZ2NNrYXcD4IhTSgIUNlQmNCQ87MD5+gz0J
aIHUGGiEi1DwMHihEAKXXyClDdcEE9eXWcRiZ/aes2ZmzZo5t19Mj00VKaXn
OqXOUVdKZzprurdySuNy/q6l1OxO6YfOrvwdBdwpA7sizIDux7LPZG/qrAqz
Jey2zo7ul4qfkP80R45+vf8qR1PvIfnXc9Q86I66m8ZQ86oI/0t9f1eP+sPC
t4rgdi7/ot53dV+QnciB7ZEd0TkR7qnsqyL4kn9S77buN2T3/K1TCVdFLDnI
23EMueEN50YteuM+Ldwf2RnZX8INCjcjO0dO2bEqeuAb/nlh75fxLuuB762i
1q0ytFq1nuiKftTiTdygY+/ZosWXHH7yoeVILTRbt7ZfZYermMuHHNo2rD89
0/sj+V+b81z+X4P3hjAPdF/LwYVY+LSL6OfCc6Mu2i7liH1fDx8c8JMDrejx
wlqQnzlvWk/wB575vufCfB573t9lD4uYKfuy7FpL7uubtaJOx7WeOGYohwbk
Zj/Re8v7ieUNB+bMvK/3nNmA+eQdY9fgDO56P9kZcraMP7ImcOQbvODHDjTc
LzzZDzT4bI5njkX/pv+10SriZoV5mEPLjRz/36H384207hP+bT1yN12L/4Qc
H3PoTV7q9bnfc/Nrm//PHHGj3ouW8/8DueqfkQ==
         "]], PolygonBox[CompressedData["
1:eJwlkjsvg3EUh0/7ak8TXVgsFiYLixVxjaFdsJokFkMvYRDX+Ah2ibCw0y5S
EQMhwYJQ38CEREJC4vk5wy95zv1/zvt2zZWnS2kz60YtaDNn1p+YXcIbcN7N
nlNmjyQV4VFUhevER+Bd1Ef+L74luBUtpKJGtRX0TWyYnEbWbAv1wl/4SsQ+
Mmaz2LfYY9jXHqwZV/Ai+oE7yJmktu7R64L5n5nooV6aUYbfePMZi1SYf++R
o9xzfO/E2vHtkNtEU/ADGkiiRrXrqAd+of7GQ+L/N3rsqF07sYvZ6Kne6lEj
NoHu0rGjdj2RL4kdtMsTmsd+pecqXPC4rWrGPXqqt96wlosc5VbRCtzwuL16
nsJtqJmKmxeoPcYeSmJH7brtcbsZfVN42eM2g9hHcD4brBrV7nl8e33TffjA
Y7b+iUP4DxggTiw=
         "]]}]}, 
     {RGBColor[0.5454545454545454, 
       NCache[
        Rational[1, 11], 0.09090909090909091], 0.5454545454545454], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVL1Om0EQPGP7u5MwlkhBDRRgY/PzBiFSUpEiUJMCE1pImcpSlAYeACh4
BDAuCOlimxBken7S0IcOU0RpM+MZKcXq9u7b252Z3fumGjtr2yMhhA+wPGyx
EMIGnN+5EOaKIXRhV0H+FmwZ59sxhAesn7MQvsPqSPARZ8e49wr3q9gfwjqI
r2D9im/3yFFC7NuobyWsPeyX4B8k5XjpuqzZcd1NnH1BzkecdxA/j7gxxPfw
vQabw34wotqsW8Z6AqvRT4p/F5WnAbtDzr84O4L9hF9Bjtmi7l5j7bt2Ky/O
xFBCnjb2+0mxvEteo0l1p6mB8VAf4ukbG7mR4wVizqJE/hRVt1oUTuIiP3Jf
tVYvoow+9SO+Wet5k6RJLgoLz8mFuKktMV9Y28tMvLrGU7L+o1ibxrxk3arW
gXgmrdWOe82eD/U2x+ekfv3B/sn9JrbTvOaE+g3xGhv1GDiGmJ/sbzlny/Ur
xjBImsM71J3JVHMiiWPfOlAv6lbL6ezaHImzbl7M++CYsbwwMObeM/EL63kU
l2fPVdeY2POsIE7UZKEgXRb8RiadmzWoedcYOuZaNccN3yFeYmsaZ8X9pz6s
v+gY4mwaPzUpe555t1f8/y57zlO3FuT4w1pRs/dJ+NeT6jf8vrhueuZ2o/Lv
Rb3dst/RbRTugWefGjA/15Z9vq22ffaR31ibM0E+35BjJVO/xz1v5EbM/HdQ
uzeeL3JgntdRWq5E6Rs8h4+uN+yj3zXf9z+SnIr3
         "]], PolygonBox[CompressedData["
1:eJwlkDEvw1EUxe+/r32v0pKIhElCGSv1DUrCVANmBoSNGrsb1AdoOpjMhISw
aYT0E9BafAAbU61+N2c4ybn3nHfvfWd+v7l9kjOzWZAHg2S2F8xqFPfwc7AK
v6ZXKppNUl/y4A8cwy/ARJDHvZtgCe07M2tHswUwjr5M7wXeYcZdkKdHPTVm
Vi2YreB/pW7wvs8dXfQN+A7+mNebMnyd3lcmzxr8EPzkdFMj6ma/vY7/Ef4W
tdt3+K5PegdoA96P6G2hzwX9+QOtBSyo59pT0qwqM56py2CI5Ype4J7TJM1v
asJn6N0G3bwLr0Rl94vnKCkTz+YM/R19kfomKMM2+nRRWfgMn5Ulef3mYdJO
3+03PiTN9NmesWddSsrOM/Fs/gFtMzX6
         "]]}]}, 
     {RGBColor[0.5, 0, 0.5], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFUrtOw0AQ3HPM3SHSIUENoQkNICGXkWwSakQNDUKUUEd2asIH8B9AmQIh
+IQgUH6EmhnNIorRnfcxOzvnnau789vCzI6BHhDWzApgGsxGQAUcAM9IPvUU
b4AONTXOcWk2w/0E500yGyK2G83uce+j/gHnKXIL3FvkltlshYHzqB7ykJ/f
jJ8l8bL206SFmlqfW3ucfY1re0fvEXo318HpmpcmvdR9GDSLceojH3Pk6Wft
dJG1R+e7NKV6p843ck7mZ7478y/OX/kM6qGWNvz7wzjn/qDvGvXfSfX0Z/jX
C+wDk1L9tfPQu9ZrK68hJ+tYQ8+6QhreovgGUT3ckzvSF3J9IL6RxcX3mSfx
7SF+mfVG21ngfSvLp+D/A99i4Z7Qg7FrYKzwNxq4Bv4L9Gbl2r6SdAacr1H+
PoL/F58ZPb8=
         "]], 
        PolygonBox[{{2140, 377, 954, 2141}, {2061, 945, 1090, 1726}, {2007, 
         868, 636, 2006}, {1570, 297, 780, 2059}, {1872, 729, 946, 2062}, {
         2197, 1090, 377, 2060}, {1731, 561, 1093, 1729}, {1729, 1093, 1092, 
         2198}, {2062, 946, 945, 2061}, {1793, 636, 729, 2259}, {2198, 1092, 
         297, 1728}, {2070, 954, 1094, 1574}, {1929, 780, 298, 1928}, {1574, 
         1094, 561, 1730}}]}]}}, {{}, 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{1526, 2007, 2006, 1793, 2259, 1672, 1872, 2062, 2061, 1726, 
         2197, 2060, 2140, 2141, 2071, 2070, 1574, 1730, 2323, 1731, 1729, 
         2198, 1728, 1571, 1894, 1570, 2059, 1927, 1929, 1928, 1572}]},
       "10"],
      Annotation[#, 10, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{1873, 1810, 1972, 1548, 2051, 1971, 1912, 1617, 2004, 2288, 
         2005, 1970, 1973, 2289, 1525, 1974, 1725, 1904, 1903, 1902, 1665, 
         1861, 1860, 1867, 1868, 1804, 1803, 1893, 1611, 1809, 1901}]},
       "9"],
      Annotation[#, 9, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{1527, 2008, 1915, 1914, 1913, 1618, 1959, 1960, 1958, 2175, 
         2174, 1863, 1953, 1954, 1952, 1951, 1908, 1612, 2172, 2173, 1997, 
         1998, 1522, 1859, 1994, 1993, 1992, 1784, 1858, 1857, 1981, 1982, 
         1980, 1979, 1907, 1607, 1937, 1991}]},
       "8"],
      Annotation[#, 8, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{1528, 2009, 1918, 1917, 1916, 1619, 1962, 1963, 1961, 2177, 
         2176, 1865, 1956, 1666, 1955, 1667, 1957, 1663, 1984, 1788, 1983, 
         1787, 2252, 1862, 2250, 1785, 2249, 1786, 2251, 1659, 2243, 1778, 
         2240, 2242, 2241, 1852, 1978, 1545, 2327, 1977, 1906, 1604, 1936, 
         1656, 2155, 1657, 2156, 1603, 2119, 1602, 2120, 1658}]},
       "7"],
      Annotation[#, 7, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{1508, 2110, 2111, 2028, 2224, 1540, 2225, 1839, 1768, 2226, 
         1769, 1841, 1840, 1511, 2284, 1653, 1599, 1905, 1975, 2326, 1542, 
         1976, 1845, 1773, 2236, 2238, 2237, 1654, 2160, 2161, 2157, 2159, 
         2158, 1847, 2162, 1945, 1946, 2123, 2122, 1608, 2253, 2254, 1995, 
         1996, 1519, 1864, 2001, 2000, 1999, 1791, 1870, 1869, 2178, 1668, 
         1964, 1966, 1965, 1620, 1919, 1920, 1921, 2010, 1529}]},
       "6"],
      Annotation[#, 6, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzb1KgnEYhvFHwnTpIFrMxSVQWoLm0MXsBIJq0yWaakn0CFprKkHzI8jq
BGo2Ww0aWiShIZsCoV/DxXXf9/O+/Ff3auVqIiKKmCQj8umIAj5TEVe8tBxx
zRl9IrfkN87qa3j3z9RWtW1gZmvrHXRxg5ztw60nD9BHTX/gR9zhHkOs+/bI
bV8+xAG29G/7HCl56s2CPOMv97ntBE/yz7/dnrGJU/3VvuARj/GCbbdjvuBL
VOQdlHx3rjd4wE2+5V0+4zpW5F9v/wE3HzBo
         "]]},
       "5"],
      Annotation[#, 5, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzzsvQwEYh/HX4DL5BDRhUoOELiaJyyIRQ2eTpUTiEqFsBr4AYWn5HNQg
IdSsTdpBaWklOthMFr8zPHn6/N9zktOR1a3sZk9ErOCvN2KwL+KkP+IYFzhH
BS/IYx97WPbcwUDEIfI40mf2RV7Sp34XUcCunuEnLuMRv557Tt7labcH3ONH
39lneY4XMI81ZNxvuIRrdD1zyzs84dby/V3d0dto41s37Wn3Bn/pN/sGGujo
V/uoe50/dd2+jho+dM2ecq9yU1ftw3oIV7qiL7mIti2jc3hPbt4Z5yk9xpOc
Tv4P/wOq4jn1
         "]]},
       "4"],
      Annotation[#, 4, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzzkvhFEYhuFDMrYaESTWitFRGJFoSEhEYquQWBoKkonaH7CVMyhsBX+E
2GmnECIUwiBUluD6ijv3+zznPV/OVzMx1z+bE0JIYjA/hH4MIBfvBSH8xELo
M39wUZ4l3Z88zEN403/LX/hEj51e/bP+UF6Q5+Uu7uZOLisMIe1sRp5GqzmB
V2dZ+dHdZvmBY7oXcxbt5g7nd/onTsqJiOgb3MYTGEeD/X2+0e/xLdfr6pBx
/16X0bWg0dyEOMZQZWeLt7GJXexgyu4VSrz/MvoPe+dcKV/wJE5RLJ9wqfMj
rpCPeQzrvrOBNRxEu3bS5l9vSvG1HNfXmke43N3R6I2ojv6La/jM/ordVSxi
GUtI4R9kXT02
         "]]},
       "3"],
      Annotation[#, 3, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0Dsvg3EYhvHHuWYRaU0GiYToYmudBkaHDorFoZiEQSyMBvFxfASJSEhE
OlhoXhGhSKQkWPm9w5Xrue/n+ad527e+W9ppiogKLtsicpmIXmQx0B5xjnvz
lV1XR8Q11+QL/Qq6davc0hmxxnkkugf8ub1Bj7nKiXdV+5ycxaa51bstHsGz
7gV13Lofdp/Hq/yGZjd3+n5zwnW7R92QPIiKvC2PcoGLXOQN3uMzN0/eTcpj
ckP+xFf6u/op/TS+5R9k3LzrC+YPbtj96ibkcezLs5jDDEqYxwEOsZju3ZfT
G17iYz5Nv993L5iXdWU+4pP0v7ar4R9O3DZ1
         "]]},
       "2"],
      Annotation[#, 2, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVz0krhXEYhvH/kekgltIxZsqCTDl8DVsynJUU1vbmeVpQlKKUpSTyEZSk
DBvlUDZKlJCQ31lcXc9zP/f7vr0ViZHO4UgIYRRnGSGUZIdQimLUZYZQxl1c
xfVcyQ2cwJ353DPV3Gi/zwohiWC+kNfIa/Ege0REfimPma856XYlq7CXo9fe
hObU+9CKFvRhUK+d2zjOce7gIb7hW0SRgzLZYOqdPMGZSIv6jn3A/MQH+NYt
5G7ZOufpbPAzDvHjXsQ97puc777FrzjCn3uM+9z7sW3+4E984cU/zugcy6f5
hGd5h8d4N/UNvV/84U1/Xn4qn+NFLGDPPs4TiCANubJ3/WXzCpawhlXsu03y
FNKRgQLZr/4/RgA+ZQ==
         "]]},
       "1"],
      Annotation[#, 1, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0clKXEEYQOFqtCdFux1aRFRwIb6PoNEWEdqAhEh8DXGeBQVDAkqCMyKC
BFy6cSWJoMtssnEjDlHE4avF4dy/DrequLetNNL5JRFCGEVHKoTGTAgt2RAq
0iFcea5HAZ/N7Xqei5yxlkYKPeY+DtpPz7Xe/8Efza2cMP/iV2ygxrzOg3oL
B/Mx/8f3eIb5G5f0Zn6z9xHf4Cty+hoP6E38oh/yNVZRpa9wv97Iz/oB/8My
KvWleGe9gZ/0ff6LRVToC1zUC/yo7/EV5pHV57hXr4/31nf5ArPx2+gz3KPX
8YO+w+eYRlqf4g96Ld/r23yGSaT0Ce7Wa/hO3+JTjCOpj3GXnudbfZNP4tnW
xuK+1uowFPfgPHLxn5kvuTfel8vNv7mM/3CWc6jGMJL4hCq8A/2UP8M=
         "]]},
       "0"],
      Annotation[#, 0, "Tooltip"]& ], {}, {}}}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"RMS Fluctuation angle, \[Theta] (\[Degree])\"", TraditionalForm], 
    FormBox["\"Propogation Efficiency, \[Eta]prop\"", TraditionalForm]},
  ImageSize->{581., Automatic},
  LabelStyle->Large,
  PlotLabel->FormBox[
    StyleBox[
    "\"Expected squeezing level, white region is 0dB, darkest region between \
10 and 11dB, 1dB contours\"", Medium, Bold, StripOnInput -> False], 
    TraditionalForm],
  PlotRange->{{0, 10}, {0.5, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.455469282284444*^9, 3.455469333561644*^9}, 
   3.4554693651204443`*^9, {3.455469457534844*^9, 3.455469491277644*^9}, {
   3.455469558279644*^9, 3.455469567967244*^9}, {3.455469605563244*^9, 
   3.455469640167244*^9}, {3.455469853638444*^9, 3.455469862561644*^9}, {
   3.455469956208444*^9, 3.455469976972044*^9}, {3.455470029512844*^9, 
   3.455470079292444*^9}, 3.455470476215844*^9, {3.455470524388644*^9, 
   3.455470563841044*^9}, {3.455470599284244*^9, 3.455470631435844*^9}, 
   3.455470685146644*^9, 3.455470742289444*^9, {3.4554710829760437`*^9, 
   3.4554711239416437`*^9}, {3.455640198825116*^9, 3.455640279227516*^9}, 
   3.4556405731471157`*^9, 3.455640726479516*^9, {3.455640771735116*^9, 
   3.455640797958716*^9}, {3.455640837816716*^9, 3.455640874944716*^9}, 
   3.455640919841516*^9, {3.455640957562316*^9, 3.455641080864716*^9}, 
   3.455641155853916*^9, {3.455641196725916*^9, 3.455641213979516*^9}, {
   3.455641247535116*^9, 3.455641279624316*^9}, {3.4556413492627163`*^9, 
   3.455641426919516*^9}, 3.4556414750923157`*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd03k01esawHHDpszD/qWMYcuWpJxTRHiekkhyKkNddSnJpkwpJWlSicyd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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
    "\"RMS fluctuation angle, \[Theta] (\[Degree])\"", TraditionalForm], 
    FormBox["\"Squeezing relative to SNL\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  GridLines->{{5.1}, {3}},
  ImageSize->{581., Automatic},
  PlotLabel->FormBox[
    StyleBox[
    "\"Squeezing level as a function of \[Theta], for given propogation \
efficiency of 75%\"", Medium, Bold, StripOnInput -> False], TraditionalForm],
  PlotRange->{{0, 10}, {-0.1601458373248492, 5.077177266067502}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.455469282284444*^9, 3.455469333561644*^9}, 
   3.4554693651204443`*^9, {3.455469457534844*^9, 3.455469491277644*^9}, {
   3.455469558279644*^9, 3.455469567967244*^9}, {3.455469605563244*^9, 
   3.455469640167244*^9}, {3.455469853638444*^9, 3.455469862561644*^9}, {
   3.455469956208444*^9, 3.455469976972044*^9}, {3.455470029512844*^9, 
   3.455470079292444*^9}, 3.455470476215844*^9, {3.455470524388644*^9, 
   3.455470563841044*^9}, {3.455470599284244*^9, 3.455470631435844*^9}, 
   3.455470685146644*^9, 3.455470742289444*^9, {3.4554710829760437`*^9, 
   3.4554711239416437`*^9}, {3.455640198825116*^9, 3.455640279227516*^9}, 
   3.4556405731471157`*^9, 3.455640726479516*^9, {3.455640771735116*^9, 
   3.455640797958716*^9}, {3.455640837816716*^9, 3.455640874944716*^9}, 
   3.455640919841516*^9, {3.455640957562316*^9, 3.455641080864716*^9}, 
   3.455641155853916*^9, {3.455641196725916*^9, 3.455641213979516*^9}, {
   3.455641247535116*^9, 3.455641279624316*^9}, {3.4556413492627163`*^9, 
   3.455641426919516*^9}, 3.455641475123516*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"0.815", " ", "0.75"}]], "Input"],

Cell[BoxData["0.61125`"], "Output",
 CellChangeTimes->{3.455644191388216*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dB", "[", 
  RowBox[{"Sqzcav", "/.", 
   RowBox[{"\[Eta]prop", "\[Rule]", "0.815"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"dB", "[", 
  RowBox[{"ASqzcav", "/.", 
   RowBox[{"\[Eta]prop", "\[Rule]", "0.815"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.455643298120116*^9, 3.455643353905716*^9}, {
  3.455643388771716*^9, 3.455643399270516*^9}, {3.455643818323216*^9, 
  3.455643845250716*^9}}],

Cell[BoxData[
 RowBox[{"-", "6.004736904302419`"}]], "Output",
 CellChangeTimes->{{3.455643301006116*^9, 3.4556433541085157`*^9}, {
  3.455643395666916*^9, 3.4556433995513163`*^9}, {3.455643821813216*^9, 
  3.455643845798216*^9}}],

Cell[BoxData["14.223738729032537`"], "Output",
 CellChangeTimes->{{3.455643301006116*^9, 3.4556433541085157`*^9}, {
  3.455643395666916*^9, 3.4556433995513163`*^9}, {3.455643821813216*^9, 
  3.455643845798216*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dB", "[", 
  RowBox[{"Sqzcav", "/.", 
   RowBox[{"\[Eta]prop", "\[Rule]", 
    RowBox[{"0.815", " ", "0.75"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"dB", "[", 
  RowBox[{"ASqzcav", "/.", 
   RowBox[{"\[Eta]prop", "\[Rule]", 
    RowBox[{"0.815", " ", "0.75"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.455643298120116*^9, 3.455643353905716*^9}, {
   3.455643388771716*^9, 3.455643399270516*^9}, 3.455643859885716*^9}],

Cell[BoxData[
 RowBox[{"-", "3.583413897937469`"}]], "Output",
 CellChangeTimes->{{3.455643301006116*^9, 3.4556433541085157`*^9}, {
   3.455643395666916*^9, 3.4556433995513163`*^9}, 3.4556438603332157`*^9}],

Cell[BoxData["13.028747310641123`"], "Output",
 CellChangeTimes->{{3.455643301006116*^9, 3.4556433541085157`*^9}, {
   3.455643395666916*^9, 3.4556433995513163`*^9}, 3.4556438603332157`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Having a look at the state with no phase jitter", "Subsubsection",
 CellChangeTimes->{{3.455471343629444*^9, 3.4554713736906443`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dB", "[", 
  RowBox[{"Sqzcav", "/.", 
   RowBox[{"\[Eta]prop", "\[Rule]", "0.75"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"dB", "[", 
  RowBox[{"ASqzcav", "/.", 
   RowBox[{"\[Eta]prop", "\[Rule]", "0.75"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.455471228688644*^9, 3.4554712607934437`*^9}, {
  3.4554716913110437`*^9, 3.455471703011044*^9}}],

Cell[BoxData[
 RowBox[{"-", "5.0771772660675065`"}]], "Output",
 CellChangeTimes->{{3.455471243649044*^9, 3.4554712614486437`*^9}, 
   3.455471333957444*^9, {3.455471693167444*^9, 3.4554717034322443`*^9}, 
   3.455640198949916*^9}],

Cell[BoxData["13.87698389579345`"], "Output",
 CellChangeTimes->{{3.455471243649044*^9, 3.4554712614486437`*^9}, 
   3.455471333957444*^9, {3.455471693167444*^9, 3.4554717034322443`*^9}, 
   3.455640198965516*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
And after phase jitter of \[Theta] = 5.1\[Degree] this state becomes\
\>", "Subsubsection",
 CellChangeTimes->{{3.455471394251444*^9, 3.455471426574644*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dB", "[", 
  RowBox[{"Sqzfluc", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Eta]prop", "\[Rule]", "0.75"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "5.1"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"dB", "[", 
  RowBox[{"ASqzfluc", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Eta]prop", "\[Rule]", "0.75"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "5.1"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.455471508755444*^9, 3.455471550157844*^9}}],

Cell[BoxData[
 RowBox[{"-", "3.000291861471031`"}]], "Output",
 CellChangeTimes->{{3.4554715396590443`*^9, 3.455471550594644*^9}, 
   3.4556401989811163`*^9}],

Cell[BoxData["13.842968866972615`"], "Output",
 CellChangeTimes->{{3.4554715396590443`*^9, 3.455471550594644*^9}, 
   3.4556401989811163`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"dB", "[", "Sqzfluc", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Theta]", ",", "0", ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Eta]prop", ",", "0.5", ",", "1"}], "}"}], ",", 
    RowBox[{"Contours", "\[Rule]", 
     RowBox[{"Range", "[", 
      RowBox[{"0", ",", "10"}], "]"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<RMS Fluctuation angle, \[Theta] (\[Degree])\>\"", ",", " ", 
       "\"\<Propogation Efficiency, \!\(\*SubscriptBox[\(\[Eta]\), \
\(prop\)]\)\>\""}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "Large"}], ",", 
    RowBox[{"ContourShading", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"11", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"10", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"9", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"8", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"7", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"6", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"5", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"4", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"3", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"2", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"1", "/", "11"}]}], "]"}], ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Purple", ",", "White"}], "}"}], ",", 
         RowBox[{"0", "/", "11"}]}], "]"}]}], "}"}]}], ",", 
    RowBox[{"ContourLabels", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"ToString", "[", "z", "]"}], "<>", " ", "\"\< dB\>\""}], 
           ",", "15", ",", "Bold"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Which", "[", 
            RowBox[{
             RowBox[{"x", "<", "0.45"}], ",", "0.45", ",", 
             RowBox[{"x", ">", "9.4"}], ",", "9.4", ",", "True", ",", "x"}], 
            "]"}], ",", 
           RowBox[{"Which", "[", 
            RowBox[{
             RowBox[{"y", "<", "0.51"}], ",", "0.51", ",", 
             RowBox[{"y", ">", "0.99"}], ",", "0.99", ",", "True", ",", "y"}],
             "]"}]}], "}"}]}], "]"}]}], "]"}]}]}], "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.455641457230316*^9, 3.455641489225916*^9}, {
  3.4556415234055157`*^9, 3.455641533358316*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1fQVY1M/z/4GAoCjdHTbYhTVrYrfY2N1+vsrZ2GIrih0oiopgY2Bgi60o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   "], {{
     {RGBColor[1, 1, 1], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtVUtvjVEUPfe77fnOvcLtw6OqGoSOiLSCRIiJiZiIkTCQGGhEokNSUzRe
fXmlJISkQrzjUfWIgX8gITHwKBERMVGq9aq1stZg5+yzv33O2Xvttfc3f3vH
pt1ZCOEJpAhZh81EIYQt0IdgeABZif2MFMIw9OlY38FnNmQc9psxhEboP2F/
i7UBMgZ7N9Y78E/Qb0T5j8HnepTPD+jXoM+C/h36Zuh74Buhv8lsx34O1vWQ
nUGxDDseSidkMSQl6Vtwx4GqEPZD9mJ/K+r8eNJ9KyBLgvzoX5OHcBX6TNhH
k/Jg/sz9kXNfB79yKYS/WE/C925RebVif6+oPfX2aul8d1FUfLtw/1piA30D
7jyMuAawbyvINmb7PtjqIc+Dcp7lOBkTY6uJ8iVuq4Pwok9tVK3GXa9VxLUg
n514exT7aqwtWPdAnsFeQYz3HTNzY41HYF9jnXHXJ/nUYc1LirUHb03BHZ8h
Zb/z3W8R19GCYq5JwqU2yfbN9k/wmQeJkD5Ib6bcmNMq50UMd1QL31c4fwh4
5Yj/A743Qf7hrstRWNWVhPch13p5QXVv83rA+sEq4U69y3b6cz1oO9/kGXJ1
EPdXiG1JtRqDHIdUsM+xnsf3qlx3vUSMp7CfxLkp+H4iiifkS69rk6AfjcIr
Qu+OwpO4jmTi3K+C3mC9lkE/HIVdNXxeJMVZzMXJI1Xi5bmoeBjXGehF6FOh
vzauxH0I9gXQJ5P6hP1FjrEXyUty73YUthPwuQO9GfrvpD6kf56UA3Ppw/d7
UXX8mxQf4zwC2+MonhVgewh9IYdKSbgQn9OwhVxc35rEgaWQZph7MvGSnPyY
KYYMUsLZ38QGZy+YfzWwpVxnn8LWkcl+F/e8z9TvfwrCgpicdX4bIXvhUzaO
c/G9P+p+vkNOfSWvIP2Z+ERufMmUyzTznngOBs0y4ljvWr025syjx7mRQ+TS
pah5R67XRfXrbONPHIlnY1TcczzrOLOozzB33ngeTsvFy0oubo6an8xjxFzq
dK1Zc2K5GdIVxLu3ns/spSZjwtq+8zzvNwcrQX3BnmS/1Bsb8oe8++Re5nuN
npn83uI5Qx5Qb47CbqFrxJp8dH0/G8+yuUKfuZ6x7Z4D/N5uzNk/xOKYe/SL
6/LTs3t6VB+zduxl3tfhd9kzQ57n7NH35gl7g280mV9l+5Nn3F90f3/w/Fnj
fw+xXW/cWa/o+XYqqEeH/f+oOEZi0u9aEd/MPGdd2G/UG6K40+2+YC47jD+x
oM68cmM/aDwzv8seZk1nmte/HBvzZtyc84xxm/15J99qNV/2ub78XrRPnXvj
StQ/pOJcWJPcMZDrfZ47X80BcmHA+bKP6NPjvJabZ+QYz/S6d9iT7M2GJFuf
/bt9lnGyj1k/8pbrH+uT5jTxPO4e5rvk/qTt/wGWfgaD
         "]], PolygonBox[CompressedData["
1:eJwlk1uIzVEUxvc5Z6z/H3HOzJkZx2BCLo+Sorx4mZQ3KcyQpoaaNDKPI56R
M+7XUEQRuceQS3n04klMUe5pEh40MUkuv6/v4avv22vtvdde69uzevpXbS2m
lJaDBlDOUjrJQh0xHv44UlqAbgVX4JUwfw1WE3+GXgafCq7DS6ztYu9O8DxP
6SlrS4nVwLXwmTpbOS+ID4Pd8G2FlLqIv0IPoh+WUppAbgb2oO+gy7lzlKu1
l+g68XLJNebwCthOfAmYG96jvUOgAm8K1/IWrCX3CXoxfAq4Cm8M8zdgDfEx
dD98DngA/wsG4PPAI3gzZ94vuWbVfoK1f9zdSXwEPghGC75Dd23kzC/wMriA
3oT+Bq+CS+hJ6EXkj6I3w7eAn0XPZDK8E7yD/yLnIPnjMucqR7ld4D38N/HD
xNejPxZd03H0OvQH9B/0UfQG9Cd0CZwK90S9GSO+P9wD9eIHei+6iTfeLbnn
6n0vWFjwWpVYX+beqyct6B70Z/ZPBOdUD2s74APqEXoYdKDbwI2wp+Qt9ayO
7kaPoDNwRv4AK+DTwE14New99US92ReuVZ6T9xpzz141qtbvrPUSmw3uwU+H
394NvsLPhu9SjnLPh2uXB+SFi+HZyQPywvTwWXqj3toSrk09Vq9blVP0DDSL
Grq96J6r91nuXsizOfxYeDYrdQb8SHiWerPefiA8G/05/b1a7r/Swdr8sOfk
Pd1xO/wmvW0mGAqfqbNV0y14WzimHqvX7WFvy5Py5oyw9+VZefdQ2HuamWan
P66/rj/cQLw5PEt5UF68HPa2Zp7Q/wE0kIyj
         "]]}]}, 
     {RGBColor[0.9545454545454546, 
       NCache[
        Rational[10, 11], 0.9090909090909091], 0.9545454545454546], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmWuMlsUVx5/33feZ5+G23BbEcllXQWxVUm1FWJB+MhHTxKa6LOtCETBi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         "]], PolygonBox[CompressedData["
1:eJwllUloV1cUxu/75/+/7yVRM6pRE5OIcQJBpWit4NpFV4JYqqh1IQ7QLoQu
unCAGqc4JraaNo7VKm2dtSMU3QoiiFGhVm0dkarRaJxi+/v6LQ6c757vnHvf
mV7j/E+mf5wLIXyG5JHK4hBGFFCSEA7GECqQu8CLGLuzEH4FT0F/D2kBl4Nv
Y78AfiqM/zD8X3G2B1tZGsJaLliJ9EMfAWcytk+LQhiJ/hOcSfhORNaC94KH
JY6hWNvA/cEDwCXgCXCu4TuDs3Ho65F38e1D/H1wh0a//RVnCfwD4CbwcPwr
wK3gKnA1uLjYPvKdAP9zYi3kjU/AM5E72DI4lXAfEHZz9Bv1Vt35M/gN/B28
px3pRd+C/QLcqdi3opfiX4N/F2dfwF+lHBF7F/zmzG/S23qx78fehX4mOMcb
sD8nZivcNqQHfShnZ9Gn8Q216GX4N+DTg89O/J9zdhXfMuyHwQ+xHQ/O8Tps
Kfxyzu5zthF7AzG/5z2l2OdiLyD7iH8dexn2Avw+Bdd4HbgTfRp6B/ybcGs4
6wbfA78GB/g9edfwF2zjkPPEW4rcSF0T1UY1+Q3bl8igxDlSrr4C1+rbwH3B
bZlzWc0bW9HnY38feytn18CXkYPgQ8S/gj44OhcPsfdmjqFYemM7tkvI9sTf
3Ji6p9XbpTqL7gn1xj/wt4JXZ75bOVmjXkN2wp2JTNS3wR0T/I1N2Gqje7+b
mP+C66Jrq5woN52cdRBvBZLn/shZv4JnrAXuLqQ+cU1V2xT+t8Q+gETVD5/V
Oce4Cv4munfVg+rFQupZ244sSu0j3wKcD6JrpFop5yfAHaox3AXIY/SbqWul
GQ3gF/Cv5z0zR8Gzsd+Cm+gOcDX2FvRnSH/lKjp3f+DTA94RzZ2DPNAsI4+C
Yyr2BnDfxDlQLlRT1fb/nHI2h/vu5PzGr+F+BL6HPh7ObvBL+H/lvSOOgUdH
z8ZypB7bpuhZUM+r9/WN+tZG5HT0jGvW65Dj0W/UW+uRk+i/qyfwXwPONN/a
iYl3gnZDLvMsa+ZLo2dCs6EeU69VgLtyrlk5+jzkzyL30GLsb1PvDs28Zl85
U+50xxHsszLXbhQ4wK1Rzoi1GW5dsUW6alCCfVD025Uz5a4qendpJ2g3aIdq
l6oGbdE5VC61Y7RrDkXfpX+A/gWbMu967ayN6MMz51YzOBbuktS1b0eatMuj
Z0MzORnukOhcq2bz4JZkntUBqg+2Z+DOvHvgh+gdpF2kHT8evTJ6V4kjrv4x
+teoJt9hK099d8rZh7oLac55h2uXr4+ebe0w7bKi1LOnf9IlYr1IvVu1I7Ur
KzPXWjWrQh8Y3RvqefW+/jn696iG72TeMdo12lmn4J4jxrLEO7oOW0P0t+pN
zal3gnaDZvxH2aL/Deph9fLfqf+N2rFJ9Dfp27QDMuz/AS4d648=
         "]]}]}, 
     {RGBColor[0.9090909090909092, 
       NCache[
        Rational[9, 11], 0.8181818181818182], 0.9090909090909092], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFl1uMVlcVx/d85zv7bMCmEtPgTKUFkU4bb6htqSm2tcSZMA9QmxRiY1pa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         "]], PolygonBox[CompressedData["
1:eJwllWtolmUYx+/32fvez23z+EFkWx6mmQQec2iRRyQFPzgT8tSHzFTIPBQe
gpS+6Ka5nFNLFBQKxIn0JRFJxEAUQZ2kgik4llOaVOoy1CSc+vvz//Dnvc7X
/Vynt3rx6jmrshDC56AInuYhSNAN/Af9O/isLIRx6F6UQrgDNkF3IpuaQpgP
bhRCWA1qYwhrQG8CzUR/Gt+30N+G7o5sOboJYGHBNkvQFUAfco2Fr4e+gr4R
fTOySvxHwrfgfwEMQV8FfoGegU0F9EjwPu/5Ctko6HbsD6E7jv9w/N9D9hzd
MOJ/Cb0hmdab9fae3UIYwDc9JsZ+fLug9+B7EJ9e8G+AM/oW8Cr2K+F74X8H
/m34n8jRQaxV+FUQ611ku4jVhH469CjsL5W5hm3YvomsFXoeNmP0NmTrydcD
dEGPj47dDsajv0/cH7A9Rc5O+Hno15NvNPwm+D/w2YDtRtAB/b9k6PphcxTb
u/A/Fl0T1eZKyb38Dlkbuh1gAvRQ8n8DXYPNtTLHVOzXkf0K3YD/ZXwz+O/L
3DP17qPcs/KUmIugdyKbrFoje4R9G1gS/Aa95WD0t/4FNsOfjM6tGmyH/zr6
2z4lx03ijUW2LLhmNdCD0JdDP8J+OfrzxN9Y8ExUoo/I6jLb1EMPSO5dOTH6
Q88GXfCf4DMLelL0LG8DnblrrFq3oH+C7mcwJPNObEueQc3iRTAiuufqvXoy
F/5x7t6rZwn+z9yzqRpk8E2av8w12gU9ETQXvBPvoF8MthQ885r97sSvJP6/
+O+Fv4l9o/oLfwH5h8jqsK8Hfcn1DP3f6Cvhj0X3TL1bS7wQ/Y361gbwD/Sl
kmM14dOK775oX+VU7nXIBhdds9rkndZu6wboFryC7Aj8Zt0M6Ibk3qpmJ4g1
O/o2aEcWJNdctddOzoEuJe9aX+yL0NXRs/uMnBn5K3Lfgh3IlkbvhHZDN2Uc
fBX6w+gngaslQ/QX6Avapdx0Lf63oa/jv7XoHdYuHwD9C74BugW/8Tstc0zF
HpR7VyWrzv2N+lbFuJE845p17UQ5sT5Ovj3q6Qr4I+AB/BTsd6N7LXl2EvwH
6BYl30bNuGZdM6/ZXwFaodtz924W8W5BTwYtmXui3miHtcu6mbqdd3PfAt3E
ayXXVLWtwWYr9LfJb9EMahZVY9VaO6Pd6Rc9a7ohuiXaAe2Cck5B/zD37OjG
dRC/Gf29zDekEfuK6FuqGdQsVkXfhofwz3UvomdVN1G3cVl0b3VzdHtkI1v1
5Hh0z9Q73aBh6EZH10I7MhS+Lvm/Q2/QW3QTdBs0kwOja6xa64YPxPZs9H+H
dki7pJnX7GuHzmn3kmulnql3LwFfTupk
         "]]}]}, 
     {RGBColor[0.8636363636363636, 
       NCache[
        Rational[8, 11], 0.7272727272727273], 0.8636363636363636], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNV1uIVVUY3uecvdbeIxRWjqD2Yo4TmBfIGZrRMS0ds8TRGc0aSMJbWHQh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         "]], PolygonBox[CompressedData["
1:eJwllEtslVUUhc/9773/f2yigQBKcaCVh4a2mhgIllsemhQIBNveFggmKC3F
CAEMjxEkGGBASMDHRKoSnmJMGAADEhjYTmgFtKIDE1uwTYwBpZRXdKAQ4Fus
wU72Omvv89h7nV3V/mF5QxJCWIcVsE1pCMtzIZwBDMcQ/s1C+CwfQhtr/+BP
he8F92Avwv8MrmeDb7AO/Grse7idxK/Af56Y78Ckhgn4Jex4zmfUaS+IMvxJ
+JvFEH7ERgefURW9Ju4+eDH4AbgPfJ773QNPJf8MZz8NbgO3R/s6Q2d1wnfj
f0De+KdCOMxaE/wJcl6Au4ud1V2xO/h93KkEdxwbD75MXh3+Rs5/hH+dtf3E
lrFrehT7Hcj7ThXkrgWPK/hMnf0LObPI/xp7DvwX1go3QM5rxLaRsxicEZfn
fqfhS3C17LEbbhn2MrgAfof4MvwV9rqKteLXw9+Ev4HVwzdj3dzlAbiM/zf7
fgo+R/4IeC85o8Cj4Pfh/wG/A3wLPDe6pqrtbe6UwM9Kze3GRjJr4IkWwPOI
XZi6N59j/8G9Au7Ou+eV0Wfq7C5ybsP9qf6D2zmzn7Pvq57EdoHvgN9PXdsK
/AL1eDW6Vqr5r6zVgn8Dt4Cr8evI70lc8zXgJdF7qSdLo3uu3ncQ36DeEt9L
/GrsRtEal9ZVA9VCb9bbVeMW/AHWFuB/xH4J+auIf4b4zcRXw19gbQb8UexZ
cBM4D5/DlhG7EjyF2CO6Y+YaqVZ68/+ZNSFtSGPSmvbQXm9gl1L/Kf2tZvY7
yn6rwMcSa/Qn/HdZqyi4JjX421mrKvhP6W91srYAfIj4sZk1JC1JY0uJfSn6
ry7CalL3SL1STWdm/gP6C/rjl3V29F3eAh+SVlh7PXHP1fvN2MmcNdkRrUlp
cxgrwf2Q+m16g96iHqvXDdRoNXgPdjdnze+KnjGaNZopmi0TM2vnbfIn4Vdm
ztUfm4D/kL3mF/xmvf33zG/T2n7wJ5m1rxnzceY/pr+mni2Hn5daK6rhluge
q9eN7F+DP1i0fwqbDN5GTFLwn9sqvcOvT6wxaa0/tValeWl/DmungmPm6n9F
10aaWkdsU/TfVUyj/m9m7WlmaHZIs9KuZnIkfijzbNIMGcx8J91NmpV2x4AP
Ju7RpaI1KW3qzo2pZ6BmoTQkLWkGaRZJs9LuF6xNg18E/xX+e6m1PF1vlP6w
w4n/wMXUGpPWlNMD/jI6VzGKnZ161kojb8L1Fb2X7qi7SlPSlmb0Efyh1L3W
jP8WfCvzLNJMK8I1RM8izfBr7PUYhFLYPg==
         "]]}]}, 
     {RGBColor[0.8181818181818181, 
       NCache[
        Rational[7, 11], 0.6363636363636364], 0.8181818181818181], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1l1lsV1UQxi/9/++CDyYaJDy4ABojS6EtJooGBNewqriABrAoCUIrRWNE
HpSCQDQRSSwWWrAUTMoSUgUDQo3yYhEsbmAoRFBjwB01JiZuUb+f8/lwcuae
O/ecOTPffDN30IMN0xZWJElS3ydJSprHFUnSKfnLNEl69KJe47CeF2dJ8o7k
Q3o/SYpvaK1N+tflSTJX6z/p/UytrdFao8ZpPW/Rc53mJ6Tzj3QWa96otUV6
P0djezlJtmk0SH5b72dq7NH7i6W3XfIlmh/V912S39S5t0t3qsZq6Twj+2o0
npN8ley5QGOZ5BulV6t5vL7bJN02jVY931YRZ3Pufn3XJPkGyRU64ym9+0Xf
/az1Xq3/qbUNep6ob1s079Z8Vvsv9bf7NMZJ/lvfLZT+Eckn0zjjjPQv0/ME
rQ/UvEDrD0t+S/JdPoszW9O4f63W+2rvs9L5VPJr9gk+Oq713lLYfEb32Ynv
NA/ENslDJT+r97MqwvfrtL5Qz6e1/3rtsU7jTq3/prX+GheVIrboEqMG2VBO
Yy/sxv6T2vNMHt9t1Nov+mZvn/Dp98bGY9JZpu9GaKzQ8wydM70c/m3Uu+Pg
pYhYcg6YwIc7HfuRSfgI/2zVHh0aJY1VGl+VwtfXSN7s2IG3WmNrZRo+wTft
3C8JH462P8Fct+YJGo9I50KNxj4Rjy7ptJYj9sSwOok4Lpc8UqNSY1YW/him
eYWeR6Gn0azvqpLATIvk8Zrv0DichQ9ma/6oFHcbm0QMiRv3fSEPO9Zoflnz
EuNmUBG2HUnDvkZj5nqtfy29BzXX690wye/p3a5y4AM/co8u45B5v+WtWu+w
H1jrMtbJ507HED/tsM6AvkkyRPuvl23DivBtpeYVeeByZR45sdAY3uQ8fEVz
T5/AdmcSMZ9nnR/SeHcwj33Zf0ERHAFXnCsCX+ATfxIn4kU8WAO7+HC99AaT
Z2lw0H/41XOzsYH/hxjXm5JY22LMMPP8gPVfSgMv5DD4ApcHtP8irf2YxR79
vX+VbcIe7k2ecy+4BE65XfJsfTsNHOt+R6XbV+tj9LylCH6amwVXgVMwerf0
TmmepvmPUsQUf82R/qNaH5rHOZeV4ixwBJ5GJJET39hmeLKuHFz5XRbzPu3R
VcT6fs1LNK6U/GQRPNOSBh4fL+KOt2aRLx3mH3gT/gSD7cYPfludx/rzedjF
nsQZ/31le762zB3Oz4LD/tTek0vhW/J2uvmTXICf8O0gyYdK8YxMziITb7gQ
7MGr78rmxXp3UPMfeeDt9zxsbLf9H5fCV2DmgyxqwkOad6SBVeJETKaaL8D+
dtcdahz7U+d+zWLudh6cNPe2uI4Qd3x53OvDjQGwQD5uMLesNc+Qj+T6iYq4
E+9bvQ84bzb+hxSBoeosvm1K48xmc/hYY6/FmAefvAMjE811+K0xjWf4CJ+w
5xjnyG/Ok1FZ5N4Z12Qwh5/B48By8Ax1fkop6vsw8yE1h7XJXp9kmfhudIyJ
773SSyTfUwRvIJNDxALuJgbE6mPb9ob5HW5nv0nev7YU9mHb/CLye7RsPuZv
8Qk1os0+eVW697sGbZP+fZI/z6I2IYPPTtcYbEV3hvVZn2Ed6l2/ctS8cRXh
K2IE3rY6Lw5UBI9hO/lHfwKvgB18h/34sce90yLX7rNZcB/ffqszh+SBwS+o
pXnsQ79DPLsdU+x4230Rdf6Az702j7Poy7a5LjS4f9hlmTNfc1ywo962EY8l
9m3ZtZe6Qw9Ef/JXGnhFhrOuyMO/l+fRI7zqXoqa/rrrEbnb7ZpLru/2uXXu
Az/LQne3OZg74AfiOtN3AwN77FN06J3q0uBk8n6B5Xqvw5/wWY9r0DzrwJ9X
u3bfmEQdr7H8nuyo0dxfd2nKg8/oWT7M4v2APHKY2BP3l4uQj+n94Dzif0p7
ncvD7jFZ5E697VniXMe3n5rLThk/cO4W18xe18rtXq91joNp6ld3FvHvp3Om
uNb+4HtzFviCk497H+7KneG5zd6HvPgkDb65NI9ei3gPcn0h7lXmNziHngbs
gzdwx9pa9xXk+V73YHDYWnPULONxjbmx9f+7OMbEF75s8TpYRZ7ju7e6NlW7
RmMzvI4MVzM3ex3bG2z/JmO6zRwI900wFy51b4ePDhsbcA8cBF/zvtG9Kz0s
vSyYwG/N7hMajUVwCDd0mjfgD2S4otJcPc6+7LA/2XO5+0n6AGLyURbYAmPv
Z8G18AM2thXxv8N/D3EiXr1p1DBqWY/m+Vng4kQWmAAb9EeV7l2J3Wz3oq1F
9CXctb0IrHO/Q+bysvMdO5faD9S7lfYPNXOHuRrdreaIkb4Xe5FPzzinwMUe
YwAcrvB6jeVq77XStbPDexJHeodV9ucjfsf6/76GS06kkXfkX52xT0yRFzjv
bvK/ys1F1NunnIc1WdSMoUXYAY7w1egsehd67Wb3uvS8+9xLk/vf+H8JLCzz
PwT/LcQKTmhyj0tuPp0F5vYZAy+6z5tchE/AAHj+3T3MROkfzaPOHdM8PIt+
aLD/H8nPEcYVMvFK/b/3Yx41dIx1+G+Y6H+Hze7P6dM35MFNG/PAdrvr1y1Z
9AT0/sSDvMQ2+oPDztlGY4N86jX2wCAYAJPjjX+wz72bjPfx5ocW9zno1ni9
2pzMWexT5b3Oy+K/KCkCk5XOX84fYZlejNoDb1QZi+BwuXVqzBXV3h8cgacq
x4R4Is9z/0MfdDqNOkkdbnafNdK4rbbN/wKMUCLp
         "]], PolygonBox[CompressedData["
1:eJwtlGloz3Ecx7/7H7/fbx4owgNHDGkXOaZYEXO1ZZaJ0JYjtTna3LMHrlDE
KMu5zZgHjkTyxFEUxphzW7bFzLVhRSKlEV7vPnvw7vd5fz/H9/v7XHFLC7ML
Qs65PBABkz3nFsc4txpyK3DuGliJfBOjMb5zV+E5ITu7jjwVfA+bTxryV2x2
w3PgX5BnctYJz4OnE/urZ7FncnYb/Sz4QOS/xNwAP419FvoS7KuQ74EieC36
iejro3x551HOWtHd4SwT/7voxyFXc7YqZD73kd9gX4j9ZfhneP9Y53Zwtof4
T7i7Hp/F+D/C5hDya86q0J3Hvh376fA+6H+BdHgbOBMxmxZ07+FV8EX4NxH3
mWdvT0HuzV1L0X/Edw36Jci1nt09En0v9DXw0ei2w/vBc+Bx8EJ4X3gT/HiM
3aG72uAX4FfgHfBG7LKwr4S/gztQwX0F2Pzz7Uw6xWhULPhO5AzOypA3gWER
q4FqcRKe7awGp5BvgOshq3kH+gPE7KlcEGOvb2/W2xXzAfpWsADf+eAMvom+
/bvOzqoe6BciXyLeUHS7QCzxXmLTHd2rqOVSOVaudYfu6oFNCfI+3+R4cET9
gM8kYp0DJ5Qf/HND1oNRz3KsXCvHD+ETPOvNi2AS9hnwfORakBlYT6m3ZsPz
0MXDnxOrHoyGjwJ1YTuTTj2sXlYPqhfHom9GbgRJ6FPhn5DbQSr8WGC5H8x7
qtF95m3LeO8tkIL/eFDp7CwV+Q/6zchNIAueDV45O5vjW4+oVzJ4b65nNrIt
Bj+i1tPqbeX4sG8zpFkaxBvW8ZYWeAG6GpCM/xDfajMDNEdt5jX7vbDPDyym
YqvHunn2Zr1dOW/r6nn1fhp3PkX/Fnmrsx4agW0R+BeymatDHuBb7Up5f4Ny
53XdHbZcamdod7wApdjODWxRNcK/Ra3H1es6m4cuH/vYiNUoAb4CJIQtp8sD
q4FqoZkc79nO0e7RmzYil4OksO2sg9JFrVbK0RF8awLbNdoxP/F/hH5bjM3E
fux/+/Y29VQn8uDAcquZ1mwXBfYvmrniwGqgWujOMt9yrFxrp04JbAdpF2mH
tXDX8MB6SzOaHNhO0m7SP04j/hbPelk7az26tZ71unpQvZgYWC9rh2qXPvas
VtqJ2o3lgfW+ZqoisBnWLGtmNbuJnvWa/jlO8wzKIraDGqK2Y7VrtaM+eLaj
tKvUA+oF1Vi1lo98/wOH1OCc
         "]]}]}, 
     {RGBColor[0.7727272727272727, 
       NCache[
        Rational[6, 11], 0.5454545454545454], 0.7727272727272727], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVk1oXVUQvi/3vnMPgm7cVVyICVYRQcXSjWLUBmzfi21Si5BaQdEmkhcX
9rUpmCJKXRQjWFM3aRIhIhjzEiXR2tQgVK2SLtQmoUVbE00rmkJojW4U0e/L
94mLw5k7Z+ac+flm5t705HMtXXVJkvyFlWKNxyR5IkuSMeyNOBjB6iskSRn7
JNZwQd/3F5OkGfIb8yR5CvzPci3SJ7HPQ2Ye9Bz2XsiuS0VvAq+GtQu6JewT
WF2g2/Hmx6Db/E6r36JOFfQoZLZg/wBrCLxb8EYneAu4uwm8Max+8CewDoDf
i7Wayp4B0FPw51m+gb0CnX9Ad0J2Gqs5lUwLZI/R54LsoD09iWw5Xqd7KXuq
IPlfcM9R7Btgy1bwH0ll50ydvknvxVmFPmA/BPmr4L9q2WbLNPub934J+/bC
ti+w12ey8xPI7MTqhszjiexjzHrMYy7IvxAU00vQnQXvdcjdBvpikA+/gn4e
qwbZ+3LF4fZUuToblJufcL4fqwHv7sPejvUa5O/OFZud4G/Dngf5zhiMRvHf
w34+KE/rIX/OuVkC/3vz3wF9GWeP4c13o+4iXUmEkRtS+ftGLvph6E06r8zp
lVTfpPeDLmXCIWPQaEyST5qxYc6oy1hVnYtm3DkQpXsU+x6/8XTU/ddn+h7E
dxn0bBCOpp135qea6Zt3lG3DSeN/BfJzqewoJ7KFNGWY+6lMsetzPbAWGHfS
Z4vyhWfM6ee0D/K/B73Hd0edd2KC95eMj7ZEOKI8sbQxKLaM92RRdjP3d4G/
Ffz1UVghZs7j/HBBfN7HWiq5Nrsz6fL9VuwtWJvrdCdrmzZ9i3texP5NVN20
uHZYw62uHeKW+WauB3JhbxD7PdBZAL0B+0RRddKRqU80OT6sv+2+pzNTLdcK
6h9l20ld8olXYn/O8SfuacMizu/Idc+PoP8O6i1fR/UU+sQ4sm/RF55tcb9h
r6EdtUx5GctEV0yPZ5JhvMfM5/mY+TOZfGL+WXvMw6kofm8qPN+bq3f0BOWP
OFnrXdhPGDPXQLYDa6UgTHXbR9o64z455XcGjIuScXIG91+E3r5c9cw4HY/q
nSX3T9oyY33au2affaH/9Is9qd79c8g47XSdtTnvjOWOgt5vNKa7XbvTdZJd
DsrlCdgwV9S8WQT9UdQ8OIb9jyD8fRU1izZ5HrHnMh6XobcUhLcaZJYKsus0
zn7L5c9qrvMR9wFinPhgTJaj8HAJd/Tl0j8YhKMOY6w+FZ937g7SXYBetag+
WXE/HnEfoz7lx3HfnqJiTt0Gx439jXNtnXvdvOcc6QeiZsRDUXOBNcecDrpe
toN/XRAODuaqP9Yh8TRu+18Jkr05092s3UnX6UuQyXH2suug5nnJmNE22jnt
OTzhfjNnG+hH1b5wJwa/A304ly9Hsa8auy8E3U3sHHBNVf0/8KBnCmcL5/lm
11jNtUI8fYiz3bQ7Cm/zjg/7xFsFYYt2UqbN2K24Rlk/rIUzvr/V/Yp+M5en
XUcr9odzbZvx0eWeyd45bLx0uW9fdU19GvVv0RgUk4ZU9/R6thOXa7Gvk93U
W7Uuexv7FP2n/BXX/qL/t+bC/32Tcbs1qi+3O6ec2czVtUGx/7MoHeremGte
cm6WomzK7S+xSizWu1exL9FPYrJqPmPK2HKOsIfzP5B183ZUz0+DZgbr586g
+qA/9Jk4IRb/w3WvMVlyvZXdN2j/vPvCDr/FXkwsLvsfbcL9//1c+Xo0KIaH
HLc3c8X8SK7eP+z6Y4+c8uzjjGddduPOn6PkfgDvQlE0eUd8z2wuzLGvED+5
88n4tkbFuwzdfvdt/kPxn4az6ZxjT13O9yZjcZfrhTGvGJv9tpN10eG+yj7C
fsL/NWK0xXlgPqi71nOi/kmeifp/4kzifxZtHnIsKVv1W/8CC8eZYQ==
         "]], PolygonBox[CompressedData["
1:eJwllEtIVVEUhrfX4z6boCbNekEPK6OCjKJJkL0GdS31WgQFQVFmmRbotaCB
9JoVZNEkjQY1yLpaZKmZNFGLJpUaSmYGGoSBVLdGEfT9rMHi/Gv9a6+91+ss
PFRTVp1wzpUiETKe51wV3zaUb8G5U965LhxSyCR4LTKU69y1HOcqwB34HMN3
P/wTcG/s3G74EqQPXI5tJbgK/xT4HdKA/wf8d8DPR4rAu7hzHrgbvgo+g/9p
4l/EVgfOJ8ZN8Fv4uoTFeA/+y3sr4WYgs/DfgywBx8h5/AdjOztJjAFwA/wL
7pqL7Tr6VmL8BF/FtgVcA9+ZsJyeBctBubzBthH8GtsZuB7i1eO7HNvOhNVs
GbgQ6UFvh6+F/8T7kuityCK4L3lWy3akAH0V0gEuQybwn0Lfy9ky7rjLXU1I
EnxWOcDleuNSyD24S7HlrhqpVqqhalkMfzuYj3wfE38p3DTnD4OznHkJdxl9
Isdq9gi+FdvByGqgWqgH6kU5+mr4B/AHInuz3j7o7S69sRmu2FuvFfMG/IXY
evGRN82EGyX/O3Dj2NYpP/g54Az8LfAw/DZityAL0Otj691JJA0eIcZ2uAxS
6a0H6oVy2gDfSczjkc3QlLeaqXaaWc1uJlitlWMb+Ku33DTjmvU+bOnIevwH
/bPy02wjJ8At8KUJq8FDzUKwt+WrR+Aib7XVTG0OdkZnNQNj3nqu3ivmGLlm
0a/g20T+sbeclJtqMOytBqqFdmQI/+955tvNfdPE/41PbWQ7p91rx1YR2Qxq
FpPBZl01boxtR7Wr8nkKPsf5/hyL0YveFWwXVMPn4P5gvVFNXgX7J+jfsI8z
1ZxdEexfUIIUoqfRF0e2883cNxBsd7Sz/+A3IT9yLedf8EfhZ0dmE3ck2O7I
VgFe4y12I1KAXh+s1tph7bJqoFooh6y3GdesaydHve2cdk8zM0Lt7gd7u3qo
XuofpH+R3qy3rw82m9pB7eJ/6civDw==
         "]]}]}, 
     {RGBColor[0.7272727272727273, 
       NCache[
        Rational[5, 11], 0.45454545454545453`], 0.7272727272727273], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFlktoXVUUhs+959yztwMHceAsLVJQEQUVFCNotaNSqQO1xhpy2wasNoU0
gSioBZtUjC8cObHiQLCDmKSmqSZgqrTm1fpsnYh2YNGCVamCdar1//xXyOCw
11177bXX4//Xvtf17XtooFkUxXf6Sn1bk2QpRnNR/FoXxeOSb5NurFUUL+ub
aBTFHq3/VkWxW/Jp7e/VN6Gz3aX1yPck65e0TstuQmeel3639p+o7Ke3st/X
CuvGwv82yY/qe1dyl3y29H0umzrk7wvbcmb17McNyx8o7rZ+T2kdlu5Sw/a7
mrZ5W/Kizi60HNOKdMcbjrmvaRmbmZZjfV3yp/K1T/InWk82LeNvMnw8J5sD
iuuRyvJh2e2lnrVzQc/vqZZ/k9cfsumXj9+l26CzPzWcI/f3Rz2J4ZXIE789
2ntW6/amZXRz2pvV19bvkeQa/aD12quK4n7JtWI4IfudkT+9oA+v6uvQucGW
82Ufe/wsR8zkNCP9eMMx35D8+0atQy2fxceTyuUa+qr1jdJ13NFw7B3RG2pO
vfCD78moG+tU6KkNMvubSsezGjcr/aW34BDs0Av6QPyTurtHuvez4+oLPT2c
iRqCZfInd2JDT3/p4XTUEww/Vhrbw7X3b1e+P0veL/mW5PiWo6fUazZwOFpa
xv/1yfuHIx7qRU1uTd7/Rb/Xy3ahuYbBpcAeua1Uvm8xePS37j9YWs891KAd
PAIPOytjAt7QI+qJfU/42SI/81rPgOXa545Ivqk0n8kXv72RC3lybiK7loMR
P/zeE7xBXgnuTASnwBbreOAMXDNPzmt9MGYLM+Zits2PYbsQGPhNeyOK487s
s+eDF9TgVNw1nZ1vpTxGtL5Qee//uVX5TG9pPTnPZPeeeXaudl/oT7u0HfbU
7mjwCywPBXbBDVgBgx9l4+mY1l2VY6D2HWEDVqajH2DpbHYM32idza45taee
n8WsAS9zgRlqsBh1mAx5dUYthD3+iJl8wSV3fijfi9mzeH9tDtD38Wx+nAgO
MVdOx2wBO72Bjfmm8yFuMHgyuEMflmMOHIvc57T+ST20v1n3Z+09VXrOvli7
Z5PSb66Nqa9kv077N1fuIzXfUfr8VMwE+MRd3NMv/VvJuDyU3A/01PO+2hjc
na1jD/sDMfeYf3PJc4P5d3Xt+A5Kty7mBfltyY6NGOF6d8TTWTpW4oRn8If6
DGafH9L6ZrLN1to8IM7V/nRW9o9ufbWmXwp+XyjtE14sR85gcTY4De9OBXaJ
J0ddh0PXDj3vxV3lGj/YA+f/BB++VZyp9iy+nPyG3l3aD+9nV8j0pCvyHajN
Q3gJ9uEAtX4m2zfz41D05YHg7oXIhZxGQ95YeyYOyfZe2V2SfqPWI8kxTyXP
rrGY4fC1HRzEBzzAD+eOBi/PJmPmTDJWt8ccJ8aOeKPh93zowTp6MHxHNkbO
6b6HJV/hnSau2tw4zjzM7t1Adn2G4z/D5dqc4a2+GP+FmCXTyfV8qTZ26Bl9
uRL46YyPnKjdaLLPbbJ/OupDnZgB/cFrbDujF7x17fg/81dyH8A+93Af/P0i
Gbtfan0vG0vMzpXgNbWE95viDWVWd8e79nX2WXyQ74a49514I+j5Urw7vD//
Af9BXgY=
         "]], PolygonBox[CompressedData["
1:eJwlk02IzVEYxs+9/3v//7OxsZ+RLEgKixlDIUqJWDAjmbpjplyayVwjrEZj
7mAhWdlYsJKa5lsYGeSzKF9jIx+lmKJmJmVsKI3f41m89Tznec55z3nf9yxu
q+zqzIcQthAF4lMawh5AE3EthnCAWAg+j3YMbWUWwgQb9hHf4X3wmKDlQqiC
PxAp/D3+38UQpuF98CmiAf8Ua2N4Z+EbOLsHvZh4zylwgqeDvb3wq+gjrK0F
r+AOZ9DesDaB3gOfBPcTzQXnUK55PFX4O+63Ez6A3h3sGQR/Jn8/+a+jL0W/
Ef22MvpNcIH9+8GtxBi8Hs8jvG16L3vXwB+DF6EfRX8NLyXOqdwniIfotfAj
6PeISsFr0mbwN+ecYxTtLtGat+e+zot+Wy/xF38d/gd5e2bhw+gD7C+hj4Bf
oO8l/x3e8IP7DUVrevNX/HPoF9Bb2PMTPEh8ATewNgyuj651O/468En2PEPv
IN969EbW5tFriCvwanRtdcZp9YO1lsQ1UC22Zr6L1iYz11C11MxodlRD1VJ3
ylL3VL2thV/MPHOaPc3Ax9Q5lVs9vwzuRK8puAfqxUt4OecavAKvzjyb5/Cv
Apej364ZPhjdM/VuOf5L6IfhT3M+swKe5n7tefdcvf8/s4lnphO8MXp21UP1
cihzLZcQjehNqf/COvgo2tnUWDOsWR6PnjX18Bb4V+paPyeewFP4Jrybidv4
Z1gbx1/CfxytKzOWZzxzTuXWH9Jf2pG6lurZbvZ+K7oWOkNnbY9+u2q2Dbws
81/Qn9ff7059F9VgDvyH/YcS//EFqe+ku2kmNZtvo2dVM6PZ6YqefdVUtf0H
ubKVsQ==
         "]]}]}, 
     {RGBColor[0.6818181818181819, 
       NCache[
        Rational[4, 11], 0.36363636363636365`], 0.6818181818181819], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVEtIVVEUvb533z3XcYMsm+SwBtXAmhWkhBU0iCZNNcioLH0WRqRWL0h0
0CxtFtVA+6hNUvqoRX7KysdzUA2EIKiBEQQVWlBrtZY0OJx9993ftfbZ6+tP
7G/KRFF0HSeL8zqNovY4il7hflYWRcch90Nfibs7F0UPoWvAGYTcB/2pJIpG
8b0I+x7ommLZULcqKxvqGOca5GXYtyDhTCodYzL+mqzytuJfHroKfBcRoxZ3
DU4jfRyHdfFQx/jTuI9kFGckKE/CPLCd8r9f+M7jHsP/LOJtw8mXqS/mY65l
52Bs1jjtmJdgOw19gX7wH2BPqP85/CZx7pepR/bP+haDfHa4xxn3nnXOt5Dr
Y8XsgrwxVj0zkL8ixkHIs4ixBPkw5PeQO4N8O3BXQbcV5wP5QY518G9OhQe5
ISbEftn4PEvVy1lgcDIVP6ch/8Fpg/5NEAb9OfUWZ1Ur6zwK+wnYtyXihDyN
Qv8kVc+PcJ9JZENbzgVr6IVNA/4P59Qra2R84s3YVe6X3BBv4ky/CfvSZygn
mX55+z4I6qsZ970g3O4E8UA+Bs3JkHnhPWy52zGYaw9qXYLvXuPGGWswvsT5
AHpaXS59OeQviTisxv+WVDhxFjhftZ7PUkZ4luD/ORG3m2BTA/knbI6Zq0q/
kaFUc8J5+YF7LfRXI9U86N5Zc4/fXV1Os8T+iQlj/avDfBHPiVRz/zQVtlPG
d9zf38xj3lyTo0Ox8GGN37PKy/6Jw92g/N2e7Qnb9XonFFe4i8UZe+Y7oUyb
Jc8McxYcnz3OZfTG6M+55Hy+RI27gv7NQu6Avgj5VtDbpS1nbzhVnti757n5
3Qy7R7DbEpTnh3OR/wb3WOV3Q6w2QDef8XcsfMkx+170O+VeY45P+HcR+RYg
30D8fUFc8w0x/6jfHd80OWV9o0HzwzlqD3pX73DXpaptZ6J9V3JfrKPk2piD
uS4k4rDRPPZ5/3AGt+Nchvwxpz4W7F9w35fd+5DfIP8tOBd3DOeV+Ykx8aW+
6N3X717qvfe4r6lfSsRnq+0LifbXBfzvTIXp+VQ5Jz3Hg36bxId7h7P8OBVH
Bc9Sm3fIFfT3ItUMcBbGg+rrMPZF5632nh/xrmUc9ss+5jwr7JccEU/OBTni
DPBNdnmO3pjHuSCfiux/LubNzc0geTfu20G7dyDo3TAuY455Rn+jznPmmpyf
8Jvnnl5e4ZA4B+Ffh7s20e5pCZ4H5/0LW1IdBQ==
         "]], PolygonBox[CompressedData["
1:eJwlkz1I1lEUxs/r//X+r7MQKS412mIQuUiCCr0VNuTUqkEI8ZqvBSYqagq2
teZsg1YiLuInvjmUH4VSQzoITRUYguBnDf4ezvDAc+5zvu45915p7XiQLzGz
GyAL3qdmtYnZNYzhYNaJfY5DOWf1sqNZFdpCxuwp/JCzdvTPYBV7EFSj/0Sf
IPY6WER7xNkffG+jH5HrBDRij6Ffhk9S+w38V6nZXMZjarC3QDf8G9iGD4J9
9C4wAF+K3kue/MvwTbCFbxf4F7ymareBGbQn0WsXiXmBFtQDtXPUvVRm9gW9
H98KfHJo9dgj8FF8bik/NR9iPyP/BrwOfIIXiCmi51LvVT4HpT4zzU53eh68
hmppprP4NoM18zveh79Ovbc20IT/PXKeJT4jzUo1VVs9fkW7g/29xGc+EP2O
uusrcv4mfhf9ceIz0+x0J91NOe/i+zF679rhCnwj+i4L4BzffPTdaOcd8Lfk
2EbbI99L9AZwnPhOtduz4LHawTp2D3Zl1n1y2EPBY9XzOLl6QYKWBX3wndT5
D2qeMqdC6rNo1AzhZcF5E5iXb/C7akfT5P8ffPfqcQV9EtxEuwpagr9JvU2d
vUv9TJp6UC/KqdzaqXb7IfW3pj8xpbcc/a3pzfwldij6X9EOtcsL5M51bA==

         "]]}]}, 
     {RGBColor[0.6363636363636364, 
       NCache[
        Rational[3, 11], 0.2727272727272727], 0.6363636363636364], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFUz1PVFEQvbvv7b3P3qCWW1oJRjoawcgarfwqoNsEY4JR2LVhWVDhD+gv
MBp1V/0BfkWDaKKyLiQ0akH8AXZU6lp4jucYipeZN/fM3DNn5lbr185eLYcQ
LuPL8J2uhNDLQxgguFkKYQ62g/jTFMIoAI9hl4sQDgNzA/YD/reAuwM7j9h5
YLrAL8QQDuH/CjB9nE0jvgR/A98i4r+isO+R+wz4LjDH8N9Jup88WKeaKf4d
uBPI2Q//NjAXMuUzt5SJW6Ok84E5vwHuJP5fJ/XRqCi+A9wsvufwryf5d5Pq
sS77Jt+pTGc998X4GnA1+H+i6kzC34ZdyuWzZhOYGcRewfbL4sD7eV4zfigX
5lEQL57z/wFyRoBZQf1N60b92NsPfF+CtBhG/CP8M1Ec2UfVOjG+jXpHMnE8
bh7jsOVMerFODbNYx3kLNdYKzW8dtpWrd87maKa7yPkA4gdzaUj+5D1jDXas
J++lT3zJM+Fd56L8J+DQrahWx7OrupcJYOqsV4jvnHeQe0Q8z0bNn/hh98u7
Lnp23Ady2rK2Lfe8mJRP3oz/329yIB/2wjPWHHF9alN3He47e+N9zOVOMP9+
ks73YAdRe/C5EJcFY9q5NKWetNx/akWNW/bfIacJfzeKKzl/9U7yLr6Ftvfg
n5YV8SZ/zq3p+i+S+DVg3xbKG4O/GjXLh/BfJsX3ka9rsjZ1Z7/jUXp3rclP
2EvI/Zb0/jmDW8B+StJ9wzznzeFmIf1OJc+nvLc/Q57jZNSc+FaYM+XZUbO+
Z8PYtOPcO75t9jvrM+r2O0rfHu6cSMLugm+7EI7vY8z9su+/Q4Gnww==
         "]], PolygonBox[CompressedData["
1:eJwlkskuhFEQhevvbv//20uwtLQyhAcwRBM7CRs7CRti3Gi08QV4AvMQHgAx
DwvdpqQ3WIgHsLMxLnwntTjJqapTt26deyt6hjoGE2ZWBVKgMTTrCcwuQWts
1kFckTQLQCYyS4MCDZWIp6n3g1J4Ocig/QOtaNPgDO0JaIHf09MAv0Q/gnaH
WRfwGfSFwHvOqd+Sm6J+TW6S2iK5Empl5MaJ24hv6K0htwGfD51Xg3XiLfBG
bx3xDnwVVCX9zrr7C+gjfkczDd+OXKsdtesd87PMOmBGC7VnkKD2RPxZZLZL
PEpvPbm9yM/QWcpl4cWh79aOtrTYbJNcbdJ31K5HxL3wYe5zDM8yr5t6P7mp
2D2Td7rDL/oV4tfAd1iDf5AbS7mH5+iXI++VRtqZ2N9GHsgLeSbv9EZ6K3kq
b3XGFXEeTRdn73PnJvhA7G+pP9CEdi72XeX5bOwey2vttBD6DtpFb3wqb8Bv
wt+sOfQ/o78jDyfgjZH/hQwzvqh/FPlsefAQuefyfpJ6nnlLxI+Be5YOvUe9
nbpT5BDXDjn4d+i9EyAX+xvoLXSnw8hzqumP/aD9By3zZVA=
         "]]}]}, 
     {RGBColor[0.5909090909090909, 
       NCache[
        Rational[2, 11], 0.18181818181818182`], 0.5909090909090909], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFkztPVVEQhTfncM++CTRWNjZ2NNrYXcD4IhTSgIUNlQmNCQ87MD5+gz0J
aIHUGGiEi1DwMHihEAKXXyClDdcEE9eXWcRiZ/aes2ZmzZo5t19Mj00VKaXn
OqXOUVdKZzprurdySuNy/q6l1OxO6YfOrvwdBdwpA7sizIDux7LPZG/qrAqz
Jey2zo7ul4qfkP80R45+vf8qR1PvIfnXc9Q86I66m8ZQ86oI/0t9f1eP+sPC
t4rgdi7/ot53dV+QnciB7ZEd0TkR7qnsqyL4kn9S77buN2T3/K1TCVdFLDnI
23EMueEN50YteuM+Ldwf2RnZX8INCjcjO0dO2bEqeuAb/nlh75fxLuuB762i
1q0ytFq1nuiKftTiTdygY+/ZosWXHH7yoeVILTRbt7ZfZYermMuHHNo2rD89
0/sj+V+b81z+X4P3hjAPdF/LwYVY+LSL6OfCc6Mu2i7liH1fDx8c8JMDrejx
wlqQnzlvWk/wB575vufCfB573t9lD4uYKfuy7FpL7uubtaJOx7WeOGYohwbk
Zj/Re8v7ieUNB+bMvK/3nNmA+eQdY9fgDO56P9kZcraMP7ImcOQbvODHDjTc
LzzZDzT4bI5njkX/pv+10SriZoV5mEPLjRz/36H384207hP+bT1yN12L/4Qc
H3PoTV7q9bnfc/Nrm//PHHGj3ouW8/8DueqfkQ==
         "]], PolygonBox[CompressedData["
1:eJwlkjsvg3EUh0/7ak8TXVgsFiYLixVxjaFdsJokFkMvYRDX+Ah2ibCw0y5S
EQMhwYJQ38CEREJC4vk5wy95zv1/zvt2zZWnS2kz60YtaDNn1p+YXcIbcN7N
nlNmjyQV4VFUhevER+Bd1Ef+L74luBUtpKJGtRX0TWyYnEbWbAv1wl/4SsQ+
Mmaz2LfYY9jXHqwZV/Ai+oE7yJmktu7R64L5n5nooV6aUYbfePMZi1SYf++R
o9xzfO/E2vHtkNtEU/ADGkiiRrXrqAd+of7GQ+L/N3rsqF07sYvZ6Kne6lEj
NoHu0rGjdj2RL4kdtMsTmsd+pecqXPC4rWrGPXqqt96wlosc5VbRCtzwuL16
nsJtqJmKmxeoPcYeSmJH7brtcbsZfVN42eM2g9hHcD4brBrV7nl8e33TffjA
Y7b+iUP4DxggTiw=
         "]]}]}, 
     {RGBColor[0.5454545454545454, 
       NCache[
        Rational[1, 11], 0.09090909090909091], 0.5454545454545454], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVL1Om0EQPGP7u5MwlkhBDRRgY/PzBiFSUpEiUJMCE1pImcpSlAYeACh4
BDAuCOlimxBken7S0IcOU0RpM+MZKcXq9u7b252Z3fumGjtr2yMhhA+wPGyx
EMIGnN+5EOaKIXRhV0H+FmwZ59sxhAesn7MQvsPqSPARZ8e49wr3q9gfwjqI
r2D9im/3yFFC7NuobyWsPeyX4B8k5XjpuqzZcd1NnH1BzkecdxA/j7gxxPfw
vQabw34wotqsW8Z6AqvRT4p/F5WnAbtDzr84O4L9hF9Bjtmi7l5j7bt2Ky/O
xFBCnjb2+0mxvEteo0l1p6mB8VAf4ukbG7mR4wVizqJE/hRVt1oUTuIiP3Jf
tVYvoow+9SO+Wet5k6RJLgoLz8mFuKktMV9Y28tMvLrGU7L+o1ibxrxk3arW
gXgmrdWOe82eD/U2x+ekfv3B/sn9JrbTvOaE+g3xGhv1GDiGmJ/sbzlny/Ur
xjBImsM71J3JVHMiiWPfOlAv6lbL6ezaHImzbl7M++CYsbwwMObeM/EL63kU
l2fPVdeY2POsIE7UZKEgXRb8RiadmzWoedcYOuZaNccN3yFeYmsaZ8X9pz6s
v+gY4mwaPzUpe555t1f8/y57zlO3FuT4w1pRs/dJ+NeT6jf8vrhueuZ2o/Lv
Rb3dst/RbRTugWefGjA/15Z9vq22ffaR31ibM0E+35BjJVO/xz1v5EbM/HdQ
uzeeL3JgntdRWq5E6Rs8h4+uN+yj3zXf9z+SnIr3
         "]], PolygonBox[CompressedData["
1:eJwlkDEvw1EUxe+/r32v0pKIhElCGSv1DUrCVANmBoSNGrsb1AdoOpjMhISw
aYT0E9BafAAbU61+N2c4ybn3nHfvfWd+v7l9kjOzWZAHg2S2F8xqFPfwc7AK
v6ZXKppNUl/y4A8cwy/ARJDHvZtgCe07M2tHswUwjr5M7wXeYcZdkKdHPTVm
Vi2YreB/pW7wvs8dXfQN+A7+mNebMnyd3lcmzxr8EPzkdFMj6ma/vY7/Ef4W
tdt3+K5PegdoA96P6G2hzwX9+QOtBSyo59pT0qwqM56py2CI5Ype4J7TJM1v
asJn6N0G3bwLr0Rl94vnKCkTz+YM/R19kfomKMM2+nRRWfgMn5Ulef3mYdJO
3+03PiTN9NmesWddSsrOM/Fs/gFtMzX6
         "]]}]}, 
     {RGBColor[0.5, 0, 0.5], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFUrtOw0AQ3HPM3SHSIUENoQkNICGXkWwSakQNDUKUUEd2asIH8B9AmQIh
+IQgUH6EmhnNIorRnfcxOzvnnau789vCzI6BHhDWzApgGsxGQAUcAM9IPvUU
b4AONTXOcWk2w/0E500yGyK2G83uce+j/gHnKXIL3FvkltlshYHzqB7ykJ/f
jJ8l8bL206SFmlqfW3ucfY1re0fvEXo318HpmpcmvdR9GDSLceojH3Pk6Wft
dJG1R+e7NKV6p843ck7mZ7478y/OX/kM6qGWNvz7wzjn/qDvGvXfSfX0Z/jX
C+wDk1L9tfPQu9ZrK68hJ+tYQ8+6QhreovgGUT3ckzvSF3J9IL6RxcX3mSfx
7SF+mfVG21ngfSvLp+D/A99i4Z7Qg7FrYKzwNxq4Bv4L9Gbl2r6SdAacr1H+
PoL/F58ZPb8=
         "]], 
        PolygonBox[{{2140, 377, 954, 2141}, {2061, 945, 1090, 1726}, {2007, 
         868, 636, 2006}, {1570, 297, 780, 2059}, {1872, 729, 946, 2062}, {
         2197, 1090, 377, 2060}, {1731, 561, 1093, 1729}, {1729, 1093, 1092, 
         2198}, {2062, 946, 945, 2061}, {1793, 636, 729, 2259}, {2198, 1092, 
         297, 1728}, {2070, 954, 1094, 1574}, {1929, 780, 298, 1928}, {1574, 
         1094, 561, 1730}}]}]}}, {{}, 
     {GrayLevel[0], Opacity[0.4], 
      LineBox[{1526, 2007, 2006, 1793, 2259, 1672, 1872, 2062, 2061, 1726, 
       2197, 2060, 2140, 2141, 2071, 2070, 1574, 1730, 2323, 1731, 1729, 2198,
        1728, 1571, 1894, 1570, 2059, 1927, 1929, 1928, 1572}]}, 
     {GrayLevel[0], Opacity[0.4], 
      LineBox[{1873, 1810, 1972, 1548, 2051, 1971, 1912, 1617, 2004, 2288, 
       2005, 1970, 1973, 2289, 1525, 1974, 1725, 1904, 1903, 1902, 1665, 1861,
        1860, 1867, 1868, 1804, 1803, 1893, 1611, 1809, 1901}]}, 
     {GrayLevel[0], Opacity[0.4], 
      LineBox[{1527, 2008, 1915, 1914, 1913, 1618, 1959, 1960, 1958, 2175, 
       2174, 1863, 1953, 1954, 1952, 1951, 1908, 1612, 2172, 2173, 1997, 1998,
        1522, 1859, 1994, 1993, 1992, 1784, 1858, 1857, 1981, 1982, 1980, 
       1979, 1907, 1607, 1937, 1991}]}, 
     {GrayLevel[0], Opacity[0.4], 
      LineBox[{1528, 2009, 1918, 1917, 1916, 1619, 1962, 1963, 1961, 2177, 
       2176, 1865, 1956, 1666, 1955, 1667, 1957, 1663, 1984, 1788, 1983, 1787,
        2252, 1862, 2250, 1785, 2249, 1786, 2251, 1659, 2243, 1778, 2240, 
       2242, 2241, 1852, 1978, 1545, 2327, 1977, 1906, 1604, 1936, 1656, 2155,
        1657, 2156, 1603, 2119, 1602, 2120, 1658}]}, 
     {GrayLevel[0], Opacity[0.4], 
      LineBox[{1508, 2110, 2111, 2028, 2224, 1540, 2225, 1839, 1768, 2226, 
       1769, 1841, 1840, 1511, 2284, 1653, 1599, 1905, 1975, 2326, 1542, 1976,
        1845, 1773, 2236, 2238, 2237, 1654, 2160, 2161, 2157, 2159, 2158, 
       1847, 2162, 1945, 1946, 2123, 2122, 1608, 2253, 2254, 1995, 1996, 1519,
        1864, 2001, 2000, 1999, 1791, 1870, 1869, 2178, 1668, 1964, 1966, 
       1965, 1620, 1919, 1920, 1921, 2010, 1529}]}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzb1KgnEYhvFHwnTpIFrMxSVQWoLm0MXsBIJq0yWaakn0CFprKkHzI8jq
BGo2Ww0aWiShIZsCoV/DxXXf9/O+/Ff3auVqIiKKmCQj8umIAj5TEVe8tBxx
zRl9IrfkN87qa3j3z9RWtW1gZmvrHXRxg5ztw60nD9BHTX/gR9zhHkOs+/bI
bV8+xAG29G/7HCl56s2CPOMv97ntBE/yz7/dnrGJU/3VvuARj/GCbbdjvuBL
VOQdlHx3rjd4wE2+5V0+4zpW5F9v/wE3HzBo
       "]]}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzzsvQwEYh/HX4DL5BDRhUoOELiaJyyIRQ2eTpUTiEqFsBr4AYWn5HNQg
IdSsTdpBaWklOthMFr8zPHn6/N9zktOR1a3sZk9ErOCvN2KwL+KkP+IYFzhH
BS/IYx97WPbcwUDEIfI40mf2RV7Sp34XUcCunuEnLuMRv557Tt7labcH3ONH
39lneY4XMI81ZNxvuIRrdD1zyzs84dby/V3d0dto41s37Wn3Bn/pN/sGGujo
V/uoe50/dd2+jho+dM2ecq9yU1ftw3oIV7qiL7mIti2jc3hPbt4Z5yk9xpOc
Tv4P/wOq4jn1
       "]]}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzzkvhFEYhuFDMrYaESTWitFRGJFoSEhEYquQWBoKkonaH7CVMyhsBX+E
2GmnECIUwiBUluD6ijv3+zznPV/OVzMx1z+bE0JIYjA/hH4MIBfvBSH8xELo
M39wUZ4l3Z88zEN403/LX/hEj51e/bP+UF6Q5+Uu7uZOLisMIe1sRp5GqzmB
V2dZ+dHdZvmBY7oXcxbt5g7nd/onTsqJiOgb3MYTGEeD/X2+0e/xLdfr6pBx
/16X0bWg0dyEOMZQZWeLt7GJXexgyu4VSrz/MvoPe+dcKV/wJE5RLJ9wqfMj
rpCPeQzrvrOBNRxEu3bS5l9vSvG1HNfXmke43N3R6I2ojv6La/jM/ordVSxi
GUtI4R9kXT02
       "]]}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0Dsvg3EYhvHHuWYRaU0GiYToYmudBkaHDorFoZiEQSyMBvFxfASJSEhE
OlhoXhGhSKQkWPm9w5Xrue/n+ad527e+W9ppiogKLtsicpmIXmQx0B5xjnvz
lV1XR8Q11+QL/Qq6davc0hmxxnkkugf8ub1Bj7nKiXdV+5ycxaa51bstHsGz
7gV13Lofdp/Hq/yGZjd3+n5zwnW7R92QPIiKvC2PcoGLXOQN3uMzN0/eTcpj
ckP+xFf6u/op/TS+5R9k3LzrC+YPbtj96ibkcezLs5jDDEqYxwEOsZju3ZfT
G17iYz5Nv993L5iXdWU+4pP0v7ar4R9O3DZ1
       "]]}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVz0krhXEYhvH/kekgltIxZsqCTDl8DVsynJUU1vbmeVpQlKKUpSTyEZSk
DBvlUDZKlJCQ31lcXc9zP/f7vr0ViZHO4UgIYRRnGSGUZIdQimLUZYZQxl1c
xfVcyQ2cwJ353DPV3Gi/zwohiWC+kNfIa/Ege0REfimPma856XYlq7CXo9fe
hObU+9CKFvRhUK+d2zjOce7gIb7hW0SRgzLZYOqdPMGZSIv6jn3A/MQH+NYt
5G7ZOufpbPAzDvHjXsQ97puc777FrzjCn3uM+9z7sW3+4E984cU/zugcy6f5
hGd5h8d4N/UNvV/84U1/Xn4qn+NFLGDPPs4TiCANubJ3/WXzCpawhlXsu03y
FNKRgQLZr/4/RgA+ZQ==
       "]]}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0clKXEEYQOFqtCdFux1aRFRwIb6PoNEWEdqAhEh8DXGeBQVDAkqCMyKC
BFy6cSWJoMtssnEjDlHE4avF4dy/DrequLetNNL5JRFCGEVHKoTGTAgt2RAq
0iFcea5HAZ/N7Xqei5yxlkYKPeY+DtpPz7Xe/8Efza2cMP/iV2ygxrzOg3oL
B/Mx/8f3eIb5G5f0Zn6z9xHf4Cty+hoP6E38oh/yNVZRpa9wv97Iz/oB/8My
KvWleGe9gZ/0ff6LRVToC1zUC/yo7/EV5pHV57hXr4/31nf5ArPx2+gz3KPX
8YO+w+eYRlqf4g96Ld/r23yGSaT0Ce7Wa/hO3+JTjCOpj3GXnudbfZNP4tnW
xuK+1uowFPfgPHLxn5kvuTfel8vNv7mM/3CWc6jGMJL4hCq8A/2UP8M=
       "]]}, {}, {}}, {InsetBox[
      StyleBox["\<\"0 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {9.4, 0.51}], InsetBox[
      StyleBox["\<\"1 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {8.567916342700551, 0.99}], InsetBox[
      StyleBox["\<\"2 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {4.404845704708276, 0.51}], InsetBox[
      StyleBox["\<\"3 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {0.45, 0.5428416430362186}], InsetBox[
      StyleBox["\<\"4 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {2.63971772145512, 0.7072998282129582}], InsetBox[
      StyleBox["\<\"5 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {4.856331762744049, 0.99}], InsetBox[
      StyleBox["\<\"6 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {0.45, 0.8152073291755136}], InsetBox[
      StyleBox["\<\"7 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {2.881660592919575, 0.9553571428571426}], InsetBox[
      StyleBox["\<\"8 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {1.015806370664754, 0.9257903185332376}], InsetBox[
      StyleBox["\<\"9 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {2.1437998473365134`, 0.99}], InsetBox[
      StyleBox["\<\"10 dB\"\>",
       StripOnInput->False,
       FontSize->15,
       FontWeight->Bold], {0.45, 0.9792268994036885}]}}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"RMS Fluctuation angle, \[Theta] (\[Degree])\"", TraditionalForm], 
    FormBox[
    "\"Propogation Efficiency, \\!\\(\\*SubscriptBox[\\(\[Eta]\\), \
\\(prop\\)]\\)\"", TraditionalForm]},
  ImageSize->{557., Automatic},
  LabelStyle->Large,
  PlotRange->{{0, 10}, {0.5, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.455641452019916*^9, 3.455641459414316*^9}, {
  3.4556415288343163`*^9, 3.455641534309916*^9}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"dB", "[", 
     RowBox[{"(", 
      RowBox[{"Sqzfluc", "/.", 
       RowBox[{"\[Eta]prop", "\[Rule]", 
        RowBox[{"0.815", " ", "0.75"}]}]}], ")"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<Squeezing level as a function of \[Theta], for given propogation \
efficiency of 75%\>\"", ",", "Medium", ",", "Bold"}], "]"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<RMS fluctuation angle, \[Theta] (\[Degree])\>\"", ",", 
      "\"\<Squeezing relative to SNL\>\""}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "3.3", "}"}], ",", 
      RowBox[{"{", "3", "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.455643912625716*^9, 3.4556439720857162`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd1Hs01WkXB/DDiYpfJkxGynE5oSRJmlLYu4yUKe8UUiiRSwqVBoVkSG5d
3NKhOCH3EnVoUH6i3EkkhaYz5BKV45bLUd7nff941rM+a+0/nr3Xdz8qjqf2
O4syGIxkcv5/BzqKb3CKMhp2fD/wOpfC523Ke6yV3SCobur2/zxfXR6irHwe
bFbsedJGLBVbXCDxNhhEnTpNWomTK64qiSlHQG5xmn4LsdaI07V51+ugo51x
s4n4vVTKj7mOWFj15V/7euJVmYt/nRXegCrFQ7HVxO6G3h5TSokwOiqxvpL4
0Wv+3Qnj22CWPrXpKfHsyT3do65ckDqrlPWY+I5Id8SUSSro5QYHFxL/1hSj
9q0jDewSVWpziQc5ps8m3O5CE2fON534itN3u3FhBoQu+jn2FnGb8Hi8QCkH
pD/MLIgk9qlh6YwU5sJ2rbrDQcQKca8bvhjfA6fiN8o+xI6ayBx2fQCZafl9
9sSiQr+XEwEFELzab8CC+DXfSnHCpBBadS9bmBKfuydZMtbxEIpOO57QIjaL
7Rcfu/MI3MT0lrGIV557ZjnqxoNO/i7Nn4grjH0FI8IiSAyGuJEcChd29Wh8
USqB6ae+R3OI31Y89f48WAI6XL/DCcS5mZyq4cJS+FpW8zyY2NzL3H7I+Ams
4/3Weog4YXFpwoArDY9TBwYZxDxfM6+z8hVQuNZmy6dsCm8PbV4+HlAB1S1K
Yy3Eni0yrmMmzyDSI+duCrHM7VrR0Y5KMM3uFNtILJQqzjltUAVjURLZcsQf
/0r/Q3CnCpIsObyZLAqLXQNTRtyew8GoNqqc2Gaj3tavwhcgMz1eAsSp9dwz
w0p1MK+3b5FGJoUTnCLND1fqoNVXi/Ujg8Kdrg29rTN10F9gduk18WfmlFVp
Wz3My9psv0i8xdB8a0RYI2z5z5KLjXcpbHkwJ6ox8hI4f6+T3JlO3guLjyzR
bgHLd/7qMsTb1OO3hjm1gMyIfuz7NAqvTeSM+71qgZwcGVsvYr2YdmfHvFeg
di7mYVwqhRfrtcw22LfB5Te0fxGXwuzCx+p5N9qgJIvL9SFu5exgqjW2wU8C
9Z83E69yPfhEXv81ZG/aNlKUQmE985I2Q7YdpiQGPfKSKZQz7JJ5Wf0GxPn8
aO9bFOY/iOhy1+6Em8t7oy4nUDgkM3TFzKETDjOFpzYTa/iYGa2O74Rb5/PL
Bm6QfBtIpvbOdEJW2XTETuLYuisuNi+6wFo5RvR7HMlr7/VRU7v3MB7Odd0b
QyFXsiFE2oQPBb6gEhBFoZGhv13QET54J3mJKBB3e67dNOLLhzvl7bsfR1Io
3xrV35jLB7kMlBVEUBjD2bM7fOm/sK91a4RNOIUhas1S813/grujm7hsKIWu
8Crxs1cvXJeLcpcJpJCR9q20K6oXbvbeyOVeoJCzYGV3/d1eODHsaK1FXFvn
wsp50wsXi22+GwdQuNpyLs1560eIlXXyd/cj+3lc494/In0g3yFpkuZD4YnY
C+Ut0f1QzojWT/Uk+zWZ9oHO6QfR0GjblcRJ1rWMB5X9YM1c/iXBg8x7pazx
1Yl+sPPrPhLpTuHarOya3QcHQCFv8MKJEyQ/ZW0tlUqDoJ+0sOAnF5LvvjW9
vPxPcKvHatlXOwr5R94telb3CV5t83E2I7Z4G67d9PETXMlKpTJtSd4aBs73
KQyBpwgetbWhkFmYsVQubAgK32UrlluTfgNUjHzth0HvSenMsf0UPpNdnqi/
9Au4+++8sMGUQgmVSxoftgjAMyKK+UabzMMgZn2giQDUZoLV5IgvH0zZrLhf
AJueZxRbrSP9Rv9tantSADHf49Tb1pL/7sdn145kAaScUjWqWU3hcLdV9kvR
UTCZ5VjGq1LYyNFYU9E4Cvk275wql5F8L23QTD06DkbhFdanZyXRscuSZjZ+
gwLLEw+5jyXxzItLjqc0ZuHGgYmzCu6SWHiaspDf/R3sa7cliClKYqr/ySEd
awZKcVM6WeUSGMyd2zfxWQSvMbdF6h2WQEYbH5/4MXFCGCKd920xqv/pcs5S
Uwwltoub7724GD9O3jwg+VQcUwydFVMWLUazvhMXYs8sQsOz/sl2QYvQ/GP0
WhZLApeKPbxlMr4Qh6ocg2rvS+Jqm0jTALeFqC39RtHYfgmqDAx+T28SRwmY
dOgel8JNDrqHg38VR9MvNlOqVktRsL5MMHZFDN9WOonYaEmjVzTt8Z2/AIvC
nx9RnpTGBK+AcobBAnQR8+Y3N8ugGMNCNegSE495+RdRSbIo9Vj+o3q7KK53
Xdu8x+FnfHZgR/ELNVF8KaMl6a2/DFfc51kKjolgWX7wLS2mHN5b4/F5Lo+B
/iKafzS+l0NeTOzGdVXzINHtt8uT9wv2SO0IMtD5AX2ZKvHcAHnUrHLXEj6a
g/jVyxeUWC3H8MBG3f2yQohOcqlxUFbAnrYb11siZ8Am/nAzNaCA20IcQ1gL
p2H6t4wZbvkK3PuSH5hk/w16+3acqwxbiVaTG1botk5AmuGGFU0Oipj/i1S0
lco43A/1lnZdx8KuMd7TuKhRCLM69jtzkoVHA3X3b58ZgU3dqTlhTUrIYhrq
8298Bs6aW/ebfldGl/Y7QrWTn+BixVXO7yXKKDBd6zkg7IO9K6wy6lepYOiR
1K6Y2z2w3bPGVjpCBb9pR45uHPkHuCsdVzVOqmCziLvnIaW3sKoqK8HcVhU1
f7Hb0friFUSvq9RsLVdFOaaE9QNWDbiML3hVp8nG3JA77/nWj8CxcEw54job
b0ceHGeUJdDuwRZzZjFstGsPPLTnPIf2tuB1UHFsPB6WeC5mcxIdPul9LTqB
jboZCe2LeMl0vv6M8GYyGwsyNbusDqTRM8/m32TmsbE9sKHE3jyHjm6lrj6v
YeMh44eXRVMe0UnpHscv17Fx7sG+YoclPDr9z2bjXQ1sdHYINaADeHSxXPRs
QzOpX1O929u2iO62kT3e1s5GinnJokn+Ma3Ru9y4p5eNpVNBIVpxpbQOz491
t4+NfN1d1adFy+itoV0zzgNs3K2jZ/noTBm9RyO54NMQGz0Ss8w3/vGE9jqp
zBodZeMW3s5c1pJyOsDgr5mH42y8XBKgaxVQTocu6Xn95yTp7+IWRuRwOc15
kB41Pc1GRp6P29c6mk4LWuBaOsvGRJ16kesrK+i8fc47AubYWG+wWaBmWUHz
VKsVjX6wUcjNmS+LqqDLx9Vn5ufZOMmtXb+vqoL+L3mdk0Y=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
    "\"RMS fluctuation angle, \[Theta] (\[Degree])\"", TraditionalForm], 
    FormBox["\"Squeezing relative to SNL\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  GridLines->{{3.3}, {3}},
  ImageSize->{741., Automatic},
  PlotLabel->FormBox[
    StyleBox[
    "\"Squeezing level as a function of \[Theta], for given propogation \
efficiency of 75%\"", Medium, Bold, StripOnInput -> False], TraditionalForm],
  PlotRange->{{0, 10}, {-0.13096060593784356`, 3.5834138979374663`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.455643914933216*^9, 3.455643972415716*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Assume ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "CD"], TraditionalForm]], "None",
  FormatType->"TraditionalForm"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "LO"], TraditionalForm]], "None",
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "SB"], TraditionalForm]], "None",
  FormatType->"TraditionalForm"],
 " to be the light amplitude after the OMC for carrier contrast defecct, for \
carrier local oscillator due to arm offset and RF sideband power"
}], "Subsection",
 CellChangeTimes->{{3.455467114985044*^9, 3.455467147105044*^9}, 
   3.4554697268416443`*^9, {3.4562415614375*^9, 3.456241686484375*^9}, {
   3.4562423759375*^9, 3.45624238675*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ECR", "=", 
  RowBox[{"ECD", "+", " ", 
   RowBox[{"\[ImaginaryI]", " ", "ELO"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"ESB", "=", 
  RowBox[{
   RowBox[{"ESBP", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}], "-", 
   RowBox[{"ESBM", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", 
      "t"}]]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"ETOT", "=", 
  RowBox[{"ECR", "+", "ESB"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ComplexExpand", "[", 
   RowBox[{
    RowBox[{"ETOT", "\[Conjugate]"}], " ", "ETOT"}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"ESBM", "\[Rule]", "ESBP"}]}]}], "Input",
 CellChangeTimes->{{3.456241702875*^9, 3.45624201015625*^9}, {
  3.456242052484375*^9, 3.456242054484375*^9}, {3.45624219803125*^9, 
  3.45624220928125*^9}, {3.456242241125*^9, 3.456242324140625*^9}, {
  3.456313853375*^9, 3.456313857265625*^9}, {3.45631548753125*^9, 
  3.456315521453125*^9}, {3.45631581378125*^9, 3.456315816609375*^9}, {
  3.4563158815625*^9, 3.456315882046875*^9}}],

Cell[BoxData[
 RowBox[{"ECD", "+", 
  RowBox[{"\[ImaginaryI]", " ", "ELO"}]}]], "Output",
 CellChangeTimes->{
  3.456241796515625*^9, {3.45624183328125*^9, 3.45624185175*^9}, {
   3.4562418833125*^9, 3.456241909734375*^9}, {3.4562419844375*^9, 
   3.456242010609375*^9}, 3.456242055140625*^9, {3.4562421990625*^9, 
   3.456242209875*^9}, {3.45624225571875*^9, 3.456242292109375*^9}, 
   3.45624232446875*^9, 3.45631364090625*^9, {3.4563154940625*^9, 
   3.456315522859375*^9}, 3.456315817546875*^9, {3.456315863375*^9, 
   3.45631588290625*^9}, 3.4563161954375*^9, 3.45632658984375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]]}], " ", 
   "ESBM"}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]], " ", 
   "ESBP"}]}]], "Output",
 CellChangeTimes->{
  3.456241796515625*^9, {3.45624183328125*^9, 3.45624185175*^9}, {
   3.4562418833125*^9, 3.456241909734375*^9}, {3.4562419844375*^9, 
   3.456242010609375*^9}, 3.456242055140625*^9, {3.4562421990625*^9, 
   3.456242209875*^9}, {3.45624225571875*^9, 3.456242292109375*^9}, 
   3.45624232446875*^9, 3.45631364090625*^9, {3.4563154940625*^9, 
   3.456315522859375*^9}, 3.456315817546875*^9, {3.456315863375*^9, 
   3.45631588290625*^9}, 3.4563161954375*^9, 3.456326589921875*^9}],

Cell[BoxData[
 RowBox[{"ECD", "+", 
  RowBox[{"\[ImaginaryI]", " ", "ELO"}], "-", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], " ", 
   "ESBM"}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]], " ", 
   "ESBP"}]}]], "Output",
 CellChangeTimes->{
  3.456241796515625*^9, {3.45624183328125*^9, 3.45624185175*^9}, {
   3.4562418833125*^9, 3.456241909734375*^9}, {3.4562419844375*^9, 
   3.456242010609375*^9}, 3.456242055140625*^9, {3.4562421990625*^9, 
   3.456242209875*^9}, {3.45624225571875*^9, 3.456242292109375*^9}, 
   3.45624232446875*^9, 3.45631364090625*^9, {3.4563154940625*^9, 
   3.456315522859375*^9}, 3.456315817546875*^9, {3.456315863375*^9, 
   3.45631588290625*^9}, 3.4563161954375*^9, 3.45632658996875*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["ECD", "2"], "+", 
  SuperscriptBox["ELO", "2"], "+", 
  SuperscriptBox["ESBM", "2"], "+", 
  SuperscriptBox["ESBP", "2"], "-", 
  RowBox[{"2", " ", "ECD", " ", 
   RowBox[{"(", 
    RowBox[{"ESBM", "-", "ESBP"}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "-", 
  RowBox[{"2", " ", "ESBM", " ", "ESBP", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "t", " ", "\[Omega]"}], "]"}]}], "+", 
  RowBox[{"2", " ", "ELO", " ", "ESBM", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "+", 
  RowBox[{"2", " ", "ELO", " ", "ESBP", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.456241796515625*^9, {3.45624183328125*^9, 3.45624185175*^9}, {
   3.4562418833125*^9, 3.456241909734375*^9}, {3.4562419844375*^9, 
   3.456242010609375*^9}, 3.456242055140625*^9, {3.4562421990625*^9, 
   3.456242209875*^9}, {3.45624225571875*^9, 3.456242292109375*^9}, 
   3.45624232446875*^9, 3.45631364090625*^9, {3.4563154940625*^9, 
   3.456315522859375*^9}, 3.456315817546875*^9, {3.456315863375*^9, 
   3.45631588290625*^9}, 3.4563161954375*^9, 3.456326590046875*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["ECD", "2"], "+", 
  SuperscriptBox["ELO", "2"], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["ESBP", "2"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["ESBP", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "t", " ", "\[Omega]"}], "]"}]}], "+", 
  RowBox[{"4", " ", "ELO", " ", "ESBP", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.456241796515625*^9, {3.45624183328125*^9, 3.45624185175*^9}, {
   3.4562418833125*^9, 3.456241909734375*^9}, {3.4562419844375*^9, 
   3.456242010609375*^9}, 3.456242055140625*^9, {3.4562421990625*^9, 
   3.456242209875*^9}, {3.45624225571875*^9, 3.456242292109375*^9}, 
   3.45624232446875*^9, 3.45631364090625*^9, {3.4563154940625*^9, 
   3.456315522859375*^9}, 3.456315817546875*^9, {3.456315863375*^9, 
   3.45631588290625*^9}, 3.4563161954375*^9, 3.456326590078125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EAVRG", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"ETOT", 
     FractionBox["\[Omega]", 
      RowBox[{"2", "\[Pi]"}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      FractionBox[
       RowBox[{"2", "\[Pi]"}], "\[Omega]"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ComplexExpand", "[", 
   FractionBox[
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"ETOT", "\[Conjugate]"}], 
      RowBox[{"(", 
       RowBox[{"\[ImaginaryI]", " ", "EAVRG"}], ")"}]}], "]"}], 
    RowBox[{"ComplexExpand", "[", 
     RowBox[{
      RowBox[{"EAVRG", "\[Conjugate]"}], "EAVRG"}], "]"}]], "]"}], "/.", 
  RowBox[{"ESBM", "\[Rule]", "ESBP"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[CapitalGamma]", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"%", "//.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ECD", "\[Rule]", 
             SqrtBox["PCD"]}], ",", 
            RowBox[{"ELO", "\[Rule]", 
             SqrtBox[
              RowBox[{"PCR", "-", 
               SuperscriptBox["ECD", "2"]}]]}]}], "}"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{"PCD", "\[Rule]", 
           RowBox[{
            FractionBox["1", "\[Eta]"], " ", "PCR"}]}], "}"}]}], "/.", 
        RowBox[{"ESBP", "\[Rule]", 
         SqrtBox[
          FractionBox["PSB", "2"]]}]}], "/.", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"t", " ", "\[Omega]"}], "]"}], "\[Rule]", 
        FractionBox["1", 
         SqrtBox["2"]]}]}], "//", "FullSimplify"}], "//", "PowerExpand"}], "//",
     "Together"}], "//", "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox["\[CapitalGamma]", "Degree"], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"PSB", "\[Rule]", 
     RowBox[{"0.009", " ", "20*^-3"}]}], ",", 
    RowBox[{"PCR", "\[Rule]", "10*^-3"}], ",", 
    RowBox[{"\[Eta]", "\[Rule]", 
     FractionBox["10", "0.4"]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.456313825921875*^9, 3.456313828125*^9}, {
   3.45631385925*^9, 3.456313877375*^9}, {3.456313911078125*^9, 
   3.456314087234375*^9}, {3.456314148546875*^9, 3.456314266375*^9}, {
   3.456314362484375*^9, 3.4563143704375*^9}, {3.45631445775*^9, 
   3.456314480421875*^9}, {3.456314535234375*^9, 3.456314550859375*^9}, 
   3.456314734328125*^9, {3.4563148093125*^9, 3.45631482684375*^9}, {
   3.45631486190625*^9, 3.456314896578125*^9}, {3.456314937828125*^9, 
   3.45631493971875*^9}, {3.45631507803125*^9, 3.45631512175*^9}, {
   3.456315195375*^9, 3.45631527240625*^9}, {3.456315317265625*^9, 
   3.456315330953125*^9}, {3.456315552140625*^9, 3.456315679390625*^9}, {
   3.456326571890625*^9, 3.4563266011875*^9}, {3.456328016203125*^9, 
   3.456328097546875*^9}}],

Cell[BoxData[
 RowBox[{"ECD", "+", 
  RowBox[{"\[ImaginaryI]", " ", "ELO"}]}]], "Output",
 CellChangeTimes->{
  3.456313878546875*^9, 3.456313916171875*^9, {3.45631395540625*^9, 
   3.456314008265625*^9}, {3.45631405115625*^9, 3.456314057015625*^9}, 
   3.4563140878125*^9, 3.456314150078125*^9, 3.456314267453125*^9, 
   3.45631437228125*^9, 3.4563144596875*^9, 3.4563148390625*^9, {
   3.456314872390625*^9, 3.456314897484375*^9}, 3.456314940453125*^9, {
   3.456315079359375*^9, 3.4563151225*^9}, {3.456315236734375*^9, 
   3.456315273015625*^9}, {3.45631532103125*^9, 3.456315331640625*^9}, {
   3.456315509921875*^9, 3.4563156806875*^9}, 3.456315931046875*^9, 
   3.456316197171875*^9, {3.45632657421875*^9, 3.4563266248125*^9}, 
   3.45632805990625*^9, 3.4563280981875*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "ECD", " ", "ESBP", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
  RowBox[{
   SuperscriptBox["ECD", "2"], "+", 
   SuperscriptBox["ELO", "2"]}]]], "Output",
 CellChangeTimes->{
  3.456313878546875*^9, 3.456313916171875*^9, {3.45631395540625*^9, 
   3.456314008265625*^9}, {3.45631405115625*^9, 3.456314057015625*^9}, 
   3.4563140878125*^9, 3.456314150078125*^9, 3.456314267453125*^9, 
   3.45631437228125*^9, 3.4563144596875*^9, 3.4563148390625*^9, {
   3.456314872390625*^9, 3.456314897484375*^9}, 3.456314940453125*^9, {
   3.456315079359375*^9, 3.4563151225*^9}, {3.456315236734375*^9, 
   3.456315273015625*^9}, {3.45631532103125*^9, 3.456315331640625*^9}, {
   3.456315509921875*^9, 3.4563156806875*^9}, 3.456315931046875*^9, 
   3.456316197171875*^9, {3.45632657421875*^9, 3.4563266248125*^9}, 
   3.45632805990625*^9, 3.45632809825*^9}],

Cell[BoxData[
 FractionBox[
  SqrtBox["PSB"], 
  RowBox[{
   SqrtBox["PCR"], " ", 
   SqrtBox["\[Eta]"]}]]], "Output",
 CellChangeTimes->{
  3.456313878546875*^9, 3.456313916171875*^9, {3.45631395540625*^9, 
   3.456314008265625*^9}, {3.45631405115625*^9, 3.456314057015625*^9}, 
   3.4563140878125*^9, 3.456314150078125*^9, 3.456314267453125*^9, 
   3.45631437228125*^9, 3.4563144596875*^9, 3.4563148390625*^9, {
   3.456314872390625*^9, 3.456314897484375*^9}, 3.456314940453125*^9, {
   3.456315079359375*^9, 3.4563151225*^9}, {3.456315236734375*^9, 
   3.456315273015625*^9}, {3.45631532103125*^9, 3.456315331640625*^9}, {
   3.456315509921875*^9, 3.4563156806875*^9}, 3.456315931046875*^9, 
   3.456316197171875*^9, {3.45632657421875*^9, 3.4563266248125*^9}, 
   3.45632805990625*^9, 3.45632809828125*^9}],

Cell[BoxData["1.5374070937811024`"], "Output",
 CellChangeTimes->{
  3.456313878546875*^9, 3.456313916171875*^9, {3.45631395540625*^9, 
   3.456314008265625*^9}, {3.45631405115625*^9, 3.456314057015625*^9}, 
   3.4563140878125*^9, 3.456314150078125*^9, 3.456314267453125*^9, 
   3.45631437228125*^9, 3.4563144596875*^9, 3.4563148390625*^9, {
   3.456314872390625*^9, 3.456314897484375*^9}, 3.456314940453125*^9, {
   3.456315079359375*^9, 3.4563151225*^9}, {3.456315236734375*^9, 
   3.456315273015625*^9}, {3.45631532103125*^9, 3.456315331640625*^9}, {
   3.456315509921875*^9, 3.4563156806875*^9}, 3.456315931046875*^9, 
   3.456316197171875*^9, {3.45632657421875*^9, 3.4563266248125*^9}, 
   3.45632805990625*^9, 3.45632809828125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["\[CapitalGamma]", "Degree"], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PSB", "\[Rule]", 
        RowBox[{"0.009", " ", "20*^-3"}]}], ",", 
       RowBox[{"PCR", "\[Rule]", "10*^-3"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Eta]", ",", "1", ",", "100"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "8"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.1", ",", "0.5", ",", "0.2"}], "]"}]}], "}"}]}], "}"}]}], 
   ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(P\), \(CR\)], SubscriptBox[\(P\), \
\(CD\)]]\)\>\"", ",", "\"\<Phase Noise (\[Degree])\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.456244786640625*^9, 3.456244848234375*^9}, {
   3.456244891703125*^9, 3.456244915078125*^9}, {3.4562449579375*^9, 
   3.45624497590625*^9}, {3.456245015015625*^9, 3.4562450191875*^9}, {
   3.45624538475*^9, 3.456245443296875*^9}, {3.456245493671875*^9, 
   3.456245594421875*^9}, {3.4562456449375*^9, 3.456245653125*^9}, {
   3.4562456891875*^9, 3.45624570771875*^9}, {3.45624578090625*^9, 
   3.456245835515625*^9}, {3.456247576546875*^9, 3.4562476261875*^9}, {
   3.456247855109375*^9, 3.456247868203125*^9}, {3.456248579234375*^9, 
   3.4562485825625*^9}, {3.4562499116875*^9, 3.45624991196875*^9}, 
   3.456252922234375*^9, {3.456255856046875*^9, 3.456255887640625*^9}, {
   3.456313708375*^9, 3.456313717125*^9}, {3.4563153668125*^9, 
   3.456315378953125*^9}, 3.4563157056875*^9, {3.456315953890625*^9, 
   3.45631595646875*^9}, {3.456316230859375*^9, 3.456316285359375*^9}, {
   3.456326384078125*^9, 3.456326384921875*^9}, {3.45632799071875*^9, 
   3.4563280016875*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVxXk01AkcAPAxxjWO4efMMa015rVakeeYhO+3YxSrJklLwkxCjXbt5m1e
5dhFB/FsMVolKxNS0ZJbEq/sWmrZDJseI12/H3Kfa9bs7h+f97E+Ers/kk6j
0fb85/9LC679GO9+2qul7Zr1+VY22rlGVkZzvoSBupzLS41sXDA6tcWFEw1X
zkvp4ho2HkpbW7PgxMP+d3s++JezUfdhu4jFuQCc9qZa+xw2vh/gGGpxroJb
ymkv42g2vngnG1fjlIFMebSlmMXGzhObghicetDskJ+piLDCrvshxz+z+g0K
bmUkja1a4Mtv7vDaqV7wavHtz2g2x9FvIwQXygbA18yhMDR7HVbOFgTIXw9B
Wz7U3Agyw+HonwrJv17Dn55+2ZM7TNE771PmRuVbqC3u4kzZmmDjMhMaTUgw
3PlyfZq5MfqlF0UZrYxBZYfrUNznRtgWvMhoXDcJqyG/pNq6GqLdPYWvJGUa
BAnaZO8hAs/w7ZfnpmdANNJlujfLAJvXWoTxSXOQ5cHPPt2gjzqCku2imXnw
3EwvW1lg4d7WCXls6iLM2P1AmX+thxKfNyKO3jIYn0q7X67UwQmxYygkrQD3
ZvGB+EZtdL43ZJisuwoNu8/1DEYzMTPt9Q7bFAXo00uUnlu1UJbAd5g2XoOS
RS+jXIYm2mQHKYXFSnD6w+e85ag6brMUcSwzaHir8FZPmlwNSVoH99p+FdRu
irDV7GOg6eb+yC5dOkoONI7L3qmiz6TnVcFTOkrj03eXqqtiXHMgNypTFcV3
LFlX1tPRts9s1sGbgZdcn6298FfBHsUli0yWGkp6QoqsE2mYWH3QbatMDcdU
hhhJJ5RQ/aA7+0aWOj7TtJAdZa7ByJNZ/pVADcwbCdmluK6APOsnPHd9TdQf
znBuCFwFgfZHK5dfNVH6t27DPzZ/A02tQ9iepYUndd5uPPhhGbb4+o7QdzHR
e1RVEPNsCcQ/J7XIWNrIU1lMGy5fBBsMGwjp0sZzId37PEoXQP6V5I1zqg52
JqwPXameh9y7CXuKfHUx5Xi3yK5+DnqdWfOPGHqY4eDmsdA/C+rP/Zdjn+vh
ceuoFd7UDHjNj0/G5bIwcdmz9ZLJDCirzS5LuPr44kyutDRwGl7F5QQ3Zeij
09ApJ0fLKTg7GPGYR+qj4/vx5M6Gj1CgISwa2WGAUwGuj5/GTECTh/N9/zID
dM6RLk0S41BgGnbYkkHg3dixg5ScAnP39qomNQJV5bKOikEK8g9zNYI1CKz5
5DY/TkZB3s3JKgmTwKt0bqxKFwXZG5M1WAYECmiZMXZ1FKRAUbUKm8AK9heD
lZkUREePan5wIzC1bIPR9+4UvE/3Dju3hUBFZuFSpAsFR+/deWCzlcDmOLc3
fo4UCGdOhgm9CDQrUfRacSk4dFa15uVOAm1ylRrdBhT4ZXPCu/0JpIaPlAVT
JPxedbFGHEDg4WMm84K3JPj0TWhpBRIoDbjO3yUnwXtdbQ0/iMC5MO9FnowE
kPKZrWEE9mmEX9zQRsKjp+XhoUIC041eLXAfkuBB6tauiggU1aVGcetJ4Nn3
h/MiCVy2TN+3oYKEOoF7bX8Ugav2iZ12t0lwOVnI/O4YgfknundukpJQk0sX
GooJFOdvb3cqJMGpPqq2KobA68l3t/HySfgXTKcuUA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{9.398306502016513*^-8, 0},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*FractionBox[SubscriptBox[\\(P\\), \\(CR\\)], \
SubscriptBox[\\(P\\), \\(CD\\)]]\\)\"", TraditionalForm], 
    FormBox["\"Phase Noise (\[Degree])\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {{{0., 
       FormBox["1", TraditionalForm]}, {0.6931471805599453, 
       FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {2.995732273553991, 
       FormBox["20", TraditionalForm]}, {3.912023005428146, 
       FormBox["50", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {5.298317366548036, 
       FormBox["200", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{{0., 0.6931471805599453, 1.6094379124341003`, 2.302585092994046,
     2.995732273553991, 3.912023005428146, 4.605170185988092, 
    5.298317366548036, 6.214608098422191, 1.0986122886681098`, 
    1.3862943611198906`, 1.791759469228055, 1.9459101490553132`, 
    2.0794415416798357`, 2.1972245773362196`, 3.4011973816621555`, 
    3.6888794541139363`, 4.0943445622221, 4.248495242049359, 
    4.382026634673881, 4.499809670330265, 5.703782474656201, 
    5.991464547107982}, Automatic},
  Method->{},
  PlotRange->{{9.398306502016513*^-8, 4.605170092005027}, {0, 8}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{0., 
      FormBox["1", TraditionalForm]}, {0.6931471805599453, 
      FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
      FormBox["5", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {2.995732273553991, 
      FormBox["20", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {5.298317366548036, 
      FormBox["200", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.456244850453125*^9, {3.456244892046875*^9, 3.4562449155625*^9}, {
   3.4562449605*^9, 3.4562449770625*^9}, {3.456245015640625*^9, 
   3.456245020734375*^9}, {3.4562453871875*^9, 3.456245443921875*^9}, {
   3.4562454961875*^9, 3.4562455373125*^9}, {3.456245582671875*^9, 
   3.45624559503125*^9}, 3.456245654046875*^9, {3.456245689875*^9, 
   3.456245708171875*^9}, {3.456245806546875*^9, 3.456245836046875*^9}, 
   3.456247590171875*^9, {3.45624762046875*^9, 3.45624762678125*^9}, {
   3.456247857671875*^9, 3.45624786865625*^9}, {3.4562485734375*^9, 
   3.456248583375*^9}, {3.45624951653125*^9, 3.45624953125*^9}, 
   3.456249567859375*^9, {3.45624987384375*^9, 3.456249913359375*^9}, {
   3.45625291559375*^9, 3.45625292340625*^9}, {3.456255865703125*^9, 
   3.456255888453125*^9}, 3.456313696125*^9, 3.456313730015625*^9, 
   3.4563153364375*^9, 3.456315380328125*^9, {3.45631569096875*^9, 
   3.4563157063125*^9}, 3.456315957453125*^9, 3.456316209875*^9, {
   3.456316240796875*^9, 3.45631628721875*^9}, 3.45632638584375*^9, 
   3.45632800465625*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{730, 680},
WindowMargins->{{Automatic, 126}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 222, 3, 170, "Title"],
Cell[792, 27, 222, 6, 35, "Input"],
Cell[1017, 35, 1066, 29, 102, "Input"],
Cell[CellGroupData[{
Cell[2108, 68, 129, 1, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[2262, 73, 235, 5, 91, "Subsection"],
Cell[CellGroupData[{
Cell[2522, 82, 9899, 250, 1101, "Input"],
Cell[12424, 334, 104456, 1786, 782, 62960, 1107, "CachedBoxData", "BoxData", \
"Output"],
Cell[116883, 2122, 5119, 90, 376, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122039, 2217, 56, 1, 35, "Input"],
Cell[122098, 2220, 77, 1, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122212, 2226, 422, 9, 58, "Input"],
Cell[122637, 2237, 230, 4, 35, "Output"],
Cell[122870, 2243, 214, 3, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123121, 2251, 452, 10, 58, "Input"],
Cell[123576, 2263, 206, 3, 35, "Output"],
Cell[123785, 2268, 190, 2, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124012, 2275, 140, 1, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[124177, 2280, 375, 8, 58, "Input"],
Cell[124555, 2290, 231, 4, 35, "Output"],
Cell[124789, 2296, 213, 3, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[125051, 2305, 167, 3, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[125243, 2312, 511, 14, 58, "Input"],
Cell[125757, 2328, 158, 3, 35, "Output"],
Cell[125918, 2333, 142, 2, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126097, 2340, 4046, 110, 410, "Input"],
Cell[130146, 2452, 105177, 1790, 709, 63485, 1105, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[235360, 4247, 976, 26, 168, "Input"],
Cell[236339, 4275, 4127, 76, 499, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[240527, 4358, 734, 21, 91, "Subsection"],
Cell[CellGroupData[{
Cell[241286, 4383, 1184, 28, 126, "Input"],
Cell[242473, 4413, 586, 10, 35, "Output"],
Cell[243062, 4425, 837, 19, 35, "Output"],
Cell[243902, 4446, 873, 19, 35, "Output"],
Cell[244778, 4467, 1221, 27, 58, "Output"],
Cell[246002, 4496, 926, 20, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[246965, 4521, 2812, 74, 288, "Input"],
Cell[249780, 4597, 779, 13, 35, "Output"],
Cell[250562, 4612, 924, 18, 54, "Output"],
Cell[251489, 4632, 809, 16, 65, "Output"],
Cell[252301, 4650, 737, 11, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[253075, 4666, 2722, 62, 207, "Input"],
Cell[255800, 4730, 18306, 323, 364, 9266, 174, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
