(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    995978,      24231]
NotebookOptionsPosition[    965461,      23337]
NotebookOutlinePosition[    965931,      23355]
CellTagsIndexPosition[    965888,      23352]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Squeezer Cavity Models", "Title",
 CellChangeTimes->{{3.4560539625408*^9, 3.4560539670024*^9}}],

Cell[CellGroupData[{

Cell["Setup", "Section"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Controls`LinearControl`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4565781292194*^9, 3.4565781457086*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$TextStyle", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
     RowBox[{"FontSize", "\[Rule]", "13"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"plotopt", "=", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.1", ",", "0.7", ",", "0.2"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.5", ",", "0.5", ",", "0.2"}], "]"}]}], "}"}]}], "}"}]}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"popt", "=", 
   RowBox[{"Sequence", "@@", 
    RowBox[{"{", 
     RowBox[{"plotopt", ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "}"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4572762429496*^9, 3.4572762946792*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cavity Parameters", "Section",
 CellChangeTimes->{{3.456053950092*^9, 3.456053953524*^9}}],

Cell[CellGroupData[{

Cell["PPKTP", "Subsection",
 CellChangeTimes->{{3.4561398548050003`*^9, 3.4561398559126*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"PPKTPnx", "=", 
   RowBox[{"{", 
    RowBox[{"2.1146", ",", "0.89188", ",", "0.20861", ",", "0.01320"}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PPKTPny", "=", 
   RowBox[{"{", 
    RowBox[{"2.1518", ",", "0.87862", ",", "0.21801", ",", "0.01327"}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PPKTPnz", "=", 
   RowBox[{"{", 
    RowBox[{"2.3136", ",", "1.00012", ",", "0.23831", ",", "0.01679"}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4561398705453997`*^9, 3.4561399476406*^9}}],

Cell[CellGroupData[{

Cell["Sellmeier Equation", "Subsubsection",
 CellChangeTimes->{{3.4561404401638002`*^9, 3.4561404421605997`*^9}}],

Cell["\<\
The wavelength \[Lambda] is in \[Mu]m.
J. D. Bierlein and H. Vanherzeele, \[OpenCurlyDoubleQuote]Potassium titanyl \
phosphate: properties and new applications,\[CloseCurlyDoubleQuote] J. Opt. \
Soc. Am. B 6, 622 (1989).\
\>", "Text",
 CellChangeTimes->{{3.4561404099934*^9, 3.456140434501*^9}, {
  3.4561406319658003`*^9, 3.4561406348674*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sellmeier", "[", 
   RowBox[{"A_", ",", "B_", ",", "C_", ",", "D_", ",", "\[Lambda]_"}], "]"}], 
  ":=", 
  SqrtBox[
   RowBox[{"A", "+", 
    FractionBox["B", 
     RowBox[{"1", "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"C", "/", "\[Lambda]"}], ")"}], "2"]}]], "-", 
    RowBox[{"D", " ", 
     SuperscriptBox["\[Lambda]", "2"]}]}]]}]], "Input",
 CellChangeTimes->{{3.4561399634746*^9, 3.456140036467*^9}, {
  3.4561403984806004`*^9, 3.456140399869*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Sellmeier", "@@", 
  RowBox[{"Append", "[", 
   RowBox[{"PPKTPnz", ",", "1.064"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Sellmeier", "@@", 
  RowBox[{"Append", "[", 
   RowBox[{"PPKTPnx", ",", "1.064"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Sellmeier", "@@", 
  RowBox[{"Append", "[", 
   RowBox[{"PPKTPnz", ",", 
    RowBox[{"1.064", "/", "2"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Sellmeier", "@@", 
  RowBox[{"Append", "[", 
   RowBox[{"PPKTPnx", ",", 
    RowBox[{"1.064", "/", "2"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4561400425354*^9, 3.4561401527806*^9}, {
  3.456140218597*^9, 3.4561402236046*^9}, {3.4561404772293997`*^9, 
  3.4561405107693996`*^9}, {3.4561405468366003`*^9, 3.4561405494105997`*^9}}],

Cell[BoxData["1.8296264485109082`"], "Output",
 CellChangeTimes->{{3.4561400565754004`*^9, 3.4561400603974*^9}, {
   3.4561401213934*^9, 3.456140165479*^9}, {3.4561402186906*^9, 
   3.4561402239166*^9}, {3.4561404811294003`*^9, 3.4561405111282*^9}, {
   3.4561405469614*^9, 3.4561405496134*^9}, 3.4561415277646*^9, 
   3.4564975860875998`*^9, 3.4566640955112944`*^9, 3.456745594079294*^9, 
   3.4568448422892942`*^9, 3.4569340505595746`*^9, 3.4571137347434*^9, 
   3.4571328920395746`*^9, 3.4571769113403997`*^9, 3.4572239213165746`*^9, 
   3.4572609141424*^9, 3.4573072915405746`*^9, 3.457525864993082*^9, 
   3.459512941583931*^9, 3.4595253820109997`*^9, 3.4595399397325597`*^9}],

Cell[BoxData["1.7398824857890849`"], "Output",
 CellChangeTimes->{{3.4561400565754004`*^9, 3.4561400603974*^9}, {
   3.4561401213934*^9, 3.456140165479*^9}, {3.4561402186906*^9, 
   3.4561402239166*^9}, {3.4561404811294003`*^9, 3.4561405111282*^9}, {
   3.4561405469614*^9, 3.4561405496134*^9}, 3.4561415277646*^9, 
   3.4564975860875998`*^9, 3.4566640955112944`*^9, 3.456745594079294*^9, 
   3.4568448422892942`*^9, 3.4569340505595746`*^9, 3.4571137347434*^9, 
   3.4571328920395746`*^9, 3.4571769113403997`*^9, 3.4572239213165746`*^9, 
   3.4572609141424*^9, 3.4573072915405746`*^9, 3.457525864993082*^9, 
   3.459512941583931*^9, 3.4595253820109997`*^9, 3.4595399397355595`*^9}],

Cell[BoxData["1.886804331573617`"], "Output",
 CellChangeTimes->{{3.4561400565754004`*^9, 3.4561400603974*^9}, {
   3.4561401213934*^9, 3.456140165479*^9}, {3.4561402186906*^9, 
   3.4561402239166*^9}, {3.4561404811294003`*^9, 3.4561405111282*^9}, {
   3.4561405469614*^9, 3.4561405496134*^9}, 3.4561415277646*^9, 
   3.4564975860875998`*^9, 3.4566640955112944`*^9, 3.456745594079294*^9, 
   3.4568448422892942`*^9, 3.4569340505595746`*^9, 3.4571137347434*^9, 
   3.4571328920395746`*^9, 3.4571769113403997`*^9, 3.4572239213165746`*^9, 
   3.4572609141424*^9, 3.4573072915405746`*^9, 3.457525864993082*^9, 
   3.459512941583931*^9, 3.4595253820109997`*^9, 3.45953993973656*^9}],

Cell[BoxData["1.7789880173950479`"], "Output",
 CellChangeTimes->{{3.4561400565754004`*^9, 3.4561400603974*^9}, {
   3.4561401213934*^9, 3.456140165479*^9}, {3.4561402186906*^9, 
   3.4561402239166*^9}, {3.4561404811294003`*^9, 3.4561405111282*^9}, {
   3.4561405469614*^9, 3.4561405496134*^9}, 3.4561415277646*^9, 
   3.4564975860875998`*^9, 3.4566640955112944`*^9, 3.456745594079294*^9, 
   3.4568448422892942`*^9, 3.4569340505595746`*^9, 3.4571137347434*^9, 
   3.4571328920395746`*^9, 3.4571769113403997`*^9, 3.4572239213165746`*^9, 
   3.4572609141424*^9, 3.4573072915405746`*^9, 3.457525864993082*^9, 
   3.459512941583931*^9, 3.4595253820109997`*^9, 3.4595399397385597`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SHG", "Subsection",
 CellChangeTimes->{{3.4560546407195997`*^9, 3.4560546412656*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"redSHG", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"F", "\[Rule]", 
     FractionBox[
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{"r1", " ", "r2", 
         SqrtBox[
          RowBox[{"1", "-", "\[Delta]"}]]}]]}], 
      RowBox[{"1", "-", 
       RowBox[{"r1", " ", "r2", 
        SqrtBox[
         RowBox[{"1", "-", "\[Delta]"}]]}]}]]}], ",", 
    RowBox[{"t1", "\[Rule]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["r1", "2"]}]]}], ",", 
    RowBox[{"t2", "\[Rule]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["r2", "2"]}]]}], ",", 
    RowBox[{"r1", "\[Rule]", 
     SqrtBox["0.9"]}], ",", 
    RowBox[{"r2", "\[Rule]", 
     SqrtBox["0.9992"]}], ",", 
    RowBox[{"k", "\[Rule]", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], "lambda"]}], ",", 
    RowBox[{"c", "\[Rule]", "2.99793*^8"}], ",", 
    RowBox[{"lambda", "\[Rule]", "1.064*^-6"}], ",", 
    RowBox[{"FSR", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", "L"}]]}], ",", 
    RowBox[{"fcav", "\[Rule]", 
     FractionBox["FSR", 
      RowBox[{"2", " ", "F"}]]}], ",", 
    RowBox[{
     RowBox[{"L", "\[Rule]", 
      RowBox[{
       FractionBox["94.7*^-3", "2"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"nPPKTP", "-", "1"}], ")"}], "10*^-3"}]}]}], "/.", 
     RowBox[{"nPPKTP", "\[Rule]", "1.74"}]}], ",", 
    RowBox[{"fM", "\[Rule]", "35.5*^6"}], ",", 
    RowBox[{"\[Delta]", "\[Rule]", "0.05"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"L", "//.", "redSHG"}], "\[IndentingNewLine]", 
 RowBox[{"F", "//.", "redSHG"}], "\[IndentingNewLine]", 
 RowBox[{"FSR", "//.", "redSHG"}], "\[IndentingNewLine]", 
 RowBox[{"fcav", "//.", "redSHG"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", "\[Delta]"}]], 
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["r1", "2"]}]], 
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["r2", "2"]}]]}], 
      RowBox[{"1", "-", 
       RowBox[{"r1", " ", "r2", 
        SqrtBox[
         RowBox[{"1", "-", "\[Delta]"}]]}]}]], ")"}], "2"], "//.", "redSHG"}],
   " ", 
  RowBox[{"(*", " ", 
   RowBox[{"carrier", " ", "power", " ", "transmission"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"Abs", "[", 
     FractionBox[
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", "\[Delta]"}]], 
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["r1", "2"]}]], 
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["r2", "2"]}]]}], 
      RowBox[{"1", "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
          RowBox[{"fM", "/", "FSR"}]}]], "r1", " ", "r2", 
        SqrtBox[
         RowBox[{"1", "-", "\[Delta]"}]]}]}]], "]"}], "2"], "//.", "redSHG"}],
   " ", 
  RowBox[{"(*", " ", 
   RowBox[{"sb", " ", "power", " ", "transmission"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"Abs", "[", 
     FractionBox[
      RowBox[{"t1", " ", "t2"}], 
      RowBox[{"1", "-", 
       RowBox[{"r1", " ", "r2"}]}]], "]"}], "2"], "//.", "redSHG"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "carrier", " ", "power", " ", "transmission", " ", "no", " ", "loss"}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"Abs", "[", 
     FractionBox[
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["r1", "2"]}]], 
      RowBox[{"1", "-", 
       RowBox[{"r1", " ", "r2", 
        SqrtBox[
         RowBox[{"1", "-", "\[Delta]"}]]}]}]], "]"}], "2"], "//.", "redSHG"}],
   " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"power", " ", "build"}], "-", 
    RowBox[{"up", " ", "inside", " ", "cavity"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"\[Delta]", " ", 
    SuperscriptBox[
     RowBox[{"Abs", "[", 
      FractionBox[
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["r1", "2"]}]], 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2", 
         SqrtBox[
          RowBox[{"1", "-", "\[Delta]"}]]}]}]], "]"}], "2"]}], "//.", 
   "redSHG", " ", 
   RowBox[{"(*", " ", 
    RowBox[{"greeen", " ", "power", " ", "conversion", " ", "efficiency"}], 
    " ", "*)"}]}]}]}], "Input",
 CellChangeTimes->{{3.4559904928154*^9, 3.4559905326577997`*^9}, {
   3.4559925506280003`*^9, 3.4559925508464003`*^9}, {3.4559925819528*^9, 
   3.4559926153368*^9}, {3.45599265234*^9, 3.4559926560528*^9}, {
   3.455993685216*^9, 3.4559937006288*^9}, {3.4559937977855997`*^9, 
   3.4559938110299997`*^9}, {3.4560540182952003`*^9, 3.4560540207444*^9}, {
   3.4560541519560003`*^9, 3.4560542694396*^9}, {3.4560579907104*^9, 
   3.4560580334388*^9}, {3.4560581953824*^9, 3.4560582431184*^9}, {
   3.4560583039116*^9, 3.4560583202292*^9}, {3.4560608468988*^9, 
   3.4560608950404*^9}, {3.4560633171916*^9, 3.4560633181744003`*^9}, {
   3.456063377158*^9, 3.4560634065172*^9}, 3.4561405526554003`*^9, {
   3.4561415597914*^9, 3.4561415644558*^9}, {3.459511417146431*^9, 
   3.459511419356431*^9}, {3.4595129321264315`*^9, 3.459513026066431*^9}, {
   3.4595130762214313`*^9, 3.4595131088889313`*^9}, {3.459513174833931*^9, 
   3.459513221918931*^9}, {3.4595133172689314`*^9, 3.459513343189931*^9}, {
   3.459513504889931*^9, 3.4595136565799313`*^9}, {3.4595136990339313`*^9, 
   3.4595137022179313`*^9}, {3.459513777364931*^9, 3.459513777564931*^9}, {
   3.4595138439585*^9, 3.4595138557485*^9}, 3.4595139095685*^9, {
   3.4595141164309998`*^9, 3.459514273726*^9}, {3.4595143845135*^9, 
   3.4595143912609997`*^9}, {3.4595146997185*^9, 3.4595147064560003`*^9}, {
   3.4595157000555*^9, 3.4595157785655003`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"F", "\[Rule]", 
    FractionBox[
     RowBox[{"\[Pi]", " ", 
      SqrtBox[
       RowBox[{"r1", " ", "r2", " ", 
        SqrtBox[
         RowBox[{"1", "-", "\[Delta]"}]]}]]}], 
     RowBox[{"1", "-", 
      RowBox[{"r1", " ", "r2", " ", 
       SqrtBox[
        RowBox[{"1", "-", "\[Delta]"}]]}]}]]}], ",", 
   RowBox[{"t1", "\[Rule]", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r1", "2"]}]]}], ",", 
   RowBox[{"t2", "\[Rule]", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r2", "2"]}]]}], ",", 
   RowBox[{"r1", "\[Rule]", "0.9486832980505138`"}], ",", 
   RowBox[{"r2", "\[Rule]", "0.999599919967984`"}], ",", 
   RowBox[{"k", "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", "\[Pi]"}], "lambda"]}], ",", 
   RowBox[{"c", "\[Rule]", "2.99793`*^8"}], ",", 
   RowBox[{"lambda", "\[Rule]", "1.064`*^-6"}], ",", 
   RowBox[{"FSR", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "L"}]]}], ",", 
   RowBox[{"fcav", "\[Rule]", 
    FractionBox["FSR", 
     RowBox[{"2", " ", "F"}]]}], ",", 
   RowBox[{"L", "\[Rule]", "0.05475000000000001`"}], ",", 
   RowBox[{"fM", "\[Rule]", "3.55`*^7"}], ",", 
   RowBox[{"\[Delta]", "\[Rule]", "0.05`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560542148084*^9, 3.4560542286144*^9}, {3.4560542607036*^9, 
   3.4560542700480003`*^9}, {3.4560580235172*^9, 3.4560580338599997`*^9}, {
   3.4560581963964*^9, 3.4560582437736*^9}, {3.4560583045355997`*^9, 
   3.4560583311492*^9}, 3.4560608957424*^9, 3.4560633196252003`*^9, {
   3.4560633776415997`*^9, 3.4560634071412*^9}, 3.4561405535134*^9, 
   3.4561415277958*^9, {3.4561415615386*^9, 3.4561415656726*^9}, 
   3.4564975861344*^9, 3.4566640955268946`*^9, 3.4567455941082945`*^9, 
   3.4568448423828945`*^9, 3.4569340506835747`*^9, 3.4571137347902*^9, 
   3.4571328921665745`*^9, 3.457176911434*^9, 3.4572239214785748`*^9, 
   3.457260914236*^9, 3.4573072916995745`*^9, 3.4575258651780825`*^9, 
   3.4595114205339313`*^9, {3.459513093958931*^9, 3.459513109521431*^9}, {
   3.459513175578931*^9, 3.459513222378931*^9}, {3.459513319521431*^9, 
   3.459513343637431*^9}, {3.4595135092549314`*^9, 3.459513568197431*^9}, {
   3.459513693682931*^9, 3.4595137027169313`*^9}, 3.4595138564084997`*^9, 
   3.4595139098885*^9, {3.4595141569435*^9, 3.459514242266*^9}, 
   3.459514339861*^9, {3.459514385146*^9, 3.459514391466*^9}, 
   3.4595144932635*^9, 3.4595147071584997`*^9, {3.4595157251045*^9, 
   3.4595157788195*^9}, 3.4595253820485*^9, 3.4595399397685595`*^9}],

Cell[BoxData["0.05475000000000001`"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560542148084*^9, 3.4560542286144*^9}, {3.4560542607036*^9, 
   3.4560542700480003`*^9}, {3.4560580235172*^9, 3.4560580338599997`*^9}, {
   3.4560581963964*^9, 3.4560582437736*^9}, {3.4560583045355997`*^9, 
   3.4560583311492*^9}, 3.4560608957424*^9, 3.4560633196252003`*^9, {
   3.4560633776415997`*^9, 3.4560634071412*^9}, 3.4561405535134*^9, 
   3.4561415277958*^9, {3.4561415615386*^9, 3.4561415656726*^9}, 
   3.4564975861344*^9, 3.4566640955268946`*^9, 3.4567455941082945`*^9, 
   3.4568448423828945`*^9, 3.4569340506835747`*^9, 3.4571137347902*^9, 
   3.4571328921665745`*^9, 3.457176911434*^9, 3.4572239214785748`*^9, 
   3.457260914236*^9, 3.4573072916995745`*^9, 3.4575258651780825`*^9, 
   3.4595114205339313`*^9, {3.459513093958931*^9, 3.459513109521431*^9}, {
   3.459513175578931*^9, 3.459513222378931*^9}, {3.459513319521431*^9, 
   3.459513343637431*^9}, {3.4595135092549314`*^9, 3.459513568197431*^9}, {
   3.459513693682931*^9, 3.4595137027169313`*^9}, 3.4595138564084997`*^9, 
   3.4595139098885*^9, {3.4595141569435*^9, 3.459514242266*^9}, 
   3.459514339861*^9, {3.459514385146*^9, 3.459514391466*^9}, 
   3.4595144932635*^9, 3.4595147071584997`*^9, {3.4595157251045*^9, 
   3.4595157788195*^9}, 3.4595253820485*^9, 3.4595399397715597`*^9}],

Cell[BoxData["39.89455832067035`"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560542148084*^9, 3.4560542286144*^9}, {3.4560542607036*^9, 
   3.4560542700480003`*^9}, {3.4560580235172*^9, 3.4560580338599997`*^9}, {
   3.4560581963964*^9, 3.4560582437736*^9}, {3.4560583045355997`*^9, 
   3.4560583311492*^9}, 3.4560608957424*^9, 3.4560633196252003`*^9, {
   3.4560633776415997`*^9, 3.4560634071412*^9}, 3.4561405535134*^9, 
   3.4561415277958*^9, {3.4561415615386*^9, 3.4561415656726*^9}, 
   3.4564975861344*^9, 3.4566640955268946`*^9, 3.4567455941082945`*^9, 
   3.4568448423828945`*^9, 3.4569340506835747`*^9, 3.4571137347902*^9, 
   3.4571328921665745`*^9, 3.457176911434*^9, 3.4572239214785748`*^9, 
   3.457260914236*^9, 3.4573072916995745`*^9, 3.4575258651780825`*^9, 
   3.4595114205339313`*^9, {3.459513093958931*^9, 3.459513109521431*^9}, {
   3.459513175578931*^9, 3.459513222378931*^9}, {3.459513319521431*^9, 
   3.459513343637431*^9}, {3.4595135092549314`*^9, 3.459513568197431*^9}, {
   3.459513693682931*^9, 3.4595137027169313`*^9}, 3.4595138564084997`*^9, 
   3.4595139098885*^9, {3.4595141569435*^9, 3.459514242266*^9}, 
   3.459514339861*^9, {3.459514385146*^9, 3.459514391466*^9}, 
   3.4595144932635*^9, 3.4595147071584997`*^9, {3.4595157251045*^9, 
   3.4595157788195*^9}, 3.4595253820485*^9, 3.4595399397735596`*^9}],

Cell[BoxData["2.737835616438356`*^9"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560542148084*^9, 3.4560542286144*^9}, {3.4560542607036*^9, 
   3.4560542700480003`*^9}, {3.4560580235172*^9, 3.4560580338599997`*^9}, {
   3.4560581963964*^9, 3.4560582437736*^9}, {3.4560583045355997`*^9, 
   3.4560583311492*^9}, 3.4560608957424*^9, 3.4560633196252003`*^9, {
   3.4560633776415997`*^9, 3.4560634071412*^9}, 3.4561405535134*^9, 
   3.4561415277958*^9, {3.4561415615386*^9, 3.4561415656726*^9}, 
   3.4564975861344*^9, 3.4566640955268946`*^9, 3.4567455941082945`*^9, 
   3.4568448423828945`*^9, 3.4569340506835747`*^9, 3.4571137347902*^9, 
   3.4571328921665745`*^9, 3.457176911434*^9, 3.4572239214785748`*^9, 
   3.457260914236*^9, 3.4573072916995745`*^9, 3.4575258651780825`*^9, 
   3.4595114205339313`*^9, {3.459513093958931*^9, 3.459513109521431*^9}, {
   3.459513175578931*^9, 3.459513222378931*^9}, {3.459513319521431*^9, 
   3.459513343637431*^9}, {3.4595135092549314`*^9, 3.459513568197431*^9}, {
   3.459513693682931*^9, 3.4595137027169313`*^9}, 3.4595138564084997`*^9, 
   3.4595139098885*^9, {3.4595141569435*^9, 3.459514242266*^9}, 
   3.459514339861*^9, {3.459514385146*^9, 3.459514391466*^9}, 
   3.4595144932635*^9, 3.4595147071584997`*^9, {3.4595157251045*^9, 
   3.4595157788195*^9}, 3.4595253820485*^9, 3.4595399397745595`*^9}],

Cell[BoxData["3.431339675992623`*^7"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560542148084*^9, 3.4560542286144*^9}, {3.4560542607036*^9, 
   3.4560542700480003`*^9}, {3.4560580235172*^9, 3.4560580338599997`*^9}, {
   3.4560581963964*^9, 3.4560582437736*^9}, {3.4560583045355997`*^9, 
   3.4560583311492*^9}, 3.4560608957424*^9, 3.4560633196252003`*^9, {
   3.4560633776415997`*^9, 3.4560634071412*^9}, 3.4561405535134*^9, 
   3.4561415277958*^9, {3.4561415615386*^9, 3.4561415656726*^9}, 
   3.4564975861344*^9, 3.4566640955268946`*^9, 3.4567455941082945`*^9, 
   3.4568448423828945`*^9, 3.4569340506835747`*^9, 3.4571137347902*^9, 
   3.4571328921665745`*^9, 3.457176911434*^9, 3.4572239214785748`*^9, 
   3.457260914236*^9, 3.4573072916995745`*^9, 3.4575258651780825`*^9, 
   3.4595114205339313`*^9, {3.459513093958931*^9, 3.459513109521431*^9}, {
   3.459513175578931*^9, 3.459513222378931*^9}, {3.459513319521431*^9, 
   3.459513343637431*^9}, {3.4595135092549314`*^9, 3.459513568197431*^9}, {
   3.459513693682931*^9, 3.4595137027169313`*^9}, 3.4595138564084997`*^9, 
   3.4595139098885*^9, {3.4595141569435*^9, 3.459514242266*^9}, 
   3.459514339861*^9, {3.459514385146*^9, 3.459514391466*^9}, 
   3.4595144932635*^9, 3.4595147071584997`*^9, {3.4595157251045*^9, 
   3.4595157788195*^9}, 3.4595253820485*^9, 3.4595399397755594`*^9}],

Cell[BoxData["0.013259645077831955`"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560542148084*^9, 3.4560542286144*^9}, {3.4560542607036*^9, 
   3.4560542700480003`*^9}, {3.4560580235172*^9, 3.4560580338599997`*^9}, {
   3.4560581963964*^9, 3.4560582437736*^9}, {3.4560583045355997`*^9, 
   3.4560583311492*^9}, 3.4560608957424*^9, 3.4560633196252003`*^9, {
   3.4560633776415997`*^9, 3.4560634071412*^9}, 3.4561405535134*^9, 
   3.4561415277958*^9, {3.4561415615386*^9, 3.4561415656726*^9}, 
   3.4564975861344*^9, 3.4566640955268946`*^9, 3.4567455941082945`*^9, 
   3.4568448423828945`*^9, 3.4569340506835747`*^9, 3.4571137347902*^9, 
   3.4571328921665745`*^9, 3.457176911434*^9, 3.4572239214785748`*^9, 
   3.457260914236*^9, 3.4573072916995745`*^9, 3.4575258651780825`*^9, 
   3.4595114205339313`*^9, {3.459513093958931*^9, 3.459513109521431*^9}, {
   3.459513175578931*^9, 3.459513222378931*^9}, {3.459513319521431*^9, 
   3.459513343637431*^9}, {3.4595135092549314`*^9, 3.459513568197431*^9}, {
   3.459513693682931*^9, 3.4595137027169313`*^9}, 3.4595138564084997`*^9, 
   3.4595139098885*^9, {3.4595141569435*^9, 3.459514242266*^9}, 
   3.459514339861*^9, {3.459514385146*^9, 3.459514391466*^9}, 
   3.4595144932635*^9, 3.4595147071584997`*^9, {3.4595157251045*^9, 
   3.4595157788195*^9}, 3.4595253820485*^9, 3.4595399397775593`*^9}],

Cell[BoxData["0.006406347850900218`"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560542148084*^9, 3.4560542286144*^9}, {3.4560542607036*^9, 
   3.4560542700480003`*^9}, {3.4560580235172*^9, 3.4560580338599997`*^9}, {
   3.4560581963964*^9, 3.4560582437736*^9}, {3.4560583045355997`*^9, 
   3.4560583311492*^9}, 3.4560608957424*^9, 3.4560633196252003`*^9, {
   3.4560633776415997`*^9, 3.4560634071412*^9}, 3.4561405535134*^9, 
   3.4561415277958*^9, {3.4561415615386*^9, 3.4561415656726*^9}, 
   3.4564975861344*^9, 3.4566640955268946`*^9, 3.4567455941082945`*^9, 
   3.4568448423828945`*^9, 3.4569340506835747`*^9, 3.4571137347902*^9, 
   3.4571328921665745`*^9, 3.457176911434*^9, 3.4572239214785748`*^9, 
   3.457260914236*^9, 3.4573072916995745`*^9, 3.4575258651780825`*^9, 
   3.4595114205339313`*^9, {3.459513093958931*^9, 3.459513109521431*^9}, {
   3.459513175578931*^9, 3.459513222378931*^9}, {3.459513319521431*^9, 
   3.459513343637431*^9}, {3.4595135092549314`*^9, 3.459513568197431*^9}, {
   3.459513693682931*^9, 3.4595137027169313`*^9}, 3.4595138564084997`*^9, 
   3.4595139098885*^9, {3.4595141569435*^9, 3.459514242266*^9}, 
   3.459514339861*^9, {3.459514385146*^9, 3.459514391466*^9}, 
   3.4595144932635*^9, 3.4595147071584997`*^9, {3.4595157251045*^9, 
   3.4595157788195*^9}, 3.4595253820485*^9, 3.4595399398195596`*^9}],

Cell[BoxData["0.02993449149926799`"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560542148084*^9, 3.4560542286144*^9}, {3.4560542607036*^9, 
   3.4560542700480003`*^9}, {3.4560580235172*^9, 3.4560580338599997`*^9}, {
   3.4560581963964*^9, 3.4560582437736*^9}, {3.4560583045355997`*^9, 
   3.4560583311492*^9}, 3.4560608957424*^9, 3.4560633196252003`*^9, {
   3.4560633776415997`*^9, 3.4560634071412*^9}, 3.4561405535134*^9, 
   3.4561415277958*^9, {3.4561415615386*^9, 3.4561415656726*^9}, 
   3.4564975861344*^9, 3.4566640955268946`*^9, 3.4567455941082945`*^9, 
   3.4568448423828945`*^9, 3.4569340506835747`*^9, 3.4571137347902*^9, 
   3.4571328921665745`*^9, 3.457176911434*^9, 3.4572239214785748`*^9, 
   3.457260914236*^9, 3.4573072916995745`*^9, 3.4575258651780825`*^9, 
   3.4595114205339313`*^9, {3.459513093958931*^9, 3.459513109521431*^9}, {
   3.459513175578931*^9, 3.459513222378931*^9}, {3.459513319521431*^9, 
   3.459513343637431*^9}, {3.4595135092549314`*^9, 3.459513568197431*^9}, {
   3.459513693682931*^9, 3.4595137027169313`*^9}, 3.4595138564084997`*^9, 
   3.4595139098885*^9, {3.4595141569435*^9, 3.459514242266*^9}, 
   3.459514339861*^9, {3.459514385146*^9, 3.459514391466*^9}, 
   3.4595144932635*^9, 3.4595147071584997`*^9, {3.4595157251045*^9, 
   3.4595157788195*^9}, 3.4595253820485*^9, 3.45953993982156*^9}],

Cell[BoxData["17.446901418201854`"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560542148084*^9, 3.4560542286144*^9}, {3.4560542607036*^9, 
   3.4560542700480003`*^9}, {3.4560580235172*^9, 3.4560580338599997`*^9}, {
   3.4560581963964*^9, 3.4560582437736*^9}, {3.4560583045355997`*^9, 
   3.4560583311492*^9}, 3.4560608957424*^9, 3.4560633196252003`*^9, {
   3.4560633776415997`*^9, 3.4560634071412*^9}, 3.4561405535134*^9, 
   3.4561415277958*^9, {3.4561415615386*^9, 3.4561415656726*^9}, 
   3.4564975861344*^9, 3.4566640955268946`*^9, 3.4567455941082945`*^9, 
   3.4568448423828945`*^9, 3.4569340506835747`*^9, 3.4571137347902*^9, 
   3.4571328921665745`*^9, 3.457176911434*^9, 3.4572239214785748`*^9, 
   3.457260914236*^9, 3.4573072916995745`*^9, 3.4575258651780825`*^9, 
   3.4595114205339313`*^9, {3.459513093958931*^9, 3.459513109521431*^9}, {
   3.459513175578931*^9, 3.459513222378931*^9}, {3.459513319521431*^9, 
   3.459513343637431*^9}, {3.4595135092549314`*^9, 3.459513568197431*^9}, {
   3.459513693682931*^9, 3.4595137027169313`*^9}, 3.4595138564084997`*^9, 
   3.4595139098885*^9, {3.4595141569435*^9, 3.459514242266*^9}, 
   3.459514339861*^9, {3.459514385146*^9, 3.459514391466*^9}, 
   3.4595144932635*^9, 3.4595147071584997`*^9, {3.4595157251045*^9, 
   3.4595157788195*^9}, 3.4595253820485*^9, 3.4595399398225594`*^9}],

Cell[BoxData["0.8723450709100927`"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560542148084*^9, 3.4560542286144*^9}, {3.4560542607036*^9, 
   3.4560542700480003`*^9}, {3.4560580235172*^9, 3.4560580338599997`*^9}, {
   3.4560581963964*^9, 3.4560582437736*^9}, {3.4560583045355997`*^9, 
   3.4560583311492*^9}, 3.4560608957424*^9, 3.4560633196252003`*^9, {
   3.4560633776415997`*^9, 3.4560634071412*^9}, 3.4561405535134*^9, 
   3.4561415277958*^9, {3.4561415615386*^9, 3.4561415656726*^9}, 
   3.4564975861344*^9, 3.4566640955268946`*^9, 3.4567455941082945`*^9, 
   3.4568448423828945`*^9, 3.4569340506835747`*^9, 3.4571137347902*^9, 
   3.4571328921665745`*^9, 3.457176911434*^9, 3.4572239214785748`*^9, 
   3.457260914236*^9, 3.4573072916995745`*^9, 3.4575258651780825`*^9, 
   3.4595114205339313`*^9, {3.459513093958931*^9, 3.459513109521431*^9}, {
   3.459513175578931*^9, 3.459513222378931*^9}, {3.459513319521431*^9, 
   3.459513343637431*^9}, {3.4595135092549314`*^9, 3.459513568197431*^9}, {
   3.459513693682931*^9, 3.4595137027169313`*^9}, 3.4595138564084997`*^9, 
   3.4595139098885*^9, {3.4595141569435*^9, 3.459514242266*^9}, 
   3.459514339861*^9, {3.459514385146*^9, 3.459514391466*^9}, 
   3.4595144932635*^9, 3.4595147071584997`*^9, {3.4595157251045*^9, 
   3.4595157788195*^9}, 3.4595253820485*^9, 3.4595399398245597`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"greenSHG", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"F", "\[Rule]", 
     FractionBox[
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{"r1", " ", "r2"}]]}], 
      RowBox[{"1", "-", 
       RowBox[{"r1", " ", "r2"}]}]]}], ",", 
    RowBox[{"t1", "\[Rule]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["r1", "2"]}]]}], ",", 
    RowBox[{"t2", "\[Rule]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["r2", "2"]}]]}], ",", 
    RowBox[{"r2", "\[Rule]", 
     SqrtBox["0.9992"]}], ",", 
    RowBox[{"r1", "\[Rule]", 
     SqrtBox["0.01"]}], ",", 
    RowBox[{"k", "\[Rule]", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], "lambda"]}], ",", 
    RowBox[{"c", "\[Rule]", "2.99793*^8"}], ",", 
    RowBox[{"lambda", "\[Rule]", "1.064*^-6"}], ",", 
    RowBox[{"FSR", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", "L"}]]}], ",", 
    RowBox[{"fcav", "\[Rule]", 
     FractionBox["FSR", 
      RowBox[{"2", " ", "F"}]]}], ",", 
    RowBox[{
     RowBox[{"L", "\[Rule]", 
      RowBox[{
       FractionBox["94.7*^-3", "2"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"nPPKTP", "-", "1"}], ")"}], "10*^-3"}]}]}], "/.", 
     RowBox[{"nPPKTP", "\[Rule]", "1.779"}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"F", "//.", "greenSHG"}], "\[IndentingNewLine]", 
 RowBox[{"FSR", "//.", "greenSHG"}], "\[IndentingNewLine]", 
 RowBox[{"fcav", "//.", "greenSHG"}]}], "Input",
 CellChangeTimes->{{3.4559904928154*^9, 3.4559905326577997`*^9}, {
  3.4559925506280003`*^9, 3.4559925508464003`*^9}, {3.4559925819528*^9, 
  3.4559926153368*^9}, {3.45599265234*^9, 3.4559926560528*^9}, {
  3.455993685216*^9, 3.4559937006288*^9}, {3.4559937977855997`*^9, 
  3.4559938110299997`*^9}, {3.4560540182952003`*^9, 3.4560540454236*^9}, {
  3.4560540863112*^9, 3.4560541184472*^9}, {3.4560545056548*^9, 
  3.4560545194296*^9}, {3.4561405780522003`*^9, 3.4561406040886*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"F", "\[Rule]", 
    FractionBox[
     RowBox[{"\[Pi]", " ", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}], 
     RowBox[{"1", "-", 
      RowBox[{"r1", " ", "r2"}]}]]}], ",", 
   RowBox[{"t1", "\[Rule]", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r1", "2"]}]]}], ",", 
   RowBox[{"t2", "\[Rule]", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r2", "2"]}]]}], ",", 
   RowBox[{"r2", "\[Rule]", "0.999599919967984`"}], ",", 
   RowBox[{"r1", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"k", "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", "\[Pi]"}], "lambda"]}], ",", 
   RowBox[{"c", "\[Rule]", "2.99793`*^8"}], ",", 
   RowBox[{"lambda", "\[Rule]", "1.064`*^-6"}], ",", 
   RowBox[{"FSR", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "L"}]]}], ",", 
   RowBox[{"fcav", "\[Rule]", 
    FractionBox["FSR", 
     RowBox[{"2", " ", "F"}]]}], ",", 
   RowBox[{"L", "\[Rule]", "0.05514`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560540907883997`*^9, 3.4560541188059998`*^9}, {3.4560545159196*^9, 
   3.4560545202564*^9}, 3.4561406057265997`*^9, 3.4561415279206*^9, 
   3.4564975862592*^9, 3.4566640956984944`*^9, 3.4567455942862945`*^9, 
   3.4568448425544944`*^9, 3.456934050884575*^9, 3.4571137348213997`*^9, 
   3.4571328923715744`*^9, 3.45717691159*^9, 3.4572239217485743`*^9, 
   3.457260914392*^9, 3.4573072918835745`*^9, 3.457525865382082*^9, 
   3.4595253824309998`*^9, 3.45953993986156*^9}],

Cell[BoxData["1.1035732482409817`"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560540907883997`*^9, 3.4560541188059998`*^9}, {3.4560545159196*^9, 
   3.4560545202564*^9}, 3.4561406057265997`*^9, 3.4561415279206*^9, 
   3.4564975862592*^9, 3.4566640956984944`*^9, 3.4567455942862945`*^9, 
   3.4568448425544944`*^9, 3.456934050884575*^9, 3.4571137348213997`*^9, 
   3.4571328923715744`*^9, 3.45717691159*^9, 3.4572239217485743`*^9, 
   3.457260914392*^9, 3.4573072918835745`*^9, 3.457525865382082*^9, 
   3.4595253824309998`*^9, 3.4595399398815594`*^9}],

Cell[BoxData["2.7184711643090315`*^9"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560540907883997`*^9, 3.4560541188059998`*^9}, {3.4560545159196*^9, 
   3.4560545202564*^9}, 3.4561406057265997`*^9, 3.4561415279206*^9, 
   3.4564975862592*^9, 3.4566640956984944`*^9, 3.4567455942862945`*^9, 
   3.4568448425544944`*^9, 3.456934050884575*^9, 3.4571137348213997`*^9, 
   3.4571328923715744`*^9, 3.45717691159*^9, 3.4572239217485743`*^9, 
   3.457260914392*^9, 3.4573072918835745`*^9, 3.457525865382082*^9, 
   3.4595253824309998`*^9, 3.4595399399125595`*^9}],

Cell[BoxData["1.2316677522955925`*^9"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.45599370144*^9, {
   3.4559937874272003`*^9, 3.4559938115448*^9}, 3.4560540241296*^9, {
   3.4560540907883997`*^9, 3.4560541188059998`*^9}, {3.4560545159196*^9, 
   3.4560545202564*^9}, 3.4561406057265997`*^9, 3.4561415279206*^9, 
   3.4564975862592*^9, 3.4566640956984944`*^9, 3.4567455942862945`*^9, 
   3.4568448425544944`*^9, 3.456934050884575*^9, 3.4571137348213997`*^9, 
   3.4571328923715744`*^9, 3.45717691159*^9, 3.4572239217485743`*^9, 
   3.457260914392*^9, 3.4573072918835745`*^9, 3.457525865382082*^9, 
   3.4595253824309998`*^9, 3.4595399399425597`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["OPO", "Subsection",
 CellChangeTimes->{{3.4560546407195997`*^9, 3.45605465373*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"greenOPO", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"F", "\[Rule]", 
     FractionBox[
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{"r1", " ", "r2"}]]}], 
      RowBox[{"1", "-", 
       RowBox[{"r1", " ", "r2"}]}]]}], ",", 
    RowBox[{"t1", "\[Rule]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["r1", "2"]}]]}], ",", 
    RowBox[{"t2", "\[Rule]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["r2", "2"]}]]}], ",", 
    RowBox[{"r2", "\[Rule]", 
     SqrtBox["1"]}], ",", 
    RowBox[{"r1", "\[Rule]", 
     SqrtBox["0.7"]}], ",", 
    RowBox[{"k", "\[Rule]", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], "lambda"]}], ",", 
    RowBox[{"c", "\[Rule]", "2.99793*^8"}], ",", 
    RowBox[{"lambda", "\[Rule]", 
     FractionBox["1.064*^-6", "2"]}], ",", 
    RowBox[{"FSR", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", "L"}]]}], ",", 
    RowBox[{"fcav", "\[Rule]", 
     FractionBox["FSR", 
      RowBox[{"2", " ", "F"}]]}], ",", 
    RowBox[{"L", "\[Rule]", "0.14"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"F", "//.", "greenOPO"}], "\[IndentingNewLine]", 
 RowBox[{"FSR", "//.", "greenOPO"}], "\[IndentingNewLine]", 
 RowBox[{"fcav", "//.", "greenOPO"}]}], "Input",
 CellChangeTimes->{{3.4559904928154*^9, 3.4559905326577997`*^9}, {
  3.4559925506280003`*^9, 3.4559925508464003`*^9}, {3.4559925819528*^9, 
  3.4559926791408*^9}, {3.4560545314728003`*^9, 3.4560545545296*^9}, {
  3.4560547774068003`*^9, 3.4560547781088*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"F", "\[Rule]", 
    FractionBox[
     RowBox[{"\[Pi]", " ", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}], 
     RowBox[{"1", "-", 
      RowBox[{"r1", " ", "r2"}]}]]}], ",", 
   RowBox[{"t1", "\[Rule]", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r1", "2"]}]]}], ",", 
   RowBox[{"t2", "\[Rule]", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r2", "2"]}]]}], ",", 
   RowBox[{"r2", "\[Rule]", "1"}], ",", 
   RowBox[{"r1", "\[Rule]", "0.8366600265340756`"}], ",", 
   RowBox[{"k", "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", "\[Pi]"}], "lambda"]}], ",", 
   RowBox[{"c", "\[Rule]", "2.99793`*^8"}], ",", 
   RowBox[{"lambda", "\[Rule]", "5.32`*^-7"}], ",", 
   RowBox[{"FSR", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "L"}]]}], ",", 
   RowBox[{"fcav", "\[Rule]", 
    FractionBox["FSR", 
     RowBox[{"2", " ", "F"}]]}], ",", 
   RowBox[{"L", "\[Rule]", "0.14`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4559926659432*^9, 3.4559926799364*^9}, 
   3.4560547791851997`*^9, 3.4561415280142*^9, 3.4564975863528*^9, 
   3.4566640958388944`*^9, 3.4567455944042945`*^9, 3.4568448426948943`*^9, 
   3.4569340510715747`*^9, 3.4571137348526*^9, 3.4571328925545745`*^9, 
   3.4571769117460003`*^9, 3.457223921969575*^9, 3.4572609145480003`*^9, 
   3.4573072920535746`*^9, 3.4575258655720825`*^9, 3.4595253827735*^9, 
   3.4595399399775596`*^9}],

Cell[BoxData["17.592675899579707`"], "Output",
 CellChangeTimes->{{3.4559926659432*^9, 3.4559926799364*^9}, 
   3.4560547791851997`*^9, 3.4561415280142*^9, 3.4564975863528*^9, 
   3.4566640958388944`*^9, 3.4567455944042945`*^9, 3.4568448426948943`*^9, 
   3.4569340510715747`*^9, 3.4571137348526*^9, 3.4571328925545745`*^9, 
   3.4571769117460003`*^9, 3.457223921969575*^9, 3.4572609145480003`*^9, 
   3.4573072920535746`*^9, 3.4575258655720825`*^9, 3.4595253827735*^9, 
   3.4595399400035596`*^9}],

Cell[BoxData["1.0706892857142856`*^9"], "Output",
 CellChangeTimes->{{3.4559926659432*^9, 3.4559926799364*^9}, 
   3.4560547791851997`*^9, 3.4561415280142*^9, 3.4564975863528*^9, 
   3.4566640958388944`*^9, 3.4567455944042945`*^9, 3.4568448426948943`*^9, 
   3.4569340510715747`*^9, 3.4571137348526*^9, 3.4571328925545745`*^9, 
   3.4571769117460003`*^9, 3.457223921969575*^9, 3.4572609145480003`*^9, 
   3.4573072920535746`*^9, 3.4575258655720825`*^9, 3.4595253827735*^9, 
   3.4595399400325594`*^9}],

Cell[BoxData["3.0429972444949795`*^7"], "Output",
 CellChangeTimes->{{3.4559926659432*^9, 3.4559926799364*^9}, 
   3.4560547791851997`*^9, 3.4561415280142*^9, 3.4564975863528*^9, 
   3.4566640958388944`*^9, 3.4567455944042945`*^9, 3.4568448426948943`*^9, 
   3.4569340510715747`*^9, 3.4571137348526*^9, 3.4571328925545745`*^9, 
   3.4571769117460003`*^9, 3.457223921969575*^9, 3.4572609145480003`*^9, 
   3.4573072920535746`*^9, 3.4575258655720825`*^9, 3.4595253827735*^9, 
   3.45953994005956*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"redOPO", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"F", "\[Rule]", 
     FractionBox[
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{"r1", " ", "r2"}]]}], 
      RowBox[{"1", "-", 
       RowBox[{"r1", " ", "r2"}]}]]}], ",", 
    RowBox[{"t1", "\[Rule]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["r1", "2"]}]]}], ",", 
    RowBox[{"t2", "\[Rule]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["r2", "2"]}]]}], ",", 
    RowBox[{"r2", "\[Rule]", 
     SqrtBox["0.85"]}], ",", 
    RowBox[{"r1", "\[Rule]", 
     SqrtBox["0.99"]}], ",", 
    RowBox[{"k", "\[Rule]", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], "lambda"]}], ",", 
    RowBox[{"c", "\[Rule]", "2.99793*^8"}], ",", 
    RowBox[{"lambda", "\[Rule]", "1.064*^-6"}], ",", 
    RowBox[{"FSR", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", "L"}]]}], ",", 
    RowBox[{"fcav", "\[Rule]", 
     FractionBox["FSR", 
      RowBox[{"2", " ", "F"}]]}], ",", 
    RowBox[{"L", "\[Rule]", "0.14"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"F", "//.", "redOPO"}], "\[IndentingNewLine]", 
 RowBox[{"FSR", "//.", "redOPO"}], "\[IndentingNewLine]", 
 RowBox[{"fcav", "//.", "redOPO"}]}], "Input",
 CellChangeTimes->{{3.4559904928154*^9, 3.4559905326577997`*^9}, {
   3.4559925506280003`*^9, 3.4559925508464003`*^9}, {3.4559925819528*^9, 
   3.4559926153368*^9}, {3.45599265234*^9, 3.4559926560528*^9}, {
   3.4560545427827997`*^9, 3.4560545495064*^9}, 3.4560547935372*^9, {
   3.4595313312105*^9, 3.459531354758*^9}, {3.459531423583*^9, 
   3.4595314305155*^9}, {3.459531481543*^9, 3.4595314853055*^9}, 
   3.459531990498*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"F", "\[Rule]", 
    FractionBox[
     RowBox[{"\[Pi]", " ", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}], 
     RowBox[{"1", "-", 
      RowBox[{"r1", " ", "r2"}]}]]}], ",", 
   RowBox[{"t1", "\[Rule]", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r1", "2"]}]]}], ",", 
   RowBox[{"t2", "\[Rule]", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r2", "2"]}]]}], ",", 
   RowBox[{"r2", "\[Rule]", "0.9219544457292888`"}], ",", 
   RowBox[{"r1", "\[Rule]", "0.99498743710662`"}], ",", 
   RowBox[{"k", "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", "\[Pi]"}], "lambda"]}], ",", 
   RowBox[{"c", "\[Rule]", "2.99793`*^8"}], ",", 
   RowBox[{"lambda", "\[Rule]", "1.064`*^-6"}], ",", 
   RowBox[{"FSR", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "L"}]]}], ",", 
   RowBox[{"fcav", "\[Rule]", 
    FractionBox["FSR", 
     RowBox[{"2", " ", "F"}]]}], ",", 
   RowBox[{"L", "\[Rule]", "0.14`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.4560547945512*^9, 
   3.4561415281858*^9, 3.456497586462*^9, 3.4566640959636946`*^9, 
   3.456745594541294*^9, 3.4568448428352947`*^9, 3.4569340512715745`*^9, 
   3.457113734993*^9, 3.4571328927275743`*^9, 3.4571769118864*^9, 
   3.4572239221715746`*^9, 3.4572609146884003`*^9, 3.4573072922105746`*^9, 
   3.457525865752082*^9, 3.4595253829635*^9, 3.459531331743*^9, 
   3.4595314310905*^9, 3.4595314858205*^9, 3.4595319910305*^9, 
   3.4595399400955596`*^9}],

Cell[BoxData["36.39835060551217`"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.4560547945512*^9, 
   3.4561415281858*^9, 3.456497586462*^9, 3.4566640959636946`*^9, 
   3.456745594541294*^9, 3.4568448428352947`*^9, 3.4569340512715745`*^9, 
   3.457113734993*^9, 3.4571328927275743`*^9, 3.4571769118864*^9, 
   3.4572239221715746`*^9, 3.4572609146884003`*^9, 3.4573072922105746`*^9, 
   3.457525865752082*^9, 3.4595253829635*^9, 3.459531331743*^9, 
   3.4595314310905*^9, 3.4595314858205*^9, 3.4595319910305*^9, 
   3.4595399401215596`*^9}],

Cell[BoxData["1.0706892857142856`*^9"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.4560547945512*^9, 
   3.4561415281858*^9, 3.456497586462*^9, 3.4566640959636946`*^9, 
   3.456745594541294*^9, 3.4568448428352947`*^9, 3.4569340512715745`*^9, 
   3.457113734993*^9, 3.4571328927275743`*^9, 3.4571769118864*^9, 
   3.4572239221715746`*^9, 3.4572609146884003`*^9, 3.4573072922105746`*^9, 
   3.457525865752082*^9, 3.4595253829635*^9, 3.459531331743*^9, 
   3.4595314310905*^9, 3.4595314858205*^9, 3.4595319910305*^9, 
   3.4595399401465597`*^9}],

Cell[BoxData["1.4707936869426997`*^7"], "Output",
 CellChangeTimes->{{3.4559905050302*^9, 3.4559905329698*^9}, {
   3.4559925521256*^9, 3.4559925829667997`*^9}, 3.4559926220292*^9, 
   3.4559926565832*^9, 3.4559926905912*^9, 3.4560547945512*^9, 
   3.4561415281858*^9, 3.456497586462*^9, 3.4566640959636946`*^9, 
   3.456745594541294*^9, 3.4568448428352947`*^9, 3.4569340512715745`*^9, 
   3.457113734993*^9, 3.4571328927275743`*^9, 3.4571769118864*^9, 
   3.4572239221715746`*^9, 3.4572609146884003`*^9, 3.4573072922105746`*^9, 
   3.457525865752082*^9, 3.4595253829635*^9, 3.459531331743*^9, 
   3.4595314310905*^9, 3.4595314858205*^9, 3.4595319910305*^9, 
   3.45953994017056*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Non-Linear Conversion", "Subsection",
 CellChangeTimes->{{3.4595260158335*^9, 3.459526029516*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Print", "[", 
  "\"\<\!\(\*SubscriptBox[\(\[Eta]\), \(TRANS, aux\)]\):\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Eta]", 
   RowBox[{"TRANS", ",", "aux"}]], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Abs", "[", 
     FractionBox[
      RowBox[{"t1", " ", "t2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
         RowBox[{"fAux", " ", "/", "FSR"}]}]], "-", " ", 
       RowBox[{"r1", " ", "r2"}]}]], "]"}], "/.", 
    RowBox[{"fAux", "\[Rule]", "29.507*^6"}]}], "//.", 
   "redOPO"}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<\!\(\*SubscriptBox[\(\[Eta]\), \(TRANS, aux2\)]\):\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"cavg", "=", 
  RowBox[{
   FractionBox["t1", 
    RowBox[{"1", "-", 
     RowBox[{"r1", " ", "r2"}]}]], "//.", 
   "greenOPO"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"t1", " ", "t2"}], 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", "r1", " ", "r2", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", "\[Pi]", " ", 
        RowBox[{"fAux", " ", "/", "FSR"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["r1", "2"], 
      SuperscriptBox["r2", "2"]}]}]], "/.", 
   RowBox[{"fAux", "\[Rule]", "29.507*^6"}]}], "//.", 
  "redOPO"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Eta]", 
   RowBox[{"TRANS", ",", "aux2"}]], "=", 
  RowBox[{"\[Xi]", "%", " ", "cavg"}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<\[Alpha]:\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]", "[", "\[Xi]_", "]"}], "=", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[Eta]", 
     RowBox[{"TRANS", ",", "aux"}]], "-", 
    SubscriptBox["\[Eta]", 
     RowBox[{"TRANS", ",", "aux2"}]]}], 
   RowBox[{
    SubscriptBox["\[Eta]", 
     RowBox[{"TRANS", ",", "aux"}]], "+", 
    SubscriptBox["\[Eta]", 
     RowBox[{"TRANS", ",", "aux2"}]]}]]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Alpha]", "[", "\[Xi]", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Xi]", ",", "0", ",", "0.1"}], "}"}], ",", 
   RowBox[{"Evaluate", "[", "popt", "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"sol", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Alpha]", "[", "\[Xi]", "]"}], "==", 
      FractionBox["1", "3"]}], ",", "\[Xi]"}], "]"}], "\[LeftDoubleBracket]", 
   "1", "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<\!\(\*SubscriptBox[\(\[Eta]\), \(REFL, aux\)]\):\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Eta]", 
   RowBox[{"REFL", ",", "aux"}]], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Abs", "[", 
     FractionBox[
      RowBox[{"r2", "-", 
       RowBox[{"r1", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "2"}], "\[Pi]", " ", "\[ImaginaryI]", " ", 
          RowBox[{"fAux", " ", "/", "FSR"}]}]]}]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2"}], "\[Pi]", " ", "\[ImaginaryI]", " ", 
         RowBox[{"fAux", " ", "/", "FSR"}]}]], "-", 
       RowBox[{"r1", " ", "r2"}]}]], "]"}], "/.", 
    RowBox[{"fAux", "\[Rule]", "29.507*^6"}]}], "//.", 
   "redOPO"}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  "\"\<\!\(\*SubscriptBox[\(\[Eta]\), \(REFL, aux2\)]\):\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Eta]", 
   RowBox[{"REFL", ",", "aux2"}]], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Xi]", "  ", 
     FractionBox[
      SuperscriptBox["t1", "2"], 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "r1", " ", "r2", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", "\[Pi]", " ", 
          RowBox[{"fAux", " ", "/", "FSR"}]}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["r1", "2"], 
        SuperscriptBox["r2", "2"]}]}]], "cavg"}], "/.", 
    RowBox[{"fAux", "\[Rule]", "29.507*^6"}]}], "//.", 
   "redOPO"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", "sol"}]}], "Input",
 CellChangeTimes->{{3.4595254274484997`*^9, 3.4595255091335*^9}, {
   3.459525595461*^9, 3.4595256773485003`*^9}, {3.459525771941*^9, 
   3.459525996986*^9}, 3.4595260708835*^9, {3.459526111461*^9, 
   3.4595261612135*^9}, 3.4595262070535*^9, {3.4595285956445*^9, 
   3.4595286566345*^9}, {3.459528702717*^9, 3.4595287034995003`*^9}, {
   3.4595293656195*^9, 3.4595293857395*^9}, {3.459529444112*^9, 
   3.459529450352*^9}, {3.4595294842320004`*^9, 3.4595296245095*^9}, {
   3.4595297043269997`*^9, 3.459529704527*^9}, {3.459529738492*^9, 
   3.459529834587*^9}, {3.4595298705594997`*^9, 3.4595299040095*^9}, {
   3.4595399953565598`*^9, 3.4595400312525597`*^9}, {3.4595402707915597`*^9, 
   3.45954028182156*^9}}],

Cell[BoxData["\<\"\\!\\(\\*SubscriptBox[\\(\[Eta]\\), \\(TRANS, aux\\)]\\):\"\
\>"], "Print",
 CellChangeTimes->{{3.459529782927*^9, 3.4595297951070004`*^9}, 
   3.4595298350220003`*^9, {3.459529875237*^9, 3.4595299044195004`*^9}, 
   3.4595313380705*^9, 3.4595314358780003`*^9, 3.4595314918855*^9, 
   3.45953994020356*^9, {3.45954001026956*^9, 3.45954003278156*^9}, 
   3.45954028250756*^9}],

Cell[BoxData["0.20921278185045486`"], "Output",
 CellChangeTimes->{{3.4595261858785*^9, 3.459526207421*^9}, 
   3.4595286574744997`*^9, 3.4595287038970003`*^9, {3.4595293672095003`*^9, 
   3.4595293922095003`*^9}, {3.4595294450645*^9, 3.459529450807*^9}, {
   3.459529560627*^9, 3.459529572887*^9}, 3.4595296251945*^9, {
   3.459529705422*^9, 3.459529795087*^9}, 3.4595298350245*^9, {
   3.4595298752395*^9, 3.4595299044195004`*^9}, 3.459531338073*^9, 
   3.4595314358805*^9, 3.459531491888*^9, 3.4595399402185593`*^9, {
   3.4595400102715597`*^9, 3.45954003278356*^9}, 3.4595402825095596`*^9}],

Cell[BoxData["\<\"\\!\\(\\*SubscriptBox[\\(\[Eta]\\), \\(TRANS, \
aux2\\)]\\):\"\>"], "Print",
 CellChangeTimes->{{3.459529782927*^9, 3.4595297951070004`*^9}, 
   3.4595298350220003`*^9, {3.459529875237*^9, 3.4595299044195004`*^9}, 
   3.4595313380705*^9, 3.4595314358780003`*^9, 3.4595314918855*^9, 
   3.45953994020356*^9, {3.45954001026956*^9, 3.45954003278156*^9}, 
   3.4595402825105596`*^9}],

Cell[BoxData["3.353267090002501`"], "Output",
 CellChangeTimes->{{3.4595261858785*^9, 3.459526207421*^9}, 
   3.4595286574744997`*^9, 3.4595287038970003`*^9, {3.4595293672095003`*^9, 
   3.4595293922095003`*^9}, {3.4595294450645*^9, 3.459529450807*^9}, {
   3.459529560627*^9, 3.459529572887*^9}, 3.4595296251945*^9, {
   3.459529705422*^9, 3.459529795087*^9}, 3.4595298350245*^9, {
   3.4595298752395*^9, 3.4595299044195004`*^9}, 3.459531338073*^9, 
   3.4595314358805*^9, 3.459531491888*^9, 3.4595399402185593`*^9, {
   3.4595400102715597`*^9, 3.45954003278356*^9}, 3.4595402825115595`*^9}],

Cell[BoxData["1.130136232898286`"], "Output",
 CellChangeTimes->{{3.4595261858785*^9, 3.459526207421*^9}, 
   3.4595286574744997`*^9, 3.4595287038970003`*^9, {3.4595293672095003`*^9, 
   3.4595293922095003`*^9}, {3.4595294450645*^9, 3.459529450807*^9}, {
   3.459529560627*^9, 3.459529572887*^9}, 3.4595296251945*^9, {
   3.459529705422*^9, 3.459529795087*^9}, 3.4595298350245*^9, {
   3.4595298752395*^9, 3.4595299044195004`*^9}, 3.459531338073*^9, 
   3.4595314358805*^9, 3.459531491888*^9, 3.4595399402185593`*^9, {
   3.4595400102715597`*^9, 3.45954003278356*^9}, 3.4595402825135593`*^9}],

Cell[BoxData[
 RowBox[{"3.789648636997224`", " ", "\[Xi]"}]], "Output",
 CellChangeTimes->{{3.4595261858785*^9, 3.459526207421*^9}, 
   3.4595286574744997`*^9, 3.4595287038970003`*^9, {3.4595293672095003`*^9, 
   3.4595293922095003`*^9}, {3.4595294450645*^9, 3.459529450807*^9}, {
   3.459529560627*^9, 3.459529572887*^9}, 3.4595296251945*^9, {
   3.459529705422*^9, 3.459529795087*^9}, 3.4595298350245*^9, {
   3.4595298752395*^9, 3.4595299044195004`*^9}, 3.459531338073*^9, 
   3.4595314358805*^9, 3.459531491888*^9, 3.4595399402185593`*^9, {
   3.4595400102715597`*^9, 3.45954003278356*^9}, 3.4595402825145597`*^9}],

Cell[BoxData["\<\"\[Alpha]:\"\>"], "Print",
 CellChangeTimes->{{3.459529782927*^9, 3.4595297951070004`*^9}, 
   3.4595298350220003`*^9, {3.459529875237*^9, 3.4595299044195004`*^9}, 
   3.4595313380705*^9, 3.4595314358780003`*^9, 3.4595314918855*^9, 
   3.45953994020356*^9, {3.45954001026956*^9, 3.45954003278156*^9}, 
   3.4595402825155597`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"0.20921278185045486`", "\[InvisibleSpace]", "-", 
   RowBox[{"3.789648636997224`", " ", "\[Xi]"}]}], 
  RowBox[{"0.20921278185045486`", "\[InvisibleSpace]", "+", 
   RowBox[{"3.789648636997224`", " ", "\[Xi]"}]}]]], "Output",
 CellChangeTimes->{{3.4595261858785*^9, 3.459526207421*^9}, 
   3.4595286574744997`*^9, 3.4595287038970003`*^9, {3.4595293672095003`*^9, 
   3.4595293922095003`*^9}, {3.4595294450645*^9, 3.459529450807*^9}, {
   3.459529560627*^9, 3.459529572887*^9}, 3.4595296251945*^9, {
   3.459529705422*^9, 3.459529795087*^9}, 3.4595298350245*^9, {
   3.4595298752395*^9, 3.4595299044195004`*^9}, 3.459531338073*^9, 
   3.4595314358805*^9, 3.459531491888*^9, 3.4595399402185593`*^9, {
   3.4595400102715597`*^9, 3.45954003278356*^9}, 3.4595402825165596`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVjn8803kcx1HpiqRafgxdisvl6jzo6Jx6R3KiKERJGXIuj8LOaNcZc9W1
DrVlVGN15ldJu00zfdxDH+zUWc3su5JfacqvSLv1g35tzv3xejz/eP7xfDnG
p4YlmhgZGe2c3f8UjCOa4rTj5iXckO6ZGS0kmyxvriMZgV6z1Xh0SgtTNsdF
50iWcJQyijsnteBTUeuSTVoJRV7E++t9WnjyvO1QBskNnF/97pvboAVxPmFC
JW0BrfKrdVWpWiAPdKtSSLsgKOqbD6rBl9BhGoOOkihADzzPPKaYBNLgzn0F
LWlQSaVzREUTQHUveTZvmA4vRh9cWVX9HFbQ8iaVqUzILZaH0jSj8IEaN1Mr
OwkLDOaJz5aMgPBLC5sSBQuWMoSlCVlDEDVXHWC7vgACsqfxvwNPoYRlbUVq
YgPN4aDBIm4QpifczJ1un4emMlZOtqUGOiiRi7LGubAzfuwNNeUxcNxHOf26
YpCl1UoHzPogjS+jztNehJZ302w10Q1y29qYTOsSsL/+y/75rC6wfD0j15L5
MIUWLnPNeQCqx7H+4u1XIHP/Zt+CRAIeiU7lOzT8AW+vju13Su0EH0fOrRFp
GYRS2u3iYhVwgLdqPPy+ANx1hUUNuB3ethw+sE1ZDhN+EwcvnrgDwa88u3pH
K2BFeAgbuchgvfZaVsTHSnCI9eHqjJvhNx5xKOxTFbiK83puxDZCaUhu2Jul
V8GDm5iVzpSAi3g4l2x9DZ5+v2WIRxeCn0Y74GRVA5KHf3k7nq4AWxumr3rt
dRjK6arZFsSFJEPb8Lx1tRCdLL8zZBkN6ZOcc/3+N8CLerb7SB8Hm1+bk3Qh
SgiXCZPqsdUCTF7myuyK+hNKKZxN4yk1+LXfEWW/pwj0CtaLz86JMVfNz2Hf
EsHkgP+x+J/rcVaQIEDqJYZWd51zvhvCsrbDlsIWMaSn+Divtm7C22zMPyb5
1UF9nvHN1JBm7JxKHXutqAPXEepI1ZpWvIUvnvLddRPmR7Ra8tQyLBD/bWfS
eRPKgyrsJMltOEHO28qNlkBgMGPjtNVdHNsYnD/WJ4HFp5aFS3n/4EYhfmTx
Yz2wN2zwoLnLccwZU+9qXT24LzFrRdJ7+NvvXJqMf5JCxt6VyjIrBabpzLeu
10vB3/CQkXmmA49n339un9MALcy78TM9Slz96mA1w9AAc0L4pqUFnViWLEkS
sW7Bmj0cbzcvFSY3DgVWLkDgYWsge6pUWM+YSx42QzCpX93br1Zhja/ThJMF
gsyw2OATXSpc1Z5QULEUQbg22F/Zp8IePU9V5XYIfpWncxJGVHjHO020YB0C
Zl5NBeOjCjM8Hx+5shvBRBndjO5MYMqHT5uehM96qsWa5S4E9r9tv/jzSAS5
pnFT4rUEXhgQI74cjcBQliYa/5rAxXv63vITELgOVhbu9SawkNaTXZqBYPuT
ZscvQgnM2fg+tP8YAl77xpzbuwlM+2TjaH989m+1DycygsDeJ/fKSrIRFArs
1Kf2Efhu4aP5JacRREj4Sk0CgWuiprt7zyDIOtpPZP5A4LN21jXkfAT6C4vy
zA8TOKI8cgePjYAIPE72SiGwV1KmQ+95BB3BSt29NAKTXYtf2hYhSEfbsynp
BNa/rMf7LiAYDJzCbzIIrKl7yL50abYnHJSy6AT+Dw+ig5A=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  GridLines->Automatic,
  PlotRange->{{0, 0.1}, {-0.288606813998489, 0.999999926065927}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.4595261858785*^9, 3.459526207421*^9}, 
   3.4595286574744997`*^9, 3.4595287038970003`*^9, {3.4595293672095003`*^9, 
   3.4595293922095003`*^9}, {3.4595294450645*^9, 3.459529450807*^9}, {
   3.459529560627*^9, 3.459529572887*^9}, 3.4595296251945*^9, {
   3.459529705422*^9, 3.459529795087*^9}, 3.4595298350245*^9, {
   3.4595298752395*^9, 3.4595299044195004`*^9}, 3.459531338073*^9, 
   3.4595314358805*^9, 3.459531491888*^9, 3.4595399402185593`*^9, {
   3.4595400102715597`*^9, 3.45954003278356*^9}, 3.4595402825185595`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Xi]", "\[Rule]", "0.02760318988520098`"}], "}"}]], "Output",
 CellChangeTimes->{{3.4595261858785*^9, 3.459526207421*^9}, 
   3.4595286574744997`*^9, 3.4595287038970003`*^9, {3.4595293672095003`*^9, 
   3.4595293922095003`*^9}, {3.4595294450645*^9, 3.459529450807*^9}, {
   3.459529560627*^9, 3.459529572887*^9}, 3.4595296251945*^9, {
   3.459529705422*^9, 3.459529795087*^9}, 3.4595298350245*^9, {
   3.4595298752395*^9, 3.4595299044195004`*^9}, 3.459531338073*^9, 
   3.4595314358805*^9, 3.459531491888*^9, 3.4595399402185593`*^9, {
   3.4595400102715597`*^9, 3.45954003278356*^9}, 3.4595402825445595`*^9}],

Cell[BoxData["\<\"\\!\\(\\*SubscriptBox[\\(\[Eta]\\), \\(REFL, \
aux\\)]\\):\"\>"], "Print",
 CellChangeTimes->{{3.459529782927*^9, 3.4595297951070004`*^9}, 
   3.4595298350220003`*^9, {3.459529875237*^9, 3.4595299044195004`*^9}, 
   3.4595313380705*^9, 3.4595314358780003`*^9, 3.4595314918855*^9, 
   3.45953994020356*^9, {3.45954001026956*^9, 3.45954003278156*^9}, 
   3.4595402825615597`*^9}],

Cell[BoxData["0.9778701406170424`"], "Output",
 CellChangeTimes->{{3.4595261858785*^9, 3.459526207421*^9}, 
   3.4595286574744997`*^9, 3.4595287038970003`*^9, {3.4595293672095003`*^9, 
   3.4595293922095003`*^9}, {3.4595294450645*^9, 3.459529450807*^9}, {
   3.459529560627*^9, 3.459529572887*^9}, 3.4595296251945*^9, {
   3.459529705422*^9, 3.459529795087*^9}, 3.4595298350245*^9, {
   3.4595298752395*^9, 3.4595299044195004`*^9}, 3.459531338073*^9, 
   3.4595314358805*^9, 3.459531491888*^9, 3.4595399402185593`*^9, {
   3.4595400102715597`*^9, 3.45954003278356*^9}, 3.4595402825765595`*^9}],

Cell[BoxData["\<\"\\!\\(\\*SubscriptBox[\\(\[Eta]\\), \\(REFL, aux2\\)]\\):\"\
\>"], "Print",
 CellChangeTimes->{{3.459529782927*^9, 3.4595297951070004`*^9}, 
   3.4595298350220003`*^9, {3.459529875237*^9, 3.4595299044195004`*^9}, 
   3.4595313380705*^9, 3.4595314358780003`*^9, 3.4595314918855*^9, 
   3.45953994020356*^9, {3.45954001026956*^9, 3.45954003278156*^9}, 
   3.45954028259256*^9}],

Cell[BoxData[
 RowBox[{"0.9784830706045262`", " ", "\[Xi]"}]], "Output",
 CellChangeTimes->{{3.4595261858785*^9, 3.459526207421*^9}, 
   3.4595286574744997`*^9, 3.4595287038970003`*^9, {3.4595293672095003`*^9, 
   3.4595293922095003`*^9}, {3.4595294450645*^9, 3.459529450807*^9}, {
   3.459529560627*^9, 3.459529572887*^9}, 3.4595296251945*^9, {
   3.459529705422*^9, 3.459529795087*^9}, 3.4595298350245*^9, {
   3.4595298752395*^9, 3.4595299044195004`*^9}, 3.459531338073*^9, 
   3.4595314358805*^9, 3.459531491888*^9, 3.4595399402185593`*^9, {
   3.4595400102715597`*^9, 3.45954003278356*^9}, 3.4595402826085596`*^9}],

Cell[BoxData["0.027009253997351254`"], "Output",
 CellChangeTimes->{{3.4595261858785*^9, 3.459526207421*^9}, 
   3.4595286574744997`*^9, 3.4595287038970003`*^9, {3.4595293672095003`*^9, 
   3.4595293922095003`*^9}, {3.4595294450645*^9, 3.459529450807*^9}, {
   3.459529560627*^9, 3.459529572887*^9}, 3.4595296251945*^9, {
   3.459529705422*^9, 3.459529795087*^9}, 3.4595298350245*^9, {
   3.4595298752395*^9, 3.4595299044195004`*^9}, 3.459531338073*^9, 
   3.4595314358805*^9, 3.459531491888*^9, 3.4595399402185593`*^9, {
   3.4595400102715597`*^9, 3.45954003278356*^9}, 3.45954028262356*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", "r1"}], "+", 
   FractionBox[
    RowBox[{"t1", " ", "r2", " ", "t1", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Phi]", " "}]]}], 
    RowBox[{"1", "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Phi]", " "}]], "r1", " ", "r2"}]}]]}],
   "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{"%", "/.", 
    RowBox[{
     SuperscriptBox["t1", "2"], "\[Rule]", 
     RowBox[{"1", "-", 
      SuperscriptBox["r1", "2"]}]}]}], "]"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"-", "r1"}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r2", " ", 
    SuperscriptBox["t1", "2"]}], 
   RowBox[{"1", "-", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", 
     "r2"}]}]]}], "\n", 
 FractionBox[
  RowBox[{"r1", "-", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r2"}]}], 
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", 
    "r2"}]}]]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "r1"}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r2", " ", 
    SuperscriptBox["t1", "2"]}], 
   RowBox[{"1", "-", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", 
     "r2"}]}]]}]], "Output",
 CellChangeTimes->{3.4595293768120003`*^9, 3.4595399405295596`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"r1", "-", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r2"}]}], 
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", 
    "r2"}]}]]], "Output",
 CellChangeTimes->{3.4595293768120003`*^9, 3.4595399405445595`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "r1"}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r2", " ", 
    SuperscriptBox["t1", "2"]}], 
   RowBox[{"1", "-", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", 
     "r2"}]}]]}]], "Output",
 CellChangeTimes->{3.4595293768120003`*^9, 3.4595399405625596`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"r1", "-", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r2"}]}], 
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", 
    "r2"}]}]]], "Output",
 CellChangeTimes->{3.4595293768120003`*^9, 3.45953994057856*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["OMC", "Subsection",
 CellChangeTimes->{{3.4560549764004*^9, 3.4560549768996*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"redOMC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"F", "\[Rule]", 
      FractionBox[
       RowBox[{"\[Pi]", 
        SqrtBox[
         RowBox[{"r1", " ", "r2"}]]}], 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}]]}], ",", 
     RowBox[{"T1", "\[Rule]", "8000.*^-6"}], ",", 
     RowBox[{"t1", "\[Rule]", 
      SqrtBox["T1"]}], ",", " ", 
     RowBox[{"r1", "\[Rule]", 
      SqrtBox[
       RowBox[{"1", "-", "T1"}]]}], ",", 
     RowBox[{"t2", "\[Rule]", "t1"}], ",", 
     RowBox[{"r2", "\[Rule]", "r1"}], ",", 
     RowBox[{"k", "\[Rule]", 
      FractionBox[
       RowBox[{"2", "\[Pi]"}], "lambda"]}], ",", 
     RowBox[{"c", "\[Rule]", "2.99793*^8"}], ",", 
     RowBox[{"lambda", "\[Rule]", "1.064*^-6"}], ",", 
     RowBox[{"FSR", "\[Rule]", 
      FractionBox["c", 
       RowBox[{"2", "L"}]]}], ",", 
     RowBox[{"fcav", "\[Rule]", 
      FractionBox["FSR", 
       RowBox[{"2", " ", "F"}]]}], ",", 
     RowBox[{"L", "\[Rule]", "0.5"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"F", "//.", "redOMC"}], "\[IndentingNewLine]", 
 RowBox[{"FSR", "//.", "redOMC"}], "\[IndentingNewLine]", 
 RowBox[{"fcav", "//.", "redOMC"}]}], "Input",
 CellChangeTimes->{{3.455648209861216*^9, 3.455648265100816*^9}, {
  3.455648350791616*^9, 3.4556483614308157`*^9}, {3.4560549939504004`*^9, 
  3.4560551056464*^9}}],

Cell[BoxData["391.12513114971887`"], "Output",
 CellChangeTimes->{
  3.455648361774016*^9, 3.455648598660016*^9, {3.4560550667244*^9, 
   3.45605510613*^9}, 3.456141528295*^9, 3.4564975865712*^9, 
   3.4566640960572944`*^9, 3.456745594645294*^9, 3.456844842928894*^9, 
   3.4569340514145746`*^9, 3.4571137350866003`*^9, 3.4571328928595743`*^9, 
   3.45717691198*^9, 3.4572239223635745`*^9, 3.457260914782*^9, 
   3.4573072923225746`*^9, 3.457525865882082*^9, 3.4595253831184998`*^9, 
   3.4595399406055593`*^9}],

Cell[BoxData["2.99793`*^8"], "Output",
 CellChangeTimes->{
  3.455648361774016*^9, 3.455648598660016*^9, {3.4560550667244*^9, 
   3.45605510613*^9}, 3.456141528295*^9, 3.4564975865712*^9, 
   3.4566640960572944`*^9, 3.456745594645294*^9, 3.456844842928894*^9, 
   3.4569340514145746`*^9, 3.4571137350866003`*^9, 3.4571328928595743`*^9, 
   3.45717691198*^9, 3.4572239223635745`*^9, 3.457260914782*^9, 
   3.4573072923225746`*^9, 3.457525865882082*^9, 3.4595253831184998`*^9, 
   3.4595399406225595`*^9}],

Cell[BoxData["383244.3585493388`"], "Output",
 CellChangeTimes->{
  3.455648361774016*^9, 3.455648598660016*^9, {3.4560550667244*^9, 
   3.45605510613*^9}, 3.456141528295*^9, 3.4564975865712*^9, 
   3.4566640960572944`*^9, 3.456745594645294*^9, 3.456844842928894*^9, 
   3.4569340514145746`*^9, 3.4571137350866003`*^9, 3.4571328928595743`*^9, 
   3.45717691198*^9, 3.4572239223635745`*^9, 3.457260914782*^9, 
   3.4573072923225746`*^9, 3.457525865882082*^9, 3.4595253831184998`*^9, 
   3.4595399406435595`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["RF Sideband Transmission", "Subsubsection",
 CellChangeTimes->{{3.4560552585264*^9, 3.4560552766692*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"t1", " ", "t2"}], 
    RowBox[{"1", "-", 
     RowBox[{"r1", " ", "r2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"fM", "/", "FSR"}]}]]}]}]], " ", "//.", "redOMC"}], "/.", 
  RowBox[{"fM", "\[Rule]", "25*^6"}]}], "\[IndentingNewLine]", 
 SuperscriptBox[
  RowBox[{"Abs", "[", "%", "]"}], "2"]}], "Input",
 CellChangeTimes->{{3.455648269500016*^9, 3.455648346860416*^9}, {
  3.4556486125284157`*^9, 3.455648692650016*^9}, {3.4560551471424*^9, 
  3.456055170324*^9}}],

Cell[BoxData[
 RowBox[{"0.013160715172732483`", "\[InvisibleSpace]", "-", 
  RowBox[{"0.09499631976897144`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{
  3.4556483146464157`*^9, 3.4556483477496157`*^9, {3.455648614852816*^9, 
   3.455648692821616*^9}, 3.4560551371428003`*^9, 3.4560551714004*^9, 
   3.4561415283574*^9, 3.4564975866336*^9, 3.4566640961196947`*^9, 
   3.4567455947122946`*^9, 3.4568448429912944`*^9, 3.4569340515195746`*^9, 
   3.457113735149*^9, 3.4571328929425745`*^9, 3.4571769120424*^9, 
   3.457223922471575*^9, 3.4572609148444*^9, 3.4573072923945746`*^9, 
   3.4575258659630823`*^9, 3.459525383186*^9, 3.45953994067056*^9}],

Cell[BoxData["0.009197505193506466`"], "Output",
 CellChangeTimes->{
  3.4556483146464157`*^9, 3.4556483477496157`*^9, {3.455648614852816*^9, 
   3.455648692821616*^9}, 3.4560551371428003`*^9, 3.4560551714004*^9, 
   3.4561415283574*^9, 3.4564975866336*^9, 3.4566640961196947`*^9, 
   3.4567455947122946`*^9, 3.4568448429912944`*^9, 3.4569340515195746`*^9, 
   3.457113735149*^9, 3.4571328929425745`*^9, 3.4571769120424*^9, 
   3.457223922471575*^9, 3.4572609148444*^9, 3.4573072923945746`*^9, 
   3.4575258659630823`*^9, 3.459525383186*^9, 3.4595399406795597`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cavity Equations", "Section",
 CellChangeTimes->{{3.45580730103125*^9, 3.455807308359375*^9}}],

Cell[CellGroupData[{

Cell["Basic propagation", "Subsection",
 CellChangeTimes->{{3.4559752043442*^9, 3.4559752102254*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TP", "=", 
   RowBox[{"(", GridBox[{
      {"0", 
       FractionBox[
        RowBox[{"k", " ", "\[Delta]l"}], "2"], 
       FractionBox[
        RowBox[{"k", " ", "\[Delta]l"}], "2"]},
      {
       FractionBox[
        RowBox[{"k", " ", "\[Delta]l"}], "2"], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Omega]", " ", "L"}], "c"]}], "0"},
      {
       FractionBox[
        RowBox[{"k", " ", "\[Delta]l"}], "2"], "0", 
       FractionBox[
        RowBox[{"\[Omega]", " ", "L"}], "c"]}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P", "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "k", " ", "\[CapitalDelta]"}]], 
    RowBox[{"MatrixExp", "[", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "TP"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PP", "=", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "k", " ", "\[CapitalDelta]"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "3", "]"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "TP"}]}], ")"}]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"small", " ", "\[Omega]", " ", "and", " ", "\[Delta]l"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T1", "=", 
   RowBox[{"t2", " ", "P"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T2", "=", 
   RowBox[{"t1", " ", "r2", " ", 
    RowBox[{"P", ".", "P"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RT", "=", 
   RowBox[{"r1", " ", "r2", " ", 
    RowBox[{"P", " ", ".", "P"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RTT", "=", 
    RowBox[{"r1", " ", "r2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], "\[ImaginaryI]", " ", "k", " ", 
       "\[CapitalDelta]"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "3", "]"}], "-", 
       RowBox[{"2", "\[ImaginaryI]", " ", "TP"}]}], ")"}]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"small", " ", "\[Omega]", " ", "and", " ", "\[Delta]l"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cav", "=", 
   RowBox[{"t1", " ", 
    RowBox[{"Inverse", "[", 
     RowBox[{
      RowBox[{"IdentityMatrix", "[", "3", "]"}], "-", "RT"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cavv", "=", 
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"Series", "[", 
      RowBox[{"cav", ",", 
       RowBox[{"{", 
        RowBox[{"\[Omega]", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "//",
     "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"refl", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "r1"}], " ", 
     RowBox[{"IdentityMatrix", "[", "3", "]"}]}], "+", 
    RowBox[{"t1", " ", "cavv"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trans", "=", 
   RowBox[{"cavv", " ", "t2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"det", "[", 
    RowBox[{"+", "1"}], "]"}], "=", 
   RowBox[{"(", GridBox[{
      {"0", "1", "0"},
      {"0", "0", "0"},
      {"1", "0", "0"}
     }], ")"}]}], ";", 
  RowBox[{
   RowBox[{"det", "[", 
    RowBox[{"-", "1"}], "]"}], "=", 
   RowBox[{"(", GridBox[{
      {"0", "0", "1"},
      {"1", "0", "0"},
      {"0", "0", "0"}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LaserPN", "=", 
   RowBox[{"(", GridBox[{
      {"1", 
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[CurlyPhi]", "2"]}], 
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[CurlyPhi]", "2"]}]},
      {
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[CurlyPhi]", "2"]}], "1", "0"},
      {
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[CurlyPhi]", "2"]}], "0", "1"}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ein", "=", 
   RowBox[{"LaserPN", ".", 
    RowBox[{"(", GridBox[{
       {"1"},
       {"0"},
       {"0"}
      }], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Erefp", "=", 
   RowBox[{"\[ImaginaryI]", " ", "rSB", "  ", "Ein"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Erefm", "=", 
   RowBox[{"\[ImaginaryI]", " ", "rSB", "  ", "Ein"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "S", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S", "[", "n_", "]"}], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"refl", ".", "Ein"}], "]"}], "]"}], ".", 
      RowBox[{"det", "[", "n", "]"}], ".", "Erefm"}], "+", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Conjugate", "[", "Erefp", "]"}], "]"}], ".", 
      RowBox[{"det", "[", "n", "]"}], ".", "refl", ".", "Ein"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"S", "[", 
       RowBox[{"+", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"S", "[", 
       RowBox[{"-", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"T", "[", "n_", "]"}], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"rCR", " ", "Ein"}], "]"}], "]"}], ".", 
      RowBox[{"det", "[", "n", "]"}], ".", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"refl", ".", "Ein"}]}], "/.", 
        RowBox[{"\[CapitalDelta]", "\[Rule]", 
         RowBox[{"\[CapitalDelta]", "-", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Conjugate", "[", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"refl", ".", "Ein"}]}], "/.", 
         RowBox[{"\[CapitalDelta]", "\[Rule]", 
          RowBox[{"\[CapitalDelta]", "+", 
           RowBox[{
            FractionBox["1", 
             RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}]}], "]"}], "]"}], ".", 
      RowBox[{"det", "[", "n", "]"}], ".", 
      RowBox[{"(", 
       RowBox[{"rCR", " ", "Ein"}], ")"}]}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"T", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"+", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"-", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U", "[", "n_", "]"}], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"refl", ".", "Ein"}], "]"}], "]"}], ".", 
      RowBox[{"det", "[", "n", "]"}], ".", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"refl", ".", "Ein"}]}], "/.", 
        RowBox[{"\[CapitalDelta]", "\[Rule]", 
         RowBox[{"\[CapitalDelta]", "-", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Conjugate", "[", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"refl", ".", "Ein"}]}], "/.", 
         RowBox[{"\[CapitalDelta]", "\[Rule]", 
          RowBox[{"\[CapitalDelta]", "+", 
           RowBox[{
            FractionBox["1", 
             RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}]}], "]"}], "]"}], ".", 
      RowBox[{"det", "[", "n", "]"}], ".", "refl", ".", "Ein"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"U", "[", 
       RowBox[{"+", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"U", "[", 
       RowBox[{"-", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "n_", "]"}], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"trans", ".", "Ein"}], "]"}], "]"}], ".", 
      RowBox[{"det", "[", "n", "]"}], ".", "Erefm"}], "+", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Conjugate", "[", "Erefp", "]"}], "]"}], ".", 
      RowBox[{"det", "[", "n", "]"}], ".", "trans", ".", "Ein"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"+", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"-", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"W", "[", "n_", "]"}], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Conjugate", "[", 
        RowBox[{"trans", ".", "Ein"}], "]"}], "]"}], ".", 
      RowBox[{"det", "[", "n", "]"}], ".", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"trans", ".", "Ein"}]}], "/.", 
        RowBox[{"\[CapitalDelta]", "\[Rule]", 
         RowBox[{"\[CapitalDelta]", "-", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Conjugate", "[", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"trans", ".", "Ein"}]}], "/.", 
         RowBox[{"\[CapitalDelta]", "\[Rule]", 
          RowBox[{"\[CapitalDelta]", "+", 
           RowBox[{
            FractionBox["1", 
             RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}]}], "]"}], "]"}], ".", 
      RowBox[{"det", "[", "n", "]"}], ".", "trans", ".", "Ein"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"W", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"W", "[", 
       RowBox[{"+", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"W", "[", 
       RowBox[{"-", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4557376007261877`*^9, 3.4557376632041874`*^9}, {
   3.4557377214701877`*^9, 3.4557378053045874`*^9}, 3.4557378822593875`*^9, {
   3.4557379236617875`*^9, 3.4557379611017876`*^9}, {3.4557381199409876`*^9, 
   3.4557381915761876`*^9}, {3.455738247361788*^9, 3.455738363269788*^9}, 
   3.4557383996957874`*^9, {3.455738663554188*^9, 3.4557387695093875`*^9}, {
   3.4557388223153877`*^9, 3.4557389106737876`*^9}, {3.455738949299388*^9, 
   3.4557391267181873`*^9}, {3.4557392311445875`*^9, 
   3.4557392386169877`*^9}, {3.4557392789585876`*^9, 3.455739338425788*^9}, {
   3.4557393685649877`*^9, 3.4557394141793876`*^9}, {3.4557395224745874`*^9, 
   3.4557396495833874`*^9}, {3.4557396812357874`*^9, 3.455739713434188*^9}, 
   3.4557399108833876`*^9, {3.4557406621481876`*^9, 3.4557407130509872`*^9}, {
   3.4557408275705876`*^9, 3.4557408419849873`*^9}, {3.4557408806417875`*^9, 
   3.4557408962105875`*^9}, 3.4557409480649877`*^9, {3.455741148493788*^9, 
   3.4557411502097874`*^9}, {3.4557417066235876`*^9, 
   3.4557417600847874`*^9}, {3.455741837101988*^9, 3.4557418960075874`*^9}, {
   3.455741973383588*^9, 3.4557419842099876`*^9}, {3.4557420507751875`*^9, 
   3.4557420528967876`*^9}, {3.455742102894788*^9, 3.4557421216147876`*^9}, {
   3.4557424494175873`*^9, 3.455742452802788*^9}, 3.4557425307715874`*^9, {
   3.4557425965723877`*^9, 3.4557426259627876`*^9}, 3.4557427467067876`*^9, {
   3.4557430976443872`*^9, 3.4557430999063873`*^9}, {3.455743198108388*^9, 
   3.4557432410863876`*^9}, 3.4557443255203876`*^9, {3.455744447262788*^9, 
   3.4557444566227875`*^9}, {3.4559752610034*^9, 3.4559752634526*^9}, {
   3.4559755508514*^9, 3.4559755516001997`*^9}, {3.4559761164918003`*^9, 
   3.4559761312650003`*^9}, {3.4559762121042*^9, 3.4559762270334*^9}, {
   3.4559763043938*^9, 3.4559763128802*^9}, {3.4559763539082003`*^9, 
   3.4559763575118*^9}, {3.4559765128878*^9, 3.4559765157426*^9}, {
   3.4559765819178*^9, 3.4559767476521997`*^9}, 3.4559770782005997`*^9, 
   3.455977990083*^9, {3.4559781905118*^9, 3.4559781972198*^9}, {
   3.455978552541*^9, 3.4559786329122*^9}, {3.455981213901*^9, 
   3.4559812154922*^9}, {3.4559868749382*^9, 3.4559869855734*^9}, {
   3.4559883936946*^9, 3.4559884037566*^9}, {3.4559884476394*^9, 
   3.4559884640038*^9}, {3.4559910217958*^9, 3.4559910735254*^9}, 
   3.4559916698354*^9, {3.4559922051493998`*^9, 3.4559922335882*^9}, {
   3.4571772243543997`*^9, 3.4571772891099997`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Carrier (PDH)", "Subsection",
 CellChangeTimes->{{3.4559752043442*^9, 3.4559752102254*^9}, {
  3.455975241285*^9, 3.4559752428606*^9}, {3.4559975049938*^9, 
  3.4559975069906*^9}}],

Cell[CellGroupData[{

Cell["Reflectivity", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
  3.4559753770986*^9, 3.4559753791734*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"refl", ".", "Ein"}], " ", "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], ")"}], "\[LeftDoubleBracket]", 
  RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.4559753543694*^9, 3.455975396817*^9}, {
  3.4559756202869997`*^9, 3.4559756463389997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "r1"}], "+", 
  FractionBox[
   SuperscriptBox["t1", "2"], 
   RowBox[{"1", "-", 
    RowBox[{"r1", " ", "r2"}]}]]}]], "Output",
 CellChangeTimes->{{3.4559753698602*^9, 3.4559753972538*^9}, {
   3.4559755985718*^9, 3.4559756467602*^9}, 3.4559812338066*^9, 
   3.4560556020383997`*^9, 3.4564976035596*^9, 3.4566641008464947`*^9, 
   3.4569340570805745`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "r1"}], "+", 
  FractionBox[
   SuperscriptBox["t1", "2"], 
   RowBox[{"1", "-", 
    RowBox[{"r1", " ", "r2"}]}]]}]], "Output",
 CellChangeTimes->{{3.4559753698602*^9, 3.4559753972538*^9}, {
   3.4559755985718*^9, 3.4559756467602*^9}, 3.4559812338066*^9, 
   3.4560556020383997`*^9, 3.4564976035596*^9, 3.4566641008464947`*^9, 
   3.4569340570835743`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transmission", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
  3.4559753770986*^9, 3.4559753791734*^9}, {3.4559908983686*^9, 
  3.455990901473*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"trans", ".", "Ein"}], " ", "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], ")"}], "\[LeftDoubleBracket]", 
  RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.4559753543694*^9, 3.455975396817*^9}, {
  3.4559756202869997`*^9, 3.4559756463389997`*^9}, {3.4559909100685997`*^9, 
  3.4559909107082*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"t1", " ", "t2"}], 
  RowBox[{"1", "-", 
   RowBox[{"r1", " ", "r2"}]}]]], "Output",
 CellChangeTimes->{3.4559909113634*^9, 3.4560556021008*^9, 
  3.4564976035908003`*^9, 3.4566641008932943`*^9, 3.4569340571455746`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"t1", " ", "t2"}], 
  RowBox[{"1", "-", 
   RowBox[{"r1", " ", "r2"}]}]]], "Output",
 CellChangeTimes->{3.4559909113634*^9, 3.4560556021008*^9, 
  3.4564976035908003`*^9, 3.4566641008932943`*^9, 3.4569340571475744`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Slope & Pole (reflection)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753342766*^9}, {
  3.4559910067106*^9, 3.4559910093157997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ComplexExpand", "[", 
   RowBox[{
    RowBox[{"S", "[", "0", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}], ",", 
      RowBox[{"\[CurlyPhi]", "\[Rule]", "0"}]}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", " ", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{
    SuperscriptBox["t1", "2"], "\[Rule]", 
    RowBox[{"1", "-", 
     SuperscriptBox["r1", "2"]}]}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"%%", "/.", 
      RowBox[{"t", "\[Rule]", 
       FractionBox["\[Pi]", 
        RowBox[{"2", "\[Omega]"}]]}]}], "%"], 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.4557430302679873`*^9, 3.455743031843588*^9}, {
  3.4557431199991875`*^9, 3.4557431216059875`*^9}, {3.45580788128125*^9, 
  3.455807893734375*^9}, {3.4558079250625*^9, 3.455807956609375*^9}, {
  3.4558080705625*^9, 3.45580809290625*^9}, {3.455808521421875*^9, 
  3.455808593265625*^9}, {3.455809050703125*^9, 3.45580909465625*^9}, {
  3.45580915059375*^9, 3.455809167328125*^9}, {3.4559870052762003`*^9, 
  3.4559870091918*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", "k", " ", "r1", " ", "r2", " ", "rSB", " ", 
    SuperscriptBox["t1", "2"], " ", "\[Delta]l", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"L", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}], 
   RowBox[{"c", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"r1", " ", "r2"}]}], ")"}], "3"]}]]}]], "Output",
 CellChangeTimes->{
  3.4557428367187877`*^9, {3.455743019831588*^9, 3.4557430322959876`*^9}, {
   3.4557431051635876`*^9, 3.4557431222299876`*^9}, 3.4557432076243877`*^9, 
   3.4557441178219876`*^9, 3.4557444798823876`*^9, 3.4558078764375*^9, {
   3.45580790803125*^9, 3.455807958046875*^9}, 3.455808094265625*^9, 
   3.455808550078125*^9, 3.45580859978125*^9, {3.455809056625*^9, 
   3.455809095765625*^9}, 3.4558091685*^9, 3.4559752754334*^9, 
   3.4559756081034*^9, 3.4559762314638*^9, 3.4559763618174*^9, 
   3.4559765193618*^9, 3.455981236365*^9, 3.455987009925*^9, 
   3.4559914583462*^9, 3.4560556144716*^9, 3.4564976037623997`*^9, 
   3.4566641010804944`*^9, 3.4569340573785744`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", "F", " ", "k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["r1", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", "rSB", " ", "\[Delta]l", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"L", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}], 
   RowBox[{"c", " ", "\[Pi]", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"r1", " ", "r2"}]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{
  3.4557428367187877`*^9, {3.455743019831588*^9, 3.4557430322959876`*^9}, {
   3.4557431051635876`*^9, 3.4557431222299876`*^9}, 3.4557432076243877`*^9, 
   3.4557441178219876`*^9, 3.4557444798823876`*^9, 3.4558078764375*^9, {
   3.45580790803125*^9, 3.455807958046875*^9}, 3.455808094265625*^9, 
   3.455808550078125*^9, 3.45580859978125*^9, {3.455809056625*^9, 
   3.455809095765625*^9}, 3.4558091685*^9, 3.4559752754334*^9, 
   3.4559756081034*^9, 3.4559762314638*^9, 3.4559763618174*^9, 
   3.4559765193618*^9, 3.455981236365*^9, 3.455987009925*^9, 
   3.4559914583462*^9, 3.4560556144716*^9, 3.4564976037623997`*^9, 
   3.4566641010804944`*^9, 3.456934057582575*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", "F", " ", "k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["r1", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", "rSB", " ", "\[Delta]l"}], 
   RowBox[{"\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.4557428367187877`*^9, {3.455743019831588*^9, 3.4557430322959876`*^9}, {
   3.4557431051635876`*^9, 3.4557431222299876`*^9}, 3.4557432076243877`*^9, 
   3.4557441178219876`*^9, 3.4557444798823876`*^9, 3.4558078764375*^9, {
   3.45580790803125*^9, 3.455807958046875*^9}, 3.455808094265625*^9, 
   3.455808550078125*^9, 3.45580859978125*^9, {3.455809056625*^9, 
   3.455809095765625*^9}, 3.4558091685*^9, 3.4559752754334*^9, 
   3.4559756081034*^9, 3.4559762314638*^9, 3.4559763618174*^9, 
   3.4559765193618*^9, 3.455981236365*^9, 3.455987009925*^9, 
   3.4559914583462*^9, 3.4560556144716*^9, 3.4564976037623997`*^9, 
   3.4566641010804944`*^9, 3.4569340575845747`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]"}], 
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]]}]]}]], "Output",
 CellChangeTimes->{
  3.4557428367187877`*^9, {3.455743019831588*^9, 3.4557430322959876`*^9}, {
   3.4557431051635876`*^9, 3.4557431222299876`*^9}, 3.4557432076243877`*^9, 
   3.4557441178219876`*^9, 3.4557444798823876`*^9, 3.4558078764375*^9, {
   3.45580790803125*^9, 3.455807958046875*^9}, 3.455808094265625*^9, 
   3.455808550078125*^9, 3.45580859978125*^9, {3.455809056625*^9, 
   3.455809095765625*^9}, 3.4558091685*^9, 3.4559752754334*^9, 
   3.4559756081034*^9, 3.4559762314638*^9, 3.4559763618174*^9, 
   3.4559765193618*^9, 3.455981236365*^9, 3.455987009925*^9, 
   3.4559914583462*^9, 3.4560556144716*^9, 3.4564976037623997`*^9, 
   3.4566641010804944`*^9, 3.4569340576095743`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Laser Phase Noise (reflection)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753342766*^9}, {
  3.4559870203458*^9, 3.4559870241834*^9}, {3.4559910117181997`*^9, 
  3.4559910142142*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ComplexExpand", "[", 
   RowBox[{
    RowBox[{"S", "[", "0", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}], ",", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", " ", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{
    SuperscriptBox["t1", "2"], "\[Rule]", 
    RowBox[{"1", "-", 
     SuperscriptBox["r1", "2"]}]}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"%%", "/.", 
     RowBox[{"t", "\[Rule]", 
      FractionBox["\[Pi]", 
       RowBox[{"2", "\[Omega]"}]]}]}], ")"}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.4557430302679873`*^9, 3.455743031843588*^9}, {
  3.4557431199991875`*^9, 3.4557431216059875`*^9}, {3.45580788128125*^9, 
  3.455807893734375*^9}, {3.4558079250625*^9, 3.455807956609375*^9}, {
  3.4558080705625*^9, 3.45580809290625*^9}, {3.455808521421875*^9, 
  3.455808593265625*^9}, {3.455809050703125*^9, 3.45580909465625*^9}, {
  3.45580915059375*^9, 3.455809167328125*^9}, {3.4559870052762003`*^9, 
  3.4559870342609997`*^9}, {3.4559884864522*^9, 3.4559885122078*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", "L", " ", "r1", " ", "r2", " ", "rSB", " ", 
    SuperscriptBox["t1", "2"], " ", "\[CurlyPhi]", " ", "\[Omega]", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
   RowBox[{"c", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"r1", " ", "r2"}]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{
  3.4559870355402*^9, {3.4559884752202*^9, 3.4559885126289997`*^9}, 
   3.4560556183716*^9, 3.4564976040432*^9, 3.4566641013456945`*^9, 
   3.4569340577025747`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", "F", " ", "L", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["r1", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", "rSB", " ", "\[CurlyPhi]", " ", 
    "\[Omega]", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
   RowBox[{"c", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.4559870355402*^9, {3.4559884752202*^9, 3.4559885126289997`*^9}, 
   3.4560556183716*^9, 3.4564976040432*^9, 3.4566641013456945`*^9, 
   3.456934057752575*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.4559870355402*^9, {3.4559884752202*^9, 3.4559885126289997`*^9}, 
   3.4560556183716*^9, 3.4564976040432*^9, 3.4566641013456945`*^9, 
   3.456934057754575*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "F", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["r1", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", "rSB", " ", "\[CurlyPhi]", " ", 
    "\[Omega]"}], 
   RowBox[{"FSR", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.4559870355402*^9, {3.4559884752202*^9, 3.4559885126289997`*^9}, 
   3.4560556183716*^9, 3.4564976040432*^9, 3.4566641013456945`*^9, 
   3.4569340577795744`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Slope & Pole (transmission)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753342766*^9}, {
  3.4559910067106*^9, 3.4559910093157997`*^9}, {3.4559910956618*^9, 
  3.4559910999049997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ComplexExpand", "[", 
   RowBox[{
    RowBox[{"V", "[", "0", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}], ",", 
      RowBox[{"\[CurlyPhi]", "\[Rule]", "0"}]}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", " ", 
     FractionBox[
      RowBox[{"F", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
    RowBox[{"t1", "\[Rule]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["r1", "2"]}]]}]}], "/.", 
   RowBox[{"t2", "\[Rule]", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r2", "2"]}]]}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"dccr", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"t", "\[Rule]", "0"}]}], " ", "//", "Factor"}], "//", 
   "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"%%", "/.", 
      RowBox[{"t", "\[Rule]", 
       FractionBox["\[Pi]", 
        RowBox[{"2", "\[Omega]"}]]}]}], "%"], 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.4557430302679873`*^9, 3.455743031843588*^9}, {
   3.4557431199991875`*^9, 3.4557431216059875`*^9}, {3.45580788128125*^9, 
   3.455807893734375*^9}, {3.4558079250625*^9, 3.455807956609375*^9}, {
   3.4558080705625*^9, 3.45580809290625*^9}, {3.455808521421875*^9, 
   3.455808593265625*^9}, {3.455809050703125*^9, 3.45580909465625*^9}, {
   3.45580915059375*^9, 3.455809167328125*^9}, {3.4559870052762003`*^9, 
   3.4559870091918*^9}, 3.4559911037894*^9, {3.4559912307578*^9, 
   3.455991246467*^9}, {3.4559913123613997`*^9, 3.4559913171506*^9}, {
   3.4559940200388002`*^9, 3.4559940226284*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
   "4", " ", "k", " ", "r1", " ", "r2", " ", "rSB", " ", "t1", " ", "t2", " ",
     "\[Delta]l", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "+", 
      RowBox[{"L", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}], 
   RowBox[{"c", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"r1", " ", "r2"}]}], ")"}], "3"]}]]}]], "Output",
 CellChangeTimes->{
  3.4559911044758*^9, 3.4559912471066*^9, 3.4559913176809998`*^9, 
   3.4559914341974*^9, 3.4559917064798*^9, {3.4559940118487997`*^9, 
   3.4559940232679996`*^9}, 3.4560556240811996`*^9, 3.4564976042928*^9, 
   3.4566641016264944`*^9, 3.4569340584795747`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"c", " ", "\[Pi]", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"r1", " ", "r2"}]}], ")"}], "2"]}]], 
  RowBox[{"4", " ", "F", " ", "k", " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox["r1", "2"]}]], " ", 
   SqrtBox[
    RowBox[{"r1", " ", "r2"}]], " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox["r2", "2"]}]], " ", "rSB", " ", "\[Delta]l", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "+", 
     RowBox[{"L", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.4559911044758*^9, 3.4559912471066*^9, 3.4559913176809998`*^9, 
   3.4559914341974*^9, 3.4559917064798*^9, {3.4559940118487997`*^9, 
   3.4559940232679996`*^9}, 3.4560556240811996`*^9, 3.4564976042928*^9, 
   3.4566641016264944`*^9, 3.4569340584825745`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", "F", " ", "k", " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r1", "2"]}]], " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r2", "2"]}]], " ", "rSB", " ", "\[Delta]l"}], 
   RowBox[{"\[Pi]", "-", 
    RowBox[{"\[Pi]", " ", "r1", " ", "r2"}]}]]}]], "Output",
 CellChangeTimes->{
  3.4559911044758*^9, 3.4559912471066*^9, 3.4559913176809998`*^9, 
   3.4559914341974*^9, 3.4559917064798*^9, {3.4559940118487997`*^9, 
   3.4559940232679996`*^9}, 3.4560556240811996`*^9, 3.4564976042928*^9, 
   3.4566641016264944`*^9, 3.4569340584845743`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]"}], 
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]]}]]}]], "Output",
 CellChangeTimes->{
  3.4559911044758*^9, 3.4559912471066*^9, 3.4559913176809998`*^9, 
   3.4559914341974*^9, 3.4559917064798*^9, {3.4559940118487997`*^9, 
   3.4559940232679996`*^9}, 3.4560556240811996`*^9, 3.4564976042928*^9, 
   3.4566641016264944`*^9, 3.4569340584875746`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Laser Phase Noise (transmission)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753342766*^9}, {
  3.4559870203458*^9, 3.4559870241834*^9}, {3.4559910117181997`*^9, 
  3.4559910142142*^9}, {3.4559945834172*^9, 3.4559945851800003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ComplexExpand", "[", 
   RowBox[{
    RowBox[{"V", "[", "0", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}], ",", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", " ", 
     FractionBox[
      RowBox[{"F", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
    RowBox[{"t1", "\[Rule]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["r1", "2"]}]]}]}], "/.", 
   RowBox[{"t2", "\[Rule]", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r2", "2"]}]]}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"%%", "/.", 
     RowBox[{"t", "\[Rule]", 
      FractionBox["\[Pi]", 
       RowBox[{"2", "\[Omega]"}]]}]}], ")"}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.4557430302679873`*^9, 3.455743031843588*^9}, {
   3.4557431199991875`*^9, 3.4557431216059875`*^9}, {3.45580788128125*^9, 
   3.455807893734375*^9}, {3.4558079250625*^9, 3.455807956609375*^9}, {
   3.4558080705625*^9, 3.45580809290625*^9}, {3.455808521421875*^9, 
   3.455808593265625*^9}, {3.455809050703125*^9, 3.45580909465625*^9}, {
   3.45580915059375*^9, 3.455809167328125*^9}, {3.4559870052762003`*^9, 
   3.4559870342609997`*^9}, {3.4559884864522*^9, 3.4559885122078*^9}, 
   3.455994689388*^9, 3.4559947247532*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
   "4", " ", "L", " ", "r1", " ", "r2", " ", "rSB", " ", "t1", " ", "t2", " ",
     "\[CurlyPhi]", " ", "\[Omega]", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
   RowBox[{"c", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"r1", " ", "r2"}]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{
  3.4559870355402*^9, {3.4559884752202*^9, 3.4559885126289997`*^9}, 
   3.4559946902616*^9, 3.4559947258452*^9, 3.4560556407108*^9, 
   3.4564976046828003`*^9, 3.456664102047694*^9, 3.4569340586105747`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", "F", " ", "L", " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox["r1", "2"]}]], " ", 
   SqrtBox[
    RowBox[{"r1", " ", "r2"}]], " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox["r2", "2"]}]], " ", "rSB", " ", "\[CurlyPhi]", " ", 
   "\[Omega]", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"-", "c"}], " ", "\[Pi]"}], "+", 
   RowBox[{"c", " ", "\[Pi]", " ", "r1", " ", "r2"}]}]]], "Output",
 CellChangeTimes->{
  3.4559870355402*^9, {3.4559884752202*^9, 3.4559885126289997`*^9}, 
   3.4559946902616*^9, 3.4559947258452*^9, 3.4560556407108*^9, 
   3.4564976046828003`*^9, 3.456664102047694*^9, 3.456934058660575*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.4559870355402*^9, {3.4559884752202*^9, 3.4559885126289997`*^9}, 
   3.4559946902616*^9, 3.4559947258452*^9, 3.4560556407108*^9, 
   3.4564976046828003`*^9, 3.456664102047694*^9, 3.4569340586615744`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "F", " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r1", "2"]}]], " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["r2", "2"]}]], " ", "rSB", " ", "\[CurlyPhi]", " ", 
    "\[Omega]"}], 
   RowBox[{
    RowBox[{"FSR", " ", "\[Pi]"}], "-", 
    RowBox[{"FSR", " ", "\[Pi]", " ", "r1", " ", "r2"}]}]]}]], "Output",
 CellChangeTimes->{
  3.4559870355402*^9, {3.4559884752202*^9, 3.4559885126289997`*^9}, 
   3.4559946902616*^9, 3.4559947258452*^9, 3.4560556407108*^9, 
   3.4564976046828003`*^9, 3.456664102047694*^9, 3.4569340586955748`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sidebands", "Subsection",
 CellChangeTimes->{{3.4559752043442*^9, 3.4559752102254*^9}, {
  3.455975241285*^9, 3.4559752428606*^9}, {3.4559759465922003`*^9, 
  3.4559759478557997`*^9}}],

Cell[CellGroupData[{

Cell["Reflectivity", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
  3.4559753770986*^9, 3.4559753791734*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sbf", "=", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", "\[Rule]", 
     FractionBox[
      RowBox[{"2", "\[Pi]", " ", "f"}], "FSR"]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4559759543142*^9, 3.4559760151698*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"refl", ".", "Ein"}], " ", "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], ")"}], "\[LeftDoubleBracket]", 
  RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"refl", ".", "Ein"}], " ", "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", "k"}]]}], "\[Phi]"}]}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], ")"}], "\[LeftDoubleBracket]", 
  RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "Input",
 CellChangeTimes->{{3.4559753543694*^9, 3.455975396817*^9}, {
  3.4559756202869997`*^9, 3.4559756463389997`*^9}, {3.4559758051470003`*^9, 
  3.4559758608389997`*^9}, {3.4559759001354*^9, 3.4559759390573997`*^9}, {
  3.455976025731*^9, 3.4559760416742*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "r1"}], "+", 
  FractionBox[
   SuperscriptBox["t1", "2"], 
   RowBox[{"1", "-", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "r1", " ", 
     "r2"}]}]]}]], "Output",
 CellChangeTimes->{3.4559803263546*^9, 3.4564976047764*^9, 
  3.4566641022036943`*^9, 3.4569340587485743`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "r1"}], "+", 
  FractionBox[
   SuperscriptBox["t1", "2"], 
   RowBox[{"1", "-", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", 
     "r2"}]}]]}]], "Output",
 CellChangeTimes->{3.4559803263546*^9, 3.4564976047764*^9, 
  3.4566641022036943`*^9, 3.4569340588365746`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transmission", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
  3.4559753770986*^9, 3.4559753791734*^9}, {3.4559908983686*^9, 
  3.455990901473*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sbf", "=", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", "\[Rule]", 
     FractionBox[
      RowBox[{"2", "\[Pi]", " ", "f"}], "FSR"]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4559759543142*^9, 3.4559760151698*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"trans", ".", "Ein"}], " ", "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], ")"}], "\[LeftDoubleBracket]", 
  RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"trans", ".", "Ein"}], " ", "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"2", "k"}]]}], "\[Phi]"}]}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], ")"}], "\[LeftDoubleBracket]", 
  RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "Input",
 CellChangeTimes->{{3.4559753543694*^9, 3.455975396817*^9}, {
  3.4559756202869997`*^9, 3.4559756463389997`*^9}, {3.4559758051470003`*^9, 
  3.4559758608389997`*^9}, {3.4559759001354*^9, 3.4559759390573997`*^9}, {
  3.455976025731*^9, 3.4559760416742*^9}, {3.4559918111870003`*^9, 
  3.455991814541*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"t1", " ", "t2"}], 
  RowBox[{"1", "-", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "r1", " ", 
    "r2"}]}]]], "Output",
 CellChangeTimes->{3.4559918149466*^9, 3.4564976048388*^9, 
  3.4566641022972946`*^9, 3.4569340589375744`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"t1", " ", "t2"}], 
  RowBox[{"1", "-", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", 
    "r2"}]}]]], "Output",
 CellChangeTimes->{3.4559918149466*^9, 3.4564976048388*^9, 
  3.4566641022972946`*^9, 3.456934058969575*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Slope & Pole (Reflection)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753342766*^9}, {
  3.4559922482209997`*^9, 3.4559922542894*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ComplexExpand", "[", 
   RowBox[{
    RowBox[{"T", "[", "0", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", " ", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{
    SuperscriptBox["t1", "2"], "\[Rule]", 
    RowBox[{"1", "-", 
     SuperscriptBox["r1", "2"]}]}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"%%", "/.", 
      RowBox[{"t", "\[Rule]", 
       FractionBox["\[Pi]", 
        RowBox[{"2", "\[Omega]"}]]}]}], "%"], 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{
  3.455976798867*^9, {3.4559782737534*^9, 3.4559782742058*^9}, {
   3.4559784824346*^9, 3.455978482809*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", "r1", " ", "r2", " ", "rCR", " ", 
    SuperscriptBox["t1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", " ", "k", " ", "\[Delta]l", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         SuperscriptBox["\[CurlyPhi]", "2"]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r1", " ", "r2"}], "-", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", "L", " ", "\[Omega]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r1", " ", "r2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", " ", "\[Delta]l"}], "+", "\[CurlyPhi]"}], ")"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", " ", "\[Delta]l"}], "-", "\[CurlyPhi]"}], ")"}], " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", " ", "\[Delta]l"}], "-", "\[CurlyPhi]"}], ")"}], " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"c", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r1", " ", "r2"}], "-", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "r1", " ", "r2", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.455976800193*^9, 3.4559769380034*^9, 
  3.4559770839258003`*^9, 3.455978211837*^9, 3.4559782750014*^9, 
  3.4559784833394003`*^9, 3.4559812440558*^9, 3.4564976057592*^9, 
  3.4566641031708946`*^9, 3.4569340599455748`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", "F", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["r1", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "rCR", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", " ", "k", " ", "\[Delta]l", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         SuperscriptBox["\[CurlyPhi]", "2"]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r1", " ", "r2"}], "-", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", "L", " ", "\[Omega]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r1", " ", "r2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", " ", "\[Delta]l"}], "+", "\[CurlyPhi]"}], ")"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", " ", "\[Delta]l"}], "-", "\[CurlyPhi]"}], ")"}], " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", " ", "\[Delta]l"}], "-", "\[CurlyPhi]"}], ")"}], " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"c", " ", "\[Pi]", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r1", " ", "r2"}], "-", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "r1", " ", "r2", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.455976800193*^9, 3.4559769380034*^9, 
  3.4559770839258003`*^9, 3.455978211837*^9, 3.4559782750014*^9, 
  3.4559784833394003`*^9, 3.4559812440558*^9, 3.4564976057592*^9, 
  3.4566641031708946`*^9, 3.456934060469575*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "F", " ", "k", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["r1", "2"]}], ")"}], " ", 
   SqrtBox[
    RowBox[{"r1", " ", "r2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "rCR", " ", "\[Delta]l", " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", 
     SuperscriptBox["\[CurlyPhi]", "2"]}], ")"}]}], 
  RowBox[{"\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r1", " ", "r2"}], "-", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"r1", " ", "r2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "r1", " ", "r2", " ", 
      RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.455976800193*^9, 3.4559769380034*^9, 
  3.4559770839258003`*^9, 3.455978211837*^9, 3.4559782750014*^9, 
  3.4559784833394003`*^9, 3.4559812440558*^9, 3.4564976057592*^9, 
  3.4566641031708946`*^9, 3.4569340604935746`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"F", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r1", " ", "r2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k", " ", "\[Delta]l"}], "+", "\[CurlyPhi]"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k", " ", "\[Delta]l"}], "-", "\[CurlyPhi]"}], ")"}], " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k", " ", "\[Delta]l"}], "-", "\[CurlyPhi]"}], ")"}], " ", 
      RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], 
  RowBox[{"FSR", " ", "k", " ", "\[Pi]", " ", 
   SqrtBox[
    RowBox[{"r1", " ", "r2"}]], " ", "\[Delta]l", " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", 
     SuperscriptBox["\[CurlyPhi]", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r1", " ", "r2"}], "-", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.455976800193*^9, 3.4559769380034*^9, 
  3.4559770839258003`*^9, 3.455978211837*^9, 3.4559782750014*^9, 
  3.4559784833394003`*^9, 3.4559812440558*^9, 3.4564976057592*^9, 
  3.4566641031708946`*^9, 3.4569340605845747`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Both", "Subsection",
 CellChangeTimes->{{3.4559752043442*^9, 3.4559752102254*^9}, {
  3.455975241285*^9, 3.4559752428606*^9}, {3.4559759465922003`*^9, 
  3.4559759478557997`*^9}, {3.4559786478414*^9, 3.4559786483873997`*^9}}],

Cell[CellGroupData[{

Cell["Slope & Pole (Reflection)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753342766*^9}, {
  3.4559922573938*^9, 3.4559922602642*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ComplexExpand", "[", 
    RowBox[{
     RowBox[{"U", "[", "0", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}], ",", 
       RowBox[{"\[CurlyPhi]", "\[Rule]", "0"}]}], "}"}]}], "]"}], "//", 
   "Simplify"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", " ", 
     FractionBox[
      RowBox[{"F", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
    RowBox[{
     SuperscriptBox["t1", "2"], "\[Rule]", 
     RowBox[{"1", "-", 
      SuperscriptBox["r1", "2"]}]}]}], "//", "Simplify"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"dc", "=", 
  RowBox[{"%", "/.", 
   RowBox[{"t", "\[Rule]", "0"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ac", "=", 
   RowBox[{"%%", "/.", 
    RowBox[{"t", "\[Rule]", 
     FractionBox["\[Pi]", 
      RowBox[{"2", "\[Omega]"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox["ac", "dc"], 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{
  3.455976798867*^9, {3.4559782737534*^9, 3.4559782742058*^9}, {
   3.4559784824346*^9, 3.455978482809*^9}, 3.4559786552046003`*^9, {
   3.455982780219*^9, 3.4559828028702*^9}, {3.4559924838444*^9, 
   3.4559925036408*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"4", " ", "F", " ", "k", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SuperscriptBox["r1", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Delta]l", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "r1", "-", 
         SuperscriptBox["r1", "2"], "+", 
         RowBox[{
          SuperscriptBox["r1", "3"], " ", 
          SuperscriptBox["r2", "2"]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "r1", "+", 
         SuperscriptBox["r1", "2"], "+", 
         RowBox[{
          SuperscriptBox["r1", "3"], " ", 
          SuperscriptBox["r2", "2"]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "-", 
      RowBox[{"r1", " ", "r2"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"\[Pi]", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"r1", " ", "r2"}]}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r1", " ", "r2"}], "-", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "r1", " ", "r2", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.455976800193*^9, 3.4559769380034*^9, 3.4559770839258003`*^9, 
   3.455978211837*^9, 3.4559782750014*^9, 3.4559784833394003`*^9, 
   3.4559786576070004`*^9, 3.455981271387*^9, 3.4559828250846*^9, 
   3.4559924034098*^9, {3.4559924933915997`*^9, 3.4559925076656*^9}, 
   3.4559939389032*^9, 3.4559944945284*^9, 3.4560554087232*^9, 
   3.4560562047288*^9, 3.4564976113128*^9, 3.456664107788494*^9, 
   3.4569340652135744`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r1", " ", "r2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "r1", "+", 
         RowBox[{
          SuperscriptBox["r1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"6", " ", "r2"}]}], ")"}]}], "+", 
         RowBox[{"3", " ", "r1", " ", "r2"}], "+", 
         RowBox[{
          SuperscriptBox["r1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "r2"}], ")"}], " ", "r2"}]}], ")"}]}], 
      "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "r1", "+", 
         SuperscriptBox["r1", "2"], "+", 
         RowBox[{
          SuperscriptBox["r1", "4"], " ", 
          SuperscriptBox["r2", "3"]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "r1", "-", 
         SuperscriptBox["r1", "2"], "+", 
         RowBox[{
          SuperscriptBox["r1", "4"], " ", 
          SuperscriptBox["r2", "3"]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "r1", "-", 
         SuperscriptBox["r1", "2"], "+", 
         RowBox[{
          SuperscriptBox["r1", "3"], " ", 
          SuperscriptBox["r2", "2"]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "r1", "+", 
         SuperscriptBox["r1", "2"], "+", 
         RowBox[{
          SuperscriptBox["r1", "3"], " ", 
          SuperscriptBox["r2", "2"]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.455976800193*^9, 3.4559769380034*^9, 3.4559770839258003`*^9, 
   3.455978211837*^9, 3.4559782750014*^9, 3.4559784833394003`*^9, 
   3.4559786576070004`*^9, 3.455981271387*^9, 3.4559828250846*^9, 
   3.4559924034098*^9, {3.4559924933915997`*^9, 3.4559925076656*^9}, 
   3.4559939389032*^9, 3.4559944945284*^9, 3.4560554087232*^9, 
   3.4560562047288*^9, 3.4564976113128*^9, 3.456664107788494*^9, 
   3.4569340655135746`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"fff", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"dc", "//.", "redSHG"}], "//.", "greenOPO"}], "/.", 
   RowBox[{"\[Delta]l", "\[Rule]", "1"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"ff0", "=", 
  RowBox[{"fff", "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "\[Pi]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Re", "[", "fff", "]"}], ",", 
     RowBox[{"Im", "[", "fff", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Abs", "[", "fff", "]"}], "/.", 
       RowBox[{"\[Phi]", "\[Rule]", 
        RowBox[{"2", "\[Pi]", 
         FractionBox["n", 
          RowBox[{"2", "F"}]]}]}]}], "//.", "redSHG"}], ",", 
     RowBox[{"Abs", "[", 
      FractionBox[
       RowBox[{"ff0", " ", "\[ImaginaryI]", " ", "n"}], 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", "n"}]}]], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4559822894118*^9, 3.4559823309858*^9}, {
   3.455982370875*^9, 3.4559823966306*^9}, {3.4559828760030003`*^9, 
   3.4559828798094*^9}, {3.4559829367806*^9, 3.4559829655626*^9}, {
   3.4559835000810003`*^9, 3.4559835206418*^9}, {3.4559839224042*^9, 
   3.4559839258518*^9}, {3.4559844857202*^9, 3.4559845135818*^9}, {
   3.4559846571174*^9, 3.4559846846202*^9}, 3.4559847452262*^9, {
   3.455984840823*^9, 3.4559848477026*^9}, {3.4559849066394*^9, 
   3.4559850694722*^9}, {3.455992349855*^9, 3.4559923822406*^9}, {
   3.4559924196806*^9, 3.4559924390558*^9}, 3.4559925128604*^9, {
   3.455992818558*^9, 3.455992829868*^9}, {3.455992864656*^9, 
   3.4559928887111998`*^9}, {3.4559929342788*^9, 3.455992940316*^9}, {
   3.4559929749636*^9, 3.4559929750416*^9}, {3.4559931097788*^9, 
   3.4559931117132*^9}, {3.4559931608844*^9, 3.455993181024*^9}, {
   3.455993331954*^9, 3.4559934064128*^9}, {3.4559939281392*^9, 
   3.4559939521788*^9}, {3.4559944591632*^9, 3.4559944599432*^9}, {
   3.4560561936996*^9, 3.4560561981768*^9}, {3.4560562509672003`*^9, 
   3.4560562836804*^9}, {3.4560563664852*^9, 3.4560564164676*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"6.705290288380491`*^6", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "0.09987970393917545`"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "+", 
      RowBox[{"1.8977201359967926`", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "0.051696251193743326`"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "+", 
      RowBox[{"1.9483037488062567`", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1.9483037488062567`"}], "+", 
      RowBox[{"1.9483037488062567`", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
      RowBox[{"0.051696251193743326`", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"0.9483037488062567`", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{"0.9483037488062567`", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"0.9483037488062567`", "\[InvisibleSpace]", "-", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], "3"]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.455982944877*^9, 3.4559829658901997`*^9}, {
   3.4559835009858*^9, 3.4559835212502003`*^9}, {3.4559839227474003`*^9, 
   3.4559839264446*^9}, {3.4559844871242*^9, 3.4559845140341997`*^9}, {
   3.4559846532953997`*^9, 3.455984686773*^9}, {3.4559847455382*^9, 
   3.4559847613878*^9}, {3.455984822571*^9, 3.455984848233*^9}, {
   3.4559849267790003`*^9, 3.4559850218297997`*^9}, 3.4559850706422*^9, {
   3.4559923511654*^9, 3.4559924502888002`*^9}, 3.4559925135467997`*^9, 
   3.455992831038*^9, {3.4559928662316*^9, 3.4559928895692*^9}, {
   3.4559929346688004`*^9, 3.4559929407684*^9}, 3.4559930058672*^9, 
   3.4559931124776*^9, {3.4559931659388*^9, 3.4559931816324*^9}, {
   3.4559933376168003`*^9, 3.4559934068652*^9}, {3.4559939297304*^9, 
   3.4559939587776003`*^9}, 3.45599446077*^9, 3.45599449626*^9, 
   3.4560554175996*^9, 3.4560562055088*^9, {3.4560562733064003`*^9, 
   3.4560562847412*^9}, {3.4560563700108*^9, 3.4560564175128*^9}, 
   3.4564976113908*^9, 3.4566641080536947`*^9, 3.4569340656135745`*^9}],

Cell[BoxData["6.7045002814055225`*^6"], "Output",
 CellChangeTimes->{{3.455982944877*^9, 3.4559829658901997`*^9}, {
   3.4559835009858*^9, 3.4559835212502003`*^9}, {3.4559839227474003`*^9, 
   3.4559839264446*^9}, {3.4559844871242*^9, 3.4559845140341997`*^9}, {
   3.4559846532953997`*^9, 3.455984686773*^9}, {3.4559847455382*^9, 
   3.4559847613878*^9}, {3.455984822571*^9, 3.455984848233*^9}, {
   3.4559849267790003`*^9, 3.4559850218297997`*^9}, 3.4559850706422*^9, {
   3.4559923511654*^9, 3.4559924502888002`*^9}, 3.4559925135467997`*^9, 
   3.455992831038*^9, {3.4559928662316*^9, 3.4559928895692*^9}, {
   3.4559929346688004`*^9, 3.4559929407684*^9}, 3.4559930058672*^9, 
   3.4559931124776*^9, {3.4559931659388*^9, 3.4559931816324*^9}, {
   3.4559933376168003`*^9, 3.4559934068652*^9}, {3.4559939297304*^9, 
   3.4559939587776003`*^9}, 3.45599446077*^9, 3.45599449626*^9, 
   3.4560554175996*^9, 3.4560562055088*^9, {3.4560562733064003`*^9, 
   3.4560562847412*^9}, {3.4560563700108*^9, 3.4560564175128*^9}, 
   3.4564976113908*^9, 3.4566641080536947`*^9, 3.4569340656505747`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxd2Hk81M//APAlShFCSGIdKTlacp8zrghZN7uLFVEpuYqID8ktt5Aj5Ugq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     "]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.455982944877*^9, 3.4559829658901997`*^9}, {
   3.4559835009858*^9, 3.4559835212502003`*^9}, {3.4559839227474003`*^9, 
   3.4559839264446*^9}, {3.4559844871242*^9, 3.4559845140341997`*^9}, {
   3.4559846532953997`*^9, 3.455984686773*^9}, {3.4559847455382*^9, 
   3.4559847613878*^9}, {3.455984822571*^9, 3.455984848233*^9}, {
   3.4559849267790003`*^9, 3.4559850218297997`*^9}, 3.4559850706422*^9, {
   3.4559923511654*^9, 3.4559924502888002`*^9}, 3.4559925135467997`*^9, 
   3.455992831038*^9, {3.4559928662316*^9, 3.4559928895692*^9}, {
   3.4559929346688004`*^9, 3.4559929407684*^9}, 3.4559930058672*^9, 
   3.4559931124776*^9, {3.4559931659388*^9, 3.4559931816324*^9}, {
   3.4559933376168003`*^9, 3.4559934068652*^9}, {3.4559939297304*^9, 
   3.4559939587776003`*^9}, 3.45599446077*^9, 3.45599449626*^9, 
   3.4560554175996*^9, 3.4560562055088*^9, {3.4560562733064003`*^9, 
   3.4560562847412*^9}, {3.4560563700108*^9, 3.4560564175128*^9}, 
   3.4564976113908*^9, 3.4566641080536947`*^9, 3.456934065766575*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VVsbAHCEzNO5DUpokAihidC7lyEKlZlzzjaWohKijE1kvEpFlJBI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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwVz3s0lHkcBnB3S9Mw3qmzrcWQKAw5XWTb+v2+aXMdyTDzjlplMK4RmbJh
t5RwdtVsVIy141K6LW3b6KRaJVPu0xaxos0xpuyUSpoal9h3/3jOcz7/PY+9
MDU01kBPT49D5f+u+F5o4hmTtbEpsHNd4qgaKXpYQXyWAEXGpATpmAo8f7/p
MIuVgGqmXZ+1MntxxZ0iO2PWd4h3PDRBxhzFyRvEuz/aFSJOrXxVAPM97pmJ
L3lrV4aevFZ0WxNGYDo44jxudwH131Lt2k9nQlWHLO2lXSPqDF9rZzG7FOov
Fw4mu3egPRqnHPbB1RCHHpa9Su9BS26frhlo2gAp6hUqef0A2hH6xc07NB8w
tz/i/GzdMMqfcxvTsHzhmGWnS9UuFVrqefFh1/cBIBwMu23Y9RyNlKZWDtVx
IO3eEWGqswbJjIP6RR4hcGUPjfu5/zg6LijuD9i8DaqykjQr+W+RtOpQk/uW
UMiVzW57/2oC7V9kypYyuaDXM4xvHZhEc7SVnLQWLjhliDLDXLSow2+LzWtR
GIxqT/MW/PkBefnkmEo1YRCgTsw5kaZDuZ2iEw6icAgelbja2k6jFWX+Ow0f
hIOmRXiwrW4GeUcGJ6U58sCd0Wfjs/MTsmU6ep0R88AcaaOGJucQjWWA0HUe
+I5HfHQI18O1mTPXVB958PfdGP0IN32skHndm3XnQ0OBIpKl1cchY7G513fw
QWQsHlYqDfDq4eIhXQEfotOzGmhSQ5yMejlv6/jgEeeqDIoywqoCxbJKJR8e
WLktEHsb4z6ux1Hpaz7crM8tdzM0wSEv9MdPmJGQpe8S0vXUBFeePZ9PdyTB
fOiAX4rcFC8Si1jl60lQ19qXyLI/w4vz28ert5JQsnyJUWO4GYY28nB2NAkS
qag1imWO2bKk5vQMEiJKvlXSXpjjtIsB5i2HSdBtPjsla1qAZ553PKUXk6BS
b8q8m0/D7Pn28bWVJFRv8LTujlqI23YnfCOsI6EuT8yIY9PxL2a/GTdfJyE/
PDrQUEvHqoSXXJsWEtYMVV3I77bAj+eirhZ1k1C6oryuO9ASlzvEO1X0kfDD
naLSwEZL/FwkkjY/I4FjHX62w5GBx+p7R63HSICU1u2MQgYmkWtezBsSZF8K
Hbu0DPy+lHay7QMJji3nTgVvt8LVkhEn9In6x77r8qjJCu8t8m5dbSgA0aTR
w3YXAsvmxEf9zAQgvPKOVXicwGHJJvRf6QJIzuXOBvxMYPs1sW4NlMVceT+t
mMDX1nds7qJcoBUfk5wicJnz5ehpyvXeUzOnKwhstdUmgmchgKnm+b7aSwSO
bAx2XWgpAMkjWpGilcD+V3XJ+xgCkNbsjj/aTuAJX/2/fqJck6H08esk8MCF
rewaytcWS6Y7lQS2kNzre0B5KIKI73lM4H96AtXLrQTgrFriM6Ii8EmT1HcD
lFfKD9ieURNY79yN6TeUv8obnIp9QeAr1YmfjAkBBDlX/P6vhsA3V81PeFJO
T2LZTkwQONPXo7SQcvbXh6b+mCTwmdBHe2WU8xaO9GZoCZwjH/NvoFx6ueZH
nY7Ay1/uUw9Trj5oFHdjmsBF4ncXP1C+tC12U/YsgW81jyXSmAKQO9y32ThH
7Tu/fZkD5aZJp6n5eQJ7GHCeeFH+D+vRKZc=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.455982944877*^9, 3.4559829658901997`*^9}, {
   3.4559835009858*^9, 3.4559835212502003`*^9}, {3.4559839227474003`*^9, 
   3.4559839264446*^9}, {3.4559844871242*^9, 3.4559845140341997`*^9}, {
   3.4559846532953997`*^9, 3.455984686773*^9}, {3.4559847455382*^9, 
   3.4559847613878*^9}, {3.455984822571*^9, 3.455984848233*^9}, {
   3.4559849267790003`*^9, 3.4559850218297997`*^9}, 3.4559850706422*^9, {
   3.4559923511654*^9, 3.4559924502888002`*^9}, 3.4559925135467997`*^9, 
   3.455992831038*^9, {3.4559928662316*^9, 3.4559928895692*^9}, {
   3.4559929346688004`*^9, 3.4559929407684*^9}, 3.4559930058672*^9, 
   3.4559931124776*^9, {3.4559931659388*^9, 3.4559931816324*^9}, {
   3.4559933376168003`*^9, 3.4559934068652*^9}, {3.4559939297304*^9, 
   3.4559939587776003`*^9}, 3.45599446077*^9, 3.45599449626*^9, 
   3.4560554175996*^9, 3.4560562055088*^9, {3.4560562733064003`*^9, 
   3.4560562847412*^9}, {3.4560563700108*^9, 3.4560564175128*^9}, 
   3.4564976113908*^9, 3.4566641080536947`*^9, 3.4569340660255747`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ggg", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "ac"}], "//.", "greenOPO"}], "/.", 
     RowBox[{"\[Delta]l", "\[Rule]", "1"}]}], "/.", 
    RowBox[{"L", "\[Rule]", "0.5"}]}], "/.", 
   RowBox[{"\[Omega]", "\[Rule]", "10"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"gs", "=", 
  RowBox[{"ggg", "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "\[Pi]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Re", "[", "ggg", "]"}], ",", 
       RowBox[{"Im", "[", "ggg", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["gs", "2"], " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
        FractionBox["gs", "2"]}], ",", 
       RowBox[{
        FractionBox["gs", "2"], " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}]}], "Input",
 CellChangeTimes->{
  3.4559835814974003`*^9, {3.455983611777*^9, 3.4559836246314*^9}, {
   3.455983670745*^9, 3.4559837959194*^9}, {3.455983829943*^9, 
   3.4559839290810003`*^9}, {3.4559839834625998`*^9, 
   3.4559840631786003`*^9}, {3.4559944388364*^9, 3.4559944499435997`*^9}, 
   3.4560554930256*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"12.706548766854834`", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1.9449701194033406`"}], "+", 
      RowBox[{"1.8856254315755503`", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
      RowBox[{"0.08569860557215583`", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1.8366600265340756`"}], "+", 
      RowBox[{"1.8366600265340756`", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
      RowBox[{"0.16333997346592444`", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"0.8366600265340756`", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{"0.8366600265340756`", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"0.8366600265340756`", "\[InvisibleSpace]", "-", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], "3"]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.4559835822774*^9, 3.4559836189686003`*^9, {3.4559836845666*^9, 
   3.4559837963562*^9}, {3.4559838381798*^9, 3.4559839298922*^9}, {
   3.455984011527*^9, 3.455984063631*^9}, {3.4559944422995996`*^9, 
   3.4559944504272003`*^9}, 3.4559945027651997`*^9, {3.4560554691731997`*^9, 
   3.4560554936028*^9}, 3.456497611656*^9, 3.456664108303294*^9, 
   3.4569340660525746`*^9}],

Cell[BoxData["15.712221075177776`"], "Output",
 CellChangeTimes->{
  3.4559835822774*^9, 3.4559836189686003`*^9, {3.4559836845666*^9, 
   3.4559837963562*^9}, {3.4559838381798*^9, 3.4559839298922*^9}, {
   3.455984011527*^9, 3.455984063631*^9}, {3.4559944422995996`*^9, 
   3.4559944504272003`*^9}, 3.4559945027651997`*^9, {3.4560554691731997`*^9, 
   3.4560554936028*^9}, 3.456497611656*^9, 3.456664108303294*^9, 
   3.4569340660775747`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxd13k8VN/fAHCy72Mf+z7GzDAzZKnknpSSJVKWJFsllCWVkEoUKrIVCglF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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJw123k8VN//OPCxZd/3bWbs+0yiQjgvlaXlnSWEJJFdllIhlUiyJqTSRogk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     "]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.4559835822774*^9, 3.4559836189686003`*^9, {3.4559836845666*^9, 
   3.4559837963562*^9}, {3.4559838381798*^9, 3.4559839298922*^9}, {
   3.455984011527*^9, 3.455984063631*^9}, {3.4559944422995996`*^9, 
   3.4559944504272003`*^9}, 3.4559945027651997`*^9, {3.4560554691731997`*^9, 
   3.4560554936028*^9}, 3.456497611656*^9, 3.456664108303294*^9, 
   3.4569340661125746`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Slope & Pole (transmission)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753342766*^9}, {
  3.4559910067106*^9, 3.4559910093157997`*^9}, {3.4559910956618*^9, 
  3.4559910999049997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ComplexExpand", "[", 
    RowBox[{
     RowBox[{"W", "[", "0", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}], ",", 
       RowBox[{"\[CurlyPhi]", "\[Rule]", "0"}]}], "}"}]}], "]"}], "//", 
   "Simplify"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"%", " ", 
      FractionBox[
       RowBox[{"F", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
       RowBox[{"\[Pi]", 
        SqrtBox[
         RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
     RowBox[{"t1", "\[Rule]", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["r1", "2"]}]]}]}], "/.", 
    RowBox[{"t2", "\[Rule]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["r2", "2"]}]]}]}], "//", "Simplify"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"dc", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"t", "\[Rule]", "0"}]}], " ", "//", "Factor"}], "//", 
   "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"ac", "=", 
  RowBox[{
   RowBox[{"%%", "/.", 
    RowBox[{"t", "\[Rule]", 
     FractionBox["\[Pi]", 
      RowBox[{"2", "\[Omega]"}]]}]}], "//", 
   "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox["ac", "dc"], 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.4557430302679873`*^9, 3.455743031843588*^9}, {
   3.4557431199991875`*^9, 3.4557431216059875`*^9}, {3.45580788128125*^9, 
   3.455807893734375*^9}, {3.4558079250625*^9, 3.455807956609375*^9}, {
   3.4558080705625*^9, 3.45580809290625*^9}, {3.455808521421875*^9, 
   3.455808593265625*^9}, {3.455809050703125*^9, 3.45580909465625*^9}, {
   3.45580915059375*^9, 3.455809167328125*^9}, {3.4559870052762003`*^9, 
   3.4559870091918*^9}, 3.4559911037894*^9, {3.4559912307578*^9, 
   3.455991246467*^9}, {3.4559913123613997`*^9, 3.4559913171506*^9}, {
   3.4559922736334*^9, 3.4559923225238*^9}, {3.4559934428543997`*^9, 
   3.4559934440556*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"8", " ", "F", " ", "k", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "r1"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "r1"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "r2"}], ")"}], " ", 
   SqrtBox[
    RowBox[{"r1", " ", "r2"}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "r2"}], ")"}], " ", "\[Delta]l", " ", 
   RowBox[{"Sin", "[", 
    FractionBox["\[Phi]", "2"], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"Cos", "[", 
       FractionBox["\[Phi]", "2"], "]"}]}], "+", 
     RowBox[{"Sin", "[", 
      FractionBox["\[Phi]", "2"], "]"}]}], ")"}]}], 
  RowBox[{"\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}], "2"]}]]], "Output",
 CellChangeTimes->{3.4559911044758*^9, 3.4559912471066*^9, 
  3.4559913176809998`*^9, 3.4559914341974*^9, 3.4559917064798*^9, 
  3.4559923250198*^9, 3.4559934480959997`*^9, 3.4559940850284*^9, 
  3.4559945229048*^9, 3.4560555653004*^9, 3.456497614698*^9, 
  3.4566641113140945`*^9, 3.4569340696175747`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"4", " ", "F", " ", "k", " ", "L", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["r1", "2"]}], ")"}], " ", 
     SqrtBox[
      RowBox[{"r1", " ", "r2"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["r2", "2"]}], ")"}], " ", "\[Delta]l", " ", "\[Omega]", 
     " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"3", " ", "r1", " ", "r2"}]}], ")"}], " ", 
        RowBox[{"Cos", "[", 
         FractionBox["\[Phi]", "2"], "]"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"]}]}], ")"}], " ", 
        RowBox[{"Sin", "[", 
         FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"r1", " ", "r2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"3", " ", "\[Phi]"}], "2"], "]"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"3", " ", "\[Phi]"}], "2"], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"c", " ", "\[Pi]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"r1", " ", "r2"}]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r1", " ", "r2"}], "-", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"r1", " ", "r2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "r1", " ", "r2", " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.4559911044758*^9, 3.4559912471066*^9, 
  3.4559913176809998`*^9, 3.4559914341974*^9, 3.4559917064798*^9, 
  3.4559923250198*^9, 3.4559934480959997`*^9, 3.4559940850284*^9, 
  3.4559945229048*^9, 3.4560555653004*^9, 3.456497614698*^9, 
  3.4566641113140945`*^9, 3.4569340703285747`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"F", " ", "\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"2", " ", "r1", " ", "r2"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["r1", "2"], " ", 
          SuperscriptBox["r2", "2"]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["r1", "2"], " ", 
          SuperscriptBox["r2", "2"]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}]}], 
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.4559911044758*^9, 3.4559912471066*^9, 
  3.4559913176809998`*^9, 3.4559914341974*^9, 3.4559917064798*^9, 
  3.4559923250198*^9, 3.4559934480959997`*^9, 3.4559940850284*^9, 
  3.4559945229048*^9, 3.4560555653004*^9, 3.456497614698*^9, 
  3.4566641113140945`*^9, 3.4569340706305747`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"f00", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"dccr", "/.", 
     RowBox[{"rSB", "\[Rule]", 
      FractionBox[
       RowBox[{"t1", " ", "t2"}], 
       RowBox[{"1", "-", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "r1", " ", 
         "r2"}]}]]}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "1"}]}], "//.", 
   "redSHG"}]}], "\[IndentingNewLine]", 
 RowBox[{"fff", "=", 
  RowBox[{
   RowBox[{"dc", "//.", "redSHG"}], "/.", 
   RowBox[{"\[Delta]l", "\[Rule]", "1"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Re", "[", "fff", "]"}], ",", 
       RowBox[{"Im", "[", "fff", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Re", "[", "f00", "]"}], ",", 
       RowBox[{"Im", "[", "f00", "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Abs", "[", "fff", "]"}], "/.", 
     RowBox[{"\[Phi]", "\[Rule]", 
      RowBox[{"2", "\[Pi]", 
       FractionBox["n", 
        RowBox[{"2", "F"}]]}]}]}], "//.", "redSHG"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Re", "[", 
      FractionBox["fff", "f00"], "]"}], ",", 
     RowBox[{"Im", "[", 
      FractionBox["fff", "f00"], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Abs", "[", 
        FractionBox["fff", "f00"], "]"}], "/.", 
       RowBox[{"\[Phi]", "\[Rule]", 
        RowBox[{"2", "\[Pi]", 
         FractionBox["n", 
          RowBox[{"2", "F"}]]}]}]}], "//.", "redSHG"}], ",", 
     RowBox[{"Abs", "[", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "n"}], 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", "n"}]}]], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4559822894118*^9, 3.4559823309858*^9}, {
   3.455982370875*^9, 3.4559823966306*^9}, {3.4559828760030003`*^9, 
   3.4559828798094*^9}, {3.4559829367806*^9, 3.4559829655626*^9}, {
   3.4559835000810003`*^9, 3.4559835206418*^9}, {3.4559839224042*^9, 
   3.4559839258518*^9}, {3.4559844857202*^9, 3.4559845135818*^9}, {
   3.4559846571174*^9, 3.4559846846202*^9}, 3.4559847452262*^9, {
   3.455984840823*^9, 3.4559848477026*^9}, {3.4559849066394*^9, 
   3.4559850694722*^9}, {3.455992349855*^9, 3.4559923822406*^9}, {
   3.4559924196806*^9, 3.4559924390558*^9}, 3.4559925128604*^9, {
   3.455992818558*^9, 3.455992829868*^9}, {3.455992864656*^9, 
   3.4559928887111998`*^9}, {3.4559929342788*^9, 3.455992940316*^9}, {
   3.4559929749636*^9, 3.4559929750416*^9}, {3.4559931097788*^9, 
   3.4559931117132*^9}, {3.4559931608844*^9, 3.455993181024*^9}, {
   3.455993331954*^9, 3.4559934064128*^9}, {3.4559934830868*^9, 
   3.4559935002*^9}, {3.4559935499016*^9, 3.4559935500576*^9}, {
   3.4559935839252*^9, 3.4559936067636003`*^9}, {3.4559938331664*^9, 
   3.455993836224*^9}, {3.4559940326280003`*^9, 3.4559940630011997`*^9}, {
   3.4559941457748003`*^9, 3.4559941666164*^9}, {3.4559942008428*^9, 
   3.4559942020284*^9}, {3.4559942414652*^9, 3.4559942881247997`*^9}, {
   3.4559943211032*^9, 3.455994387762*^9}, {3.4559944683204*^9, 
   3.4559944777896*^9}, {3.4559959265772*^9, 3.455995967184*^9}, {
   3.4560559767504*^9, 3.4560559906656*^9}, {3.456056076918*^9, 
   3.4560561300204*^9}, {3.4560561616572*^9, 3.4560561749952*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["670529.0288380502`", 
   RowBox[{"1", "-", 
    RowBox[{"0.9483037488062567`", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]]}]}]]}]], "Output",
 CellChangeTimes->{{3.4559942438831997`*^9, 3.4559942890296*^9}, {
   3.4559943216336*^9, 3.4559943570456*^9}, 3.4559943884796*^9, 
   3.4559944784916*^9, 3.4559945240123997`*^9, 3.4559959677612*^9, 
   3.4560555728508*^9, 3.4560556655304003`*^9, 3.456055991742*^9, {
   3.4560561145764*^9, 3.4560561303948*^9}, {3.4560561651672*^9, 
   3.456056178318*^9}, 3.4564976157743998`*^9, 3.4566641123904943`*^9, 
   3.4569340706955748`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"1.3410580576761172`*^6", " ", 
    RowBox[{"Sin", "[", 
     FractionBox["\[Phi]", "2"], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "+", 
      RowBox[{"Sin", "[", 
       FractionBox["\[Phi]", "2"], "]"}]}], ")"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"0.051696251193743326`", " ", "\[ImaginaryI]", " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "+", 
      RowBox[{"1.9483037488062567`", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{{3.4559942438831997`*^9, 3.4559942890296*^9}, {
   3.4559943216336*^9, 3.4559943570456*^9}, 3.4559943884796*^9, 
   3.4559944784916*^9, 3.4559945240123997`*^9, 3.4559959677612*^9, 
   3.4560555728508*^9, 3.4560556655304003`*^9, 3.456055991742*^9, {
   3.4560561145764*^9, 3.4560561303948*^9}, {3.4560561651672*^9, 
   3.456056178318*^9}, 3.4564976157743998`*^9, 3.4566641123904943`*^9, 
   3.4569340706985745`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxd13c8le/7AHArGaXl2HuvZO/x3MY5VvYMJSUlKySlFCFKokSUkYz4KBmZ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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJw12Xc4lf//B3AzO8Kx9yaRvblve2Ufh+wtDSlESCIlW2mIKA1RZBVR3S8r
oSgre48UkpGVz/d2Xb/f+edcj+s61/U+5/1+vd7383UdYe9gOz8KMjKyCXIy
sv13I5ppY5N3gUD2fy/VY/+GpKoD4b3p1aE7f3jRKTtPq6XcQLiaNCZ5ru8w
WnBT9exmaCC0HKh3onqvjEIIY9i0TiAQw+gC6AK10GehLeSJmwGg7c7c+mwJ
QcMJDufHngTAFRONN1l0hiip/+Uol0kAuOpj6tJkJug9Z3AKH/GHFFLMtftf
zNC3A3lsVkH+cOmQQdtiiCUKjUe/7i35wQ/WCZe/c1YozwdujrlTfiDeWxP5
8o4N2qLBdcptxheYf3rG1BfaomKq32efO/tCe7BXo9xdO3RNNZKCvN0H5CPu
VRHD7NFJGauhWE0fEL/3Y7hBywF18vYskX7uDalWZxO0fzmgVWaVp2Y5vSHd
Syun4hoRzXu4EX7lmheYmKlbKzM7opnSeT9LNz3B8jdD4Wy8I/o63qSR4pQn
jE+b0O/OOqL5t4webzZ6gFGmu95LDRLqdLJA88Brd2DP0dRViiGhyczl0F3q
BsZnAtwaKkio9JERx4lSV/jFNn4mcYiEIo3YeuprF4iRRT7nb5LQe4nRWbwt
x0GrMklNmMEJ/TiUslcx4gxfrpm7HWR3QgdEf1wP+OcE40/p947j3hb2sdEU
dwIZafq4BUYntJtPxJCfSAIKKvrF9D0SSvJv+7qe4gh6+d9kDi6Q0KW/Nw3y
O4hwP0f2MlcXCX1efebbLzYigN2kkn05CTU5Eh9S4u0AYcn0Vg5pJJTRh865
sMYehnWQoMcBJPSPQbXjPYI9XLWMv/lBh4QGbK/9sI60A6dfZqIch0hoe9MB
xetTttDY/+UB06Qjym9xcCe2zQa+1HZZG15yRGtdHwmBsQ0MkvX1CZo7ol1i
uz4smdYQ+ljwdB+7Izr+sWPz9JtjcEQiPbfuGRG1p0nydBiwhO4aBaLVWSLK
XUulFEZlCcOi2peuqhPRM4MhGe9CzeGnVUlPSKsDurJjtsdTawamlRqCfhkO
6MyQV6kAtRk4sxtNRDo5oB7DmWnlFSaQYd2u6fHDHmX9Jxpw0MUIXgU6YMvM
9qjHM4JxUrchBEdYSgwP2qHl8LRK19YQXN2Frdyf2qHfNrNO+7kYgFDZ3Tkd
PTs0mf8s+f3HKGA8y6dnI2zRdMdHhpnqKFDJOLbQGNmipzhyD2JdCHyiqPDc
PmSLrrg2PtpmRKBZloA5lNqgB/6mfsU8dMBnVkg6e8IadbwrUUEJ2pC59d/c
l0RrNLy3veWAlDZciTxhfO+INepEc1vY+IAWNEda27THWqG5icf85P+pQynD
s0Qq1WMof8uD26NX1cFgLFFXYs4SVT/WsJrOqg6XD5wIeH7PEvUKvlNtqaYG
K3freN9SWKL8qlp8P5+rQJOeprL1tDkqIRyq7cCpBJOSPy6+GzNF06Vu1r3u
VITmn94PdgpN0YVzhVflbiiCQ1DaDfUTpqh7QAsbM7UiGCyz8t/bMEFLI59c
u8+iAIemvs348JmgPCdi9nYm5eCJX3T073Qj1MkoN16SUwZUEya3nm3ro3za
2EuqEWn4ujpqnvddH115+ayC77E03GsaZaV6o4/OxvZ3DapIw/qvlrf8Yfqo
KgV/20t/KQgv/zxstoGibg/d3c//lQCXYPuIX/Qoyp++oENXKgblVuT+m9O6
aBE7p9fnNDFouXaGVPFaF+WzKarjOysG/5Y8Qpeu66LvXapDbJTFwE0od25a
The1Mt9Qq2kQhaTzYlQ3L+ugh90mI4+si0B7R0Kno4Y2ar/Rd1HhoTC0Viex
2a5roOwlY3V/0oQh0rVjoKBHA/W2kLr1N1oY73mmSZ0qDbSacuRHi7MwfH91
L8ElVAMdEglfdOYQhvWV3RLaTXW0sNJE3jFHCC6QpEuIjOrouMz0JnWaIPC5
ZBaOeKuimYN2nCfCBUGksFicx1wVHdMs0+DyEIQtT7LaJAVVNHbweTxRQRA+
UYbn/0emirrfzwuSGRCA7k/GrSqPVNC5phpZAxUBuOrmvXJsURndYKuoPcPF
D70so/+VPFJC0dENo5UD/AB1kT/yU5VQ508U2PN1PhCOKgp6F6GEqtfws9Z2
8wFaw2Z03loJrUwYlNXM4oMrNpVa7/YUUYt7tgK8XHwgkGex5++riJYGNC1X
6PNC2cxuobmZAirBeOTHmw1uEB23PJPwRQ7VG7DvT17iBouIWUGkWg4VqLNL
OTfLDYQurgahXDm0Kp0r4EIfN0ytZKZYB8mhtmMUPU5vuEEpntXtOK0c+vB6
I2YZzQ1cAZ/JJsyPoPK/3Z6WHeIGxsDw8vdzh9Hye6Yxu15cEMrVXBN8XhrV
MQrUaHblglXq/uN9HtLo4rlzE3dJXLAcZdvoaCmNip1Mj/Y8xgVC/kZsj8Wl
0XK900WnNbjgunsv2ckBKbRx6LpPABsXpDT2eF0ykkJvrJ0gk/zCCfJPfr64
ICeJGvIyx+gc54SPbloJu5riaMvOTKVCNQfEJ2crX+IQQS9NiJiUWHDARQv3
rd1YQTSnyrt/b4sAJUtN66ZEXpSFt7uXrIEACrcLXdKYuVD3C9/DhO8SQNyN
XF/OjICqpzGosoURYM+vfy/tCSuaK2yFxrkQIK7erK45lAV9dkOC6q4RAcLb
JqQmCxhR5g6WolvKBBhYY3HraqdFDacjeoYkCcAtVNE3GU2NcjMcau/kI0D5
wtLaE2EKVIbWwLgEd/9Wq9cVAgUqF7AwkYjb7tu/cC86CvRgs/ZFXdwdEzSZ
kivkaAbpjGwZLwEixH6i3Rg5WuNgE3+bhwC9VQ1pTz3JUS6HTu9oLgIkPjg+
J/uIDO09ohJRwE6A7N04nWinPeTVyaC9y7hvCScQI/T2EJuwvsdeuLVY1H0j
JfaQoNc7tqK4jU77295Y+4fwvBA4XMRGgF00dGQ24x9CPaLX8oaVABsoq2ti
2y4iUWBxaImFAIZt/Lna6A4iJCUW/g23sVPWn89SO0jFg5ebr3G/t4so9GHZ
QYR9khwv427TGiPPHdtGXm34nGfHHdz0XA65tI3oMP0R1mcmAGMii65d/RbC
6PZioIKJAK2WvedjtDaRxht2+vdxn2M8XkUmtonUV15vjsf979jI/WuMm0jE
6AleIu7SipPWBSN/kTl9f8otRgJ8rv3Xuxv7Fzkn/u6NEe6b5ze/uTdvIOPX
42z/0BOgh+FTarHdOlLfsP57BHdfQfZYjtY6ktBp9PwTbmLflFOa2Dpi8srE
9yFuj1MPKi5trCGvUi9S2OHOVJe6k5CzhpR1EHrf0BGgqzi7U3hqFfGpCryS
TUuA+lT56mvhfxBj6y3rq7gvX1bydfH6g2geW1YIwz2k+e+EguUfpHH4hyIR
90cyzjPTwn+QpM6jUhy4Lbl5Dvh/XkEs1+a/36chgIrOn9kesRVEqeYi3+sD
BOAq2QzMKV5G8j1sAopwUzMWqXVcXkZ+jt1qzsFdTZu+Q05aRoaTrepjcTMH
JllGUi4jdX2Nmea4aR4Yh992XUI+fOjum6ImQDwdDW0i8yLyNf5hrhjuIvvi
y2wRC0hhCkrkwp1waH1Bx2IBOf2kTZQRN8/2PdlTAgtIpmIUxRoVAUQqwnl6
mn4gdqtpzU24NdvujHcd+oEUfb3gGoR7wOKKQMSLOeTEKd+zHrgznGPbhmPn
kJvbHfcccNNJTI8b2s8hB+M3ZfVw3zFfURDcnkVKZegdCLjdrUaLdkxmETuH
tvxmSgKUfT5/0Gp6GnHOv01bj5ti3E179s00ckUgNrECt1ng+xNxydOIZWYa
5OMedvUvwhSnkd//HVSOwt143nzXK24K0cj6R62Ku1UzX0tGcBKpCfLRqqMg
gEbL5efGtaOIQ8xuZRXu83HyURv+o8iI5gXdUtxoShhvMfso8ukdVdJD3Jln
x/L4zo4grzkl167jdjuuefWI5DCi9nVc0AX3K9oL9evZA4iYj0g1EffetcNZ
IwYDCNMkwdUGd0bm0/TWle9I6DrNmBHu6IHw78+OfUcUMztrFHC/jEyIvUHd
j4hTNdYy4sZemHP1h/Ug5crrgbS4/fj1M3+J9iB/cyukqfa/PzSmUH3rRnzz
W8Z2yAlwvMtoUkuuG4mS4BH4hVvwcPFcy+xXxDvzlPP8vk9aE5dvfUWI8ppP
p3FHC7mvcht8RZ4+1wsdwY1wv7sTlt+FtNI2THTiHn+BNd949QWx1Ksv6sBN
L2AbtMv4BXnULxr3CXdV7l57yInPyO2fyv6N+5//uh0aINKBhL9VJq/BXaEz
KRx96xPCOxxsX41b6veb83QrrQj3e8Y3FbjH5k+O3TvWikzd8a94iTtMZami
8cBHxPt4RORj3J0jMiwakU3IaWcFr0e4bQxS5FgHGpGf29nOBbgNtj6WLKo3
It/N3aNz99d7czi8ZBMQJiHsaQ5uQ3HqvFQnQPRnPk3cxb2aw9sXUoMh9DNf
k7JxBxwa8r38+z1ikPhl4yZuyrwmd4dX75CG6eDQLNwJFkzTh8/WI5l7eQ/T
cU96Vf2dXq5FTD2lbdNw//yVpdFSVoNwdTgeSsXtW991ujj4DeLln914A7es
30X2qOUq5M/FJ9VJuJ8VhGgGlFUin/yINddxt2KjtcTgCqTr5eP2a7g3A26c
MpYvRxYmspYTcWskRzudGy1DftwVFNv35oEbT1zcXyI3Q8xPXMVNCOg5bzpa
jBSwsn1IwG0ftRau7l6EvJaJFN+3Tk6C9+HRJ0jI2ejceNzFl4QWhNwLkeOP
+MT2vS3sB1yjBchionP9FdwdshNq4vW5SPYvRb99b7Y2Huerv4O8fF4ksG++
jnI7jvosJC737Xwcbvlr35nEI5IRy5LAxn1b3w96JxQRh2g0VZTum3TxEv3F
8dOIz8jd4n1fZGAq4NBzwLrXeN7su6dnarmVORK7xqLRs++9w8U5c9cSMT/d
VfL99Sapvr3eMMjATG6ZIft+q3Ykc8cgG9uQ107ft90h8XUKwxzsiFr70r6P
ykRGMRnmY1n9G+77v8/xWNgok8gj7IPxh7F9UwkJSHM+eowhDWIh+/szGs+9
ICLyDEtNl2Tb389L/O2nFR49x1h3Pzbv++vEHTIDkReYrNuBpP39V9eaXSI9
KsVkWKZc989riyNdXz3zFdZIG6m6f75Zs5GLjocqsTdHlbT3z/+TX/W9E7ZV
mF5wql3y/v5Kfqi4lFmNKVqKle/XSxaZaNOrQzXYLUbvrf16Oky+SvvFthaL
lNS3y8BNqxNjv5T5FjOm/aWyX580d+qy1FnfYf3yb7BbuBclV7q97d5jmmGS
rrdxz/2bqszI+oCdD91uuof7T3DyWhQdYH5YnPtD3N/JnWR3kxqxho+CuYW4
P8dq19aoNWFK3G6LT3DnnS3mj5hpwr6NvG0rxk18RtP5H9KCWSjJhOz379vO
E3Eqm62YdvwPi/3+vhWlEMHw9BPW0WSvWYdbJvEi/Yx9G/a9Ud4OcBdSlvsU
lrVjlypVz3zB3e5Od9c64AvmZ3hp9iturWVJHiNCJ6ahFnuuF/f9Z+iubmMn
Zm1d3TyMe54yULggvQvT4TjivH+fUZ/wa3738ys2SzRWZcbvPyXDgGNhj3uw
yDbZn2y4iWXmvXd3ejCGpZVKLtxUq/l2H+x6sRph0TgR3EPTih4E8j4stS+Y
Xg13DurBO+fWj52csBzywV1W84tMlmsQWxaP7jyBW+XhYEVC8CBW2Pq2Pxg3
X9hx4YmWQUxw/rxYNG5xhN//SdgQNk9SL8vGTdeQuOjaPYxp5hundlDs3yes
f7LSx7AaRgHTbtyLJcFk9hNjGGn+Ifsg7ohl2dhk7nHMMax+cg53Z9heBPHk
OJbxKs+eCn9ekcZjf5EzT2AjPcrJCG7BDl8ncJzELptEe5villvyM2mMncQ+
hxVb2ODmk1u7/LFoEjMebLP3xF3Xlz7ftz2Jnc5L0YrD7ZD0k5c1fwq7kl57
qgW3zF/3or25aSyf0sW3c99fViolD83g5ylx5jtuuiu7bvaaM1i+m3XNAu48
44JHFSkzGM0xf0kW/Hkd7RR1JVNhFrsx1xvqjpvn8meD3qg5bNic7Tctnh+U
quvsclgXMH5nS2kC7hkFudpcvQVMTSsvQhi3GPvrf49OLWBp64XOmrj9vs5r
17UsYKdrOCRO475UkUHijfqJXZS0XO7D7cgSJVow/Qszs/8UVYfnm58aw82L
b5exVnfitTbcujtH8yPnl7GDA2TFA7hd4rT4qRl+Y9k7g8qbuC1SKBdy1X9j
9ckPvVTxvJVkwvHqx83f2DrNd8E3uN3pySV3zFew1A8qYW14PlO6btPPWfcH
C1gnig7jfvWxgLP56x8smG1rfhH3wRwFjrD5P5jlkz9vD+H58HnJU9cRwipm
8nv84nHcRDW1sM6zqxjl3LHQ37iVrqJMOpJrWP2JpTw5Bny9Ydu/pNvr2GKn
b9IGnm8/nZHo9Lm0iQVTdg8wHsTnkexfy2a3NrE8jihUFHduUI+5UvEm1kxR
7GiD+21CWD1z3yY25DV6rwR32xRpcfnIFta6XZbmj+ftAS6PSzajWxjLi6rU
/TzvaO1wtRjdwajfuW6Y4fOAXcvVqSS2PSxSN3EhEPeCIe9dE9k9jJWkvncN
9wM+RJLeaA9jckxOaMH97vfOfF74HrbwzYjZiEAA76/2V8kG97BXh5WOmnLg
efKZz9XXD//DsjJZ9ALweaX2wUx9Qg4ZBP7MW2LiJ8DszXVWLVUK+K4z1uKK
z09dS6qG8s7UcDet4PmkEn4fpb5SiyighUs7YxG9hng/ULmwTF5ghJeKhZOF
TgT478asvaoCC/geMWtoP0+AD6Z8QYRkVnC+obWN3iKAnhWbbw3eR2vtemIy
7/A8UkF0rAVOGN+8XPbtLwGSf7/hK1HlhYbdYWp6fQ6IkaIZrKYTBN3+gM+7
FRww6BIs+pFeBPjIRmzoSJwwufi4KkFWHAbLd8i3nTnhHQ1JqkNDHN6Sp6Yv
u3LC+8OsXMIm4vB6qzvohzcnDGQjTate4qCZzODAHcwJzxX8WnTvisNtmZtz
569zQmdn5edYGglIGJh/EfSBEx6/HfnksiIBs2Lx8bdRLigd/cNavSkFTE9+
3E4x5oLds13rzxikIYb8wWqKBRdESh04WSkgDQtq49sviFzwviKkj91IGoYw
6dDTQVxQQ/Qn0tyUhpySG9QMt7mgl65keUBJBha2FqWLNrhgTI2n6fONw3Dm
2l+yxlluuLO7W8uTJwfngpql55e4wYCYSuX+Wg4G9JOshf5yA+H8QFFLpxww
Ln661EbDAzFyw0Q6SnngFhDjZpLhgWG3yhG3k/JQHBPzNf4cDz6vudO2CR+F
5+eCWVQIvNDmdNspil4BWimesCNCvCAblH2hi1sB5uq2MgIO84JxhlqDrrQC
pPgsX2TS54WsEsGBAFMFuH/yxFHsLC/E75YrrV5TABay6UnBHl5gI3VVyzAq
wopATqD0az4wTmN3UzisBMLbpo2kZj7gon67+l1HCQQ36ynLe/jAo2HoyCMb
JVj9yfFhdpUPfvlE/ZcTrgTd0tlJIcr8MNrMce1okxI0yueEPHrPD2syCnoG
/srAoBFgLvlPADQvMv7g+aQCfOWChfJsgiB6tWStZVwFLo+UeV2SFgTjLQm9
wk0VeEEp2rzqKAi3xShnlqRUYfWRRrRntSC0GKSaTiWrwvCK541qRAiEpKnO
dLqogcO3x815R4WhbcnhZ5OUBnj01XZM6wuDML1q4nlzDei9WvAulCgMjZ9P
hl84pQEdgYTQsChhODuJBiWUawDTgVBuyXZhsPJoT+3X0wQ/X37K7xdFwC8l
e7jgjBbY2AylRWWJQG7ygpDFbS1Q+lZafrVYBFy1FNW832vB2J3Kg/1DInDj
jmHXCLM2nDrKJlNpIAp+8u8v69RoQ7NHLn+NjBis/Kf9wFFIF4pevMyjNBeD
d0FqOZXWukC5VPV76oQYTL/eXMuL1QUmGRgNKRGDpouaSWITuvCCrIxdQVUc
jJ5+yEBK9KDVQK2U/4wErDXYVbGUIWCiBPq30qVhUlaUpbtYH0RCuppjPkrD
lhb5+HK7PjR0Pui9SyYDHff3jkYt6sOvu8VBieEyUO55/P6MggF8WVQsNzx3
GBjPzogaYwb43MDq9bTiCMxgPQzG64bAcujy1XAKObDw2t1wEzACWWJnhZyD
HJg+Vc5gMDXCc1+gfPY/OdhY5C5RyjMCjqsl8zQqR4GQzut/0NoYtNyDMrxH
8Drc/e/sRLcJXNdPjp7jUgTV8PejIzSmIF/5WIbWURFyuckHnmmbguvawwpS
ryK41k3xVxeZQmFHSf/vH0rAGPuWSi7ZDCJ9Rq0PKStDnnCNB3OLGZSWNxQQ
LyvDOv/bxxPk5nCXQkMmT1AF9EJmKU9FmwN7ximyZ1GqUBqPqT6MsYCX7Nk3
PQZUgfon44UszAKGVNOU9jTUYNAp2SiXyhLsuXUH/KjUYXi3kPtghiV8F4kT
iMGnQ0VKxGq76hjkp2ATJf/pwPzqyl4+vw1cYGJgk3+lC7rBtBd5rWygwLH8
OATowV+p9P/OxdpAyfGZw43hCHB2rvHUT9vA79VMymh5fag3jdhoqLWFp058
TbnP9eGblteG7Iot0PdoUdJKGwDfACnljLQdMAyFdE+pG4InvWWZb64d2DD7
Gr1+YgzVYUe9NZPtwVVpZp1gbwLdsisdCa32ELsZZn2d1hSadEUOWx9wgFmi
J9XZVDOYOndS/0C8AwyGz1kOupnDjZXv3m/BAfr1eTxQdQugo6xCosmIcJTs
84IK0zEgQDdlXAwRBL85HP9JawXmHJ/JPOuIwB7qLL3IYg3bg6Gu8ZtEgME0
kWVWG/glcaf0ibIjdPnneSo9tgEuhJkjItgRzjB3XbunbQu9XWViD4scYawy
IzJy2BbIjLIr68YcoddPilk2wQ5+USsVENlJcEiAT41e2R7k4ojnl4xIEJfD
33/ylz3EtaSsrZ8ngbssXeDTlw5gPsBS2pZHgvBmY4QhggiNWcYBNQ0kGL4y
GTtj4QjmTa8ebEyQYFn1d8YFaRKESPgyP9smQZtKlNwmixP4F/HY9TA4AVvz
/ek0Cmdo/9ZdepbdCTTmc/5Z7znDwnymBpHNCai1K7+pUbnAp20ZF5TGCWz+
nYwSZ3eFjy9klwaXSDDnZTDSc8QNOGaOCJa1koDVcF7iu4076LrzmSjfJMFF
TbHOjGgPADG33Q5LEsjQ8QqxO3mCxNTs/Y5VR+AXPqdquO4JTIKnUmISHSGC
yctOJtsLPFaiIqUpHaHCmC1lRdUbDFTkakUDiTA8qtlxf8Ab/pR4bvdWOsBO
xzI/WbQP1B7t1eictgfrJQebNj5fADn/rp4tO4hr1raIfusLolMHlNfx+vpM
pLgQYu8HSl42Dfc7bGAuJi9pesYPzo0sGJqxWUONusby32B/yHZXoR+zs4Sk
EjY8xPuDIZVWzpizGZxZ5P3s4BMAR+lOsoYcNoYqf13FgdYAUJS6a0PdoQ92
IpYmtwQCgR+zZX51RRdmMjRO7XkHQqX7JnWtmBrUP5h5+e1WINSeC5U5wScP
daz0DvyVgUDllJ3XZiAI////78mbAnYuZsHv/wf+s2kJ
     "]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.4559942438831997`*^9, 3.4559942890296*^9}, {
   3.4559943216336*^9, 3.4559943570456*^9}, 3.4559943884796*^9, 
   3.4559944784916*^9, 3.4559945240123997`*^9, 3.4559959677612*^9, 
   3.4560555728508*^9, 3.4560556655304003`*^9, 3.456055991742*^9, {
   3.4560561145764*^9, 3.4560561303948*^9}, {3.4560561651672*^9, 
   3.456056178318*^9}, 3.4564976157743998`*^9, 3.4566641123904943`*^9, 
   3.456934070754575*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4FYsbB3BKtlR0SjdXopJdWVpEvfM6ZN+O7YxE2dvTVVlTKSqpQ1RI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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.4559942438831997`*^9, 3.4559942890296*^9}, {
   3.4559943216336*^9, 3.4559943570456*^9}, 3.4559943884796*^9, 
   3.4559944784916*^9, 3.4559945240123997`*^9, 3.4559959677612*^9, 
   3.4560555728508*^9, 3.4560556655304003`*^9, 3.456055991742*^9, {
   3.4560561145764*^9, 3.4560561303948*^9}, {3.4560561651672*^9, 
   3.456056178318*^9}, 3.4564976157743998`*^9, 3.4566641123904943`*^9, 
   3.4569340708105745`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxdmHc81e/7x5GQUdKiKDtNNCjhkvCJUlRESpKsIlGiUkYJbStF9kqZKdtl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     "]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.4559942438831997`*^9, 3.4559942890296*^9}, {
   3.4559943216336*^9, 3.4559943570456*^9}, 3.4559943884796*^9, 
   3.4559944784916*^9, 3.4559945240123997`*^9, 3.4559959677612*^9, 
   3.4560555728508*^9, 3.4560556655304003`*^9, 3.456055991742*^9, {
   3.4560561145764*^9, 3.4560561303948*^9}, {3.4560561651672*^9, 
   3.456056178318*^9}, 3.4564976157743998`*^9, 3.4566641123904943`*^9, 
   3.4569340708485746`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzXs0lHkcx/HRDBZTGU9tRIy0TS6J09mLbt9flG2JyiUyR5vJtZHimD0Z
l0oXpl1WskIrxyXWqXHJpbRRLpvcRpm0asYmg9EY8zx2jEyp2Wf/+Jz3ef31
seWc8otYRqFQfMj93+I0joFrePKuuUftXT3MlF1dYub+IOYRaGcMlQYOHAHd
k7YLTGYMmCwR0WsGYqD4cZaNPjMJtp/25cr6kyB2J+/kexsBsDIvKnj9AhB/
jM4jbArB3PGd11xvIRhKxlmzNtWwYOes03ZVQ2lvSfyMTQu4WjBX+wlboKZW
IIl17gVDSsw2elAvRMHzQmWCGNYuc986YSmGuEl7WWPNKwiWHQhuTxoBY9uL
rDffjUEBK4lwvzcK2aZ9DqXHZOA/Jmzy1H8LHEnAI2r/FFRnpB4eNpVB/F8X
OadYCmhv2PIytG8C6k/T/c1/mIUVxUhitmUKSpO5CpcgAq7Z38wN5cshvWTp
0LxyDkTzGs/MC9NAEY+hh3w1VO+M0jHD38HGxMgzAQ4aGLRdedXuGwVMaK4f
NmldgIQCrdrzjQK8Jk+k5sYvQkfA4XpN6gz4TuQ4Wlt/AGnIkWQhTQmKTs65
p8KPMKR/735MghKcGS/Xefz4Ceg1b3ybXyvBGDRhUvVnuBOUvWmPyyx8Pxvy
fn0gBTFeGF+gps/CSEe4XoiTHuqcWmD0PJ2Fpsyuo0yNHlJmP/TIoKogUp83
JhItQ7URm1cf3aGC4wnJTfQiKhI8iU14xVXBlihH0f4wGrrcvePy8G8qGDRz
MuG56SM54x/+dJsK/qxJv+FENUDfPsjr/uWtCpL1HA72jxqgSAP9jhwqDsZS
/r64RkME7nFrntniMFlpm1eS8gUKljdEXNmOQ94mC1pLoBGSzzf6GQXikFMU
2R3GNEZfDY4VDZ3AISQvVESXG6N2Fzd5ahoOi3tuaUvaTFAfd/gnu1wcZJPu
Zzoy6GjugA/PqByHsp2ulgNhy9HIHwtV6gYchJd4jKjNK5A4snN3dgcOGYHH
vamaFehodPOUdBCHr6Wl1RkDK1EDe+/BvaM4FNjfEA54myJehWfs9DQOZx9n
FXi3mKJWLeV85TwOPpaBt3o3MJBS8GnmmA6H3XHdbIaAgUwelc2E0ggoseJs
6NcwENvASWdlRMCGzqp8X7YZIuZHsjyWE5CzucNhqM0M1abxfdYwCIhU0573
OGBIZZ8U/nkVAZz6f5mCXzE02vrej2tOQGy6/5LXVQwZLtU58knz/Bv/pl/D
kFffNYqAdKaGl52TjyH/YMnNStI1btqP14sxZHUnX/iWtLZd97LyNoaeccdW
BVmQ/0P0rK5uDIUnNWGwloCi8pPRl3swNORhk+hDujxR5LGvD0Mb4yXP2KSb
v8z50CfCkOfMgbNnSEtDsGjxMIbKdd519aRZMguPcRmG2CYVx+0sCXBp5FtX
TGJIPtotcCW97ZJEGyHHUO/dQ3eA9H5Wcd07BYbuuv0+xSadwGVaz81hSMB3
dskjnbLjvPauGkPjthVuZaQvLR9/kajBUOsJAdSRLqgt/3lxEUOrq6pQP+my
c7SoBx8wFLU0vv016duHItxTljAkbc7dOk26cf2Tdbs+Y8jR4D5rgXSbeqNW
p8NQmkWAOc2KgP8A37RUaA==
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwtz3lMkwcYx3Eql6uowLspiNJKVEapgkw8Yc8jmHlQGFA6x6VS5VABkdCE
0+GFolOLMBUYA6zg0FFlqSYwBQWsUi6FcTjqQEpBS9sXxGoLnexdsj+efPP5
68lvOf9IcPQcExMTf+r+a8kxvsXaAxlfp/zf5m4mZzczFJLS4yJ4VGel9SeZ
zIMgrLN9Yke15NEFhjkzDbL7ElaOMtIg3luQ8JGRC8b8I2czqHbPxBVMMAoh
Td7HpjkWguXAsLOGUQUbpMc3e9hVQbms9Og4oxZ8L9txWLRaEN/JHYhfIwNv
9b2c1MoWiIUXherkbmgVDZ57XtwFiUoXhUT8EoxbJyMbevqAvvyU8+DGIdjU
hWEeE3K4aN3KKt+nAM+lQbU784eAPxDSYNo2CiE+S7rc8obh6JNT/CPOKqjv
n0hzwxGoSbLi2u3UgLdozlBZkRLKMw6r3HdPgDqxLZzzahROlBqD3qsnwamz
R5g3OAYm3UP4IH0KtjbLmrh1b2BVSkxqCEsHnn7tP7/OeQsjuqvfzXv4ASr0
g6IyVxXsUh7KunxUDzfvt+ndpSoIGBG6OjpOQ8XznImDO8dB1cTPflY9A9Wb
y3L9JeOwxqZ3me/ef0AyHfhMaa8GOuii5FOfQLxk7+CWBDVs14R9dOKZIG/s
+wH5AzX0Nx6ghbFpeL79kL6NpoF7Z5v3MHU0HN8o+Ml8iwZizAVDHR1zsFvq
cHJ/sgb2J2fcsyoyRYcW1hc3yjTgFuvawYkyQ0XwjZe5LRrotGXPE2wyx1DX
2LwfJzXwh/hEMdvUAjdkHd7lR2ghg8YKbHtlgczFbn8nrNMCXZ6+I1FiiVWX
KmUjQVpQVi4vKM2ci4vbwyvfH9JCwZf2ZrW8zzBgeK1YdlILwqKYp1FMOhof
B900LdRCWEFkh9UYHfWF3Gr2b1rQb6swlNbPQxHdlxHYoAWF0ie18YwVhroM
eEo7tXDde61De9R8fF86E4NDWqg+LbCJXb0AJetPBaRrtXCGt9/PVLcANwY3
9ifNaMFTXl51pn0hZm0XHcueS8I1l+Lqdj9rPMCMzuslSPjh0YVrfrXWKJvf
PP4NgwR/B16FbIUNXvpWGFLnQsLWxKfhNrk2eH8ihNfnQULpUv6KNp0Nkn8p
qhZ5kbCi6eaVgHBb5C483s/eRoJwdSOrq94Wby17V1PuR0LMlNmLFhaBLH/3
LV5cEvg175i5lwis6pU3vwklIf4E17grj0C1z2CNeRgJAq6kzyqfwJW3Yq86
UT6rE1wUXiGwrOhzTgRl8SbDzNUSAl0YqyI6KRsez/ZW3iZQSUTaS8Kp/11W
F5qfEhgQfNE+NZKEIlFCXE4LgecVrksLKItSOnx3tBKY9OGXxXcp318knG7t
IPA1Z6FhjLI8jIjr7iGQtj4iZvceEpwV9r7DCgInMxvU6/aS4C5Jd7yhJLB4
XU9WIOXNpwcM0WMENv06ahlPmeNccvetisC7HhaWIsrJh5mOk5MEPjyXVmO9
j4RMr+OG36eofeNiOpvy6fnDf6boCBySvovYTvnaHdF5vZ5A8L6jzqJ8Pdss
tm6aQGMGm1VI+XZQtE+mkcCvjj3eJ6EscZIu+/oTtS8/SdhJuX5qlWF2lsAa
uletivK/dHNWKA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.4559942438831997`*^9, 3.4559942890296*^9}, {
   3.4559943216336*^9, 3.4559943570456*^9}, 3.4559943884796*^9, 
   3.4559944784916*^9, 3.4559945240123997`*^9, 3.4559959677612*^9, 
   3.4560555728508*^9, 3.4560556655304003`*^9, 3.456055991742*^9, {
   3.4560561145764*^9, 3.4560561303948*^9}, {3.4560561651672*^9, 
   3.456056178318*^9}, 3.4564976157743998`*^9, 3.4566641123904943`*^9, 
   3.456934070936575*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coherent Field", "Section",
 CellChangeTimes->{{3.4559752043442*^9, 3.4559752102254*^9}, {
  3.455975241285*^9, 3.4559752428606*^9}, {3.4559975049938*^9, 
  3.4559975163662*^9}, {3.4567040865865746`*^9, 3.456704099681575*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["E", "aux2"], "=", 
    RowBox[{"\[Eta]", " ", 
     RowBox[{
      SubscriptBox["E", "aux"], "\[Conjugate]"}], 
     SubscriptBox["E", "green"]}]}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["E", "aux"], "=", 
    RowBox[{
     SubscriptBox["A", "aux"], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"\[CapitalOmega]", "+", 
           SubscriptBox["\[Omega]", "M"]}], ")"}], "t"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "aux"]}]}]], "(", 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["a", "p"], 
        SuperscriptBox["e", 
         RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}], "+", 
       RowBox[{
        SubscriptBox["a", "m"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]]}]}], 
      ")"}]}]}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["E", "green"], "=", 
    RowBox[{
     SubscriptBox["A", "green"], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"2", "\[ImaginaryI]", " ", "\[CapitalOmega]", " ", "t"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "green"]}]}]], "(", 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["g", "p"], 
        SuperscriptBox["e", 
         RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}], "+", 
       RowBox[{
        SubscriptBox["g", "m"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]]}]}], 
      ")"}]}]}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.4567041596545744`*^9, 3.4567042225205746`*^9}, {
  3.4567063426835747`*^9, 3.4567066676475744`*^9}, {3.4567073113305745`*^9, 
  3.4567073556855745`*^9}, {3.4567455344912944`*^9, 3.4567455370502944`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"coh", "[", 
   RowBox[{
    RowBox[{"eaux_List", "?", "MatrixQ"}], ",", 
    RowBox[{"egreen_List", "?", "MatrixQ"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"coh", "[", 
   RowBox[{
    RowBox[{"First", "/@", "eaux"}], ",", 
    RowBox[{"First", "/@", "egreen"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"coh", "[", 
   RowBox[{
    RowBox[{"eaux_List", "?", "VectorQ"}], ",", 
    RowBox[{"egreen_List", "?", "VectorQ"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"\[Eta]", 
   RowBox[{"(", GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{
         "eaux", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         "\[Conjugate]"}], 
        RowBox[{
        "egreen", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
          "eaux", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          "\[Conjugate]"}], 
         RowBox[{
         "egreen", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
        "+", 
        RowBox[{
         RowBox[{
          RowBox[{
          "eaux", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
          "\[Conjugate]"}], 
         RowBox[{
         "egreen", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
          "eaux", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          "\[Conjugate]"}], 
         RowBox[{
         "egreen", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
        "+", 
        RowBox[{
         RowBox[{
          RowBox[{
          "eaux", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
          "\[Conjugate]"}], 
         RowBox[{
         "egreen", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}]}
     }], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Egreen", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", "green"]}]], 
     RowBox[{"LaserPN", ".", 
      RowBox[{"(", GridBox[{
         {"1"},
         {"0"},
         {"0"}
        }], ")"}]}]}], "/.", 
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     SubscriptBox["\[CurlyPhi]", "green"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eaux", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", "aux"]}]], 
     RowBox[{"LaserPN", ".", 
      RowBox[{"(", GridBox[{
         {"1"},
         {"0"},
         {"0"}
        }], ")"}]}]}], "/.", 
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     SubscriptBox["\[CurlyPhi]", "aux"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["cav", "green"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"cav", "/.", 
      RowBox[{"k", "\[Rule]", 
       RowBox[{"2", "k"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r1", "\[Rule]", 
        SubscriptBox["r1", "g"]}], ",", 
       RowBox[{"r2", "\[Rule]", 
        SubscriptBox["r2", "g"]}], ",", 
       RowBox[{"t1", "\[Rule]", 
        SubscriptBox["t1", "g"]}]}], "}"}]}], "/.", 
    RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["ccav", "green"], "=", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      SubscriptBox["cav", "green"], ",", 
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["T1", "aux"], "=", 
   RowBox[{
    RowBox[{"T1", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r1", "\[Rule]", 
        SubscriptBox["r1", "r"]}], ",", 
       RowBox[{"r2", "\[Rule]", 
        SubscriptBox["r2", "r"]}], ",", 
       RowBox[{"t1", "\[Rule]", 
        SubscriptBox["t1", "r"]}], ",", 
       RowBox[{"t2", "\[Rule]", 
        SubscriptBox["t2", "r"]}]}], "}"}]}], "/.", 
    RowBox[{"\[CapitalDelta]", "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["T2", "aux"], "=", 
   RowBox[{
    RowBox[{"T2", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r1", "\[Rule]", 
        SubscriptBox["r1", "r"]}], ",", 
       RowBox[{"r2", "\[Rule]", 
        SubscriptBox["r2", "r"]}], ",", 
       RowBox[{"t1", "\[Rule]", 
        SubscriptBox["t1", "r"]}]}], "}"}]}], "/.", 
    RowBox[{"\[CapitalDelta]", "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["cav", "aux"], "=", 
   RowBox[{
    RowBox[{"cav", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r1", "\[Rule]", 
        SubscriptBox["r1", "r"]}], ",", 
       RowBox[{"r2", "\[Rule]", 
        SubscriptBox["r2", "r"]}], ",", 
       RowBox[{"t1", "\[Rule]", 
        SubscriptBox["t1", "r"]}]}], "}"}]}], "/.", 
    RowBox[{"\[CapitalDelta]", "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["ccav", "aux"], "=", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      SubscriptBox["cav", "aux"], ",", 
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["refl", "aux"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["T2", "aux"], ".", 
     SubscriptBox["cav", "aux"]}], "-", 
    RowBox[{
     SubscriptBox["r1", "r"], " ", 
     RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["cav", "aux2"], "=", 
   RowBox[{
    RowBox[{
     FractionBox["cav", "t1"], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r1", "\[Rule]", 
        SubscriptBox["r1", "r"]}], ",", 
       RowBox[{"r2", "\[Rule]", 
        SubscriptBox["r2", "r"]}], ",", 
       RowBox[{"t1", "\[Rule]", 
        SubscriptBox["t1", "r"]}]}], "}"}]}], "/.", 
    RowBox[{"\[CapitalDelta]", "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", "k"}]]}], "\[Phi]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["ccav", "aux2"], "=", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      SubscriptBox["cav", "aux2"], ",", 
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Egreencav", "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "green"]}]], 
    SubscriptBox["a", "g0"], 
    RowBox[{"(", GridBox[{
       {"1"},
       {
        RowBox[{
         RowBox[{
          SubscriptBox["a", "g"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Alpha]", "g"]}]], 
          SubscriptBox["\[CurlyPhi]", "green"]}], "+", 
         RowBox[{
          SubscriptBox["b", "g"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Beta]", "g"]}]], "\[Delta]l"}]}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["a", "g"]}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            SubscriptBox["\[Alpha]", "g"]}]], 
          SubscriptBox["\[CurlyPhi]", "green"]}], "-", 
         RowBox[{
          SubscriptBox["b", "g"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            SubscriptBox["\[Beta]", "g"]}]], "\[Delta]l"}]}]}
      }], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gcavprm", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["a", "g0"], "\[Rule]", 
      FractionBox[
       SubscriptBox["t1", "g"], 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["r1", "g"], 
         SubscriptBox["r2", "g"]}]}]]}], ",", 
     RowBox[{
      SubscriptBox["a", "g"], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", "-", " ", 
         FractionBox["\[Omega]", 
          SubscriptBox[
           OverscriptBox["\[Omega]", "_"], "OG"]]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["b", "g"], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubscriptBox["F", "OG"], 
          SqrtBox[
           RowBox[{
            SubscriptBox["r1", "g"], 
            SubscriptBox["r2", "g"]}]]}], "\[Pi]"]}], 
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", "-", 
         FractionBox["\[Omega]", 
          SubscriptBox["\[Omega]", "OG"]]}], ")"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eaux2", "=", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["ccav", "aux2"], ".", 
       RowBox[{"coh", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["ccav", "aux"], ".", "Eaux"}], ",", "Egreencav"}], 
        "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eaux2Refl", "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]M", " ", "t", " "}]], 
    SubscriptBox["t1", "r"], " ", "Eaux2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EauxRefl", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"+", "\[ImaginaryI]"}], " ", "\[Omega]M", " ", "t", " "}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["r1", "r"]}], " ", 
         RowBox[{"IdentityMatrix", "[", "3", "]"}]}], "+", 
        RowBox[{
         SubscriptBox["t1", "r"], " ", 
         SubscriptBox["cav", "aux"]}]}], ")"}], ".", "Eaux"}]}], "/.", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["t1", "r"], "2"], "\[Rule]", 
     RowBox[{"1", "-", 
      SuperscriptBox[
       SubscriptBox["r1", "r"], "2"]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Esum", "=", 
   RowBox[{"Eaux2Refl", "+", "EauxRefl"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "n_", "]"}], "=", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"Conjugate", "[", "Esum", "]"}], "]"}], ".", 
    RowBox[{"det", "[", "n", "]"}], ".", "Esum"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"X", "[", 
       RowBox[{"+", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"X", "[", 
       RowBox[{"-", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4567055442955747`*^9, 3.456705572167575*^9}, {
   3.456705696648575*^9, 3.456705712318575*^9}, {3.456707508608575*^9, 
   3.4567075312015743`*^9}, {3.4567075687395744`*^9, 3.456707608707575*^9}, {
   3.456707679629575*^9, 3.4567077035055747`*^9}, {3.4567078745675745`*^9, 
   3.4567079532695746`*^9}, {3.4567079901915746`*^9, 
   3.4567080315185747`*^9}, {3.4567081170935745`*^9, 
   3.4567082140105743`*^9}, {3.4567082799445744`*^9, 
   3.4567083242315745`*^9}, {3.456708473964575*^9, 3.456708536127575*^9}, {
   3.4567086249115744`*^9, 3.4567086333965745`*^9}, {3.4567086680865746`*^9, 
   3.4567086781505747`*^9}, {3.456708785825575*^9, 3.4567088395455747`*^9}, {
   3.4567090753925743`*^9, 3.4567090785935745`*^9}, {3.456709130898575*^9, 
   3.4567091656945744`*^9}, 3.4567094495195746`*^9, {3.4567096121645746`*^9, 
   3.4567096159815745`*^9}, {3.4567096565245743`*^9, 3.456709728997575*^9}, {
   3.4567098147565746`*^9, 3.4567098164675746`*^9}, {3.456710056785575*^9, 
   3.4567100685595746`*^9}, {3.4567452330292945`*^9, 
   3.4567455308602943`*^9}, {3.4567457741502943`*^9, 
   3.4567457868202944`*^9}, {3.4567459009442945`*^9, 3.4567460061832943`*^9}, 
   3.456746133916294*^9, {3.4567462087122946`*^9, 3.456746214831294*^9}, {
   3.4567462847072945`*^9, 3.4567463102412944`*^9}, {3.456746376272294*^9, 
   3.4567464357572947`*^9}, {3.4567472746902943`*^9, 
   3.4567473489142942`*^9}, {3.4567473885762944`*^9, 3.4567473958792944`*^9}, 
   3.4567546809742947`*^9, {3.4567578686032944`*^9, 3.4567578787452946`*^9}, {
   3.4567647270422945`*^9, 3.4567647693892946`*^9}, {3.4568483066226945`*^9, 
   3.4568484563982944`*^9}, {3.4568487270582943`*^9, 
   3.4568487786942945`*^9}, {3.4568495786310945`*^9, 
   3.4568496296898947`*^9}, {3.4568496836970944`*^9, 
   3.4568497569702945`*^9}, {3.4568498090898943`*^9, 3.4568499303954945`*^9}, 
   3.4568499789114943`*^9, {3.456850087456294*^9, 3.4568500915122943`*^9}, {
   3.4571774074983997`*^9, 3.4571774205868*^9}, {3.4571774660608*^9, 
   3.4571774956696*^9}, {3.4571776492047997`*^9, 3.4571776563652*^9}, 
   3.4571782917844*^9, {3.4571783398324003`*^9, 3.4571784209992*^9}, 
   3.4572645212056*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Eaux2gen", "=", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"coh", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["ccav", "aux"], ".", "Eaux"}], ",", 
        RowBox[{
         SubscriptBox["ccav", "green"], ".", "Egreen"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Omega]", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eaux2genn", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"TrigToExp", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Eaux2gen", "//", "ComplexExpand"}], ")"}], "/.", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[CurlyPhi]", "aux"], " ", 
           SubscriptBox["\[CurlyPhi]", "green"]}], "\[Rule]", "0"}]}], "/.", 
        RowBox[{
         SuperscriptBox["\[Delta]l", "2"], "\[Rule]", "0"}]}], "/.", 
       RowBox[{
        RowBox[{"\[Delta]l", " ", 
         SubscriptBox["\[CurlyPhi]", "aux"]}], "\[Rule]", "0"}]}], "/.", 
      RowBox[{
       RowBox[{"\[Delta]l", " ", 
        SubscriptBox["\[CurlyPhi]", "green"]}], "\[Rule]", "0"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eaux2cav", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{"Normal", "[", 
            RowBox[{"Series", "[", 
             RowBox[{
              RowBox[{
               SubscriptBox["ccav", "aux2"], ".", "Eaux2genn"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Omega]", ",", "0", ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], 
            "]"}], "]"}], "/.", 
          RowBox[{
           SuperscriptBox[
            SubscriptBox["t1", "r"], "2"], "\[Rule]", 
           RowBox[{"1", "-", 
            SuperscriptBox[
             SubscriptBox["r1", "r"], "2"]}]}]}], "/.", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[CurlyPhi]", "aux"], " ", 
           SubscriptBox["\[CurlyPhi]", "green"]}], "\[Rule]", "0"}]}], "/.", 
        RowBox[{
         SuperscriptBox["\[Delta]l", "2"], "\[Rule]", "0"}]}], "/.", 
       RowBox[{
        RowBox[{"\[Delta]l", " ", 
         SubscriptBox["\[CurlyPhi]", "aux"]}], "\[Rule]", "0"}]}], "/.", 
      RowBox[{
       RowBox[{"\[Delta]l", " ", 
        SubscriptBox["\[CurlyPhi]", "green"]}], "\[Rule]", "0"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eaux2Refl", "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      SubscriptBox["t1", "r"], " ", "Eaux2cav"}], "]"}], "/.", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["t1", "r"], "2"], "\[Rule]", 
     RowBox[{"1", "-", 
      SuperscriptBox[
       SubscriptBox["r1", "r"], "2"]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EauxRefl", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{"Normal", "[", 
          RowBox[{"Series", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  SubscriptBox["r1", "r"]}], " ", 
                 RowBox[{"IdentityMatrix", "[", "3", "]"}]}], "+", 
                RowBox[{
                 SubscriptBox["t1", "r"], " ", 
                 SubscriptBox["cav", "aux"]}]}], ")"}], ".", "Eaux"}], "/.", 
             RowBox[{
              SuperscriptBox[
               SubscriptBox["t1", "r"], "2"], "\[Rule]", 
              RowBox[{"1", "-", 
               SuperscriptBox[
                SubscriptBox["r1", "r"], "2"]}]}]}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Omega]", ",", "0", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}],
          "]"}], "/.", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[CurlyPhi]", "aux"], " ", 
          SubscriptBox["\[CurlyPhi]", "green"]}], "\[Rule]", "0"}]}], "/.", 
       RowBox[{
        SuperscriptBox["\[Delta]l", "2"], "\[Rule]", "0"}]}], "/.", 
      RowBox[{
       RowBox[{"\[Delta]l", " ", 
        SubscriptBox["\[CurlyPhi]", "aux"]}], "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      RowBox[{"\[Delta]l", " ", 
       SubscriptBox["\[CurlyPhi]", "green"]}], "\[Rule]", "0"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4567479493422947`*^9, 3.4567479589202943`*^9}, {
   3.456748478199294*^9, 3.4567484995392942`*^9}, {3.4567537908452945`*^9, 
   3.456753796718294*^9}, {3.4567540419332943`*^9, 3.4567540915322943`*^9}, {
   3.456754134954294*^9, 3.456754136798294*^9}, {3.4567545773182945`*^9, 
   3.4567545908442945`*^9}, 3.4567546491612945`*^9, {3.4567547978782945`*^9, 
   3.4567548970882945`*^9}, {3.456755046211294*^9, 3.4567550755872946`*^9}, 
   3.4567551806322947`*^9, {3.4567552321632943`*^9, 3.4567552340872946`*^9}, {
   3.456755689166294*^9, 3.4567556938912945`*^9}, {3.4567557241172943`*^9, 
   3.456755827013294*^9}, {3.4567578883152943`*^9, 3.4567578936552944`*^9}, {
   3.4567692976752944`*^9, 3.4567692980112944`*^9}, {3.4567702238522944`*^9, 
   3.456770226206294*^9}, {3.456770270831294*^9, 3.4567702730692945`*^9}, {
   3.4572777166816*^9, 3.4572777178984003`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.4568641065270944`*^9, 3.456864106620694*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"F", "\[Rule]", 
    FractionBox[
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}], 
     RowBox[{"1", "-", 
      RowBox[{"r1", " ", "r2"}]}]]}], "/.", 
   RowBox[{"r1", "\[Rule]", 
    SqrtBox["0.85"]}]}], "/.", 
  RowBox[{"r2", "\[Rule]", "1"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     FractionBox[
      RowBox[{"2", "  ", "k", " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}]}], ")"}]}], 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}]], "}"}], "/.", 
    RowBox[{
     SubscriptBox["r1", "r"], "\[Rule]", 
     SqrtBox["0.85"]}]}], "/.", 
   RowBox[{
    SubscriptBox["r2", "r"], "\[Rule]", "1"}]}], "/.", 
  RowBox[{"k", "\[Rule]", 
   FractionBox[
    RowBox[{"2", "\[Pi]"}], "1.064*^-6"]}]}]}], "Input",
 CellChangeTimes->{{3.4569361784775743`*^9, 3.4569361848695745`*^9}, {
  3.4569392562765746`*^9, 3.4569392707485743`*^9}, {3.4569393052715745`*^9, 
  3.456939374160575*^9}}],

Cell[BoxData[
 RowBox[{"F", "\[Rule]", "38.65061732663428`"}]], "Output",
 CellChangeTimes->{
  3.4569361854355745`*^9, {3.4569393066795745`*^9, 3.456939374497575*^9}, 
   3.457113795443*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"1.0888741780630011`*^7", " ", 
    RowBox[{"(", 
     RowBox[{"0.9219544457292888`", "\[InvisibleSpace]", "-", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}]}], ")"}]}], 
   RowBox[{"1.85`", "\[InvisibleSpace]", "-", 
    RowBox[{"1.8439088914585775`", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}]}]}]], "}"}]], "Output",
 CellChangeTimes->{
  3.4569361854355745`*^9, {3.4569393066795745`*^9, 3.456939374497575*^9}, 
   3.4571137954586*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "k", " ", 
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
            RowBox[{
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}]}], ")"}]}], 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
           SubscriptBox["r1", "r"], " ", 
           SubscriptBox["r2", "r"]}], "+", 
          RowBox[{
           SubsuperscriptBox["r1", "r", "2"], " ", 
           SubsuperscriptBox["r2", "r", "2"]}]}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"k", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
           SubscriptBox["r1", "r"], " ", 
           SubscriptBox["r2", "r"]}], "-", 
          RowBox[{
           SubsuperscriptBox["r1", "r", "2"], " ", 
           SubsuperscriptBox["r2", "r", "2"]}]}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "k", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
           SubscriptBox["r1", "r"], " ", 
           SubscriptBox["r2", "r"]}], "-", 
          RowBox[{
           SubsuperscriptBox["r1", "r", "2"], " ", 
           SubsuperscriptBox["r2", "r", "2"]}]}]]}]}], "}"}], "/.", 
     RowBox[{
      SubscriptBox["r1", "r"], "\[Rule]", 
      SqrtBox["0.85"]}]}], "/.", 
    RowBox[{
     SubscriptBox["r2", "r"], "\[Rule]", "1"}]}], "/.", 
   RowBox[{"k", "\[Rule]", 
    FractionBox[
     RowBox[{"2", "\[Pi]"}], "1.064*^-6"]}]}], "/.", 
  RowBox[{"\[Phi]", "\[Rule]", "\[Pi]"}]}]], "Input",
 CellChangeTimes->{{3.4572258415405746`*^9, 3.4572258461385746`*^9}, {
  3.457226022549575*^9, 3.4572260516895747`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.665452583866139`*^6", ",", 
   RowBox[{"-", "239796.76498685553`"}], ",", 
   RowBox[{"-", "6.14504611383985`*^6"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4572258466215744`*^9, 3.457225977464575*^9, {3.457226023681575*^9, 
   3.4572260522135744`*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "k", " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}]}], 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}]]}], "+", 
   FractionBox[
    RowBox[{"k", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "-", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}]]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"k", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}]]}], "+", 
   FractionBox[
    RowBox[{"2", " ", "k", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "-", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}]]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4572259336315746`*^9, 3.4572259539405746`*^9}, {
  3.4572260620395746`*^9, 3.4572260720345745`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "k", " ", 
            SubscriptBox["r1", "r"], " ", 
            SubscriptBox["r2", "r"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
              RowBox[{
               SubscriptBox["r1", "r"], " ", 
               SubscriptBox["r2", "r"]}]}], ")"}]}], 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "+", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}]}]]}], ",", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"k", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SubsuperscriptBox["r1", "r", "2"], " ", 
               SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "-", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}]}]]}], ",", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "k", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
               SubscriptBox["r1", "r"], " ", 
               SubscriptBox["r2", "r"]}]}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "-", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}]}]]}]}], "}"}], "/.", 
       RowBox[{
        SubscriptBox["r1", "r"], "\[Rule]", 
        SqrtBox["0.85"]}]}], "/.", 
      RowBox[{
       SubscriptBox["r2", "r"], "\[Rule]", "1"}]}], "/.", 
     RowBox[{"k", "\[Rule]", 
      FractionBox[
       RowBox[{"2", "\[Pi]"}], "1.064*^-6"]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"Evaluate", "[", "plotopt", "]"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Detuning (rad)\>\"", ",", "\"\<Signal\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4569393915745745`*^9, 3.4569394783995743`*^9}, {
  3.4569618739625745`*^9, 3.4569620497685747`*^9}, {3.4569621759805746`*^9, 
  3.4569621903875747`*^9}, {3.4572256518675747`*^9, 3.457225662634575*^9}, {
  3.4572257091405745`*^9, 3.4572257181655746`*^9}, {3.4572257542705746`*^9, 
  3.457225755549575*^9}, {3.4572257887715745`*^9, 3.4572258225475745`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Hc0l38UB3Aj3++jIsoqGVGRqPhZSd3nI5usry8VSpJkRqHQULaUkGwa
RmRWNnlkJcnKCGWT7CgUfk9/3fM6557zed977vnssnI2usDEwMDgxsjA8K8y
v93YNCTncuxUnUFUxZNkYs/3iiOCEfrg98lqTpD0Su5B6+7ws7CWa2WEJyUT
eb/gM2f2RXhQVxEgGp9MjHDZLhWEO8NyVsj4+8fJxL3t9WzZpVegNmIbTS48
mUgVN09iyPaAIYUOCduQZKJSYfYQLdkLEq6s0i/cTSa+qPtWpYTfghYrHaVD
nuR7EpslvKt8wFY6sLjROZkIkOlwTSm9C0E33KXAOpngUkoubXrtBzY7TM7f
M00mniC7DUtZAeCUsxpVrJVMHNCSPbErLQj0LSMdG5WSiVKDtUfaySFwX2px
pkEimfh8NlwsIfwBROzQm3hOJef574DiUE0YTPDusdz5PYnwUIjo9ah6CO1n
Ii1XK5OIDWCx50lpBFR+N5MUt08iBPXmCn5mPQZHTaP80YxEYtjQxCwwIxqE
TR3Dpt0TiUx66frOtBhgT+OSCUKJhKKFn6Z6chxkbN8jXt6aQBg5bP8SHZ4E
pUxKn9jG4onNivA2SiMZjpt3Z0a/iCdmi104B2qSgSUp0ljFPp4oKO9441b1
BH45P3aRm4wjjtckryWWPoPUpxsFz4/GEhbtsmFzWWnwKb6h9Hd9NPFw3vxV
VHgOZNJa51/HRBKh3LHKlWy58JLZ/rq2cSTRmucnJGeUCy56Dw1ctkQSZhPm
I4I9uXDucPVoQEAE4WS2yWV+Mg9+yKnn0W6FE5FHbQNjOF4Dl+T+95SwMKK7
m2bPTn8N1DkDTjN6GCHoDnp3Y17DffnLGXb8YURaNg+Xo8gb+JRyW/o67QFR
IlSThMsWwMc/0nAiMZT4xihSOGZaBCf0aq/3XwsmdieyxZrHF8H2L2LqXjuC
CVulZe+W/iJQg5kwl/IgYt61WaX0UjF4na7hOU8NIjYM32y671UCWt5BKYsZ
AYTWbbs85soSuFZnupnVNIC4v9Mk8tqGUlCWvf/k9IYAgpcuddoqtBQKlXwD
0q38CYnanhG5pDKwUOZcvSnlRzhb1dVnDJXBQabc0W1DvsTrtfxMIfFyGJIg
mmtjfImjCsEurHnlILHpt5P7Rl/CIF1xtbeqAp6rFayFLN0hjtRob1S5Ugmq
4YsXd27wITjaUz8pRFRC//4flNCPt4nhQaZHUq8qYc8Gu7+Vj28T9xlKhbb/
rIRq67dKFw/cJgaP7JebdSUg49M2/pL6m0Rg/ibLRNcq8GC5qckz4EVYEBf3
RIZXwUz+5Ib3QV6ETPO7iaD8Klh1bPr28j8vonfKy81tvgq4N1QzLAZ7Egf3
TQbrur6DI6orQNG4TnQkNb5ZcakGR2cHccs5dyIzW9xr9mE1tBldrOTIdCdu
l/vio3nVwFcd5Zd9wZ3Y16P8oWWuGuRHzbuf9rkR3jxZ/ekuNSAdeK96Y9dV
QjQ0dJOpSy38FmjUHv/pSizFfW/WfVgLexgPt30qcSUaM9SiVPJqIeCaKu/l
O66Ee/2q8IG5Wnhwqijw0zZXooHZSZ7FpQ4oWw9klx9zIS576p17dbkeXu2e
jZCxcSa0nZTTsbB6KAy+ku6+0ZkQtZKYsciph5TRH7+bc5yIDi3KDWy6Hk44
V3AUrToSR7dXRFvYv4f2XV4WgykOxMYiqWaqTQNojownOe62I4Yz+Xkt/Bpg
UZkrzqDrElGRxHom/3kDlNEjxThCLxEuASM/zIcawPDski/fsi3RZZJAzbf8
AOmp3zlXvlwkUhY3g7lZIyQWMoL/uwvEze8rfnmejWBMdc7uuHuBONk33kiJ
bQRuDvZznaoXiM011afzuhphRaR05Vu9NeEa6e1OMfkIplP52Meu8wT+32RW
rkETYL2CTZI8VoRj0YX7TKLNEN8/H183b0H+X4bCjLLNcGz7iZyaBxbEbLdy
/rpqM7xMvMraJmVBXP2zreOvTTOAiWnDZkdzwvNYlcDvjGawX+LWiP59mvCv
Fsz6IdMCCR/bgncqnSQ06Rth4ngLbFnUv+kyakqwji42jxu3AA1C15IjTIl7
1I8LI+6k2V0O+86aEBHaXsr9JS1wM41/F/trOpHc3PmhXaUVepW2Co+dpRFW
595ZtNFa4czrDWXP+WiE6Hz2TIt1KxyPLWbmajUiUrf5b/vk3wre9Vk5a+pG
RJaJrNn7hlb48LKVWq9oSJT0hk2UG7XB/C+eI++u6hHt41qsaVbtYD/xsq/e
UIOYiRFXu+vaDjPsKmpyM+rERh2qz9k77YBNFCdcCVUn8KzqJd6n7RA0zMVt
0ahGZLrAeOBAO3inDTik0FSJOyuydXaWn6GFHlwm54+IhMxtzBqXP8NvzbKa
yoOIKDKfPyZ6+zPArrTav904MVWRU9CT9BkEdySa3D6EEyfvSqTqfvsMNWe9
uKgfjhIHNwv7HTjTAR5GU6K/exQJ7fK1yo1OHWCbnT4cfFyRsHbq+zt6owOU
2XJ6tF8qELHNsVeTEjrAnT/94nEfeYLyiNuao68DKONC36oVZYlegU3H5806
gbHD5tH+woNE8MFfDAWnuiDAnf0qk6cQ4emhtX/UrguizxesRrsIEJfextN5
vLvgW1TEFgVHfkJT/3iGe2IXBG6T3Gl5mZegOofRFIa6YPXRX/tw7S2Eb7ZE
apFDN0heyV0WEqqvvCl1Vqf01hf4UTzgr3pzB3Jyy3f7EfYFPBKEZIt4dyKL
cpZk/qdfwC49u00pWwApn3i54FX9BTylMxNULwmjPw7LCcqsPSDD907K31sU
XXsZMVse3gPudB/GsnP7kMv++keVKb2QWV72W1hQBg1fGL6dXNALainHF0Kc
ZJBJMoPD7bpeWIgWj3CukEFK3IdV8O+9kDx653yK+X+Iaf3F9FvJPuAW3KT3
I1wWhbeGaLx91Qd+NxTpHWPyKP+6/nI58RViFDv51JWOoN2v7YcTWr/C/NiY
fovXERQ1HfDpxtBX4LkSI7JYdgR5nq9MOcryDYJCsQXWY8pI5YS0UbnmN6hn
3IzfOnIUtQlvyyz79A3kcYYQrd2AVs7bZ/c59cPkJban+CmELDl/Xitz74fw
ggd13q4I1VR4Ho+72Q/BL5NXH4UgFLY9uOvk/X7wUmaNtSxHSOxTOlN7Vj8s
yK3ZWQipIGOlUZOGyX6w+iN/TqJPBWVznFsvsBuApUul+YlIFXFVjL9/5DoA
Thsdz02bqKLr9pcjr3oOAC9DnoCIgypSrb21TyZ4AOpkOW7LR6miHq9EWtaL
AejfGSXA910VYWM9ac/GB2AtOoJhLEgNWZWbGITZDIJ/4YjpYJE6king27rd
eRCmCrWlHzaqI6acL21PPAaBS6bFY0+/OnqafMb0VeAgNHvZsa5TNNDgXZsz
HRmDICmtYOxF00BW2u4OO2cG4dVzhYm3Y6Q7HwWmewxBU8/e1uQ1TSTTbKot
fXsIzIxqCcMtWojp/fbNJYFD8JtPhTYlpIWeliQ8+BAzBC3KIpPDuBYaTEiJ
mi4dgtCzFp3dPlrIyvrNc1mGYTix9fKrpXUtdH6uvbIycBgY/ebtpqa0kaVn
mGlR2DB4f9XG0B9tZM6sO50TPQyT4hdu+2E6yIT7HX9S+jB4nK8yGxDRQZqH
89xv1A/DUNtOmTETHXTAJ1RSCRuBrf2tTsfKdNASh3r0q4AR4C+IKcv01kUL
MYwHMx+MQLdhYu3xQF00J1Je8/TxCOj77FP8FKGLJmRlfz5MG4HXu/hjKzN0
Ud9JEb3LdSNwjsFCd0uXLqpKXmOWoo5CGZNnnP2hE+jeoULnVP9RKK7CTSO6
TqAGmc5Rt/ujwGXmz+0/eAJhcr8t1KJGITjhc5bT5Anke1hBdzhlFBx/HH+2
i0EPeakUiovUjMInIXV+DjE9ZGdcOJDAPAYfJ3hrd1zRQxrXCmmPbo/BoRD9
b8c26CNfz84G68Ax2Md05B0Lmz6q8v6NZMPGoFhDib2aWx8d81E41JY0BiqP
F1jExPSRfHDhZs63YyAst5AToKWPdscX1txbHYOdy98My+/pI6bKQgVfz3E4
N4qIZIoBymDbmrp6ZxzEAt5pd280QEZmDlweIeOgmcrpy7bFAD37JTx3KX4c
7tSYC1ziNUCqUsEZ+hXjEKv8IGRKzAD5x5oL8DN9B1MH1WOHNA3QRjdG5vyg
7/Bxvt2yys8AcUroNH2LnoD39xxy9/0yQKPUJM765Ano4+nkO7ZsgEpG5o1z
0yfAnHuwQf+vAbJ+Ettzu2gCKuc9+OyZDFER38T4rq4JKP+wnOvDbojOUIOY
rXl/wNKM/V3pvYbo5XCt4vijHzDBrXUgl2aINJNUns2GT0Jqp3ROZZohCqhv
7rsTNwk7tqaIXMkwRLVzZ/i4n0+CqcDwAdEsQ6Sm6hV6+M0k1AVuFfDON0Qq
31953OmcBMf584mc5YZI+b89ulw7p+D0C7mYjy2G6FAddVEhZQosFel1ccuG
iHemUf1W4TSw3vzMyXfcCEU/fHvu+9tpaLJSv6KkZoT4ZPO9afXTIBhfymOm
Qfr643yx7mn4r0F6/2MdI7SD2UqweWUaWqcVKlZoRkiQ9/ei8LEZOPtlXtTF
2gjthV0pVdUzcKVOXVLM1wjF1pUwMl+aBUk3u9mtb43QbH/u9RmHWRBi919+
XWmENFZS53ouz0Jp1+dOepURWpCMGHh9bRY+V7jxRdYYIb1we8ImcBYof8Xr
mRqNEJPFTp+GtFn4s/q++UWXEbKfv8EQPjoLIwyqVXvmjJCyAFoXtp6Dh9ad
+CYhGtI0b3e1sp2DsiFd8UBhGjKOuzj6zGEONgYbLzGL0JD99vsf97rNwXsp
PZOl3TQUy90TJ+k/B77nt4i1S9DQEpubomL6HFwc7mM4JU9Dr9fSXfQn58Cv
/datRF0a2t/PMXzj6jyUmsTp6rrTUFb6Vts3rj9hYpcT945SGvL+atG2338B
5CtqFB6t0JCLsqJOYuQirO7Zx9lw0BitJKla/Qj7BZb9XTolp41R8+VYS4+n
v+FUjbu7/F1jdFhDZK3vyRLQDX2UFJ8bo/dqh9Px+GWwQYMXaiqNUUpezOHB
zBV4l8JzZ0evMeIWlbQ78+IPGP+YPpk5b4xaGbE728v+AvuvKyvmGB29wa6k
Nr9fhU0m2RRlfjqS5Oaws6pZg1MfDr+Yk6Cjmfu/uP7rWAclu+VICSU6Eg0I
OOhsx4Dnn2rY8lWdjgZP93xRGWPAK1Xfs28xoiPNkbblN06M+CEM05s1p6Nr
rhdseaYYccNa50ssNnSkVxCnzePOhCM+x/hmJzqa/mvnzfyLCf/7WPCRsDsd
Pen0ee10hRkfil276u9NRyu2Ry2v/2HGDSOEUzLv0JHA6kMzF88NuGhdGnth
AB2NaoQ0YBtYcMW/R9S97tHRu72NIBjCgkf/Oep6K4yOtO9/0+YJZcGFkvSO
hpJuXpynsz9gwdNRzXos6a/V2x3Wwlnw0pc/7ApIL1ldjP4ay4Lnz+t9mSQt
mcQ0l5jBgjf1LQuefEhHUbyHnwo1sOC2vQs64uF0ZIelbtjFSsF3s/E/zImg
ow9MgaHHN1FwygQDlJGWXL3EY8NGwfVd1IbqSc/MSYlnclJwG+559kHSV3ve
6MjtoODr7uw/t0XS0Y3smnCt/RT8ecjCjBvpMOMRYdcTFHzzof3vZR7RUWHy
7qPvHlJw45b+U2FRdLR7XdWLiKDgb7j3rsWQDrO4UPz2EQXvrbsQ+4y07Y5U
ubIYCn7AprukgPSOSLEDb55Q8LKBV3G9pL0DJITS8ig425zq172P6UjF6RBj
SAsF/8TD6/yGdHajAQS1UfDGlWWuCtL8+11uBHym4LHlf/NrSS+M5S3f7abg
EWo2nZ2kU879N+89QMH3TY0Ry6QxuvyQ0xwF9wyPElSOpqOmI8o1RpxUfL14
brWEdHCR2x/1bVSc+wD9bhVpDbkc6SPcVNypT52xgXTlAZFE0e1UPD+ya7SL
9KtdmMeCMBWXr2w6+Yt0NLVdPOoQFbes+dh1MIaOzrfZ3+vWp+JiSyL6CaSF
DVKqPhpS8bFmhvFnpHsbvy4RNCp+2iDwegZpk1rDCxmmVPyU62P/QtKaxQrH
vM5S8eMnGzVbSB9IYp7d6UzFE2jHnJhjyfuwi6NZ3qfi+7Ruq1iRfuD5jHor
jIo//WbmaEt6b3BmaUI4Fbd1zn3gRJr+olS0J4qKK/2qK/EknT/W85OeROYp
qc8IJ+1gvTNSJ5ec5+vH+UrS/RYJ7fKtZP/LEHHeODrycEwJpLdT8U9Ngqo7
SbPfyFK+2kHFhexVTXeRPhpf/jzvCxVfntay3k869kvfVckhKu4/Z7gdSBub
CnKLLFDxwJOzM9ak6w2S6Gw8GH5g8x9aBmm76pEKKh+GD4ZNC2STZlOUFGfa
geG8tgn9eaSNhIpXfglgeNnIAYNi0j1TrUn9ezC8u0Wqq470dDBl4pUchmvw
roUMkQ5b06VlK2C44sHegVHS/7lGlKUfxvBjYd6HJkhfOyX8IOEohtd8YCma
Jc0kriQboIbhrNpql1dJc9c43jxNx/Dhm01+3PF0VKT4eszYFMPdutYv8pE+
/XLFQP8UhuP3llX4SSdGBIiqWmB4/EWNIWHS4lZP6qUuYDj/LZOP+0krr7dv
ZXTD8Pz2EA2c9FdXfu8/7mS+NrsCFdI+o+dGFq9hODrFK6hGuvbjdOGEN4aL
iX/p1CKtH49ZtPuSeT+zLxqRtjqsnJYWieFMOS4d50lfmvq42BuF4TsOD222
IX35yVnVrTEYviBtpWRL+hbr3QHvBAwXqgrydCAd3/2e3ygVwzfrBz64SvpZ
qJldQDqG39NxuulOOgNNFZVlYHi6grX1NdLFLzhMxHIwXJ7Fh9ubdMd107C/
hRhOyPtvvku6T+r7V+kSDG/z/PnKl/TwgKfUxTIMZ+tyNfIn/VMrsaGlEsOn
utKvBpHm2DGyIe09htv6Lp14QJq3yZ3W+wHDPfavZoWRFryDPeVswnDhCm6W
cNJSE/vBuxXDU93uRkeS1i5xvW7Yg+F7Qk2MY0gbOm2o9+/D8EMr6w6xpE+K
RPGUfcNwvaYK7zjSF4OLX+0dxvBs/Rs+CaSdjukwmY9i+F2dG+6JpN3new0e
jmN4pE6EVRJp39MM038mMTx6lFH4CekQ9nBl6RkM16w5PffP4VWiITZzGJ52
sKH4KeknEhriLYvkvoWmDj4nnf61y52yhOF1X5P7/jk33K7myAqGb4yzv5NC
umIl1Cp1jdyfk3peKumabKG8HgZWHH9tciSNdKNV3joHMyuuRrtZ9s/tPMf1
1FlYcdez5bLppHsa2uO9qKw4x49tz/958KbNj1xWVpyNemfjC9ITMkuHRzex
4r+rqLb/PDcaFMjPzopvkkop++elWP5OAw5WfJfRaSyD9Lpe1h7/rax4xVEx
nX+mMMPVUi5WHFvZ5PfPbIXNVbM8rHjTA6zgn7nsrTj3bmfFfSgCX/+ZX2jh
rBk/K65orbX6zyJtftlhAqx4TlbotkzSEgG8qzVCrLju6Hfhf5Y+8kLnzy5W
nIvjzJ5//h+WoRH0
     "]]}, 
   {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwV1nc81d8bAHDz3qv6KGSllKbsPTLOJ0pCIjMjkpVkZWV8E4WIEJKMe8nO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     "]]}, 
   {RGBColor[0.1, 0.7, 0.2], Thickness[0.007], LineBox[CompressedData["
1:eJwV1mk0lV8bBnBDznlOpSglkSElKZrIWHsnRXhLpmM6hmPIlOlvSpRKSJFM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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Detuning (rad)\"", TraditionalForm], 
    FormBox["\"Signal\"", TraditionalForm]},
  GridLines->Automatic,
  ImageSize->{428.00000000000017`, Automatic},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.4569619139685745`*^9, 3.456962012384575*^9}, 
   3.4569620509215746`*^9, 3.4569621816145744`*^9, 3.457113795521*^9, 
   3.457225665931575*^9, 3.4572257199555745`*^9, 3.4572257566435747`*^9, {
   3.4572257933095746`*^9, 3.4572258230935745`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "1"}], "/", 
    FractionBox[
     RowBox[{"2", "\[Pi]", "  ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"]}], "+", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "3"], " ", 
         SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"]}], "+", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "3"], " ", 
         SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}]]}], "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4569360510465746`*^9, 3.4569360575515747`*^9}, 
   3.456936133530575*^9, 3.4569384382615747`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "-", 
   RowBox[{
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"]}]}], 
  RowBox[{"\[Pi]", "+", 
   RowBox[{"\[Pi]", " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"]}]}]]], "Output",
 CellChangeTimes->{{3.456936051575575*^9, 3.4569360579825745`*^9}, 
   3.4569361340815744`*^9, 3.4569384394095745`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "/", 
     FractionBox[
      RowBox[{"2", "\[Pi]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}], "-", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
          SubsuperscriptBox["r1", "r", "2"], " ", 
          SubsuperscriptBox["r2", "r", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["r1", "r", "3"], " ", 
          SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}], "-", 
         RowBox[{"3", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
          SubsuperscriptBox["r1", "r", "2"], " ", 
          SubsuperscriptBox["r2", "r", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["r1", "r", "3"], " ", 
          SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}]]}], "/.", 
    RowBox[{
     SubscriptBox["r1", "r"], "\[Rule]", 
     SqrtBox["0.85"]}]}], "/.", 
   RowBox[{
    SubscriptBox["r2", "r"], "\[Rule]", "1"}]}], "/.", 
  RowBox[{"\[Phi]", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.456934509497575*^9, 3.456934512049575*^9}, {
  3.456934713436575*^9, 3.456934729252575*^9}, {3.4569363294545746`*^9, 
  3.4569363450365744`*^9}, {3.4569392973015747`*^9, 3.4569393152515745`*^9}}],

Cell[BoxData["0.01292573377701783`"], "Output",
 CellChangeTimes->{{3.4569345044425745`*^9, 3.4569345126715746`*^9}, {
  3.4569347141045747`*^9, 3.4569347294825745`*^9}, {3.4569363306005745`*^9, 
  3.4569363457375746`*^9}, {3.4569392983345747`*^9, 3.4569393186315746`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", "\[Pi]", " ", "14.7*^6"}], "FSR"], "//.", 
  "greenOPO"}]], "Input",
 CellChangeTimes->{{3.4569390164305744`*^9, 3.4569390595415745`*^9}, {
  3.4569391726595745`*^9, 3.4569391738125744`*^9}}],

Cell[BoxData["0.08626482514385318`"], "Output",
 CellChangeTimes->{{3.4569390420155745`*^9, 3.456939060405575*^9}, 
   3.4569391742325745`*^9, 3.4569393213565745`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", 
        FractionBox[
         RowBox[{"2", "\[Pi]", "  ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "-", 
            RowBox[{
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "3"], " ", 
             SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "-", 
            RowBox[{"3", " ", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "3"], " ", 
             SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}]]}], "/.", 
       RowBox[{
        SubscriptBox["r1", "r"], "\[Rule]", 
        SqrtBox["0.85"]}]}], "/.", 
      RowBox[{
       SubscriptBox["r2", "r"], "\[Rule]", "1"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "2"}], "\[Pi]", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "-", 
            RowBox[{"3", " ", 
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
         RowBox[{"2", "  ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "+", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}], "/.", 
       RowBox[{
        SubscriptBox["r1", "r"], "\[Rule]", 
        SqrtBox["0.85"]}]}], "/.", 
      RowBox[{
       SubscriptBox["r2", "r"], "\[Rule]", "1"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", 
        FractionBox[
         RowBox[{"2", "\[Pi]", " ", 
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
            RowBox[{
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}]}], ")"}]}], 
         RowBox[{" ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "+", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}], "/.", 
       RowBox[{
        SubscriptBox["r1", "r"], "\[Rule]", 
        SqrtBox["0.85"]}]}], "/.", 
      RowBox[{
       SubscriptBox["r2", "r"], "\[Rule]", "1"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"Evaluate", "[", "plotopt", "]"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Detuning (rad)\>\"", ",", "\"\<Signal\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4569341850595746`*^9, 3.4569341999585743`*^9}, {
   3.4569342803075743`*^9, 3.4569343990525746`*^9}, {3.4569344455805745`*^9, 
   3.4569344816995745`*^9}, 3.456934566089575*^9, {3.4569346000125747`*^9, 
   3.4569346135215745`*^9}, {3.4569384541285744`*^9, 3.456938481266575*^9}, {
   3.4569389012715745`*^9, 3.456938945365575*^9}, {3.4569389961435747`*^9, 
   3.456939005530575*^9}, {3.4569390795625744`*^9, 3.4569391077035747`*^9}, {
   3.4569391784705744`*^9, 3.4569391884265747`*^9}, {3.457113801137*^9, 
   3.4571138407922*^9}, {3.4571138849714003`*^9, 3.4571139457802*^9}, {
   3.4571139973694*^9, 3.4571140347002*^9}, {3.4571141551322002`*^9, 
   3.4571142103562*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwdjX041AcAx814apdsemSsxXPFlForL3XRfL0UZUVUtifnrVy4yesjtYjK
S/3O4e5y3CGH7riLcy8YO0WnK0zyrAuTp+RllZoHJRdLa/s+z+f5PJ+/vuRj
cQE0fT09vb0f+c+ftpF6x5wSXE8b/n619zQBmxc3XSw5fshU/kxp/4XAguy7
iD/ZoeiLpt0tzCAgf4uHJtJIRFEUOn+CwIRplK6JHYdTpyL3vCsikGvRuVKq
SgJIc/MsMQHRBmq5njQFjy1zHazbCLTvmN56SHAWS5a33rcMEhjyylQL2emg
hqT6hL79+GdnZJeqPo/EjgDSOnMGcuz7E4Wqi1h4HO2yypUBU2eBqrchC14X
jd67RzFQ4U430NXl4OGJtSINl4Et+xwPkKsvo5Je+ljZxYDq4FKhj4CBBY+z
rTaf5OJhKNu2jJ2PE6IDtYbnciF32EIZ0xTgAnHZW9mRi5QdnOEUNQtrb+RO
HzdmwtVFl2HUxkZ4zBdrEcKEAYJtKlQcnHje1RinZKLbQ93l1HwFYteOw9bG
eWB52cZ2NxSidUpG5MfmwdJ3pul1XRE0zVpRtHs+xv0Dgy5JiqHtszl2uCEf
14+oPnxdzYP9lI/pvFkBKMFZe70EJeDTGePbSgqwFDb5aqi0FMsdp3znRgug
ifBjxfHK0Dkw3K/awkJAjMVQMbscqXav+RsesGBEQRvXW4DMUePJPZvZmG5J
MHmqEYB9m3T6CMFG043+xmR1BXzCtDZnAjng4bPl7W6VoPkZLDppOEi95XKU
1FaJ7owFC4rzFXhqBEtXVVXwqhnpuUkpxDfeDw6+2HkNPObsMUpHIUhdhlUO
zddAL04yGz/Cxd8+lLm07UKMoEYbMsNFXw/du7NBCFOJWhrILYLSt4y3ykGE
4I3U7cw9xeD23X9JlYvQWOTqPvShGMFax4KZumoMXEgU8nl8uAVGjrpsrkG4
HfPwgbMlsB7kOWZLanAqvnFreUwplh3tye7bIEaG9J2JWVwZJh8tDX5VLYY/
TUeczLyKe8HbNtFsJAjpt0sUSMshe3I8rb5KgszQZM+FFAFSxjrJuwXX8Soy
nkh6WoGjtMWkPMtafO9R5Mmsq4Trs2/vDJbWwsU8O3+CUQVydJj5+jV1WM9v
Ek2fuwaDl2z6SV4d7M/4NvEuC/EsRtP665dSOJ2h08LqReiemjfW50rxhvwX
P/1NNaTxduH7Teuxv/DH1eQQMVizVCWXXY8cv0MmVbMSMFfzd7WvlIHjFFA9
OlqLP+RZVk4BMujPbMoaWlMPM98EfQlXBrGtvmj3gAxBk9QJy0cyRDjnhQ/8
pIAge28nx0oOXcntZOd1DRhf53h9eYQc7pVWzdR9TdjYZpWXViNH2vOMFeSp
ZsQGrUiYfSVHaMsycatbK5Tzbw9FblPA3mQsYtCrHTrO6PbhZAXuK4K0n2/q
wK6tvRb+vylgMVKyuNPzLs73tPyjWVKg3zomKv38PdyJEj5x9lQiaSTNdrW5
FiRDlro+Rwk9ccQPzwOeoC/ZyCzw1sf+f9P4FwkSLPo=
     "]], LineBox[CompressedData["
1:eJwtlYk7FIoeQJEo9ZKQ575bibpXSfalUr9JEuoVKklR2boIDalEsidbjJFQ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     "]], LineBox[{{0.07735056191764295, 1.}, {0.07770234930739703, -1.}}]}, 
   {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwdVXk0FIr/tWUr6r0WKVS0SKUFzxKuKDuFSJZU0mKr8bIORjyUfUtRGArh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     "]], LineBox[CompressedData["
1:eJwd0nk01G8bBnDrzHcSITuVrc0uSQrPkywtColkKckWEmXJ1iqKFlR+iESZ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     "]], LineBox[{{0.5728378317581224, 1.}, {0.5728416273700985, -1.}}]}, 
   {RGBColor[0.1, 0.7, 0.2], Thickness[0.007], LineBox[CompressedData["
1:eJwdlHk8FIgDxZEOV23L1i/tGiFkO3aFyPGkonRiKSFFVtuWq9Lm6NhSypGZ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     "]], LineBox[CompressedData["
1:eJwd0mk41F8bB3AGM79ppaRERaSyFamQOkcURZKtRUqyhSRlp1JClGRJsit7
/GlBJUdKUZJiDCbMDDP2sYtJeY7nvDnX58V9f891n1vW7pKZA0lAQEBaUEBg
4W7VCJCtk+sCAv8/o2j/ETWzd4ZdYCp+XVCFwwh6GXZkb8rJLmBmGyGrLzeC
FKovbAly6QJVT0OTDdg8tGh35j+du10g2UitMtqeh5pkVhZUfO8Cvcb6PJ7v
MDpove1hMrMLnPIzPS+uO4zK442CA8e6wM0p07Czi4aRiUi1UiqVCa7U9VTo
pQ8hdX++4BklJgjJYNFtWwcR/7xrUYc7E2hqfu78fGUA2YpN+FZ4M0F6dqvH
7SMDqKbSXy/pGhPsWu4uz9k8gKIlI1pPRDEB2TfycEBnP9r8PZfUXMgEz9/6
/0oy60cW2lyrL0NMENGn9eyneR9603tRNm+SCYRFRptW7+pDG+KnBsPmmGBZ
pezn+jV9aGBEOPjAEhZwsv9wLbCrFwVnyRVUKbGA+KbUkReXe1GR6Ln5UhcW
ULocdutNDheJV/bVxXuyQLQ3vfTvfS7yc/WIu+rPAiFNdhoPfLlI/9P1reoR
LKCyB7EyD3MRIyDVvDCPBRxdRacNxjmI6GXkPOljgSjNic8XTTjIPe68581R
FigeuWe9fA8HNekO6pybYQEfrW03hzZzUGoy/8d6gg2upxWftSRx0E4zybnE
zWzQ8Krxfs3rHmT3zso02pEN/oo5BJir9yD10jUrJC+xgTsjvrFbpgeR/mtv
yvBhA41KxtW85T0oM/3M8RfhbHA3jzPbONyN2Lccz7Tks8GxhMZDvs+6kd1h
bzfpETbg7laK8FTvRup6mqpZv9ngW0PUuQm5bkTS4Y+oCHSDPg5jJHlVN8pU
uXYFiHUD5YrHSU6zbMQWDfW329ENrHRD6HXVbGRHjw/P9ekGdZ4r3HVPs5F6
4/HDaje6gVrsp0ayKRuR6iSXvAnvBun/0v4M6rFR5puU+18Tu0Eys7F+pTLu
l5L1kPe2G5w8+v1H/V8WsrN/9VRDoAdkPdeYDM1mofNjzVVV4T2gy2vn5P1F
LGTrH328PLoH+AlL7dxEYqHTQsa8/x71gKtfth6on2Uiq1UfpNJye4B26dSs
ST8TGWqVeAfV9gD+8We/ZeqYSDX4nrI2wQFH5OM4XyOZaEb04KMXYRwQoVoe
RJFmoslEwW0F9zmAcnJrecAqJhrb+K4mM4EDip7vs5pbxkQDGhoTD3I4oNdw
ZtdGEhN1nNho4vGZA1rLJUZnf3Sh6vR/QioULojVvJObfbkL3d1edik7lAsk
zWM2X6vqRF/U6VyvKC4Qab14W7e0ExE7f9sceMgFMQEv10g860QhWruNe7K4
4NY+O+3xhE4UsL9sy8YaLjCRjiZ5enQiF4syVopQL1CP+P7nonwnMvAtM4+/
0Qsisq21ziV0oBB/+hf78F5QKvVzXOh+B6oO/K2rEd0LPFsEo1+EdqB9wbu3
N6X1gln2Y2Et7w60K6JsiRjqBaZ5//1os+xA8sllNXf/9oLOxLHv1qs7EKmq
bHeIfx+YzhANLc38hfKXrsj+e7MPHO3N+KiS9AuZWbuJ+0T2gfB8SnZx7C/0
ZFpm7EJyH5gPvTvYGvIL6atE5B+t7ANU8+HaYqdfKPTx6XVSpH5wX9t70Hnb
L7TIS1Do+Z1+wE9w/Wb7iYGeV1tfVorpB/riSECmioFOiZZ2PX3cD0wF6Rv7
XjNQQYFLRUJBP9ibdWIwppCBjNlNXkHf+gFJYGm6aTwDRR3N7jMUGwAt+R+Q
jSMDiSkaNXQ9GgDhq+1zTZcxEJeSJlabPgDKmhJGnKgM9IYzblGcOwDkIuZN
bgszkH3GY8aN8gHgpsNS+slvR+VrBvpkWwdAzthFrRe97egM5Y6Q/epBcP0g
7+ud6nb0rOeTZl/8IKh3Lbp9MLAdBVevDWxMGQTzmvtZS33bkVW6OyrPGgSM
g7aK7VfakcBpiYN3Xg2CZ/Lz9sGu7ci8ycFckTYIWlYyU6jW7Yj/XtjdTXwI
LOlRcOBrtyPDtP1PRmOGwFt5s2LFf20orLax42bSEHgw01yrzm9Dn8bOrFn1
dAjk7eSlguk2dEA/4J7WqyHQc+uAvROvDe3vf+Fzkz4EogyH/XidbUhnxyZj
celh4F56Qbu5qg1t/0yZ2p01DOTd74fWh7WhS6Px274UDoNrEzTVMyFtqEhS
3uV06TAwsLZ9NXGjDam4wa4bn4eBn/GcvqJ/G1IU86ur6x8GIX6ynz+6tSF5
64EUa1Ue0Aut1M83a0OrR+oPXi/jgcEpqy5R2Tb06AE61494oGSb9jnZ9W1o
jcbzQPNaHmjQV/mtIYXtl/B8cxsP9GtYH3FY1YbWCtmtb+TzQPtKq80D1Da0
fvXvKZl9I6DOMarxxkQrUgCyWdUfR8DvQ8m3ampb0ePPbwSFLoyCNxsWhXf5
t6JRZrHfiNsokFu2p+mdbysy4GePMTxGwaoYcaFU71Y0qRzLeuk7Cj5YBVLs
PVuRSYzre8fwUeDgQZwnu7Qiko108JecUdBXLu6RebIVuY4HCcRwR0Hxvuah
LdqtSGed7ryM/RioMTP6IyjQigxPN3vaOY8Be3Npqvw/OrJIcuI+cRsDESrR
yGCOjlwlo74peI2B1VJH1sfN0NHjVYwk5dAxcPzeAVc4RkczS700NXPHwNzb
lCgOm45e/su9fHRoDFAP8kctPtORElO0J+jqOBg2HspzjqMjk16Zam/fcbD0
vZWHQCwdefC2p18KHAfSxazDiQ9w/Zzp6XMh46DlbOvuhig60pF80KwfNw6W
qEn+1L9DR8ZmYjWLX46DqhG9lfbX6Mjto1h24sQ4UOO9unj+Ah0V5q5wfuU5
Aa44Js6r7qejEBrSFfKZAEohPvQBSEenSReljgVMAH+qXEEOoKNFpz83DN2a
AI+WVOnK76Ujx+WBO+XjJ8Ddwx7Lt2rSkYw3hxRbNgH6BiWMbVXpKE6vPMVj
bgIEvP0UcU2KjgI7bZqUQicBL+WalOFMC5o02JviEDEJVouv9oS/W5BbibRT
WtQkOBo+HqI13YKsQxj8FQmTgOue/ktlsgVpK57cyM+ZBJ7dh+GG0RY062Vx
ubZuEmR0aAP5vhbkvdRoucPSKZCu/NTveWsLuqyjaZQaNwXAwA/zd29bED9N
324wehpAJSOb2sgW1Ojx2NYn8zdISEj/YHi2BWkZbPzXkTEDjuqeuHVzTwuq
O6CVC5NnwZKvo4ZD0i0oqyRRi13AB4xttxrG52lolZyyy5m8PyAkVrUH9NHQ
T0HipmTFHOhbPG6Z84OGXhFXshvr/gJw5s22TZU0pLxK1MWu5h/g8hNMSEU0
NBI1Lb6jZR5Mex0y9U6lIbmwsG2XXATgg4iLkVEPaIh9itG+v1cAchsrd+uE
0pAhp2n2lbsg9O+0Gz0QQEO+ng7OEsOC0Kq87vtmTxoyKU06LOFNgvuuD+y1
vkBDvDmXQKFpElTr3ZK23I6GMujBL92vCMHfxknpJdY0xHfea+v3RwiKyK2I
TbCkoXV/H1hf9heGQT3zvQmmNMQ1iPxCCIvA9k9PRphGNPRBoR6sjxSBX8kW
kf0GNHQ4quuwxD0RaJ34msfAbpwat1x2XwT23S081YDd+VHS7V+MCKQLaRm/
wJ6xc3rU+VgEevnkxQdhK6eRxlLzReCXtUerVmI/XK2VueGLCPzG6HM6eJCG
XIhsYVkqGXYr3Ez9qE9DX0nh9/QWk6FppNCGcmzlvxckHJeSoXa2WF4B9siY
ypYCMTK0nv/aFoN9lfHKaOdaMgxPDi48hx1UVBNzSIkMjeY0pQWxoy04Mp5H
yJDGv0I10KOhsnT5vR8ekCF7ifU7ni4Nyc/rB7yPxf1NuPs42NE2Dq9RPBmK
S9vWMrCd12bvrEgkw1SltRO12GvjNqu+yiDDqPlbOU+wA8MUN+SUkOGzALHI
U9j73bcLRv4gQ0ass0YDpKGielNwp4kMn+ofL6nBllK6HBRGI8PzW5fueoc9
2Vsye6uNDPeP1lk9w846t2M8kEWGcjZOUxHYhOWubvcxMjQv0sg+hN2wR6fG
TIwCHYNcG+oBDUWUe/05uJIC42dIzjXYBjv/U9uzigLVi8aJSuwq1Y2pcpIU
OD3RYvsf9gtZwmdShgIfmD5yjsF+RGne8nA7BX6sV6afxD7f5Hq37SgFNg/p
K/L20ZCMaVb1t2MUGOcvVdiL/au+c+a9OQUmBqvsZmFbfTrmkH+cArdmCZxr
xjZ8vXtfwFkKrJU2XvwWWzVNaFT6EgU2NLx/fQd7xiXJ3DaKAvWa832Vse/7
P6Fcj6bALjl5ZwVshYiCtykxFCgWLGQrg22Z91aO8ZACCytHncWxn/cyJizT
KPA74dY1t5eG3Oyl44yKKTBVTebMd2ymTUrzrp8UqFgRn+yP7XMxK9yymQJV
1m1K8MJeFlSoc7WFAm+0zid6YO9Nfve0pJ0Cf9rElTtiP27vuKrcTYHy/fIn
zbEtjq9ftXES59vs36yKXWuaZrlUgoCZi5+O9+vg/f3IqaSsIWCDq4kWF3up
pvIW0loClnWvD2Njm214zZ9eR0ALle2aDGzG8M805iYCWnWSR+uxeRHkgRc7
Cfj79rrSEuzof8bmRbsJmHxzzL0Ie4dnbEWuFgGTTHpUC7B9T8rcT9lLQP8n
8h+fYpO2aGuEHSCgVIqw/iPsVTUXr52yJOD5mt5HN7DLNV/2WhwnoAzH50MQ
9qlnfNOjJwkoGygz5Y+dGhsmp29DwKePX1/0wt5il1Gr4kBAm0eCL12wdeab
Vwh6ETAnMSnOCrvTUyrwjzcBb566s90CO5h7jjPli/O3RjQdw/70jVc2EEjA
2FcfVI9gH00mbJpDCDi1dZm2Pradlk5OThwBjwZUPdmBfWH429SvhwQ8ab3F
Rw3bI+Os/opEAvY4WZtvw75OvcUKTCHg4ixZBSXs5LY6KbNsAu6w3LRTDvvJ
PWuXsFwCzmp0mMhi5+sOl1fkE/DSE5vLG7Bf54labf6PgOkzpY1S2C1+x6Pn
ygh4+sKHGXHsDpX+TrU3BBxILDuxEruH5a/iVIHnL+H5Xgx74lDqlx9VBNzL
0yxchi26liOcU0fAG9oUHoG9usHb/NdXAjpwFeIo2OtvEpliDfg/pxfpkbFV
BpRA4E8Cul/c8FYI+/AbT79jDAKSVlwVn99DQ8fchWtDOwjYuKdE4B/2iY0P
JSq6CPhub8nUHLZTxOsXCj0EfLZ+dpaP7b7PiHSaS8D7BZC6YO/xX6YP+gh4
wu2w7Cx2yCkB3p8hAv6dfOL6GztyWYyO2ggBxbwnUqaxY6rlIh3H8PtThNum
sDMUDbb8mCKg9znXC5PYuZ2t3uQZAt6trqqcwC6OcanZwyfgWnO69IIr+ffs
sv8R0DzJYGIMu6ZoQwlDgAqZGzNcF1xvVzIvKkSFBX5vh0axmyX0TA6KUKF6
5EPvBTO+NCcHUKjwlL46dcHsa46DxVQq9IyNejqCPaA+o8VdTIW7nAsMFzzG
vRMutYwKv7wIn+JhzzyWopuKUuE7Z4WCBc+bFG4KXUGFiwNCLiyYLASuvhWn
QnFm5vYFLy1rrB6VoMLsqGCBBYu72okpSFLh32sybcPYUhsmz1pLUeHr/Otv
Fryx6XZR9Doq5CxJe7pgxbDVf2s2UCE/41rCgtX25Bn9kaXCZqf1sQv+HxYN
NFA=
     "]], LineBox[{{0.3978663463997281, 1.}, {0.3978743560372418, -1.}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Detuning (rad)\"", TraditionalForm], 
    FormBox["\"Signal\"", TraditionalForm]},
  GridLines->Automatic,
  PlotRange->NCache[{{0, Pi}, {-1, 1}}, {{0, 3.141592653589793}, {-1, 1}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{{3.4569343185155745`*^9, 3.4569343996165743`*^9}, {
   3.4569344472125745`*^9, 3.4569344822045746`*^9}, 3.4569345666905746`*^9, {
   3.4569346006775746`*^9, 3.456934614318575*^9}, {3.4569384552985744`*^9, 
   3.4569384821595745`*^9}, {3.456938902193575*^9, 3.4569389457915745`*^9}, {
   3.4569389974465747`*^9, 3.456939006094575*^9}, {3.456939082766575*^9, 
   3.4569391084565744`*^9}, {3.4569391816595745`*^9, 
   3.4569391887165747`*^9}, {3.4571138018858*^9, 3.4571138167058*^9}, 
   3.457113904877*^9, 3.4571139463262*^9, {3.4571140032662*^9, 
   3.4571140351837997`*^9}, {3.4571141721205997`*^9, 3.457114211183*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", 
        FractionBox[
         RowBox[{"2", "\[Pi]", "  ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "-", 
            RowBox[{
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "3"], " ", 
             SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "-", 
            RowBox[{"3", " ", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "3"], " ", 
             SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}]]}], "/.", 
       RowBox[{
        SubscriptBox["r1", "r"], "\[Rule]", 
        SqrtBox["0.85"]}]}], "/.", 
      RowBox[{
       SubscriptBox["r2", "r"], "\[Rule]", "1"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        FractionBox[
         RowBox[{"2", "\[Pi]", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"4", " ", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "6"}], "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}], "+", 
            RowBox[{"4", " ", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubsuperscriptBox["r1", "r", "3"], " ", 
             SubsuperscriptBox["r2", "r", "3"]}], "+", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "4"], " ", 
             SubsuperscriptBox["r2", "r", "4"]}]}], ")"}]}], 
         RowBox[{"4", "  ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "-", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}], "/.", 
       RowBox[{
        SubscriptBox["r1", "r"], "\[Rule]", 
        SqrtBox["0.85"]}]}], "/.", 
      RowBox[{
       SubscriptBox["r2", "r"], "\[Rule]", "1"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        FractionBox[
         RowBox[{"2", "\[Pi]", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}], "+", 
            RowBox[{
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubsuperscriptBox["r1", "r", "3"], " ", 
             SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"3", " ", 
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubscriptBox["r1", "r"], " ", 
             SubscriptBox["r2", "r"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
             SubsuperscriptBox["r1", "r", "2"], " ", 
             SubsuperscriptBox["r2", "r", "2"]}], "-", 
            RowBox[{
             RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
             SubsuperscriptBox["r1", "r", "3"], " ", 
             SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}]]}], "/.", 
       RowBox[{
        SubscriptBox["r1", "r"], "\[Rule]", 
        SqrtBox["0.85"]}]}], "/.", 
      RowBox[{
       SubscriptBox["r2", "r"], "\[Rule]", "1"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", ".1"}], ",", ".1"}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"Evaluate", "[", "plotopt", "]"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Detuning (rad)\>\"", ",", "\"\<Signal\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.457224896120575*^9, 3.4572249464735746`*^9}, {
  3.4572250843835745`*^9, 3.4572250944425745`*^9}, {3.4572251287775745`*^9, 
  3.457225167997575*^9}, {3.457225257707575*^9, 3.4572252596525745`*^9}, {
  3.457225290094575*^9, 3.4572253190215745`*^9}, {3.457225394905575*^9, 
  3.4572254081525745`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVjXsw2wcAx824mambnhrrcFEZTTtrPdqMzbeqaHNFKbbTeFY8Mq3XeQ2t
tR7ziyBJhcQrXkEQSZFx0VKaDTNzq9e0Z63H2mrn0KpUV137ufvc588PKTzO
l6GpoaHh8tZ3fb9fd3zRIcE5Tfu36vE0AuTHN53MeN7I6fyeOvADgW3ZlxF/
cUMwEcP4tTSbgPwFpgykUYimXlf7EASWDaPVCm4cUlKi3F6WESg0Gd4lVSYB
uptbnBYCYmt6jYY0FfNmhXaW/QQGjq4dOivKwI7Zrde9swTm3HMGG7mXQQ/O
pIW8ePuj6FEyB39E4pCvroUxC/m204mNyqvYno9x2u3MgqGjSDnelQv3q3qv
XaJZqHVhaqnb8zEVaSpW8VmwOWXvSWoqQB2zcr5zhAXlmZ1SmoiF7eMZfeT3
CjEVwrWq4hYjUuzZpn2pEHI7G+qiqgRXiAKPzqFCpB7l3Usd5MD0RuHaeX02
nJ3U2Xr9XITFfmyKYDa0EESuVfIQ+WikO66TjdHjgyMOPdfQ4jzkZ6lfBI67
1cXRrlL0rcqI4otFMPNaVzxrL4OqZ1Ic41KMJZ+Acz9JyjE5QQ736ypGq7/y
zWdNAtiu0gy3jEpADco96S6qgJDJWjpcUYKd0JWnc5WV0LFf9dpcKIEqwpsT
J6jC8My9aaUNB76xJnPl3BpkUp4Jre9woEdFP99DhJwF/RW3g1ys9SYYPFCJ
wL2tm+ZPcKG4Md2dPFgLWugkOT2ABwE+1Bk4VgeGt9YrBxUPmbecAnX76zCa
vW1CdbwGV5Vop1pZD/fm+2M3qaX43OPOmcdfNUDA3ginDpVCd0S73q6nAczy
JKMlfz7+pVE3s4404j6aJ4PX+ZgYY3oMdzXCUDIoDeCXodOrSrDbToyg/fQj
bLdy8Cf+eEKXi9Fd5uwy96YcQZP2JevtTZi5ktgoFAhxLCBqwelgM8IobD/P
jApYzgrs8yTNSInvPlQTW4kPAsfyJqxbkC19aWAUV4WVuzuznza1wIehJi7k
VOP3oMMHGGQJgqcpiSJpDWR/n8/qqJcgJyTZdTtVhNTFYdIJUSueRsUTSQ9q
Ech4lVRk1oZvjpe5stvr4Pzwi19mK9vgZJxXvMyqBykm1Hjf3nbsEyrEa5ca
oPWEy7wgaIdtupdCUNCIh7Gqvp8/kcIhnckI7RBjdHVLX5MvxXPSP8LLz5sg
jaeEnTbswOnSb/eQglvA2aB38rkdyPc+a1C/IQF7j/DrgV0y8Bx8mxYW2vCn
PNfcwVcGzfUDuXN7O2DklaAp4cvQYqUpPjEjw7kV+rLZXRkiHIvCZr67DlHe
yWGeuRzqitvJjhZdWLKwb9WJkMOlzryHfkqB/f3mRVnNcmQ9yv6ItNqD/6Yo
/jSFHELBO3rxP9Mv+Mw=
     "]], LineBox[CompressedData["
1:eJw1lfs7FIgagIkodVYWOXa3EjmrWtfctuiTdSzqKVQSodw6ctCQymVdCus2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     "]], LineBox[{{0.07750886624303228, 0.1}, {0.07754404498200769, -0.1}}]}, 
   {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwVkHswGwYAh9VQlFY7fehcVA0Vlj5wRSo/o4vOVlWOrkS1ylRmtcyKVWyo
x5p4RCKIZ9IkHkkTiSh60UnTY5iabmotrt1K20NvHr1T1buY/u6++/787n6O
8anhicZGRkaBG7z3B72WI9PeDEr2aRO3r39iwXn2VzKBdwpps0evhOawsKY6
mPCYG4ezv6dsMS9kQb2Ch9uVSVB27U7kl7Hw3PbSaic3FYHUBclaHQvFdgPW
Sm0aCLlJtf5KFpoO0BqNlBmAg+n9xHss6I4uHooQZoEayb/KnGJhgpqvl3J/
hoNDjLz47UaPaEVk6nPx92uqr3gvG0VHxr+Xaq/BJiv86QjYsPUTakc6CuB5
iRCyL5kN0ad0k1VFEfztVoiySjZIn3uddGy+DvtN8SdzB9jQhhn4IUI20mIz
23oMbDyM47rWc8vw1qdi5LfMYqg9ST7TfRxo6v1ZD3qKkXGUN5WhL0dqYf6Q
xrQEFPJqjlUvF+dWxUnciBKYINZZpOUh8OUuakVTCYYC9YPe3RW4U2TCmjaU
oJzqenmog4/BM56jClopCKFLna8VVVhc6GlnupVh5nRUzC+yalS576QsVpdB
Hqldt28WgJGZ3nRuMwc+sQUnqMJa0H+gupOLODCcn3s1UVeHiUNhOuYwB30J
p8pTBfUY0o3q83aWIzzFbqKa24h08/maKk05rHzQWxksBMmqbdtWCy4WbzO2
/9snRGSy9fKei1x03hm/dUUvQtwL5hcLzjwIYGGuC7iBMFGrLqSMB+ZdcrRl
7w04quTjMQYegvqEhgatGKJjC5ZWCxVwCf4rbNZXggA7m4QMBh+Wg6Ziz24J
arJmHx95x8foMD14oEMKmp6T1OpSBU1ovWCHZxNMmfcOlw5WoXL0j3mauglx
Jd6me9OrETvmxVlSNOPyVPoF3wUBAqKSnpE9WpAy0XKm9E4NPn4k8CqUtUAg
IN36UFCLzdHDhaMHWuE3u299Ka8Oc5OGR3ubWxF09S4nnVmP+7GH3ROdZXhB
n8+wK2qA6unF7DaxDE/Jcz/mSxqRMT3geFwoh/uSinlvmwjRie/SSgk3MeM/
a/aPTgTKy0/6H9XdxCT9vr1NzsYPyef3OH2kgMVQjvVaqBgm81z6twIFKFES
1vWDErxM6evp2q3EWFdDtsFJiqH/3mw1rlTCijg5vk5qgvI74oUvbdvwWQFF
ooloRvkyTVPJbYNN/BPKE34LSnbWHNNZq+Bh9i6z206GP9UFDt7hKuyoWSYq
h+XYFcowllWqEOT6LE/epUDMHO05YVKFZ2P7XcxetEFYeGKA56AGaU7GIHmq
MbPfS26eoEZ7/zhhUdoOt16H0uwWNUx7z21y/KoDl2O2MJZfqSHt99tFi+mE
5s1KRNLhdsT5z4x/M9AN6wdnnTyOt6NG8H638T+JF/pZ
     "]], LineBox[CompressedData["
1:eJwV13c8Vf8fB3Ar92qXUpIRkRFFiaLeJ5HVV5KkpIFklL0yG0rp3uvanOyE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     "]], LineBox[{{0.08065761455274414, 0.1}, {0.08069062908173845, -0.1}}]}, 
   {RGBColor[0.1, 0.7, 0.2], Thickness[0.007], LineBox[CompressedData["
1:eJwVjXs8FAYAx032WXnsMz61ReZmiy4RcWJev17jPJLU7BN3aeaVkWTRyCdt
Xt3DcZfjvDrHuQfO3XlEdyJ9ro/XZBvyaPkgn0SM1rjZ0ur7+Xw/3z+/lhGJ
wVG6Ojo6x976rls69QdnnZO8Hrr2Vw5eocHq+V13C84J0A1SY+vTaNiQ20eO
s8Nh9mN9tHcmDYo1jBjLYtBwIHyq8gYNc9tjta3sRDDV2sp2Lg0M0x4jmSoZ
BF/Cf2UiGmqJlFs6slT0Nhr8EaCmoctlxeEUPx1nbv5wd3iYhgnvrG4h+xrs
6J+qPVff/mwMba52X4fa2byMY0xHruPoJaHqZ4wxZkZmnenY7sZXDTZnI6XI
Rup5lo6qw3F62oZc5EdNEJU0Ovb7ko5bim7AkKpLPq2iQxW0WeTHp8N4wGzd
dYWOkXD2ngo2C3PREbbEGAYUTvtdZzUF8FRTfWMkDKS6cB6ndhdiVbt8NniF
AS93baZhJxtFapMH2zyY0APVqkrFgVoTkiVnMNF3pLvXue0mcjnNl+NnmCj0
3nOhr7kI6/+0p0V75sMicLX1r4ZifBPGYvVsYeHpyZCwPGkJyp6QKZxEFuq+
Vr0xF/Hwt0OHa8Q0C67UbLI3vwyX5kSWb74vwOa5hRcT5eXgeQbuFssKoIk8
UZjIq4BTgnXM2KsCBMebTpSwb0H6p7griVEIQ1d0cn348N+7dIX0pBAr7UnG
0xo+sok7yI4kNlo7Rlsud1dBwOurUS+xwcO2rV2HBJh9/Wvs/ZMcXL3nHqrf
KcBkViB34w4HRzX8zUpVNcaN1s7vq7wJa5/fg55/WYNHbEr64M4i6Pe+X+3U
VgO9FrnnGq8IQwNxPj3NQmglYceuK7hoCqzgmTjVIuBainqYXAzu0MNFiqIW
e0RZLaz5YlCHSQWrDSIcFPerxUd5OBQSM+NuK4ZfV/7pKJ1S7B7jkXKkYhAI
i7f9ekrxQehAzhBRAlK/y09u5WVYmNwcMxNJoGLSafYZ5fiFemBflJUUOmbV
6YfjKyCf+i6jsVoK38zXRpK4SqTO9lge49dh70cpJgXH+QiN+jc536IeGw70
XR7zfHg9s3swVl6PNoc8/1lmFSzPn9v5xa4G5Bk+IgkhgN4iOy6B14BAeVBu
36YAz+I16tufyOAkz5EMDFSjb3n9Q12uDNZCskl4XQ1kF22+DdjeCC9j2VRa
uRCFLylNXHYjEhxvBScIasHcUerRZSSHR6+Fnem4CL8psgnOwXLkvGph0u0l
+DgwSVfKlYNasuTQLpUibIEyZzEpR7JAuE8WVA9+DrmHQ1Dg3ldCtymiDE8/
J9VtjVSgY/liRYCFHHs7CfkZYgX8P+s9M+ivwIUwg6SXLxQw96GUZtQo0bS+
dirmgBJ9yrR7to7N0HJmDj6+rIT4eufh+fda4eEwaHryjhIa5ahNrFUb7jvl
zRGnlSjlvaMd/wMyxBNV
     "]], LineBox[CompressedData["
1:eJw9lnk01O0XwCfbCG0UaUMoSguRFrpFZSttb5KlslYqexuSVLIlRM13RmNI
hJdmRmWLS4zdGEuShmxJWuyS9TfvP797zj3P+Zxzz7nPXc9Vsnc77iREIpFY
Av3vvVg5peO3MheoxH+SixnNPWcPqubCCpF+ffMTuTjsyTPIv5gLISMBPvav
snH7oneqWzNzYV3Zloyn+9+ib3qK+IvhXLjyy/XacvE3WGT0+Ie8bh6cWCD/
NXEoC0V6/LkRvnmgyv59o26SjSYBLizhojyQtjy96vEaNkassoi5IZIPJu2S
ht8sWdiQs+/6L+N8MFg9YhWWzES5k5us7B/mw/iy3e4fRZhoM7Rc/2N9PiSN
DPrqdGci46GI4iHZd3DojvhJ0eYM3FD2+atO/DtQCh36UDiVjm725RVp3e/A
gnJYsUM9HV/PstMV1AqgVdfoSdT5NJyg0iNiLheAfFiDjnZWKurrhnrMZxWA
6cbI9HOSqRjYePUf/7EC6MqwNW13fYllbna6IzsLoZDc/ZbGT8GjL3fM8N8X
gnCmzH6txmSM3a/ScYyMEDwddN3PKhlbOxaVlJkh+KdOq3T2vUAH+W/BzCYE
+Wwjn5zlL7DJ6vubaKkiENWjx2/JTcJxtbPrazcXAdOxza/sTBLu5phKGHgV
wafiu3mt2c9xcVNyne7jIlgalMB95fYce7qEYjdlFcH2Yq1M/obnGEHKV5Af
KYIs0qT+pbREdFgk93WhTDGEstfrubom4o41Xmki24ph0EO9RkInEbt2b9QZ
9CyGpG25VjcrEzDb9MHk1+hiiDlsXCz2NAHDT3fjZ3Yx3DUcE01yTkCd6zTT
8uFi+FNsnkOXTMBgtuQ5uud7ELm0NWrgIgNti8+rxkS/h7NRhfkHDzBQi1fS
H8J+D8yIyDOTSgzk//K9enX4Pfx6sMHzSmE8sqY/7rokXQJcBueq4e14DJLU
JtlplcC+fWQja4N43KL+M/SQZwn0WrrO/8mlo8gO46MG0SVw/jDTYzuFji0H
k5btYJcA52mUnZMDHQMdbRjKwyUwJ2MYqjT3DJvja95MepTCZDB1Rsn0GaZn
qvkORpWCsszvsSeKzzCg4N7eXlYpmJuLfHWZiEP1z3rV9UOlsMqDrDmdHoez
3ymR5Us4oL9Z+ULCgzhsmBg9WaDJgQM6uP2qYxz6yWZ0vPTgQGCDu4+/Uhwe
U52fTI/iwGSIxirGvDhcp+10KYbFgWjppYyKLhryjq0evz3EAbXZ6ADJlzRU
fvhQ8pRHGQz0vNLy0afhBO0771BUGVSGPLIbUqFhTdqBJwasMtDI9Vu2bQEN
r1XMKG4eKgO9v3PsmS9UNPt4uld5STm8u/Z9sW8VFRV736TLa5bDuf6pD+lv
qFgl7Lpd1KMc/Cv9Z6UjqBgvXTU1GVkOu4vsCPClorfSuuJBZjkEB2iLSl2k
4mpoN+MPlkOis2Wl50EquvuY22W5V4D3QY6PmDgVTV31XopHVsCG/Fp90UkC
le03DNi+qgDfvhOtt38S2Gwidkv8dwXQ/B+78RsIZOqPltguqAQN5VsxOWUE
hmp2SWRpVEJT9I8+kXwC9eULKbaXKiHnSlJ4dxKBsgv+/cIOrYQzKTer3akE
DpKo68TTKmGYSZJzjCQwqe/qa3ZfJch/SaF53SLQn+8wRRavgh4psYth3gSe
4h0zsF1fBYV2Qi6kywRK5GzikZ2rYExBe/SvNYE96SvlbO9XAfO10TOffwgs
jJ9/hp1UBS2PLuccPUygx4OvP2y6q+BX2CGNcSDQ1LdRiy1UDRNKnSvf7yRQ
xa34JnltNUgfV0/jbyOwxeIZmX2uGtLTp87+USOQbRpmTg6ohg+X9t0bVSYw
bM/NWJv4aviZxYVdCgQ6ap3nswqrQa5Ma1P5CgL3rDupTG6vBmJ/8BAhS+Dy
FYYuNjPVYDZvqR5LmsDhBZos1qoa2DX2jSO5iMAXY1JgY10D/n/oaffFBfF/
n7zP8qmBb6NPXySKEmjZ1lcjRq2Bh3xHhVkhArXqm2Vscmsg7Z3azBMSgVKc
UitWSw0cLh/aeHmWgr057ASxiRow2uvN8JumIP7L6LOWqwVhiQqL8kkKUhgR
W1jba0F2kfpxs78U9IzxuyZmUQueS/PiyBMUPBTsUmB9tRakREyNpsYpuM7P
UoQVUwsq91ZeVBUwyf2gmdjrWqiuyVS4P0bBTw7a0daNtTAS+jBCXsDsU2s/
MYdr4Xr78i+doxQMN1usKCbNBRWF03vbBOwMs87WmlyQS6nrlRDY7932M4N5
lAupO02lXAS8Yn3rqKg7FzpUcgb+CnhkRcVu60dcCJkjfcgV+K9Z+DaQmcmF
z1N8kdQ/FEwWSqoU5XJhE5FZUyb4f8B41GLrX1wYbbD1lxbEa9V/+xRTqg4a
E7Xdw6YoqN1+hS6qUQc0zrvprTMUXNBg/dXKrA7C6umBQnOC/HFMNJguddDh
EOg4J8hvUa6ul2hoHUz7DYivFyaQmqGaZ5VaB2uGt7beENTHO0FmHrOiDkjj
ugdHyQSax84zFu2rA+dbAYUUCQJjSq8bZQjzQLNmPNtpAYFXcpwihJR5sNzs
rfR1GQI3mxxTnKfNgzX+c/OE5QTz8UmPPbefB7kL+arvBP3kPSXTPO3Mg9Ur
w2hZawncHj53fuo6DxanmOPgOgL/rPrx928wDy4wTfMtNxLos+f96j9pPPAI
ChRP0SZQry7j1Vg+D3S5ecbhgn6fOUvsG63hwUvOwB7qHgID7rg7Df3mAV36
9JHNJgQGla7J+KFVDyvdt+eonyPQ+KQE9BvWw4fNliZGzgTO7x3j9f1TD20H
6jtCBPMYTq4d/XqtHu4ejvD3u0ngY1NfvY68elAOdfWXiiWQwftY3WTQAF9O
2co+EOwPe7sS28YTDdAeOnezolWwb4YzB+odG2CFweUj6t0EJssEydQFNUCl
wxUN41ECMyy0rSurGkCFvnDxiBwV8/iR/QXHG2F5VPZejiMVm/pM5qfYN0FI
bIRPqzQNBwi1A3c9m8DKpUWtdjUNJczId84GNkHXcokLH9RouDejdEIusQna
DWYV1gEN0z2gL7izCbZ0ShzgXKZh4KR2ucu5DxDjH/Wwq5qGW6QU728+0wyl
rUzvYUocmhbMFkm4NsPmw/mVTslx6OjaNt17qxmkXb5X/MiKQyqP6h3/rBk8
O+UDt9TFoVjsMsfFbc1w4aahXIzYM+SvljQctv4IhhxXr9IbzzB0yzjp7ekW
KG9kWTq60NHnusnGXpcWSOm9M27nS8eLGHdS1q8F+h7dj/UKp6PxEcO0a/QW
cJ+bSW7IpCPZLfKEbncLbLTMb/QfpeO9zA3JOZc/QbDsq4H7d+PRf9NZs/zb
rWBTYHOIbMlAj40VsUUv+NBp5bKkgpGAPU49AYy3fMj5uHrEKz0BLRikywHl
fFC4QspUe5uAu5btNNj7nQ9eOm/S/q1OQKG51N+o0Qaa7M6ENX8SMLohzAiz
2iC7ezIn9Ugism8e+VtQ3A5VPdckLMnPcdLhUmabawfI5N46KxWVhPYFFkcj
nbuAYadOMuOmoMNQU1FRcA/cXrnmm1tnOoZvzXZLDuqFOlq/rKoCE4WKsnXv
+fRB39Yu05BQNi7ZYMb9QumHPk6FgnDgGzSON3g+GP0TnFp6zG4wcrB/7cJj
Rgq//n///g8ErNHz
     "]], LineBox[{{2.7257520714385644`, -0.1}, {2.725752085639665, 0.1}}], 
    LineBox[{{0.08549141852302662, 0.1}, {0.08551792721354345, -0.1}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Detuning (rad)\"", TraditionalForm], 
    FormBox["\"Signal\"", TraditionalForm]},
  GridLines->Automatic,
  PlotRange->
   NCache[{{0, Pi}, {-0.1, 0.1}}, {{0, 3.141592653589793}, {-0.1, 0.1}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{
  3.4572249566775746`*^9, 3.4572250962655745`*^9, {3.4572251295405746`*^9, 
   3.4572251352105746`*^9}, 3.4572251686725745`*^9, 3.4572252605145745`*^9, {
   3.4572252908175745`*^9, 3.4572253204895744`*^9}, {3.4572253961455746`*^9, 
   3.4572254092965746`*^9}}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.4572248900175743`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"1", "/", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"]}], "+", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "3"], " ", 
         SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}], 
     RowBox[{"2", " ", "FSR", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"]}], "+", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "3"], " ", 
         SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}]]}]}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]"}], 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Factor", "[", 
   RowBox[{
    FractionBox["%", 
     FractionBox[
      RowBox[{"F", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}]}], ")"}]}], 
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]]}]]], "/.", 
    RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     SubscriptBox["r1", "r"], "\[Rule]", 
     SqrtBox["0.85"]}]}], "/.", 
   RowBox[{
    SubscriptBox["r2", "r"], "\[Rule]", "1"}]}], "/.", 
  RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"1", "/", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}]}], 
     RowBox[{"FSR", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}], "+", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}]}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]"}], 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Factor", "[", 
   RowBox[{
    FractionBox["%", 
     FractionBox[
      RowBox[{"F", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}]}], ")"}]}], 
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]]}]]], "/.", 
    RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     SubscriptBox["r1", "r"], "\[Rule]", 
     SqrtBox["0.85"]}]}], "/.", 
   RowBox[{
    SubscriptBox["r2", "r"], "\[Rule]", "1"}]}], "/.", 
  RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"1", "/", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}], "-", 
        RowBox[{"3", " ", 
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
     RowBox[{"2", " ", "FSR", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}], "-", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}]}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]"}], 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Factor", "[", 
   RowBox[{
    FractionBox["%", 
     FractionBox[
      RowBox[{"F", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}]}], ")"}]}], 
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]]}]]], "/.", 
    RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     SubscriptBox["r1", "r"], "\[Rule]", 
     SqrtBox["0.85"]}]}], "/.", 
   RowBox[{
    SubscriptBox["r2", "r"], "\[Rule]", "1"}]}], "/.", 
  RowBox[{"\[Phi]", "\[Rule]", "0"}]}]}], "Input",
 CellChangeTimes->{{3.4571155450298*^9, 3.4571155731722*^9}, {
   3.4571156866466*^9, 3.457115687333*^9}, {3.457117045703*^9, 
   3.4571170681358*^9}, {3.457117129007*^9, 3.4571171297558002`*^9}, {
   3.4571171803154*^9, 3.4571171830766*^9}, {3.4571172262106*^9, 
   3.4571172803894*^9}, {3.457118347367*^9, 3.4571183661493998`*^9}, {
   3.4571184503894*^9, 3.4571184506546*^9}, {3.4571187194894*^9, 
   3.4571187273050003`*^9}, 3.4571190714877996`*^9, {3.4571192081282*^9, 
   3.4571192616362*^9}, {3.4571193344258003`*^9, 3.4571193347222*^9}, {
   3.4571194778834*^9, 3.4571194780861998`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "FSR", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "-", 
     RowBox[{"3", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "3"], " ", 
      SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"]}], "-", 
   RowBox[{
    RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
    SubsuperscriptBox["r1", "r", "2"], " ", 
    SubsuperscriptBox["r2", "r", "2"]}], "+", 
   RowBox[{
    SubsuperscriptBox["r1", "r", "3"], " ", 
    SubsuperscriptBox["r2", "r", "3"]}]}]]], "Output",
 CellChangeTimes->{{3.4571155547018003`*^9, 3.4571155742798*^9}, 
   3.4571156878634*^9, {3.4571170476686*^9, 3.4571170687130003`*^9}, 
   3.4571171302394*^9, 3.4571171835446*^9, {3.4571172271154003`*^9, 
   3.4571172808106003`*^9}, {3.4571183614849997`*^9, 3.4571183675534*^9}, 
   3.4571184510914*^9, 3.4571187276794*^9, 3.4571190719558*^9, {
   3.4571192341177998`*^9, 3.457119262541*^9}, 3.4571193353774*^9, 
   3.457119478601*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]]}], 
   RowBox[{"F", "+", 
    RowBox[{"F", " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}]}]]}]], "Output",
 CellChangeTimes->{{3.4571155547018003`*^9, 3.4571155742798*^9}, 
   3.4571156878634*^9, {3.4571170476686*^9, 3.4571170687130003`*^9}, 
   3.4571171302394*^9, 3.4571171835446*^9, {3.4571172271154003`*^9, 
   3.4571172808106003`*^9}, {3.4571183614849997`*^9, 3.4571183675534*^9}, 
   3.4571184510914*^9, 3.4571187276794*^9, 3.4571190719558*^9, {
   3.4571192341177998`*^9, 3.457119262541*^9}, 3.4571193353774*^9, 
   3.457119478601*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"3.139001404393546`", " ", "FSR"}], "F"]}]], "Output",
 CellChangeTimes->{{3.4571155547018003`*^9, 3.4571155742798*^9}, 
   3.4571156878634*^9, {3.4571170476686*^9, 3.4571170687130003`*^9}, 
   3.4571171302394*^9, 3.4571171835446*^9, {3.4571172271154003`*^9, 
   3.4571172808106003`*^9}, {3.4571183614849997`*^9, 3.4571183675534*^9}, 
   3.4571184510914*^9, 3.4571187276794*^9, 3.4571190719558*^9, {
   3.4571192341177998`*^9, 3.457119262541*^9}, 3.4571193353774*^9, 
   3.4571194786166*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"FSR", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
  RowBox[{
   SubscriptBox["r1", "r"], " ", 
   SubscriptBox["r2", "r"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.4571155547018003`*^9, 3.4571155742798*^9}, 
   3.4571156878634*^9, {3.4571170476686*^9, 3.4571170687130003`*^9}, 
   3.4571171302394*^9, 3.4571171835446*^9, {3.4571172271154003`*^9, 
   3.4571172808106003`*^9}, {3.4571183614849997`*^9, 3.4571183675534*^9}, 
   3.4571184510914*^9, 3.4571187276794*^9, 3.4571190719558*^9, {
   3.4571192341177998`*^9, 3.457119262541*^9}, 3.4571193353774*^9, 
   3.4571194786166*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"FSR", " ", "\[Pi]"}], 
   RowBox[{"F", " ", 
    SqrtBox[
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]]}]]}]], "Output",
 CellChangeTimes->{{3.4571155547018003`*^9, 3.4571155742798*^9}, 
   3.4571156878634*^9, {3.4571170476686*^9, 3.4571170687130003`*^9}, 
   3.4571171302394*^9, 3.4571171835446*^9, {3.4571172271154003`*^9, 
   3.4571172808106003`*^9}, {3.4571183614849997`*^9, 3.4571183675534*^9}, 
   3.4571184510914*^9, 3.4571187276794*^9, 3.4571190719558*^9, {
   3.4571192341177998`*^9, 3.457119262541*^9}, 3.4571193353774*^9, 
   3.4571194786166*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"3.2718632315680143`", " ", "FSR"}], "F"]}]], "Output",
 CellChangeTimes->{{3.4571155547018003`*^9, 3.4571155742798*^9}, 
   3.4571156878634*^9, {3.4571170476686*^9, 3.4571170687130003`*^9}, 
   3.4571171302394*^9, 3.4571171835446*^9, {3.4571172271154003`*^9, 
   3.4571172808106003`*^9}, {3.4571183614849997`*^9, 3.4571183675534*^9}, 
   3.4571184510914*^9, 3.4571187276794*^9, 3.4571190719558*^9, {
   3.4571192341177998`*^9, 3.457119262541*^9}, 3.4571193353774*^9, 
   3.4571194786166*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "FSR", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "-", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
  RowBox[{"1", "+", 
   RowBox[{"2", " ", 
    RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"]}], "-", 
   RowBox[{"3", " ", 
    SubsuperscriptBox["r1", "r", "2"], " ", 
    SubsuperscriptBox["r2", "r", "2"]}]}]]], "Output",
 CellChangeTimes->{{3.4571155547018003`*^9, 3.4571155742798*^9}, 
   3.4571156878634*^9, {3.4571170476686*^9, 3.4571170687130003`*^9}, 
   3.4571171302394*^9, 3.4571171835446*^9, {3.4571172271154003`*^9, 
   3.4571172808106003`*^9}, {3.4571183614849997`*^9, 3.4571183675534*^9}, 
   3.4571184510914*^9, 3.4571187276794*^9, 3.4571190719558*^9, {
   3.4571192341177998`*^9, 3.457119262541*^9}, 3.4571193353774*^9, 
   3.4571194786166*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]]}], 
   RowBox[{"F", "+", 
    RowBox[{"3", " ", "F", " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}]}]]}]], "Output",
 CellChangeTimes->{{3.4571155547018003`*^9, 3.4571155742798*^9}, 
   3.4571156878634*^9, {3.4571170476686*^9, 3.4571170687130003`*^9}, 
   3.4571171302394*^9, 3.4571171835446*^9, {3.4571172271154003`*^9, 
   3.4571172808106003`*^9}, {3.4571183614849997`*^9, 3.4571183675534*^9}, 
   3.4571184510914*^9, 3.4571187276794*^9, 3.4571190719558*^9, {
   3.4571192341177998`*^9, 3.457119262541*^9}, 3.4571193353774*^9, 
   3.4571194786166*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"1.602027785965747`", " ", "FSR"}], "F"]}]], "Output",
 CellChangeTimes->{{3.4571155547018003`*^9, 3.4571155742798*^9}, 
   3.4571156878634*^9, {3.4571170476686*^9, 3.4571170687130003`*^9}, 
   3.4571171302394*^9, 3.4571171835446*^9, {3.4571172271154003`*^9, 
   3.4571172808106003`*^9}, {3.4571183614849997`*^9, 3.4571183675534*^9}, 
   3.4571184510914*^9, 3.4571187276794*^9, 3.4571190719558*^9, {
   3.4571192341177998`*^9, 3.457119262541*^9}, 3.4571193353774*^9, 
   3.4571194786166*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Approximate", " ", 
  RowBox[{"cav", ".", 
   SubscriptBox["E", "aux"]}]}]], "Subsubsection",
 CellChangeTimes->{{3.456849308049094*^9, 3.4568493216210947`*^9}, {
  3.4568493673134947`*^9, 3.4568493682026944`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           SubscriptBox["cav", "aux"], ",", 
           RowBox[{"{", 
            RowBox[{"\[Omega]", ",", "0", ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
        ".", "Eaux"}], "]"}], "//", "Expand"}], ")"}], "/.", 
    RowBox[{
     RowBox[{"\[Delta]l", " ", 
      SubscriptBox["\[CurlyPhi]", "aux"]}], "\[Rule]", "0"}]}], "/.", 
   RowBox[{
    SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[CurlyPhi]", "aux"], "+", 
     FractionBox["\[CapitalDelta]A", "\[ImaginaryI]"]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"Simplify", "[", "%", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pm", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"TrigToExp", "[", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"+", 
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "-", 
       RowBox[{
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "\[Conjugate]"}]}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"am", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"TrigToExp", "[", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"+", 
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "+", 
       RowBox[{
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "\[Conjugate]"}]}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<carrier\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"cr", "=", 
  RowBox[{
  "res", "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<PM length\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pm", "/.", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<AM length\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"am", "/.", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<PM phase\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pm", "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<AM phase (zero at \[ImaginaryI]f/FSR has been removed)\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[Pi]", " ", "FSR", " ", "am"}], 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]], "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"%%", "-", "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<PM amplitude (zero at \[ImaginaryI]f/FSR has been removed)\>\"", 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", "\[Pi]", " ", "FSR", " ", "pm"}], 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]], "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"%%", "-", "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<AM amplitude\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"am", "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.456844980302494*^9, 3.4568450429988947`*^9}, {
   3.4568450869596944`*^9, 3.4568451086124945`*^9}, {3.4568451986556945`*^9, 
   3.4568452155036945`*^9}, {3.4568452765308943`*^9, 
   3.4568453254368944`*^9}, {3.4568453586804943`*^9, 
   3.4568453592576942`*^9}, {3.456845437320094*^9, 3.4568455048056946`*^9}, {
   3.4568455735548944`*^9, 3.4568455804344945`*^9}, {3.4568456226636944`*^9, 
   3.4568456574828944`*^9}, {3.456845777041294*^9, 3.4568458071024942`*^9}, {
   3.4568459100000944`*^9, 3.456845918642494*^9}, {3.4568459907768946`*^9, 
   3.4568459918532944`*^9}, {3.4568460847668943`*^9, 
   3.4568460982608943`*^9}, {3.456846359061694*^9, 3.456846439245694*^9}, 
   3.4568484870210943`*^9, {3.4568488763814945`*^9, 3.456848879407894*^9}, {
   3.456848948235094*^9, 3.4568489525250945`*^9}, {3.4568489944110947`*^9, 
   3.4568490183570943`*^9}, {3.456849112019494*^9, 3.456849130864294*^9}, 
   3.4568492196126947`*^9, {3.4568492498922944`*^9, 3.4568492583318944`*^9}, 
   3.4568493013098946`*^9, {3.4568493786702943`*^9, 3.456849399870694*^9}, {
   3.4568494558746943`*^9, 3.4568494835646944`*^9}, {3.4568500089102945`*^9, 
   3.4568500092534943`*^9}, 3.4568501139606943`*^9, {3.4568581151286945`*^9, 
   3.456858170181094*^9}, {3.4568582115366945`*^9, 3.4568582152806945`*^9}, {
   3.4568582493978944`*^9, 3.456858265575094*^9}, {3.4568585005578947`*^9, 
   3.4568585049258947`*^9}, {3.4568585823954945`*^9, 3.456858603471094*^9}, 
   3.4568586470262947`*^9, {3.456858695011894*^9, 3.456858737428294*^9}, {
   3.4568587911702943`*^9, 3.4568588381886945`*^9}, {3.4568589304314947`*^9, 
   3.4568591575206947`*^9}, {3.4568592678438945`*^9, 3.456859321554694*^9}, {
   3.456859991028694*^9, 3.4568600139606943`*^9}, 3.4568601781974945`*^9, 
   3.4568603104074945`*^9, {3.456860374991494*^9, 3.4568603777838945`*^9}, {
   3.456860462959894*^9, 3.4568604741762943`*^9}, {3.456860504284294*^9, 
   3.456860544454294*^9}, {3.4568607078174944`*^9, 3.456860740249894*^9}, {
   3.456860799108694*^9, 3.456860816143894*^9}, {3.4568608753146944`*^9, 
   3.4568609339550943`*^9}, {3.456860965295494*^9, 3.4568610310338945`*^9}, {
   3.456861066009094*^9, 3.4568610937146945`*^9}, {3.4568616726930943`*^9, 
   3.4568617256238947`*^9}, {3.4568618904222946`*^9, 
   3.4568618944158945`*^9}, {3.4568635014342947`*^9, 3.4568635065354943`*^9}, 
   3.4569341148535748`*^9, {3.4569615085875745`*^9, 3.456961529851575*^9}, {
   3.457116837209*^9, 3.457116844697*^9}, {3.4571168963798*^9, 
   3.4571168984702*^9}, {3.45717950899*^9, 3.4571795133736*^9}, {
   3.4571795559147997`*^9, 3.4571795597836*^9}, {3.4571796457864*^9, 
   3.457179649858*^9}, 3.4572609741556*^9, 3.4572610933708*^9}],

Cell[BoxData["\<\"carrier\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571776865668*^9, 
   3.4571795224372*^9, 3.4571795626384*^9, 3.4571796515896*^9, 
   3.4572609822208*^9, 3.4572610952584*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Phi]", "+", 
        SubscriptBox["\[Phi]", "aux"]}], ")"}]}]], " ", 
    SubscriptBox["t1", "r"]}], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], "-", 
    RowBox[{
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.457261095274*^9}],

Cell[BoxData["\<\"PM length\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571776865668*^9, 
   3.4571795224372*^9, 3.4571795626384*^9, 3.4571796515896*^9, 
   3.4572609822208*^9, 3.4572610952896*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "k", " ", "\[Delta]l", " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}], ")"}]}], 
   RowBox[{"1", "-", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], "+", 
    RowBox[{
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.4572610953208*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "3"], " ", 
        SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}], 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{"3", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "3"], " ", 
        SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.4572610954456*^9}],

Cell[BoxData["\<\"AM length\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571776865668*^9, 
   3.4571795224372*^9, 3.4571795626384*^9, 3.4571796515896*^9, 
   3.4572609822208*^9, 3.4572610954611998`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "k", " ", "\[Delta]l", " ", 
     RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.4572610954768*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.457261095508*^9}],

Cell[BoxData["\<\"PM phase\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571776865668*^9, 
   3.4571795224372*^9, 3.4571795626384*^9, 3.4571796515896*^9, 
   3.4572609822208*^9, 3.4572610955236*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[ImaginaryI]", " ", 
   SubscriptBox["\[CurlyPhi]", "aux"]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.4572610955392*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
       RowBox[{
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]}], ")"}]}], 
    RowBox[{"FSR", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.4572610955548*^9}],

Cell[BoxData["\<\"AM phase (zero at \[ImaginaryI]f/FSR has been \
removed)\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571776865668*^9, 
   3.4571795224372*^9, 3.4571795626384*^9, 3.4571796515896*^9, 
   3.4572609822208*^9, 3.4572610955704*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"2", " ", "\[Pi]", " ", 
    RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"], " ", 
    SubscriptBox["\[CurlyPhi]", "aux"]}], 
   RowBox[{"1", "-", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], "+", 
    RowBox[{
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.457261095586*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.4572610956015997`*^9}],

Cell[BoxData["\<\"PM amplitude (zero at \[ImaginaryI]f/FSR has been \
removed)\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571776865668*^9, 
   3.4571795224372*^9, 3.4571795626384*^9, 3.4571796515896*^9, 
   3.4572609822208*^9, 3.4572610956172*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{
    "2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", "\[CapitalDelta]A", " ", 
     RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.4572610956484003`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.457261095664*^9}],

Cell[BoxData["\<\"AM amplitude\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571776865668*^9, 
   3.4571795224372*^9, 3.4571795626384*^9, 3.4571796515896*^9, 
   3.4572609822208*^9, 3.4572610956796*^9}],

Cell[BoxData[
 RowBox[{"{", "\[CapitalDelta]A", "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.4572610956952*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
       RowBox[{
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]}], ")"}]}], 
    RowBox[{"FSR", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.4571776865824003`*^9, 3.4571795224528*^9, 3.4571795626540003`*^9, 
   3.4571796516052*^9, 3.4572609822363997`*^9, 3.4572610957108*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Approximate", " ", 
  SubscriptBox["E", "aux"], " ", "in", " ", "transmission"}]], "Subsubsection",
 CellChangeTimes->{{3.456849308049094*^9, 3.4568493216210947`*^9}, {
  3.4568493673134947`*^9, 3.4568493682026944`*^9}, {3.4571770198696003`*^9, 
  3.4571770294012003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["T1", "aux"], ".", 
            SubscriptBox["cav", "aux"]}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Omega]", ",", "0", ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
        ".", "Eaux"}], "]"}], "//", "Expand"}], ")"}], "/.", 
    RowBox[{
     RowBox[{"\[Delta]l", " ", 
      SubscriptBox["\[CurlyPhi]", "aux"]}], "\[Rule]", "0"}]}], "/.", 
   RowBox[{
    SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[CurlyPhi]", "aux"], "+", 
     FractionBox["\[CapitalDelta]A", "\[ImaginaryI]"]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"Simplify", "[", "%", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pm", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"TrigToExp", "[", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"+", 
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "-", 
       RowBox[{
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "\[Conjugate]"}]}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"am", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"TrigToExp", "[", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"+", 
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "+", 
       RowBox[{
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "\[Conjugate]"}]}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<carrier\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"cr", "=", 
  RowBox[{
  "res", "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<PM length\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pm", "/.", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<AM length\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"am", "/.", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<PM phase\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pm", "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<AM phase (zero at \[ImaginaryI]f/FSR has been removed)\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[Pi]", " ", "FSR", " ", "am"}], 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]], "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"%%", "-", "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<PM amplitude (zero at \[ImaginaryI]f/FSR has been removed)\>\"", 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", "\[Pi]", " ", "FSR", " ", "pm"}], 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]], "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"%%", "-", "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<AM amplitude\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"am", "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.456844980302494*^9, 3.4568450429988947`*^9}, {
   3.4568450869596944`*^9, 3.4568451086124945`*^9}, {3.4568451986556945`*^9, 
   3.4568452155036945`*^9}, {3.4568452765308943`*^9, 
   3.4568453254368944`*^9}, {3.4568453586804943`*^9, 
   3.4568453592576942`*^9}, {3.456845437320094*^9, 3.4568455048056946`*^9}, {
   3.4568455735548944`*^9, 3.4568455804344945`*^9}, {3.4568456226636944`*^9, 
   3.4568456574828944`*^9}, {3.456845777041294*^9, 3.4568458071024942`*^9}, {
   3.4568459100000944`*^9, 3.456845918642494*^9}, {3.4568459907768946`*^9, 
   3.4568459918532944`*^9}, {3.4568460847668943`*^9, 
   3.4568460982608943`*^9}, {3.456846359061694*^9, 3.456846439245694*^9}, 
   3.4568484870210943`*^9, {3.4568488763814945`*^9, 3.456848879407894*^9}, {
   3.456848948235094*^9, 3.4568489525250945`*^9}, {3.4568489944110947`*^9, 
   3.4568490183570943`*^9}, {3.456849112019494*^9, 3.456849130864294*^9}, 
   3.4568492196126947`*^9, {3.4568492498922944`*^9, 3.4568492583318944`*^9}, 
   3.4568493013098946`*^9, {3.4568493786702943`*^9, 3.456849399870694*^9}, {
   3.4568494558746943`*^9, 3.4568494835646944`*^9}, {3.4568500089102945`*^9, 
   3.4568500092534943`*^9}, 3.4568501139606943`*^9, {3.4568581151286945`*^9, 
   3.456858170181094*^9}, {3.4568582115366945`*^9, 3.4568582152806945`*^9}, {
   3.4568582493978944`*^9, 3.456858265575094*^9}, {3.4568585005578947`*^9, 
   3.4568585049258947`*^9}, {3.4568585823954945`*^9, 3.456858603471094*^9}, 
   3.4568586470262947`*^9, {3.456858695011894*^9, 3.456858737428294*^9}, {
   3.4568587911702943`*^9, 3.4568588381886945`*^9}, {3.4568589304314947`*^9, 
   3.4568591575206947`*^9}, {3.4568592678438945`*^9, 3.456859321554694*^9}, {
   3.456859991028694*^9, 3.4568600139606943`*^9}, 3.4568601781974945`*^9, 
   3.4568603104074945`*^9, {3.456860374991494*^9, 3.4568603777838945`*^9}, {
   3.456860462959894*^9, 3.4568604741762943`*^9}, {3.456860504284294*^9, 
   3.456860544454294*^9}, {3.4568607078174944`*^9, 3.456860740249894*^9}, {
   3.456860799108694*^9, 3.456860816143894*^9}, {3.4568608753146944`*^9, 
   3.4568609339550943`*^9}, {3.456860965295494*^9, 3.4568610310338945`*^9}, {
   3.456861066009094*^9, 3.4568610937146945`*^9}, {3.4568616726930943`*^9, 
   3.4568617256238947`*^9}, {3.4568618904222946`*^9, 
   3.4568618944158945`*^9}, {3.4568635014342947`*^9, 3.4568635065354943`*^9}, 
   3.4569341148535748`*^9, {3.4569615085875745`*^9, 3.456961529851575*^9}, {
   3.457116837209*^9, 3.457116844697*^9}, {3.4571168963798*^9, 
   3.4571168984702*^9}, {3.4571773255360003`*^9, 3.4571773288900003`*^9}, 
   3.4571775568684*^9, {3.4571794524244003`*^9, 3.457179470146*^9}, {
   3.4571801569672003`*^9, 3.4571801590264*^9}, 3.4572610174300003`*^9, 
   3.4572610776616*^9}],

Cell[BoxData["\<\"carrier\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, {3.4571794673848*^9, 
   3.4571794779147997`*^9}, 3.4571801640184*^9, 3.4572610311112003`*^9, 
   3.45726108256*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Phi]", "+", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Phi]", "aux"]}]}], ")"}]}]], " ", 
    SubscriptBox["t1", "r"], " ", 
    SubscriptBox["t2", "r"]}], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], "-", 
    RowBox[{
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.4572610825755997`*^9}],

Cell[BoxData["\<\"PM length\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, {3.4571794673848*^9, 
   3.4571794779147997`*^9}, 3.4571801640184*^9, 3.4572610311112003`*^9, 
   3.4572610825912*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "k", " ", "\[Delta]l", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "-", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.4572610826068*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"4", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "6"}], "+", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubsuperscriptBox["r1", "r", "3"], " ", 
       SubsuperscriptBox["r2", "r", "3"]}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "4"], " ", 
       SubsuperscriptBox["r2", "r", "4"]}]}], ")"}]}], 
   RowBox[{"4", " ", "FSR", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.4572610826692*^9}],

Cell[BoxData["\<\"AM length\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, {3.4571794673848*^9, 
   3.4571794779147997`*^9}, 3.4571801640184*^9, 3.4572610311112003`*^9, 
   3.4572610826848*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "k", " ", "\[Delta]l", " ", 
     RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.4572610827004004`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}], 
   RowBox[{"FSR", "-", 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], "+", 
    RowBox[{"FSR", " ", 
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.457261082716*^9}],

Cell[BoxData["\<\"PM phase\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, {3.4571794673848*^9, 
   3.4571794779147997`*^9}, 3.4571801640184*^9, 3.4572610311112003`*^9, 
   3.4572610827316*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[ImaginaryI]", " ", 
   SubscriptBox["\[CurlyPhi]", "aux"]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.4572610827628*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
   RowBox[{"2", " ", "FSR", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.4572610827784*^9}],

Cell[BoxData["\<\"AM phase (zero at \[ImaginaryI]f/FSR has been \
removed)\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, {3.4571794673848*^9, 
   3.4571794779147997`*^9}, 3.4571801640184*^9, 3.4572610311112003`*^9, 
   3.4572610827939997`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"2", " ", "\[Pi]", " ", 
    RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"], " ", 
    SubscriptBox["\[CurlyPhi]", "aux"]}], 
   RowBox[{"1", "-", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], "+", 
    RowBox[{
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.4572610828096*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}], 
   RowBox[{"FSR", "-", 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], "+", 
    RowBox[{"FSR", " ", 
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.4572610828252*^9}],

Cell[BoxData["\<\"PM amplitude (zero at \[ImaginaryI]f/FSR has been \
removed)\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, {3.4571794673848*^9, 
   3.4571794779147997`*^9}, 3.4571801640184*^9, 3.4572610311112003`*^9, 
   3.4572610828408003`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{
    "2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", "\[CapitalDelta]A", " ", 
     RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.4572610828564*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}], 
   RowBox[{"FSR", "-", 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], "+", 
    RowBox[{"FSR", " ", 
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.4572610828719997`*^9}],

Cell[BoxData["\<\"AM amplitude\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, {3.4571794673848*^9, 
   3.4571794779147997`*^9}, 3.4571801640184*^9, 3.4572610311112003`*^9, 
   3.4572610828876*^9}],

Cell[BoxData[
 RowBox[{"{", "\[CapitalDelta]A", "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.4572610829032*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
   RowBox[{"2", " ", "FSR", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, {
   3.4571794674004*^9, 3.4571794779147997`*^9}, 3.457180164034*^9, 
   3.4572610311268*^9, 3.4572610829188004`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{"Factor", "[", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    RowBox[{"\[Omega]", "/", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"4", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "6"}], "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
          SubsuperscriptBox["r1", "r", "2"], " ", 
          SubsuperscriptBox["r2", "r", "2"]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
          SubsuperscriptBox["r1", "r", "3"], " ", 
          SubsuperscriptBox["r2", "r", "3"]}], "+", 
         RowBox[{
          SubsuperscriptBox["r1", "r", "4"], " ", 
          SubsuperscriptBox["r2", "r", "4"]}]}], ")"}]}], 
      RowBox[{"4", " ", "FSR", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}], "-", 
         RowBox[{
          SubsuperscriptBox["r1", "r", "2"], " ", 
          SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          SubsuperscriptBox["r1", "r", "2"], " ", 
          SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Factor", "[", 
  RowBox[{
   FractionBox["%", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]]}]]], "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Factor", "[", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    RowBox[{"\[Omega]", "/", 
     FractionBox[
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], 
      RowBox[{"FSR", "-", 
       RowBox[{"2", " ", "FSR", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{"FSR", " ", 
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}]]}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Factor", "[", 
  RowBox[{
   FractionBox["%", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]]}]]], "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Factor", "[", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    RowBox[{"\[Omega]", "/", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          SubsuperscriptBox["r1", "r", "2"], " ", 
          SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", "FSR", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}], "-", 
         RowBox[{
          SubsuperscriptBox["r1", "r", "2"], " ", 
          SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Factor", "[", 
  RowBox[{
   FractionBox["%", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]]}]]], "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4572624843136*^9, 3.4572624851404*^9}, 
   3.4572631881076*^9, {3.4572632935480003`*^9, 3.4572633063087997`*^9}, {
   3.4572633635452003`*^9, 3.4572633749332*^9}, 3.457263452512*^9, {
   3.4572636178252*^9, 3.4572636571996*^9}, {3.4572637760716*^9, 
   3.4572637854004*^9}, 3.4572666842704*^9, {3.4572910156652*^9, 
   3.4572910404692*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", "FSR", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubsuperscriptBox["r1", "r", "3"], " ", 
      SubsuperscriptBox["r2", "r", "3"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "4"], " ", 
      SubsuperscriptBox["r2", "r", "4"]}]}], ")"}]}], 
  RowBox[{"1", "+", 
   RowBox[{"4", " ", 
    RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "6"}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
    SubsuperscriptBox["r1", "r", "2"], " ", 
    SubsuperscriptBox["r2", "r", "2"]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
    SubsuperscriptBox["r1", "r", "3"], " ", 
    SubsuperscriptBox["r2", "r", "3"]}], "+", 
   RowBox[{
    SubsuperscriptBox["r1", "r", "4"], " ", 
    SubsuperscriptBox["r2", "r", "4"]}]}]]], "Output",
 CellChangeTimes->{3.4572910414832*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}], ")"}]}], 
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"6", " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.4572910414832*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"FSR", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{
    SubsuperscriptBox["r1", "r", "2"], " ", 
    SubsuperscriptBox["r2", "r", "2"]}]}]]], "Output",
 CellChangeTimes->{3.4572910414988003`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]]}], 
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.4572910415144*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "FSR", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{
    SubsuperscriptBox["r1", "r", "2"], " ", 
    SubsuperscriptBox["r2", "r", "2"]}]}]]], "Output",
 CellChangeTimes->{3.4572910415299997`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]]}], 
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.4572910415456*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Approximate", " ", 
  SubscriptBox["E", "aux"], " ", "in", " ", "back", " ", 
  "transmission"}]], "Subsubsection",
 CellChangeTimes->{{3.456849308049094*^9, 3.4568493216210947`*^9}, {
  3.4568493673134947`*^9, 3.4568493682026944`*^9}, {3.4571770198696003`*^9, 
  3.4571770294012003`*^9}, {3.4571780198764*^9, 3.4571780204224*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["T2", "aux"], ".", 
            SubscriptBox["cav", "aux"]}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Omega]", ",", "0", ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
        ".", "Eaux"}], "]"}], "//", "Expand"}], ")"}], "/.", 
    RowBox[{
     RowBox[{"\[Delta]l", " ", 
      SubscriptBox["\[CurlyPhi]", "aux"]}], "\[Rule]", "0"}]}], "/.", 
   RowBox[{
    SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[CurlyPhi]", "aux"], "+", 
     FractionBox["\[CapitalDelta]A", "\[ImaginaryI]"]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"Simplify", "[", "%", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pm", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"TrigToExp", "[", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"+", 
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "-", 
       RowBox[{
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "\[Conjugate]"}]}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"am", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"TrigToExp", "[", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"+", 
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "+", 
       RowBox[{
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "\[Conjugate]"}]}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<carrier\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"cr", "=", 
  RowBox[{
  "res", "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<PM length\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pm", "/.", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<AM length\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"am", "/.", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<PM phase\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pm", "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<AM phase (zero at \[ImaginaryI]f/FSR has been removed)\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[Pi]", " ", "FSR", " ", "am"}], 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]], "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"%%", "-", "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<PM amplitude (zero at \[ImaginaryI]f/FSR has been removed)\>\"", 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", "\[Pi]", " ", "FSR", " ", "pm"}], 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]], "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"%%", "-", "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<AM amplitude\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"am", "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.456844980302494*^9, 3.4568450429988947`*^9}, {
   3.4568450869596944`*^9, 3.4568451086124945`*^9}, {3.4568451986556945`*^9, 
   3.4568452155036945`*^9}, {3.4568452765308943`*^9, 
   3.4568453254368944`*^9}, {3.4568453586804943`*^9, 
   3.4568453592576942`*^9}, {3.456845437320094*^9, 3.4568455048056946`*^9}, {
   3.4568455735548944`*^9, 3.4568455804344945`*^9}, {3.4568456226636944`*^9, 
   3.4568456574828944`*^9}, {3.456845777041294*^9, 3.4568458071024942`*^9}, {
   3.4568459100000944`*^9, 3.456845918642494*^9}, {3.4568459907768946`*^9, 
   3.4568459918532944`*^9}, {3.4568460847668943`*^9, 
   3.4568460982608943`*^9}, {3.456846359061694*^9, 3.456846439245694*^9}, 
   3.4568484870210943`*^9, {3.4568488763814945`*^9, 3.456848879407894*^9}, {
   3.456848948235094*^9, 3.4568489525250945`*^9}, {3.4568489944110947`*^9, 
   3.4568490183570943`*^9}, {3.456849112019494*^9, 3.456849130864294*^9}, 
   3.4568492196126947`*^9, {3.4568492498922944`*^9, 3.4568492583318944`*^9}, 
   3.4568493013098946`*^9, {3.4568493786702943`*^9, 3.456849399870694*^9}, {
   3.4568494558746943`*^9, 3.4568494835646944`*^9}, {3.4568500089102945`*^9, 
   3.4568500092534943`*^9}, 3.4568501139606943`*^9, {3.4568581151286945`*^9, 
   3.456858170181094*^9}, {3.4568582115366945`*^9, 3.4568582152806945`*^9}, {
   3.4568582493978944`*^9, 3.456858265575094*^9}, {3.4568585005578947`*^9, 
   3.4568585049258947`*^9}, {3.4568585823954945`*^9, 3.456858603471094*^9}, 
   3.4568586470262947`*^9, {3.456858695011894*^9, 3.456858737428294*^9}, {
   3.4568587911702943`*^9, 3.4568588381886945`*^9}, {3.4568589304314947`*^9, 
   3.4568591575206947`*^9}, {3.4568592678438945`*^9, 3.456859321554694*^9}, {
   3.456859991028694*^9, 3.4568600139606943`*^9}, 3.4568601781974945`*^9, 
   3.4568603104074945`*^9, {3.456860374991494*^9, 3.4568603777838945`*^9}, {
   3.456860462959894*^9, 3.4568604741762943`*^9}, {3.456860504284294*^9, 
   3.456860544454294*^9}, {3.4568607078174944`*^9, 3.456860740249894*^9}, {
   3.456860799108694*^9, 3.456860816143894*^9}, {3.4568608753146944`*^9, 
   3.4568609339550943`*^9}, {3.456860965295494*^9, 3.4568610310338945`*^9}, {
   3.456861066009094*^9, 3.4568610937146945`*^9}, {3.4568616726930943`*^9, 
   3.4568617256238947`*^9}, {3.4568618904222946`*^9, 
   3.4568618944158945`*^9}, {3.4568635014342947`*^9, 3.4568635065354943`*^9}, 
   3.4569341148535748`*^9, {3.4569615085875745`*^9, 3.456961529851575*^9}, {
   3.457116837209*^9, 3.457116844697*^9}, {3.4571168963798*^9, 
   3.4571168984702*^9}, {3.4571773255360003`*^9, 3.4571773288900003`*^9}, 
   3.4571775568684*^9, {3.4571780246968*^9, 3.4571780255236*^9}, {
   3.457180173862*^9, 3.4571801772472*^9}}],

Cell[BoxData["\<\"carrier\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, 3.4571780392672*^9, 
   3.4571801855464*^9, 3.4572611155383997`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "aux"]}]], " ", 
    SubscriptBox["r2", "r"], " ", 
    SubsuperscriptBox["t1", "r", "2"]}], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], "-", 
    RowBox[{
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.457261115554*^9}],

Cell[BoxData["\<\"PM length\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, 3.4571780392672*^9, 
   3.4571801855464*^9, 3.4572611156476*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "k", " ", "\[Delta]l", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "-", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.4572611158504*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubsuperscriptBox["r1", "r", "3"], " ", 
       SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}], 
   RowBox[{"2", " ", "FSR", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"3", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}], "-", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubsuperscriptBox["r1", "r", "3"], " ", 
       SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.4572611159751997`*^9}],

Cell[BoxData["\<\"AM length\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, 3.4571780392672*^9, 
   3.4571801855464*^9, 3.4572611160064*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "k", " ", "\[Delta]l", " ", 
     RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.4572611161935997`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
   RowBox[{"2", " ", "FSR", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.4572611162092*^9}],

Cell[BoxData["\<\"PM phase\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, 3.4571780392672*^9, 
   3.4571801855464*^9, 3.4572611162404003`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[ImaginaryI]", " ", 
   SubscriptBox["\[CurlyPhi]", "aux"]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.4572611163496*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}]}], 
   RowBox[{"FSR", "-", 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], "+", 
    RowBox[{"FSR", " ", 
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.4572611163964*^9}],

Cell[BoxData["\<\"AM phase (zero at \[ImaginaryI]f/FSR has been \
removed)\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, 3.4571780392672*^9, 
   3.4571801855464*^9, 3.4572611164119997`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"2", " ", "\[Pi]", " ", 
    RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"], " ", 
    SubscriptBox["\[CurlyPhi]", "aux"]}], 
   RowBox[{"1", "-", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], "+", 
    RowBox[{
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.4572611165056*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
   RowBox[{"2", " ", "FSR", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.4572611165212*^9}],

Cell[BoxData["\<\"PM amplitude (zero at \[ImaginaryI]f/FSR has been \
removed)\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, 3.4571780392672*^9, 
   3.4571801855464*^9, 3.4572611165368*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{
    "2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", "\[CapitalDelta]A", " ", 
     RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.4572611165992002`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
   RowBox[{"2", " ", "FSR", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.4572611166148*^9}],

Cell[BoxData["\<\"AM amplitude\"\>"], "Print",
 CellChangeTimes->{
  3.4568588392338943`*^9, 3.4568589351426945`*^9, {3.4568590177914944`*^9, 
   3.4568590285710945`*^9}, {3.4568591095818944`*^9, 
   3.4568591580354943`*^9}, {3.4568592942234945`*^9, 
   3.4568593234578943`*^9}, {3.4568599915590944`*^9, 3.4568600144754944`*^9}, 
   3.4568601792114944`*^9, 3.4568603110938945`*^9, 3.456860381028694*^9, 
   3.456860475907894*^9, {3.4568605179186945`*^9, 3.4568605457802944`*^9}, {
   3.456860711514694*^9, 3.4568607431514945`*^9}, 3.4568608201842947`*^9, {
   3.4568609068578944`*^9, 3.4568609360766945`*^9}, {3.456860975560294*^9, 
   3.456861032671894*^9}, 3.456861096928294*^9, 3.4568616950634947`*^9, 
   3.4568617282914944`*^9, 3.4568618989242945`*^9, 3.4568635137894945`*^9, {
   3.4569341029405746`*^9, 3.4569341169135747`*^9}, 3.4571168605934*^9, 
   3.4571169065666*^9, 3.4571214927966003`*^9, 3.4571773500903997`*^9, 
   3.457177571158*^9, 3.4571777102788*^9, 3.4571780392672*^9, 
   3.4571801855464*^9, 3.4572611166303997`*^9}],

Cell[BoxData[
 RowBox[{"{", "\[CapitalDelta]A", "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.4572611166928*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}]}], 
   RowBox[{"FSR", "-", 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], "+", 
    RowBox[{"FSR", " ", 
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568493870006943`*^9, 3.4568494015086946`*^9}, {
   3.456849459759094*^9, 3.4568494841106944`*^9}, 3.4568500100022945`*^9, 
   3.4568501149902945`*^9, {3.4568582019270945`*^9, 3.4568582250150948`*^9}, 
   3.4568582664018946`*^9, 3.456858505393894*^9, {3.4568585859210944`*^9, 
   3.4568586038922944`*^9}, 3.4568586479154944`*^9, 3.4568587205334945`*^9, 
   3.4568588391714945`*^9, 3.4568589350802946`*^9, {3.4568590177290945`*^9, 
   3.4568590284930944`*^9}, {3.456859109519494*^9, 3.4568591579730945`*^9}, 
   3.4568592933030944`*^9, 3.456859323364294*^9, {3.456859991465494*^9, 
   3.456860014381894*^9}, 3.456860179117894*^9, 3.4568603110158944`*^9, 
   3.4568603809350944`*^9, 3.456860475829894*^9, {3.4568605178562946`*^9, 
   3.4568605457490945`*^9}, {3.4568607114678946`*^9, 3.456860743167094*^9}, 
   3.4568608201998944`*^9, {3.456860906873494*^9, 3.4568609361078944`*^9}, {
   3.456860975560294*^9, 3.456861032671894*^9}, 3.4568610969438944`*^9, 
   3.4568616950790944`*^9, 3.4568617283226943`*^9, 3.4568618989242945`*^9, 
   3.4568635137894945`*^9, {3.4569341029425745`*^9, 3.4569341169155746`*^9}, 
   3.4571168605934*^9, 3.4571169065666*^9, 3.4571214928122*^9, 
   3.457177350106*^9, 3.4571775711892*^9, 3.4571777102944*^9, 
   3.4571780392984*^9, 3.4571801855620003`*^9, 3.457261116724*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{"Factor", "[", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    RowBox[{"\[Omega]", "/", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
          SubsuperscriptBox["r1", "r", "2"], " ", 
          SubsuperscriptBox["r2", "r", "2"]}], "+", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
          SubsuperscriptBox["r1", "r", "3"], " ", 
          SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}], 
      RowBox[{"2", " ", "FSR", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"3", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
          SubsuperscriptBox["r1", "r", "2"], " ", 
          SubsuperscriptBox["r2", "r", "2"]}], "-", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
          SubsuperscriptBox["r1", "r", "3"], " ", 
          SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}]]}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Factor", "[", 
  RowBox[{
   FractionBox["%", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]]}]]], "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Factor", "[", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    RowBox[{"\[Omega]", "/", 
     FractionBox[
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]}], 
      RowBox[{"FSR", "-", 
       RowBox[{"2", " ", "FSR", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{"FSR", " ", 
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}]]}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Factor", "[", 
  RowBox[{
   FractionBox["%", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]]}]]], "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Factor", "[", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    RowBox[{"\[Omega]", "/", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}], "+", 
         RowBox[{
          SubsuperscriptBox["r1", "r", "2"], " ", 
          SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", "FSR", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}], "-", 
         RowBox[{
          SubsuperscriptBox["r1", "r", "2"], " ", 
          SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Factor", "[", 
  RowBox[{
   FractionBox["%", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]]}]]], "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4572624843136*^9, 3.4572624851404*^9}, 
   3.4572631881076*^9, {3.4572632935480003`*^9, 3.4572633063087997`*^9}, {
   3.4572633635452003`*^9, 3.4572633749332*^9}, 3.457263452512*^9, {
   3.4572636178252*^9, 3.4572636571996*^9}, {3.4572637760716*^9, 
   3.4572637854004*^9}, 3.4572666842704*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "FSR", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"3", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}], "-", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubsuperscriptBox["r1", "r", "3"], " ", 
       SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}], 
   RowBox[{"1", "-", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubsuperscriptBox["r1", "r", "3"], " ", 
     SubsuperscriptBox["r2", "r", "3"]}]}]]}]], "Output",
 CellChangeTimes->{
  3.4572624855772*^9, 3.457263189262*^9, {3.4572633006772003`*^9, 
   3.457263306652*^9}, 3.4572633754012003`*^9, 3.4572634533232*^9, {
   3.4572636197752*^9, 3.4572636575428*^9}, 3.4572637858528*^9, 
   3.4572666850504*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]]}], 
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.4572624855772*^9, 3.457263189262*^9, {3.4572633006772003`*^9, 
   3.457263306652*^9}, 3.4572633754012003`*^9, 3.4572634533232*^9, {
   3.4572636197752*^9, 3.4572636575428*^9}, 3.4572637858528*^9, 
   3.4572666850504*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"FSR", "-", 
   RowBox[{"2", " ", "FSR", " ", 
    RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"]}], "+", 
   RowBox[{"FSR", " ", 
    SubsuperscriptBox["r1", "r", "2"], " ", 
    SubsuperscriptBox["r2", "r", "2"]}]}], 
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{
    RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"]}]}]]], "Output",
 CellChangeTimes->{
  3.4572624855772*^9, 3.457263189262*^9, {3.4572633006772003`*^9, 
   3.457263306652*^9}, 3.4572633754012003`*^9, 3.4572634533232*^9, {
   3.4572636197752*^9, 3.4572636575428*^9}, 3.4572637858528*^9, 
   3.4572666850816*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]]}], "F"]}]], "Output",
 CellChangeTimes->{
  3.4572624855772*^9, 3.457263189262*^9, {3.4572633006772003`*^9, 
   3.457263306652*^9}, 3.4572633754012003`*^9, 3.4572634533232*^9, {
   3.4572636197752*^9, 3.4572636575428*^9}, 3.4572637858528*^9, 
   3.4572666850816*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "FSR", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"-", "3"}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"]}], "+", 
   RowBox[{
    SubsuperscriptBox["r1", "r", "2"], " ", 
    SubsuperscriptBox["r2", "r", "2"]}]}]]], "Output",
 CellChangeTimes->{
  3.4572624855772*^9, 3.457263189262*^9, {3.4572633006772003`*^9, 
   3.457263306652*^9}, 3.4572633754012003`*^9, 3.4572634533232*^9, {
   3.4572636197752*^9, 3.4572636575428*^9}, 3.4572637858528*^9, 
   3.4572666850816*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]]}], 
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{"3", "+", 
      RowBox[{
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.4572624855772*^9, 3.457263189262*^9, {3.4572633006772003`*^9, 
   3.457263306652*^9}, 3.4572633754012003`*^9, 3.4572634533232*^9, {
   3.4572636197752*^9, 3.4572636575428*^9}, 3.4572637858528*^9, 
   3.4572666850816*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Approximate", " ", 
  SubscriptBox["E", "aux"], " ", "in", " ", "reflection"}]], "Subsubsection",
 CellChangeTimes->{{3.456849308049094*^9, 3.4568493216210947`*^9}, {
  3.4568493673134947`*^9, 3.4568493682026944`*^9}, {3.4571770198696003`*^9, 
  3.4571770294012003`*^9}, {3.4571780198764*^9, 3.4571780204224*^9}, {
  3.4571782485256*^9, 3.4571782502416*^9}, {3.4571784678148003`*^9, 
  3.4571784712156*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           SubscriptBox["refl", "aux"], ",", 
           RowBox[{"{", 
            RowBox[{"\[Omega]", ",", "0", ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
        ".", "Eaux"}], "]"}], "//", "Expand"}], ")"}], "/.", 
    RowBox[{
     RowBox[{"\[Delta]l", " ", 
      SubscriptBox["\[CurlyPhi]", "aux"]}], "\[Rule]", "0"}]}], "/.", 
   RowBox[{
    SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[CurlyPhi]", "aux"], "+", 
     FractionBox["\[CapitalDelta]A", "\[ImaginaryI]"]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%", "/.", 
     RowBox[{
      SubsuperscriptBox["t1", "r", "2"], "\[Rule]", 
      RowBox[{"1", "-", 
       SubsuperscriptBox["r1", "r", "2"]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pm", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"TrigToExp", "[", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"+", 
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "-", 
       RowBox[{
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "\[Conjugate]"}]}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"am", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"TrigToExp", "[", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"+", 
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "+", 
       RowBox[{
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "\[Conjugate]"}]}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<carrier\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cr", "=", 
   RowBox[{"res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<PM length\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pm", "/.", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r1", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t1", "r", "2"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t2", "r", "2"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r1", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t1", "r", "2"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t2", "r", "2"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<AM length\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"am", "/.", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r1", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t1", "r", "2"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t2", "r", "2"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r1", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t1", "r", "2"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t2", "r", "2"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<PM phase\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pm", "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r1", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t1", "r", "2"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t2", "r", "2"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r1", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t1", "r", "2"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t2", "r", "2"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<AM phase (zero at \[ImaginaryI]f/FSR has been removed)\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[Pi]", " ", "FSR", " ", "am"}], 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]], "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"%%", "-", "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r1", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t1", "r", "2"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t2", "r", "2"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r1", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t1", "r", "2"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t2", "r", "2"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<PM amplitude (zero at \[ImaginaryI]f/FSR has been removed)\>\"", 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", "\[Pi]", " ", "FSR", " ", "pm"}], 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]], "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"%%", "-", "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r1", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t1", "r", "2"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t2", "r", "2"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r1", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t1", "r", "2"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t2", "r", "2"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<AM amplitude\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"am", "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r1", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t1", "r", "2"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t2", "r", "2"]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r1", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t1", "r", "2"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], "\[Rule]", 
     SubsuperscriptBox["t2", "r", "2"]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.456844980302494*^9, 3.4568450429988947`*^9}, {
   3.4568450869596944`*^9, 3.4568451086124945`*^9}, {3.4568451986556945`*^9, 
   3.4568452155036945`*^9}, {3.4568452765308943`*^9, 
   3.4568453254368944`*^9}, {3.4568453586804943`*^9, 
   3.4568453592576942`*^9}, {3.456845437320094*^9, 3.4568455048056946`*^9}, {
   3.4568455735548944`*^9, 3.4568455804344945`*^9}, {3.4568456226636944`*^9, 
   3.4568456574828944`*^9}, {3.456845777041294*^9, 3.4568458071024942`*^9}, {
   3.4568459100000944`*^9, 3.456845918642494*^9}, {3.4568459907768946`*^9, 
   3.4568459918532944`*^9}, {3.4568460847668943`*^9, 
   3.4568460982608943`*^9}, {3.456846359061694*^9, 3.456846439245694*^9}, 
   3.4568484870210943`*^9, {3.4568488763814945`*^9, 3.456848879407894*^9}, {
   3.456848948235094*^9, 3.4568489525250945`*^9}, {3.4568489944110947`*^9, 
   3.4568490183570943`*^9}, {3.456849112019494*^9, 3.456849130864294*^9}, 
   3.4568492196126947`*^9, {3.4568492498922944`*^9, 3.4568492583318944`*^9}, 
   3.4568493013098946`*^9, {3.4568493786702943`*^9, 3.456849399870694*^9}, {
   3.4568494558746943`*^9, 3.4568494835646944`*^9}, {3.4568500089102945`*^9, 
   3.4568500092534943`*^9}, 3.4568501139606943`*^9, {3.4568581151286945`*^9, 
   3.456858170181094*^9}, {3.4568582115366945`*^9, 3.4568582152806945`*^9}, {
   3.4568582493978944`*^9, 3.456858265575094*^9}, {3.4568585005578947`*^9, 
   3.4568585049258947`*^9}, {3.4568585823954945`*^9, 3.456858603471094*^9}, 
   3.4568586470262947`*^9, {3.456858695011894*^9, 3.456858737428294*^9}, {
   3.4568587911702943`*^9, 3.4568588381886945`*^9}, {3.4568589304314947`*^9, 
   3.4568591575206947`*^9}, {3.4568592678438945`*^9, 3.456859321554694*^9}, {
   3.456859991028694*^9, 3.4568600139606943`*^9}, 3.4568601781974945`*^9, 
   3.4568603104074945`*^9, {3.456860374991494*^9, 3.4568603777838945`*^9}, {
   3.456860462959894*^9, 3.4568604741762943`*^9}, {3.456860504284294*^9, 
   3.456860544454294*^9}, {3.4568607078174944`*^9, 3.456860740249894*^9}, {
   3.456860799108694*^9, 3.456860816143894*^9}, {3.4568608753146944`*^9, 
   3.4568609339550943`*^9}, {3.456860965295494*^9, 3.4568610310338945`*^9}, {
   3.456861066009094*^9, 3.4568610937146945`*^9}, {3.4568616726930943`*^9, 
   3.4568617256238947`*^9}, {3.4568618904222946`*^9, 
   3.4568618944158945`*^9}, {3.4568635014342947`*^9, 3.4568635065354943`*^9}, 
   3.4569341148535748`*^9, {3.4569615085875745`*^9, 3.456961529851575*^9}, {
   3.457116837209*^9, 3.457116844697*^9}, {3.4571168963798*^9, 
   3.4571168984702*^9}, {3.4571773255360003`*^9, 3.4571773288900003`*^9}, 
   3.4571775568684*^9, {3.4571780246968*^9, 3.4571780255236*^9}, {
   3.4571784815584*^9, 3.4571784838048*^9}, {3.4571785516804*^9, 
   3.4571785965304003`*^9}, {3.4571801910376*^9, 3.4571801937363997`*^9}, {
   3.457264913218*^9, 3.4572650251168003`*^9}, {3.4572650685004*^9, 
   3.4572651084988003`*^9}, {3.4572651537855997`*^9, 3.457265156266*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"carrier\"\>"], "Print",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271532*^9, 3.45718020748*^9, 
   3.4572643613056*^9, 3.4572645662427998`*^9, 3.4572649201912003`*^9, {
   3.4572649513599997`*^9, 3.4572649761952*^9}, 3.4572650152576*^9, {
   3.4572650940376*^9, 3.4572651160024*^9}, 3.4572651641907997`*^9}],

Cell[BoxData["\<\"PM length\"\>"], "Print",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271532*^9, 3.45718020748*^9, 
   3.4572643613056*^9, 3.4572645662427998`*^9, 3.4572649201912003`*^9, {
   3.4572649513599997`*^9, 3.4572649761952*^9}, 3.4572650152576*^9, {
   3.4572650940376*^9, 3.4572651160024*^9}, 3.4572651641907997`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "k", " ", "\[Delta]l", " ", 
    SubscriptBox["r2", "r"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["r2", "r"], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubscriptBox["r2", "r"]}], "-", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}], " ", 
    SubsuperscriptBox["t1", "r", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], "-", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], "}"}]], "Output",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271688004`*^9, 3.45718020748*^9, 
   3.4572643613368*^9, 3.457264566274*^9, 3.4572649176796*^9, {
   3.457264950112*^9, 3.4572649762264*^9}, 3.4572650153199997`*^9, {
   3.4572650940844*^9, 3.4572651160336*^9}, 3.457265164222*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["r2", "r"], "-", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "4"], " ", 
         SubsuperscriptBox["r2", "r", "3"]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubsuperscriptBox["r2", "r", "2"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubsuperscriptBox["r1", "r", "3"], " ", 
         SubsuperscriptBox["r2", "r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubsuperscriptBox["r2", "r", "2"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubscriptBox["r2", "r"], " ", 
         SubsuperscriptBox["t2", "r", "2"]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", "FSR", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}], "-", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["r2", "r"], "+", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubscriptBox["r2", "r"]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}]}], ")"}]}]}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271688004`*^9, 3.45718020748*^9, 
   3.4572643613368*^9, 3.457264566274*^9, 3.4572649176796*^9, {
   3.457264950112*^9, 3.4572649762264*^9}, 3.4572650153199997`*^9, {
   3.4572650940844*^9, 3.4572651160336*^9}, 3.4572651642376003`*^9}],

Cell[BoxData["\<\"AM length\"\>"], "Print",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271532*^9, 3.45718020748*^9, 
   3.4572643613056*^9, 3.4572645662427998`*^9, 3.4572649201912003`*^9, {
   3.4572649513599997`*^9, 3.4572649761952*^9}, 3.4572650152576*^9, {
   3.4572650940376*^9, 3.4572651160024*^9}, 3.4572651642688*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"2", " ", "k", " ", "\[Delta]l", " ", 
    RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"], " ", 
    SubsuperscriptBox["t1", "r", "2"], " ", 
    SubsuperscriptBox["t2", "r", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], "-", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], "}"}]], "Output",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271688004`*^9, 3.45718020748*^9, 
   3.4572643613368*^9, 3.457264566274*^9, 3.4572649176796*^9, {
   3.457264950112*^9, 3.4572649762264*^9}, 3.4572650153199997`*^9, {
   3.4572650940844*^9, 3.4572651160336*^9}, 3.4572651642844*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["r2", "r", "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          SubsuperscriptBox["r2", "r", "2"]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}]}], 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
     SubsuperscriptBox["t2", "r", "2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271688004`*^9, 3.45718020748*^9, 
   3.4572643613368*^9, 3.457264566274*^9, 3.4572649176796*^9, {
   3.457264950112*^9, 3.4572649762264*^9}, 3.4572650153199997`*^9, {
   3.4572650940844*^9, 3.4572651160336*^9}, 3.4572651643*^9}],

Cell[BoxData["\<\"PM phase\"\>"], "Print",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271532*^9, 3.45718020748*^9, 
   3.4572643613056*^9, 3.4572645662427998`*^9, 3.4572649201912003`*^9, {
   3.4572649513599997`*^9, 3.4572649761952*^9}, 3.4572650152576*^9, {
   3.4572650940376*^9, 3.4572651160024*^9}, 3.4572651643311996`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[ImaginaryI]", " ", 
   SubscriptBox["\[CurlyPhi]", "aux"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271688004`*^9, 3.45718020748*^9, 
   3.4572643613368*^9, 3.457264566274*^9, 3.4572649176796*^9, {
   3.457264950112*^9, 3.4572649762264*^9}, 3.4572650153199997`*^9, {
   3.4572650940844*^9, 3.4572651160336*^9}, 3.4572651643468*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     SubscriptBox["r2", "r"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["r2", "r"], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}], " ", 
     SubsuperscriptBox["t1", "r", "2"]}], 
    RowBox[{"FSR", " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       SubsuperscriptBox["r2", "r", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271688004`*^9, 3.45718020748*^9, 
   3.4572643613368*^9, 3.457264566274*^9, 3.4572649176796*^9, {
   3.457264950112*^9, 3.4572649762264*^9}, 3.4572650153199997`*^9, {
   3.4572650940844*^9, 3.4572651160336*^9}, 3.4572651643624*^9}],

Cell[BoxData["\<\"AM phase (zero at \[ImaginaryI]f/FSR has been \
removed)\"\>"], "Print",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271532*^9, 3.45718020748*^9, 
   3.4572643613056*^9, 3.4572645662427998`*^9, 3.4572649201912003`*^9, {
   3.4572649513599997`*^9, 3.4572649761952*^9}, 3.4572650152576*^9, {
   3.4572650940376*^9, 3.4572651160024*^9}, 3.4572651643780003`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "\[Pi]", " ", 
     RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"], " ", 
     SubsuperscriptBox["t1", "r", "2"], " ", 
     SubsuperscriptBox["t2", "r", "2"], " ", 
     SubscriptBox["\[CurlyPhi]", "aux"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       SubsuperscriptBox["r2", "r", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271688004`*^9, 3.45718020748*^9, 
   3.4572643613368*^9, 3.457264566274*^9, 3.4572649176796*^9, {
   3.457264950112*^9, 3.4572649762264*^9}, 3.4572650153199997`*^9, {
   3.4572650940844*^9, 3.4572651160336*^9}, 3.4572651644091997`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["r2", "r", "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          SubsuperscriptBox["r2", "r", "2"]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}]}], 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
     SubsuperscriptBox["t2", "r", "2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271688004`*^9, 3.45718020748*^9, 
   3.4572643613368*^9, 3.457264566274*^9, 3.4572649176796*^9, {
   3.457264950112*^9, 3.4572649762264*^9}, 3.4572650153199997`*^9, {
   3.4572650940844*^9, 3.4572651160336*^9}, 3.4572651644248*^9}],

Cell[BoxData["\<\"PM amplitude (zero at \[ImaginaryI]f/FSR has been \
removed)\"\>"], "Print",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271532*^9, 3.45718020748*^9, 
   3.4572643613056*^9, 3.4572645662427998`*^9, 3.4572649201912003`*^9, {
   3.4572649513599997`*^9, 3.4572649761952*^9}, 3.4572650152576*^9, {
   3.4572650940376*^9, 3.4572651160024*^9}, 3.4572651644404*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{
   "2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", "\[CapitalDelta]A", " ", 
    RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"], " ", 
    SubsuperscriptBox["t1", "r", "2"], " ", 
    SubsuperscriptBox["t2", "r", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], "-", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      SubsuperscriptBox["r2", "r", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], "}"}]], "Output",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271688004`*^9, 3.45718020748*^9, 
   3.4572643613368*^9, 3.457264566274*^9, 3.4572649176796*^9, {
   3.457264950112*^9, 3.4572649762264*^9}, 3.4572650153199997`*^9, {
   3.4572650940844*^9, 3.4572651160336*^9}, 3.4572651644560003`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["r2", "r", "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          SubsuperscriptBox["r2", "r", "2"]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}]}], 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
     SubsuperscriptBox["t2", "r", "2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271688004`*^9, 3.45718020748*^9, 
   3.4572643613368*^9, 3.457264566274*^9, 3.4572649176796*^9, {
   3.457264950112*^9, 3.4572649762264*^9}, 3.4572650153199997`*^9, {
   3.4572650940844*^9, 3.4572651160336*^9}, 3.4572651644872*^9}],

Cell[BoxData["\<\"AM amplitude\"\>"], "Print",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271532*^9, 3.45718020748*^9, 
   3.4572643613056*^9, 3.4572645662427998`*^9, 3.4572649201912003`*^9, {
   3.4572649513599997`*^9, 3.4572649761952*^9}, 3.4572650152576*^9, {
   3.4572650940376*^9, 3.4572651160024*^9}, 3.4572651645028*^9}],

Cell[BoxData[
 RowBox[{"{", "\[CapitalDelta]A", "}"}]], "Output",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271688004`*^9, 3.45718020748*^9, 
   3.4572643613368*^9, 3.457264566274*^9, 3.4572649176796*^9, {
   3.457264950112*^9, 3.4572649762264*^9}, 3.4572650153199997`*^9, {
   3.4572650940844*^9, 3.4572651160336*^9}, 3.4572651645184*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     SubscriptBox["r2", "r"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["r2", "r"], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}], " ", 
     SubsuperscriptBox["t1", "r", "2"]}], 
    RowBox[{"FSR", " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       SubsuperscriptBox["r2", "r", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4571785101844*^9, 3.4571786271688004`*^9, 3.45718020748*^9, 
   3.4572643613368*^9, 3.457264566274*^9, 3.4572649176796*^9, {
   3.457264950112*^9, 3.4572649762264*^9}, 3.4572650153199997`*^9, {
   3.4572650940844*^9, 3.4572651160336*^9}, 3.457265164534*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Factor", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "k", " ", "\[Delta]l", " ", 
     SubscriptBox["r2", "r"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["r2", "r"], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}], " ", 
     SubsuperscriptBox["t1", "r", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       SubsuperscriptBox["r2", "r", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  FractionBox["%", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "k", " ", "\[Delta]l", " ", 
     SubscriptBox["r1", "r"], 
     SubscriptBox["r2", "r"]}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]}]]], "]"}]}], "Input",
 CellChangeTimes->{{3.4572689188924*^9, 3.4572689275816*^9}, {
  3.4572708883988*^9, 3.4572709346684*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "k", " ", "\[Delta]l", " ", 
    SubscriptBox["r2", "r"], " ", 
    SubsuperscriptBox["t1", "r", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["r1", "r"]}], "+", 
      SubscriptBox["r2", "r"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.4572709353548*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"1", "-", 
      SubsuperscriptBox["r1", "r", "2"]}], 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], "-", 
      RowBox[{
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}]], "/.", 
    RowBox[{
     SubscriptBox["r1", "r"], "\[Rule]", "r1"}]}], "/.", 
   RowBox[{
    SubscriptBox["r2", "r"], "\[Rule]", "r2"}]}], "//.", 
  "redOPO"}], "\[IndentingNewLine]", 
 RowBox[{"1", "/", "%"}]}], "Input",
 CellChangeTimes->{{3.457275015611*^9, 3.4572750590414*^9}}],

Cell[BoxData["0.13761422013602045`"], "Output",
 CellChangeTimes->{{3.457275036125*^9, 3.4572750593378*^9}}],

Cell[BoxData["7.266690891476051`"], "Output",
 CellChangeTimes->{{3.457275036125*^9, 3.4572750593378*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  FractionBox[
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "k", " ", "\[Delta]l", " ", 
     SubscriptBox["r2", "r"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["r2", "r"], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}], " ", 
     SubsuperscriptBox["t1", "r", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       SubsuperscriptBox["r2", "r", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "\[ImaginaryI]", " ", "k", " ", "\[Delta]l", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}]]}]], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sup1", "[", "\[Phi]_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", "%"}], "/.", 
       RowBox[{
        SubscriptBox["t1", "r"], "\[Rule]", "t1"}]}], "/.", 
      RowBox[{
       SubscriptBox["r1", "r"], "\[Rule]", "r1"}]}], "/.", 
     RowBox[{
      SubscriptBox["r2", "r"], "\[Rule]", "r2"}]}], "//.", "redOPO"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sup1", "[", 
   FractionBox[
    RowBox[{"2", "\[Pi]", " ", "29.507*^6"}], "FSR"], "]"}], "//.", 
  "redOPO"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  FractionBox[
   FractionBox[
    RowBox[{"2", " ", "k", " ", "\[Delta]l", " ", 
     RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"], " ", 
     SubsuperscriptBox["t1", "r", "2"], " ", 
     SubsuperscriptBox["t2", "r", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       SubsuperscriptBox["r2", "r", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "k", " ", "\[Delta]l", " ", 
      RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}]]}]], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sup2", "[", "\[Phi]_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "%"}], "/.", 
        RowBox[{
         SubscriptBox["t1", "r"], "\[Rule]", "t1"}]}], "/.", 
       RowBox[{
        SubscriptBox["t2", "r"], "\[Rule]", "t2"}]}], "/.", 
      RowBox[{
       SubscriptBox["r1", "r"], "\[Rule]", "r1"}]}], "/.", 
     RowBox[{
      SubscriptBox["r2", "r"], "\[Rule]", "r2"}]}], "//.", "redOPO"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sup2", "[", 
   FractionBox[
    RowBox[{"2", "\[Pi]", " ", "29.507*^6"}], "FSR"], "]"}], "//.", 
  "redOPO"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sup1", "[", 
        FractionBox[
         RowBox[{"2", "\[Pi]", " ", "f", " ", "1*^6"}], "FSR"], "]"}], ",", 
       RowBox[{"sup2", "[", 
        FractionBox[
         RowBox[{"2", "\[Pi]", " ", "f", " ", "1*^6"}], "FSR"], "]"}]}], 
      "}"}], "//.", "redOPO"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "0", ",", "100"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "100"}], ",", "100"}], "}"}]}], ",", 
   RowBox[{"Evaluate", "[", "popt", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4572751728901997`*^9, 3.4572751797542*^9}, {
   3.4572752274278*^9, 3.4572753391082*^9}, {3.4572756249088*^9, 
   3.4572756992584*^9}, {3.457275762376*^9, 3.4572760340968*^9}, {
   3.4572761165896*^9, 3.4572761342332*^9}, 3.4572761898472*^9, {
   3.4572762214372*^9, 3.4572762311872*^9}, {3.457276310716*^9, 
   3.4572763110592003`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SubscriptBox["r2", "r"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["r2", "r"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}], " ", 
    SubsuperscriptBox["t1", "r", "2"]}], 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubsuperscriptBox["r1", "r", "3"], " ", 
     SubscriptBox["r2", "r"]}], "-", 
    SubsuperscriptBox["r2", "r", "2"], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubsuperscriptBox["r2", "r", "2"]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["r1", "r", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Phi]", "]"}], "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{
  3.4572751805186*^9, {3.4572752685494003`*^9, 3.4572753395294*^9}, {
   3.4572756490576*^9, 3.4572756995704*^9}, {3.457275767368*^9, 
   3.4572758480512*^9}, {3.4572758984236*^9, 3.4572759533668003`*^9}, {
   3.4572759865480003`*^9, 3.4572760026628*^9}, 3.4572760347676*^9, {
   3.4572761173696003`*^9, 3.4572761464168*^9}, 3.4572761931856003`*^9, 
   3.457276232014*^9, 3.4572763116675997`*^9}],

Cell[BoxData[
 RowBox[{"-", "15.942330940558653`"}]], "Output",
 CellChangeTimes->{
  3.4572751805186*^9, {3.4572752685494003`*^9, 3.4572753395294*^9}, {
   3.4572756490576*^9, 3.4572756995704*^9}, {3.457275767368*^9, 
   3.4572758480512*^9}, {3.4572758984236*^9, 3.4572759533668003`*^9}, {
   3.4572759865480003`*^9, 3.4572760026628*^9}, 3.4572760347676*^9, {
   3.4572761173696003`*^9, 3.4572761464168*^9}, 3.4572761931856003`*^9, 
   3.457276232014*^9, 3.4572763116675997`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["t1", "r", "2"], " ", 
    SubsuperscriptBox["t2", "r", "2"]}], 
   RowBox[{
    SubsuperscriptBox["r1", "r", "2"], "-", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], "+", 
    SubsuperscriptBox["r2", "r", "2"]}]]}]], "Output",
 CellChangeTimes->{
  3.4572751805186*^9, {3.4572752685494003`*^9, 3.4572753395294*^9}, {
   3.4572756490576*^9, 3.4572756995704*^9}, {3.457275767368*^9, 
   3.4572758480512*^9}, {3.4572758984236*^9, 3.4572759533668003`*^9}, {
   3.4572759865480003`*^9, 3.4572760026628*^9}, 3.4572760347676*^9, {
   3.4572761173696003`*^9, 3.4572761464168*^9}, 3.4572761931856003`*^9, 
   3.457276232014*^9, 3.4572763116675997`*^9}],

Cell[BoxData[
 RowBox[{"-", "21.84670486893421`"}]], "Output",
 CellChangeTimes->{
  3.4572751805186*^9, {3.4572752685494003`*^9, 3.4572753395294*^9}, {
   3.4572756490576*^9, 3.4572756995704*^9}, {3.457275767368*^9, 
   3.4572758480512*^9}, {3.4572758984236*^9, 3.4572759533668003`*^9}, {
   3.4572759865480003`*^9, 3.4572760026628*^9}, 3.4572760347676*^9, {
   3.4572761173696003`*^9, 3.4572761464168*^9}, 3.4572761931856003`*^9, 
   3.457276232014*^9, 3.4572763116675997`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwdkwkwlQ0Xxy+usr5lTZL73MV1eW/2tS7PP1tcUeFVIkSWRKWiEqIsbWRN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     "]], LineBox[CompressedData["
1:eJwd12k8lO/bBnBkaZGkUkJJypLZzNhmLKeZMfYl61DK0mKrrFmKSBEpQigi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     "]], 
    LineBox[{{13.788988628467301`, 100.}, {13.789341984433918`, -100.}}]}, 
   {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwd1Hs41PkXB/Bhh6jvmMEYw0qDSZE1BilSn4+MSzIot1B+1RKFhGGRW0jJ
pXXXZl22JKMopBAd0U2bClFJulKrXJLYmOY3v995nvOc5/XPed5/vbX2hm73
lyaRSDGS/d/VPik6U6rZscn2a4jgUDgBV+X0VoQElqGDWDgYK3FHdO3Z1YF1
KG6mmvSHxHlm73ZSsq+iHlHw5AOJbxuFBcgG3kC6eOYMI4KAOBXxNXF5J1Io
tNQUSFyYa7NpMesOYnfb+45KXEfN7JyPvY+OlKv6hQgIuJvZaz8b8BBN9Jzn
yEcSMJVKjEULH6N7pEVolji+s05vrrwPNT2hMROjCFgq7RocWfQETb8ZNfX6
TfIff6udyRpEi5fjVe2jCdBJPDUdlvoMVUD/ja0xBFxqszSdih1CVsnjv/jF
EnDPIqX5U8AIaq919+mLI6DGUjlhbd0r5Hu3Sl0/gYDpIb8ygfA1KpxoKitI
JCBBXe7Nl/K3aMJafkGYTEBXs9dPxiXvkGKXw2O3VEkerxp2WNF71PzNJkQ5
jYCiIqeAyawxdL3C/1tPOgEvzcqPG6Z/QNlKx9/ezyCAPTBdHZL6EQ3o7i4c
zpLkoxd8Go8dR+aNBnyUS0B3zlDYh4BJNM1UES+cJuB4ceG9PO4USr92U62s
lACDQORtUjeFGjt//u5RQUD4kpzD4cJp1KPdvUymioAfNqbtU+UzaNvIeLh3
AwEVKsNOv2t+RY/n7racaSKA9/7oCKfkK9IJ5t2VaiEgI3WQFFo0i8IoVNNF
IIDZGWv9OWsOteq2Of3zkIDWXJ3+zGXzSHO/Z+ezPgJ89/7tZ5A+j/pWJ4mG
Bwk4K6WZFpT6LzrtKrjJfkUAF3fc/Ri7gGzjqrJrpglwaFviNBogRjN9dMNS
JgW44r2zjCkxWojfVLZVkwKZrP/06FiScANtPkaRTQHB3pZIty4SHtAigkc5
FOCNHuq60i+FZZ84br5iT4E3n4f3RM/+hMOunW0YTaDAQHbGld/NydjHbapV
PY0C3Rxz+ep4MpbKSP8lIIsC9WH5l57JyOAUaq7jlhIKHJl1EFswZLGhRmSM
cSsFWKKrJSIzOXxm5fITxSIK0Ev9p1QOy+GEZ1NsV1kFkEPKPMMbctgVwWpd
qgJMJh0c97WTxwuZG4JUtBSgnbzSAjyXYtlE6SGmrQLsInIHk6MJnLMzZ3dD
vgI8oJjJk3fR8Aad+AEzHhV6tyoV98TRMHeJ4/haZyo8TZ/QPVVCw1vKiu0c
vKnwTqaKZ/iChqvX5Q7UH6LCokg1aYePIr7n4slPKaWC/sS/3y54KeGhF6nF
Wj+ocLyn7Z27Bx3fCJpoqd5Hg2zijwhWFB3ft+hqig+hQb5DlPR4AR3PX/rH
faeABmW3DVlJT+jYCKsnmCfToKm9zEfopoL1PYsiI0pp8L72SO+P7Qx8dWeO
6P1TGmw+aQNVzkx8PT7L7Za7IiQ5NFb3HmTiC2PWFV27FKFdRidPlMXELJ5Y
t8dfESziSPtc/2bi1MKIYXGkIpjsb10mtlfDPU+fzg4XKgLbmuvpsVkdpwmu
PEp9rgiycxoT5LUamPc+XyF+vxLw6jMGOW4aWNChF9EZrgTJId/BO0IDxzhw
aPQ4JfjxdjDv0mUNbBIePdOXrQRzj3LNdxoux5wVUb49jUrwQSh3tGGVJub4
VXZclFYGf853CpfCwg1LPxQxzimD49CxSqYmCyf2VYWmX1YG02MqG0kcFnZ9
uocv16YM5BGj4IcuLCw4LemDfmX4KzugOySfhdUOXFwQSdNh5HN/mvBnLfy1
kP14dC8dvC7UiXX0tfEnGbv862tUgK/nP82wY2M9XkNT1GsGfM+IbB32YGPq
VsPkmQkGnJ84evTsPjYO5UJX7CIDyI3n1IzT2HjV2NK686qq0LLpgxX/FhvT
bx1QTXZSBV23oNwU65VY5dZVozXtqkBKDDOZkrRt4Z5IZ49KJtT3x0feW78a
a7trxirkqcMGJf06cqIBXnoqidrisgICFnL/rNxhhF3XjT4o9dGG0NtjJnV8
Y+x9Qr+qZO1KOOEtu1IUbIpfTsuDuHo1/Hrn8D5uoBm+2HzterWFAXQsUdsW
5LUe/9U9ph0kYwRcxaTCjwILbJXzxSudZwy7ZzYaOAVbYmvGRs/BY6ZQUXpL
Yy5rE3Yne46s118HDdkWQ73bMS6gCN31Js1B0LLR5U9HK0yWb61m1lrCje7K
L+k+m3HfrmTm/BME++3M2/bvsMaDfT71jjFWUHKeeyXoAA8/DG04tQxbQ85M
25FDv9lgarOH9wsVGxgVRkYFhtti6WPn+7+8soUu29zi5GQ77BC4Lov/0R6k
nJ+/OZlkjzXXGLvw3zkAyapJqjxmC46uVKtZ/tERjqvO8XuPOeBewk9vkOMM
h7x/vTmXshWP+TVqa9e7wOsjpn6owBFnkrb5mkxuA3reqefpFXz8IOqBUxfX
Fc7R9GPunHbCB70DxMJAN+gIX2GzqsYZv1Dn9zd3uUMpq1xjo5sLThK9TOlV
9oS2uO+kwEcu+PE5snaf/w6oqTVkCJZsw6T/jxf8FxBKhqA=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  GridLines->Automatic,
  PlotRange->{{0, 100}, {-100, 100}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{
  3.4572751805186*^9, {3.4572752685494003`*^9, 3.4572753395294*^9}, {
   3.4572756490576*^9, 3.4572756995704*^9}, {3.457275767368*^9, 
   3.4572758480512*^9}, {3.4572758984236*^9, 3.4572759533668003`*^9}, {
   3.4572759865480003`*^9, 3.4572760026628*^9}, 3.4572760347676*^9, {
   3.4572761173696003`*^9, 3.4572761464168*^9}, 3.4572761931856003`*^9, 
   3.457276232014*^9, 3.4572763116832*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{"Factor", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], 
      RowBox[{" ", "FSR"}]], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["r2", "r"], "-", 
           RowBox[{
            SubsuperscriptBox["r1", "r", "4"], " ", 
            SubsuperscriptBox["r2", "r", "3"]}], "-", 
           RowBox[{
            RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
            SubscriptBox["r1", "r"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SubsuperscriptBox["r2", "r", "2"]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
            SubsuperscriptBox["r1", "r", "3"], " ", 
            SubsuperscriptBox["r2", "r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SubsuperscriptBox["r2", "r", "2"]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
            SubsuperscriptBox["r1", "r", "2"], " ", 
            SubscriptBox["r2", "r"], " ", 
            SubsuperscriptBox["t2", "r", "2"]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", "FSR", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
            SubscriptBox["r1", "r"], " ", 
            SubscriptBox["r2", "r"]}], "-", 
           RowBox[{
            SubsuperscriptBox["r1", "r", "2"], " ", 
            SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["r2", "r"], "+", 
           RowBox[{
            SubsuperscriptBox["r1", "r", "2"], " ", 
            SubscriptBox["r2", "r"]}], "-", 
           RowBox[{
            RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
            SubscriptBox["r1", "r"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}]}], 
        ")"}]}], ")"}]}], "/.", 
    RowBox[{
     SubscriptBox["t2", "r"], "\[Rule]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SubsuperscriptBox["r2", "r", "2"]}]]}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Factor", "[", 
  RowBox[{
   FractionBox["%", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]]}]]], "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Factor", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], "FSR"], "/", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
      SubscriptBox["r2", "r"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["r2", "r"], "+", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubscriptBox["r2", "r"]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}], " ", 
      SubsuperscriptBox["t1", "r", "2"]}], 
     RowBox[{"FSR", " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}], "+", 
        SubsuperscriptBox["r2", "r", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}], "+", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Factor", "[", 
  RowBox[{
   FractionBox["%", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]]}]]], "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Factor", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}], 
     RowBox[{" ", "FSR"}]], "/", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"3", " ", 
         SubsuperscriptBox["r2", "r", "2"]}], "+", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           SubsuperscriptBox["r2", "r", "2"]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}]}], 
     RowBox[{"2", " ", "FSR", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}], "+", 
        RowBox[{
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
      SubsuperscriptBox["t2", "r", "2"]}]]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Factor", "[", 
  RowBox[{
   FractionBox["%", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]]}]]], "/.", 
   RowBox[{"\[Phi]", "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4572624843136*^9, 3.4572624851404*^9}, 
   3.4572631881076*^9, {3.4572632935480003`*^9, 3.4572633063087997`*^9}, {
   3.4572633635452003`*^9, 3.4572633749332*^9}, 3.457263452512*^9, {
   3.4572636178252*^9, 3.4572636571996*^9}, {3.4572637760716*^9, 
   3.4572637854004*^9}, {3.4572664237192*^9, 3.4572664299592*^9}, {
   3.4572664717827997`*^9, 3.4572665024992*^9}, {3.4572665478796*^9, 
   3.4572665608431997`*^9}, {3.4572665977995996`*^9, 3.4572666634132*^9}, {
   3.457266733738*^9, 3.457266750664*^9}, {3.4572668734048*^9, 
   3.457266926476*^9}, {3.4572670228216*^9, 3.457267040434*^9}, 
   3.457267370686*^9, {3.4572678478588*^9, 3.4572678518212*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["r2", "r"]}], "-", 
       RowBox[{
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["r2", "r"], "-", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "4"], " ", 
      SubsuperscriptBox["r2", "r", "3"]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "\[Phi]"}], "]"}]}], ")"}], " ", 
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubscriptBox["r2", "r"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubsuperscriptBox["r2", "r", "2"]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SubsuperscriptBox["r2", "r", "2"]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubsuperscriptBox["r1", "r", "3"], " ", 
      SubsuperscriptBox["r2", "r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.457266564244*^9, 3.4572666644584*^9}, 
   3.4572667512567997`*^9, {3.457266889972*^9, 3.4572669271156*^9}, {
   3.4572670240383997`*^9, 3.45726704098*^9}, 3.4572673711540003`*^9, 
   3.4572678522736*^9, 3.4572680748856*^9, 3.457269677848*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["r1", "r"], "-", 
      SubscriptBox["r2", "r"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]}], ")"}], "2"]}], 
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["r1", "r"], "-", 
      SubscriptBox["r2", "r"], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       SubscriptBox["r1", "r"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "3"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "3"]}], "+", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "4"], " ", 
       SubsuperscriptBox["r2", "r", "3"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "3"], " ", 
       SubsuperscriptBox["r2", "r", "4"]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.457266564244*^9, 3.4572666644584*^9}, 
   3.4572667512567997`*^9, {3.457266889972*^9, 3.4572669271156*^9}, {
   3.4572670240383997`*^9, 3.45726704098*^9}, 3.4572673711540003`*^9, 
   3.4572678522736*^9, 3.4572680748856*^9, 3.457269677848*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["r1", "r", "2"], "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     SubsuperscriptBox["r2", "r", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
  RowBox[{
   SubscriptBox["r2", "r"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["r2", "r"], "+", 
     RowBox[{
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubscriptBox["r2", "r"]}], "-", 
     RowBox[{
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}], ")"}], " ", 
   SubsuperscriptBox["t1", "r", "2"]}]]], "Output",
 CellChangeTimes->{{3.457266564244*^9, 3.4572666644584*^9}, 
   3.4572667512567997`*^9, {3.457266889972*^9, 3.4572669271156*^9}, {
   3.4572670240383997`*^9, 3.45726704098*^9}, 3.4572673711540003`*^9, 
   3.4572678522736*^9, 3.4572680748856*^9, 3.457269677848*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Pi]", " ", 
   SqrtBox[
    RowBox[{
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["r1", "r"]}], "+", 
     SubscriptBox["r2", "r"]}], ")"}]}], 
  RowBox[{"F", " ", 
   SubscriptBox["r2", "r"], " ", 
   SubsuperscriptBox["t1", "r", "2"]}]]], "Output",
 CellChangeTimes->{{3.457266564244*^9, 3.4572666644584*^9}, 
   3.4572667512567997`*^9, {3.457266889972*^9, 3.4572669271156*^9}, {
   3.4572670240383997`*^9, 3.45726704098*^9}, 3.4572673711540003`*^9, 
   3.4572678522736*^9, 3.4572680748856*^9, 3.457269677848*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "-", 
      RowBox[{
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
    SubsuperscriptBox["t2", "r", "2"]}], 
   RowBox[{"1", "-", 
    RowBox[{"3", " ", 
     SubsuperscriptBox["r2", "r", "2"]}], "+", 
    RowBox[{
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "3"}], "+", 
       SubsuperscriptBox["r2", "r", "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubsuperscriptBox["r2", "r", "2"]}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{{3.457266564244*^9, 3.4572666644584*^9}, 
   3.4572667512567997`*^9, {3.457266889972*^9, 3.4572669271156*^9}, {
   3.4572670240383997`*^9, 3.45726704098*^9}, 3.4572673711540003`*^9, 
   3.4572678522736*^9, 3.4572680748856*^9, 3.457269677848*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}]], " ", 
    SubsuperscriptBox["t2", "r", "2"]}], 
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["r2", "r", "2"]}], "+", 
      RowBox[{
       SubscriptBox["r1", "r"], " ", 
       SubsuperscriptBox["r2", "r", "3"]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.457266564244*^9, 3.4572666644584*^9}, 
   3.4572667512567997`*^9, {3.457266889972*^9, 3.4572669271156*^9}, {
   3.4572670240383997`*^9, 3.45726704098*^9}, 3.4572673711540003`*^9, 
   3.4572678522736*^9, 3.4572680748856*^9, 3.4572696778636*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Approximate", " ", 
  RowBox[{"cav", ".", 
   SubscriptBox["E", "green"]}]}]], "Subsubsection",
 CellChangeTimes->{{3.456849308049094*^9, 3.4568493216210947`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           SubscriptBox["cav", "green"], ",", 
           RowBox[{"{", 
            RowBox[{"\[Omega]", ",", "0", ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
        ".", "Egreen"}], "]"}], "//", "Expand"}], ")"}], "/.", 
    RowBox[{
     RowBox[{"\[Delta]l", " ", 
      SubscriptBox["\[CurlyPhi]", "green"]}], "\[Rule]", "0"}]}], "/.", 
   RowBox[{
    SubscriptBox["\[CurlyPhi]", "green"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[CurlyPhi]", "green"], "+", 
     FractionBox["\[CapitalDelta]A", "\[ImaginaryI]"]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"Simplify", "[", "%", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pm", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"TrigToExp", "[", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"+", 
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "-", 
       RowBox[{
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "\[Conjugate]"}]}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"am", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"TrigToExp", "[", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"+", 
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "+", 
       RowBox[{
        FractionBox[
         RowBox[{
         "res", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         RowBox[{
         "res", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "\[Conjugate]"}]}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<carrier\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"cr", "=", 
  RowBox[{
  "res", "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<PM length\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pm", "/.", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "green"], "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<AM length\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"am", "/.", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "green"], "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"%", "\[Equal]", "0"}], ",", "1", ",", "%"}], "]"}]], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<PM phase\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"pm", "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<AM phase (zero at \[ImaginaryI]f/FSR has been removed)\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[Pi]", " ", "FSR", " ", "am"}], 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]], "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[CapitalDelta]A", "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"%%", "-", "%"}], 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"%", "\[Equal]", "0"}], ",", "1", ",", "%"}], "]"}]], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<PM amplitude (zero at \[ImaginaryI]f/FSR has been removed)\>\"", 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", "\[Pi]", " ", "FSR", " ", "pm"}], 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]], "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "green"], "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"%%", "-", "%"}], 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"%", "\[Equal]", "0"}], ",", "1", ",", "%"}], "]"}]], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<AM amplitude\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"am", "/.", 
      RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "green"], "\[Rule]", "0"}]}], ")"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%", "/.", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "\[Rule]", "0"}]}], ")"}], "-", 
      "%"}], "%"], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"ExpToTrig", "[", "%%", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.456844980302494*^9, 3.4568450429988947`*^9}, {
   3.4568450869596944`*^9, 3.4568451086124945`*^9}, {3.4568451986556945`*^9, 
   3.4568452155036945`*^9}, {3.4568452765308943`*^9, 
   3.4568453254368944`*^9}, {3.4568453586804943`*^9, 
   3.4568453592576942`*^9}, {3.456845437320094*^9, 3.4568455048056946`*^9}, {
   3.4568455735548944`*^9, 3.4568455804344945`*^9}, {3.4568456226636944`*^9, 
   3.4568456574828944`*^9}, {3.456845777041294*^9, 3.4568458071024942`*^9}, {
   3.4568459100000944`*^9, 3.456845918642494*^9}, {3.4568459907768946`*^9, 
   3.4568459918532944`*^9}, {3.4568460847668943`*^9, 
   3.4568460982608943`*^9}, {3.456846359061694*^9, 3.456846439245694*^9}, 
   3.4568484870210943`*^9, {3.4568488763814945`*^9, 3.456848879407894*^9}, {
   3.456848948235094*^9, 3.4568489525250945`*^9}, {3.4568489944110947`*^9, 
   3.4568490183570943`*^9}, {3.456849112019494*^9, 3.456849130864294*^9}, 
   3.4568492196126947`*^9, {3.4568492498922944`*^9, 3.4568492583318944`*^9}, 
   3.4568493013098946`*^9, {3.4571165918677998`*^9, 3.4571166373106003`*^9}, {
   3.4571788246804*^9, 3.4571789329444*^9}, {3.4571790845452003`*^9, 
   3.4571791283188*^9}, {3.4571791794556*^9, 3.45717919465*^9}, {
   3.4571792321991997`*^9, 3.4571792327608*^9}, {3.4571802169024*^9, 
   3.4571802193828*^9}, 3.4571804697004004`*^9, 3.457180501696*^9}],

Cell[BoxData["\<\"carrier\"\>"], "Print",
 CellChangeTimes->{{3.4571788829776*^9, 3.4571788961284*^9}, 
   3.4571789347072*^9, 3.4571790876963997`*^9, 3.4571791336851997`*^9, {
   3.4571791832776003`*^9, 3.457179196054*^9}, 3.457179234352*^9, 
   3.457180222612*^9, 3.4571804712604*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "green"]}]], " ", 
    SubscriptBox["t1", "g"]}], 
   RowBox[{"1", "-", 
    RowBox[{
     SubscriptBox["r1", "g"], " ", 
     SubscriptBox["r2", "g"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.457180471276*^9}],

Cell[BoxData["\<\"PM length\"\>"], "Print",
 CellChangeTimes->{{3.4571788829776*^9, 3.4571788961284*^9}, 
   3.4571789347072*^9, 3.4571790876963997`*^9, 3.4571791336851997`*^9, {
   3.4571791832776003`*^9, 3.457179196054*^9}, 3.457179234352*^9, 
   3.457180222612*^9, 3.4571804712916*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"4", " ", "\[ImaginaryI]", " ", "k", " ", "\[Delta]l", " ", 
    SubscriptBox["r1", "g"], " ", 
    SubscriptBox["r2", "g"]}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{
     SubscriptBox["r1", "g"], " ", 
     SubscriptBox["r2", "g"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.4571804713072*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{"\[Omega]", "+", 
       RowBox[{"\[Omega]", " ", 
        SubscriptBox["r1", "g"], " ", 
        SubscriptBox["r2", "g"]}]}], ")"}]}], 
    RowBox[{"2", " ", "FSR", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SubscriptBox["r1", "g"], " ", 
        SubscriptBox["r2", "g"]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.4571804713227997`*^9}],

Cell[BoxData["\<\"AM length\"\>"], "Print",
 CellChangeTimes->{{3.4571788829776*^9, 3.4571788961284*^9}, 
   3.4571789347072*^9, 3.4571790876963997`*^9, 3.4571791336851997`*^9, {
   3.4571791832776003`*^9, 3.457179196054*^9}, 3.457179234352*^9, 
   3.457180222612*^9, 3.4571804713384*^9}],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.457180471354*^9}],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.4571804713696003`*^9}],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.4571804713852*^9}],

Cell[BoxData["\<\"PM phase\"\>"], "Print",
 CellChangeTimes->{{3.4571788829776*^9, 3.4571788961284*^9}, 
   3.4571789347072*^9, 3.4571790876963997`*^9, 3.4571791336851997`*^9, {
   3.4571791832776003`*^9, 3.457179196054*^9}, 3.457179234352*^9, 
   3.457180222612*^9, 3.4571804714007998`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[ImaginaryI]", " ", 
   SubscriptBox["\[CurlyPhi]", "green"]}], "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.4571804714164*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
    SubscriptBox["r1", "g"], " ", 
    SubscriptBox["r2", "g"]}], 
   RowBox[{"FSR", "-", 
    RowBox[{"FSR", " ", 
     SubscriptBox["r1", "g"], " ", 
     SubscriptBox["r2", "g"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.457180471432*^9}],

Cell[BoxData["\<\"AM phase (zero at \[ImaginaryI]f/FSR has been \
removed)\"\>"], "Print",
 CellChangeTimes->{{3.4571788829776*^9, 3.4571788961284*^9}, 
   3.4571789347072*^9, 3.4571790876963997`*^9, 3.4571791336851997`*^9, {
   3.4571791832776003`*^9, 3.457179196054*^9}, 3.457179234352*^9, 
   3.457180222612*^9, 3.457180471432*^9}],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.4571804714476*^9}],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.4571804714632*^9}],

Cell[BoxData["\<\"PM amplitude (zero at \[ImaginaryI]f/FSR has been \
removed)\"\>"], "Print",
 CellChangeTimes->{{3.4571788829776*^9, 3.4571788961284*^9}, 
   3.4571789347072*^9, 3.4571790876963997`*^9, 3.4571791336851997`*^9, {
   3.4571791832776003`*^9, 3.457179196054*^9}, 3.457179234352*^9, 
   3.457180222612*^9, 3.4571804714788*^9}],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.4571804714944*^9}],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.45718047151*^9}],

Cell[BoxData["\<\"AM amplitude\"\>"], "Print",
 CellChangeTimes->{{3.4571788829776*^9, 3.4571788961284*^9}, 
   3.4571789347072*^9, 3.4571790876963997`*^9, 3.4571791336851997`*^9, {
   3.4571791832776003`*^9, 3.457179196054*^9}, 3.457179234352*^9, 
   3.457180222612*^9, 3.4571804715256*^9}],

Cell[BoxData[
 RowBox[{"{", "\[CapitalDelta]A", "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.4571804715256*^9}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
    SubscriptBox["r1", "g"], " ", 
    SubscriptBox["r2", "g"]}], 
   RowBox[{"FSR", "-", 
    RowBox[{"FSR", " ", 
     SubscriptBox["r1", "g"], " ", 
     SubscriptBox["r2", "g"]}]}]], "}"}]], "Output",
 CellChangeTimes->{{3.4568449749048944`*^9, 3.4568450434200945`*^9}, {
   3.4568450903136945`*^9, 3.456845108955694*^9}, {3.4568452034448943`*^9, 
   3.456845215987294*^9}, {3.456845292817294*^9, 3.4568453257956944`*^9}, 
   3.4568453603964944`*^9, {3.456845437756894*^9, 3.4568455052580943`*^9}, 
   3.4568455810740943`*^9, {3.456845630073694*^9, 3.4568456581224947`*^9}, {
   3.456845798725294*^9, 3.4568458074924946`*^9}, 3.4568459196720943`*^9, 
   3.4568459922276945`*^9, {3.4568460913968945`*^9, 3.4568460986664944`*^9}, 
   3.4568463597012944`*^9, {3.4568464149720945`*^9, 3.4568464413672943`*^9}, 
   3.4568484892206945`*^9, 3.456848880718294*^9, 3.4568489528838944`*^9, {
   3.4568489973282948`*^9, 3.4568490186222944`*^9}, 3.456849131301094*^9, 
   3.4568492211414948`*^9, 3.456849258643894*^9, 3.4568493018090944`*^9, {
   3.4571165860022*^9, 3.4571166377942*^9}, {3.4571788829776*^9, 
   3.457178896144*^9}, 3.4571789347228003`*^9, 3.457179087712*^9, 
   3.4571791337164*^9, {3.4571791832932*^9, 3.4571791960852003`*^9}, 
   3.457179234352*^9, 3.4571802226275997`*^9, 3.4571804715411997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["E", "aux"], " ", "and", " ", 
  SubscriptBox["E", "aux2"], "in", " ", "transmission"}]], "Subsubsection",
 CellChangeTimes->{{3.456849308049094*^9, 3.4568493216210947`*^9}, {
  3.4572900688076*^9, 3.4572900876524*^9}}],

Cell[BoxData[
 RowBox[{"Transmission", " ", "of", " ", 
  SubscriptBox["f", "aux"]}]], "Text",
 CellChangeTimes->{{3.4572907212464*^9, 3.4572907313396*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eaux", "=", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"+", "\[ImaginaryI]"}], " ", 
      RowBox[{"\[Phi]", "/", "2"}]}]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "aux"]}]], " ", 
    SubscriptBox["t1", "r"], 
    SubscriptBox["t2", "r"]}], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], "-", 
    RowBox[{
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}]}]]}]], "Input",
 CellChangeTimes->{{3.4572907552232*^9, 3.4572907606832*^9}, {
   3.4572912484639997`*^9, 3.4572912510848*^9}, {3.4572916335344*^9, 
   3.4572916358276*^9}, 3.4572917392868*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "aux"]}]}]], " ", 
   SubscriptBox["t1", "r"], " ", 
   SubscriptBox["t2", "r"]}], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], "-", 
   RowBox[{
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"]}]}]]], "Output",
 CellChangeTimes->{3.4572907896368*^9, 3.4572912516464*^9, 
  3.4572916377307997`*^9, 3.4572917398484*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eauxp", "=", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"+", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Phi]", "/", "2"}]}]], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "aux"]}]], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "d"]}]], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"+", "\[ImaginaryI]"}], " ", "\[Omega]", " ", 
     "t"}]]}]}]], "Input",
 CellChangeTimes->{{3.4572920176532*^9, 3.4572920352344*^9}, {
  3.4572925977704*^9, 3.4572926029652*^9}}],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"], "+", 
   RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Omega]"}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Phi]", "aux"]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Phi]", "d"]}]}]]], "Output",
 CellChangeTimes->{3.4572921624835997`*^9, 3.457294216988*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Transmission", " ", "of", " ", 
  SubscriptBox["f", "aux2"]}]], "Text",
 CellChangeTimes->{{3.4572907212464*^9, 3.4572907417448*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eaux2", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[Phi]", "/", "2"}]}]], 
      SubscriptBox["t2", "r"]}], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], "-", 
      RowBox[{
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}]], "\[Eta]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["\[Phi]", "aux"]}]], " ", 
      SubscriptBox["t1", "r"]}], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], "-", 
      RowBox[{
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "green"]}]], 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{" ", 
        SubscriptBox["t1", "g"]}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], "-", 
        RowBox[{
         SubscriptBox["r1", "g"], " ", 
         SubscriptBox["r2", "g"]}]}]], "/.", 
      RowBox[{"\[Phi]", "\[Rule]", "0"}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4572901871492*^9, 3.457290212*^9}, {3.4572902575832*^9, 
   3.4572903338984003`*^9}, {3.4572905934512*^9, 3.4572906139807997`*^9}, {
   3.4572908373728*^9, 3.4572908397595997`*^9}, {3.4572911213552*^9, 
   3.4572911366588*^9}, {3.4572912390416*^9, 3.4572912419276*^9}, {
   3.4572912763255997`*^9, 3.457291276388*^9}, {3.4572914578472*^9, 
   3.4572914581280003`*^9}, {3.4572916408664*^9, 3.4572916423640003`*^9}, 
   3.4572921235928*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Phi]"}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Phi]", "aux"]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Phi]", "green"]}]}], ")"}]}]], " ", "\[Eta]", " ", 
    SubscriptBox["t1", "g"], " ", 
    SubscriptBox["t1", "r"], " ", 
    SubscriptBox["t2", "r"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SubscriptBox["r1", "g"], " ", 
       SubscriptBox["r2", "g"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{
  3.4572903342572002`*^9, {3.457290596384*^9, 3.4572906145736*^9}, 
   3.4572908411012*^9, {3.4572912539084*^9, 3.457291277012*^9}, 
   3.457291458908*^9, 3.45729164291*^9, 3.4572921244820004`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eaux2p", "=", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Phi]", "/", "2"}]}]], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      SubscriptBox["\[Phi]", "aux"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "green"]}]}]], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], "\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "d"]}]], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", 
     "t"}]]}]}]], "Input",
 CellChangeTimes->{{3.4572918977984*^9, 3.4572919237412*^9}, {
  3.457292049524*^9, 3.457292153342*^9}, {3.4572926080508003`*^9, 
  3.4572926105312*^9}}],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Omega]"}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Phi]", "aux"]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubscriptBox["\[Phi]", "d"]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Phi]", "green"]}]}]]], "Output",
 CellChangeTimes->{3.4572921541688004`*^9, 3.4572926113892*^9, 
  3.4572942335552*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PowerExpand", "[", 
  SqrtBox[
   RowBox[{"Simplify", "[", 
    RowBox[{"ComplexExpand", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], "-", 
         RowBox[{
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}]}], ")"}], "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], "-", 
         RowBox[{
          SubscriptBox["r1", "r"], " ", 
          SubscriptBox["r2", "r"]}]}], ")"}], "2"]}], "]"}], "]"}]], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4572904150964003`*^9, 3.4572904659992*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
   SubscriptBox["r1", "r"], " ", 
   SubscriptBox["r2", "r"]}], "+", 
  RowBox[{
   SubsuperscriptBox["r1", "r", "2"], " ", 
   SubsuperscriptBox["r2", "r", "2"]}]}]], "Output",
 CellChangeTimes->{{3.457290428684*^9, 3.4572904664048*^9}, 
   3.4572926129336*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Local", " ", "Oscillator"}]], "Text",
 CellChangeTimes->{{3.4572907212464*^9, 3.4572907417448*^9}, {
  3.457291617326*^9, 3.457291624814*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"elo", "=", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Phi]", "LO"]}]]}]], "Input",
 CellChangeTimes->{{3.4572916458272*^9, 3.4572916686656*^9}}],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{"\[ImaginaryI]", " ", 
   SubscriptBox["\[Phi]", "LO"]}]]], "Output",
 CellChangeTimes->{3.4572916725811996`*^9, 3.4572926160067997`*^9}]
}, Open  ]],

Cell[BoxData["Combined"], "Text",
 CellChangeTimes->{{3.4572907212464*^9, 3.4572907417448*^9}, {
  3.457291617326*^9, 3.457291624814*^9}, {3.4572927630836*^9, 
  3.4572927672799997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"esum", "=", 
  RowBox[{"elo", "+", "eauxp", "+", "eaux2p"}]}]], "Input",
 CellChangeTimes->{{3.4572927704156*^9, 3.4572927825836*^9}, {
  3.4572940537496*^9, 3.4572940548571997`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"], "+", 
    RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Omega]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "aux"]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "d"]}]}]], "+", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "2"]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Omega]"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "aux"]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "d"]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "green"]}]}]], "+", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Phi]", "LO"]}]]}]], "Output",
 CellChangeTimes->{
  3.4572927846896*^9, {3.4572940127372*^9, 3.4572940553408003`*^9}, 
   3.4572942401384*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"eauxp", "=", 
    RowBox[{"a1", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", "inj"]}]], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", "aux"]}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"+", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"eaux2p", "=", 
    RowBox[{"a2", "  ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", "inj"]}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", "aux2"]}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"elo", "=", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "LO"]}]]}], "\[IndentingNewLine]", 
   RowBox[{"esum", "=", 
    RowBox[{"elo", "+", "eauxp", "+", "eaux2p"}]}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"ComplexExpand", "[", 
     RowBox[{
      RowBox[{"esum", "\[Conjugate]"}], "esum"}], "]"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"%", "\[Omega]"}], "\[Pi]"], 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"t", " ", "\[Omega]"}], "+", 
        SubscriptBox["\[Phi]", "M"]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       FractionBox[
        RowBox[{"2", "\[Pi]"}], "\[Omega]"]}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%", "/.", 
     RowBox[{
      SubscriptBox["\[Phi]", "M"], "\[Rule]", 
      RowBox[{
       FractionBox[
        SubscriptBox["\[Phi]", "aux"], "2"], "-", 
       FractionBox[
        SubscriptBox["\[Phi]", "aux2"], "2"]}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%%", "/.", 
     RowBox[{
      SubscriptBox["\[Phi]", "M"], "\[Rule]", 
      RowBox[{
       FractionBox[
        SubscriptBox["\[Phi]", "aux"], "2"], "-", 
       FractionBox[
        SubscriptBox["\[Phi]", "aux2"], "2"], "+", 
       FractionBox["\[Pi]", "2"]}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4572939670604*^9, 3.4572940516280003`*^9}, {
  3.4572951692743998`*^9, 3.4572951936728*^9}, {3.4572952261208*^9, 
  3.4572952369628*^9}, {3.4572953671448*^9, 3.4572953909192*^9}, {
  3.4572955544852*^9, 3.4572955943900003`*^9}, {3.4572959115224*^9, 
  3.45729592004*^9}, {3.4572963623311996`*^9, 3.4572963751387997`*^9}, {
  3.4572967309124002`*^9, 3.4572967472924*^9}}],

Cell[BoxData[
 RowBox[{"a1", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Omega]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "aux"]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "inj"]}]}]]}]], "Output",
 CellChangeTimes->{{3.4572940050464*^9, 3.45729405194*^9}, 3.457295194406*^9, 
   3.4572952394119997`*^9, {3.4572953804048*^9, 3.4572953920112*^9}, {
   3.4572955689776*^9, 3.4572955953104*^9}, 3.4572959220524*^9, {
   3.4572963627212*^9, 3.4572963755912*^9}, 3.4572967383224*^9}],

Cell[BoxData[
 RowBox[{"a2", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "aux2"]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "inj"]}]}]]}]], "Output",
 CellChangeTimes->{{3.4572940050464*^9, 3.45729405194*^9}, 3.457295194406*^9, 
   3.4572952394119997`*^9, {3.4572953804048*^9, 3.4572953920112*^9}, {
   3.4572955689776*^9, 3.4572955953104*^9}, 3.4572959220524*^9, {
   3.4572963627212*^9, 3.4572963755912*^9}, 3.4572967383224*^9}],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{"\[ImaginaryI]", " ", 
   SubscriptBox["\[Phi]", "LO"]}]]], "Output",
 CellChangeTimes->{{3.4572940050464*^9, 3.45729405194*^9}, 3.457295194406*^9, 
   3.4572952394119997`*^9, {3.4572953804048*^9, 3.4572953920112*^9}, {
   3.4572955689776*^9, 3.4572955953104*^9}, 3.4572959220524*^9, {
   3.4572963627212*^9, 3.4572963755912*^9}, 3.4572967383224*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a1", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Omega]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "aux"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "inj"]}]}]]}], "+", 
  RowBox[{"a2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "aux2"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "inj"]}]}]]}], "+", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Phi]", "LO"]}]]}]], "Output",
 CellChangeTimes->{{3.4572940050464*^9, 3.45729405194*^9}, 3.457295194406*^9, 
   3.4572952394119997`*^9, {3.4572953804048*^9, 3.4572953920112*^9}, {
   3.4572955689776*^9, 3.4572955953104*^9}, 3.4572959220524*^9, {
   3.4572963627212*^9, 3.4572963755912*^9}, 3.4572967383224*^9}],

Cell[BoxData[
 RowBox[{"1", "+", 
  SuperscriptBox["a1", "2"], "+", 
  SuperscriptBox["a2", "2"], "+", 
  RowBox[{"2", " ", "a1", " ", "a2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "t", " ", "\[Omega]"}], "+", 
     SubscriptBox["\[Phi]", "aux"], "-", 
     SubscriptBox["\[Phi]", "aux2"]}], "]"}]}], "+", 
  RowBox[{"2", " ", "a1", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"t", " ", "\[Omega]"}], "+", 
     SubscriptBox["\[Phi]", "aux"], "+", 
     SubscriptBox["\[Phi]", "inj"], "-", 
     SubscriptBox["\[Phi]", "LO"]}], "]"}]}], "+", 
  RowBox[{"2", " ", "a2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"t", " ", "\[Omega]"}], "-", 
     SubscriptBox["\[Phi]", "aux2"], "-", 
     SubscriptBox["\[Phi]", "inj"], "+", 
     SubscriptBox["\[Phi]", "LO"]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.4572940050464*^9, 3.45729405194*^9}, 3.457295194406*^9, 
   3.4572952394119997`*^9, {3.4572953804048*^9, 3.4572953920112*^9}, {
   3.4572955689776*^9, 3.4572955953104*^9}, 3.4572959220524*^9, {
   3.4572963627212*^9, 3.4572963755912*^9}, 3.4572967383380003`*^9}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a1", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "aux"], "+", 
       SubscriptBox["\[Phi]", "inj"], "-", 
       SubscriptBox["\[Phi]", "LO"], "-", 
       SubscriptBox["\[Phi]", "M"]}], "]"}]}], "+", 
    RowBox[{"a2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "aux2"], "+", 
       SubscriptBox["\[Phi]", "inj"], "-", 
       SubscriptBox["\[Phi]", "LO"], "+", 
       SubscriptBox["\[Phi]", "M"]}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4572940050464*^9, 3.45729405194*^9}, 3.457295194406*^9, 
   3.4572952394119997`*^9, {3.4572953804048*^9, 3.4572953920112*^9}, {
   3.4572955689776*^9, 3.4572955953104*^9}, 3.4572959220524*^9, {
   3.4572963627212*^9, 3.4572963755912*^9}, 3.4572967388059998`*^9}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{"a1", "+", "a2"}], ")"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Phi]", "aux"], "+", 
      SubscriptBox["\[Phi]", "aux2"], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", "inj"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", "LO"]}]}], ")"}]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.4572940050464*^9, 3.45729405194*^9}, 3.457295194406*^9, 
   3.4572952394119997`*^9, {3.4572953804048*^9, 3.4572953920112*^9}, {
   3.4572955689776*^9, 3.4572955953104*^9}, 3.4572959220524*^9, {
   3.4572963627212*^9, 3.4572963755912*^9}, 3.4572967388059998`*^9}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{"a1", "-", "a2"}], ")"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Phi]", "aux"], "+", 
      SubscriptBox["\[Phi]", "aux2"], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", "inj"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", "LO"]}]}], ")"}]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.4572940050464*^9, 3.45729405194*^9}, 3.457295194406*^9, 
   3.4572952394119997`*^9, {3.4572953804048*^9, 3.4572953920112*^9}, {
   3.4572955689776*^9, 3.4572955953104*^9}, 3.4572959220524*^9, {
   3.4572963627212*^9, 3.4572963755912*^9}, 3.4572967388059998`*^9}],

Cell[BoxData[
 RowBox[{"a1", " ", "a2", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "aux"]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "aux2"]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", "inj"]}]}]]}]], "Output",
 CellChangeTimes->{{3.4572940050464*^9, 3.45729405194*^9}, 3.457295194406*^9, 
   3.4572952394119997`*^9, {3.4572953804048*^9, 3.4572953920112*^9}, {
   3.4572955689776*^9, 3.4572955953104*^9}, 3.4572959220524*^9, {
   3.4572963627212*^9, 3.4572963755912*^9}, 3.4572967388059998`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{
    RowBox[{"a1", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "aux"], "+", 
       SubscriptBox["\[Phi]", "inj"], "-", 
       SubscriptBox["\[Phi]", "LO"], "-", 
       SubscriptBox["\[Phi]", "M"]}], "]"}]}], "+", 
    RowBox[{"a2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "aux2"], "+", 
       SubscriptBox["\[Phi]", "inj"], "-", 
       SubscriptBox["\[Phi]", "LO"], "+", 
       SubscriptBox["\[Phi]", "M"]}], "]"}]}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4572962189828*^9, 3.45729625115*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Phi]", "aux"], "+", 
      SubscriptBox["\[Phi]", "aux2"], "+", 
      SubscriptBox["\[Phi]", "inj"], "+", 
      SubscriptBox["\[Phi]", "LO"], "+", 
      SubscriptBox["\[Phi]", "M"]}], ")"}]}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", "aux"]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "LO"]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Phi]", "aux2"], "+", 
           SubscriptBox["\[Phi]", "inj"], "+", 
           SubscriptBox["\[Phi]", "M"]}], ")"}]}]]}], ")"}]}], "+", 
    RowBox[{"a1", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", "aux2"]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Phi]", "aux"], "+", 
           SubscriptBox["\[Phi]", "inj"]}], ")"}]}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Phi]", "LO"], "+", 
           SubscriptBox["\[Phi]", "M"]}], ")"}]}]]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.457296222836*^9, 3.457296251618*^9}}]
}, Open  ]],

Cell[BoxData["Demodulator"], "Text",
 CellChangeTimes->{{3.4572907212464*^9, 3.4572907417448*^9}, {
  3.457291617326*^9, 3.457291624814*^9}, {3.457291774184*^9, 
  3.4572917802836*^9}}],

Cell[BoxData[
 RowBox[{"TrigFactor", "[", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{
     FractionBox["\[Phi]", "2"], "+", 
     RowBox[{"t", " ", "\[Omega]"}], "+", 
     SubscriptBox["\[Phi]", "aux"], "+", 
     SubscriptBox["\[Phi]", "d"], "-", 
     SubscriptBox["\[Phi]", "LO"]}], "]"}], "+", 
   RowBox[{"Cos", "[", 
    RowBox[{
     FractionBox["\[Phi]", "2"], "+", 
     RowBox[{"t", " ", "\[Omega]"}], "+", 
     SubscriptBox["\[Phi]", "aux"], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "d"]}], "-", 
     SubscriptBox["\[Phi]", "green"], "+", 
     SubscriptBox["\[Phi]", "LO"]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4572930117476*^9, 3.4572930245396*^9}, {
  3.4572932368087997`*^9, 3.4572932562307997`*^9}, {3.4572942794972*^9, 
  3.4572942851443996`*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    FractionBox["\[Phi]", "2"], "+", 
    RowBox[{"t", " ", "\[Omega]"}], "+", 
    SubscriptBox["\[Phi]", "aux"], "+", 
    FractionBox[
     RowBox[{"3", " ", 
      SubscriptBox["\[Phi]", "d"]}], "2"], "-", 
    FractionBox[
     SubscriptBox["\[Phi]", "green"], "2"]}], "]"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    FractionBox[
     SubscriptBox["\[Phi]", "d"], "2"], "-", 
    FractionBox[
     SubscriptBox["\[Phi]", "green"], "2"], "+", 
    SubscriptBox["\[Phi]", "LO"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.457294434686*^9, 3.4572944359496*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigFactor", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "a1", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"t", " ", "\[Omega]"}], "+", 
       SubscriptBox["\[Phi]", "aux"], "-", 
       SubscriptBox["\[Phi]", "LO"]}], "]"}]}], "+", 
    RowBox[{"2", " ", "a2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"t", " ", "\[Omega]"}], "-", 
       SubscriptBox["\[Phi]", "aux2"], "+", 
       SubscriptBox["\[Phi]", "LO"]}], "]"}]}]}], "/.", 
   RowBox[{"a2", "\[Rule]", "a1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4572941030924*^9, 3.4572941046836*^9}, {
  3.4572941374904003`*^9, 3.4572941421703997`*^9}}],

Cell[BoxData[
 RowBox[{"4", " ", "a1", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    RowBox[{"t", " ", "\[Omega]"}], "+", 
    FractionBox[
     SubscriptBox["\[Phi]", "aux"], "2"], "-", 
    FractionBox[
     SubscriptBox["\[Phi]", "aux2"], "2"]}], "]"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    FractionBox[
     SubscriptBox["\[Phi]", "aux"], "2"], "+", 
    FractionBox[
     SubscriptBox["\[Phi]", "aux2"], "2"], "-", 
    SubscriptBox["\[Phi]", "LO"]}], "]"}]}]], "Output",
 CellChangeTimes->{3.4572941051984*^9, 3.4572941427008*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{"ComplexExpand", "[", 
   RowBox[{
    RowBox[{"esum", "\[Conjugate]"}], "esum"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"%", "\[Omega]"}], "\[Pi]"], 
    RowBox[{"Cos", "[", 
     RowBox[{
      FractionBox["\[Phi]", "2"], "+", 
      RowBox[{"t", " ", "\[Omega]"}], "+", 
      SubscriptBox["\[Phi]", "aux"], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Phi]", "d"]}], "2"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "green"], "2"]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], "\[Omega]"]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"TrigExpand", "[", "%", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.4572917909384003`*^9, 3.4572918520123997`*^9}, {
   3.4572921732944*^9, 3.4572921745424*^9}, {3.4572926492504*^9, 
   3.4572926990299997`*^9}, {3.457292789432*^9, 3.457292793488*^9}, {
   3.4572929074616003`*^9, 3.4572929551507998`*^9}, {3.4572930601856003`*^9, 
   3.4572930621043997`*^9}, 3.4572944404268*^9}],

Cell[BoxData[
 RowBox[{"3", "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Phi]", "+", 
     RowBox[{"2", " ", "t", " ", "\[Omega]"}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "aux"]}], "+", 
     RowBox[{"3", " ", 
      SubscriptBox["\[Phi]", "d"]}], "-", 
     SubscriptBox["\[Phi]", "green"]}], "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     FractionBox["\[Phi]", "2"], "+", 
     RowBox[{"t", " ", "\[Omega]"}], "+", 
     SubscriptBox["\[Phi]", "aux"], "+", 
     SubscriptBox["\[Phi]", "d"], "-", 
     SubscriptBox["\[Phi]", "LO"]}], "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     FractionBox["\[Phi]", "2"], "+", 
     RowBox[{"t", " ", "\[Omega]"}], "+", 
     SubscriptBox["\[Phi]", "aux"], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "d"]}], "-", 
     SubscriptBox["\[Phi]", "green"], "+", 
     SubscriptBox["\[Phi]", "LO"]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.4572918380036*^9, 3.4572918532448*^9}, 
   3.4572921754472*^9, 3.4572926176604*^9, {3.45729269552*^9, 
   3.4572926993732*^9}, 3.4572927941588*^9, {3.4572929128747997`*^9, 
   3.4572929555095997`*^9}, 3.4572930626191998`*^9, 3.4572940613*^9, 
   3.4572942569708*^9, 3.4572944418464003`*^9}],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Phi]", "d"], "-", 
      SubscriptBox["\[Phi]", "green"], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", "LO"]}]}], ")"}]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.4572918380036*^9, 3.4572918532448*^9}, 
   3.4572921754472*^9, 3.4572926176604*^9, {3.45729269552*^9, 
   3.4572926993732*^9}, 3.4572927941588*^9, {3.4572929128747997`*^9, 
   3.4572929555095997`*^9}, 3.4572930626191998`*^9, 3.4572940613*^9, 
   3.4572942569708*^9, 3.457294463*^9}],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Phi]", "d"], "-", 
      SubscriptBox["\[Phi]", "green"], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", "LO"]}]}], ")"}]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.4572918380036*^9, 3.4572918532448*^9}, 
   3.4572921754472*^9, 3.4572926176604*^9, {3.45729269552*^9, 
   3.4572926993732*^9}, 3.4572927941588*^9, {3.4572929128747997`*^9, 
   3.4572929555095997`*^9}, 3.4572930626191998`*^9, 3.4572940613*^9, 
   3.4572942569708*^9, 3.4572944630312*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test", "Subsubsection",
 CellChangeTimes->{{3.456711024141575*^9, 3.4567110246245747`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eaux2", "=", 
  RowBox[{"\[Eta]", " ", 
   RowBox[{"Eaux", "\[Conjugate]"}], " ", "Egreen"}]}]], "Input",
 CellChangeTimes->{{3.456695113747575*^9, 3.456695130490575*^9}, {
  3.4566952529165745`*^9, 3.4566952547635746`*^9}, {3.456695398667575*^9, 
  3.4566954045875745`*^9}, {3.4567066728175745`*^9, 3.4567066734865746`*^9}}],

Cell[BoxData[
 RowBox[{"Egreen", " ", "\[Eta]", " ", 
  RowBox[{"Conjugate", "[", "Eaux", "]"}]}]], "Output",
 CellChangeTimes->{3.4566951312315745`*^9, 3.4566954052535744`*^9, 
  3.4567066747355747`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prm", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Eaux", "\[Rule]", 
     RowBox[{
      SubscriptBox["A", "aux"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"\[CapitalOmega]", "+", "\[Omega]"}], ")"}], "t"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "aux"]}]}]]}]}], ",", 
    RowBox[{"Egreen", "\[Rule]", 
     RowBox[{
      SubscriptBox["A", "green"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"2", "\[CapitalOmega]"}], ")"}], "t"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "green"]}]}]]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.4566951454605746`*^9, 3.4566952497555747`*^9}, {
  3.4566953083355746`*^9, 3.456695310240575*^9}, {3.4567043060005746`*^9, 
  3.4567043111765747`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Eaux", "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{"\[Omega]", "+", "\[CapitalOmega]"}], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Phi]", "aux"]}]}]], " ", 
     SubscriptBox["A", "aux"]}]}], ",", 
   RowBox[{"Egreen", "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "t", " ", "\[CapitalOmega]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Phi]", "green"]}]}]], " ", 
     SubscriptBox["A", "green"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4566952397115746`*^9, 3.4566952501425743`*^9}, 
   3.4566953125445747`*^9, 3.4567043120275745`*^9, 3.456706677641575*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Eaux2", "/.", "prm"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComplexExpand", "[", "%", "]"}], "//", "TrigToExp"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.4566952565395746`*^9, 3.4566952965835743`*^9}, {
  3.4566953287745743`*^9, 3.4566953635455747`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "t", " ", "\[CapitalOmega]"}], "-", 
      RowBox[{"Conjugate", "[", 
       RowBox[{"t", " ", 
        RowBox[{"(", 
         RowBox[{"\[Omega]", "+", "\[CapitalOmega]"}], ")"}]}], "]"}], "-", 
      RowBox[{"Conjugate", "[", 
       SubscriptBox["\[Phi]", "aux"], "]"}], "+", 
      SubscriptBox["\[Phi]", "green"]}], ")"}]}]], " ", "\[Eta]", " ", 
  RowBox[{"Conjugate", "[", 
   SubscriptBox["A", "aux"], "]"}], " ", 
  SubscriptBox["A", "green"]}]], "Output",
 CellChangeTimes->{{3.456695263259575*^9, 3.456695363997575*^9}, 
   3.4566954088215747`*^9, 3.456704314502575*^9, 3.4567066787285748`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t", " ", 
       RowBox[{"(", 
        RowBox[{"\[Omega]", "-", "\[CapitalOmega]"}], ")"}]}], "+", 
      SubscriptBox["\[Phi]", "aux"], "-", 
      SubscriptBox["\[Phi]", "green"]}], ")"}]}]], " ", "\[Eta]", " ", 
  SubscriptBox["A", "aux"], " ", 
  SubscriptBox["A", "green"]}]], "Output",
 CellChangeTimes->{{3.456695263259575*^9, 3.456695363997575*^9}, 
   3.4566954088215747`*^9, 3.456704314502575*^9, 3.456706678747575*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prm2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Eaux", "\[Rule]", 
     RowBox[{
      SubscriptBox["A", "aux"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"\[CapitalOmega]", "+", "\[Omega]"}], ")"}], "t"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "aux"]}]}]], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["a", "p"], 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Alpha]", "p"]}]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Zeta]", " ", "t"}]]}], "+", 
        RowBox[{
         SubscriptBox["a", "m"], 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Alpha]", "m"]}]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Zeta]", " ", "t"}]]}]}], 
       ")"}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Egreen", "\[Rule]", 
     RowBox[{
      SubscriptBox["A", "green"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"2", "\[ImaginaryI]", " ", "\[CapitalOmega]", " ", "t"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "green"]}]}]], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["g", "p"], 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Gamma]", "p"]}]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Zeta]", " ", "t"}]]}], "+", 
        RowBox[{
         SubscriptBox["g", "m"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Gamma]", "m"]}]], 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Zeta]", " ", "t"}]]}]}], 
       ")"}]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.4567045479565744`*^9, 3.4567045486795745`*^9}, {
  3.4567046312755747`*^9, 3.4567048407135744`*^9}, {3.4567071170195746`*^9, 
  3.4567071624595747`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Eaux", "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{"\[Omega]", "+", "\[CapitalOmega]"}], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Phi]", "aux"]}]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Zeta]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Alpha]", "m"]}]}]], " ", 
        SubscriptBox["a", "m"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Zeta]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Alpha]", "p"]}]}]], " ", 
        SubscriptBox["a", "p"]}]}], ")"}], " ", 
     SubscriptBox["A", "aux"]}]}], ",", 
   RowBox[{"Egreen", "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "t", " ", "\[CapitalOmega]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Phi]", "green"]}]}]], " ", 
     SubscriptBox["A", "green"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Zeta]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Gamma]", "m"]}]}]], " ", 
        SubscriptBox["g", "m"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Zeta]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Gamma]", "p"]}]}]], " ", 
        SubscriptBox["g", "p"]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4567048224555745`*^9, 3.4567048414655743`*^9}, 
   3.4567066802235746`*^9, 3.4567071634775743`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   FractionBox["Eaux2", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "t", 
      RowBox[{"(", 
       RowBox[{"\[CapitalOmega]", "-", "\[Omega]"}], ")"}]}]]], "/.", 
   "prm2"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"ExpandAll", "[", 
  FractionBox[
   RowBox[{
    RowBox[{"ComplexExpand", "[", "%", "]"}], "//", "TrigToExp"}], 
   RowBox[{"\[Eta]", " ", 
    SubscriptBox["A", "aux"], " ", 
    SubscriptBox["A", "green"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["\[Phi]", "aux"]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", "green"]}]}]]}]], "]"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["a", "m"], " ", 
      SubscriptBox["g", "m"]}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["a", "m"], " ", 
      SubscriptBox["g", "p"]}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["a", "p"], " ", 
      SubscriptBox["g", "m"]}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["a", "p"], " ", 
      SubscriptBox["g", "p"]}], "\[Rule]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", "%", "]"}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "ExpandAll"}]}], "Input",
 CellChangeTimes->{{3.4567048492885747`*^9, 3.4567048540455747`*^9}, {
   3.4567048878015747`*^9, 3.4567049073435745`*^9}, {3.4567049435065746`*^9, 
   3.4567051404295745`*^9}, {3.4567051810955744`*^9, 
   3.4567051813535748`*^9}, {3.4567053006045747`*^9, 
   3.4567053621175747`*^9}, {3.4567054159075747`*^9, 
   3.4567054224085746`*^9}, {3.4567066848245745`*^9, 3.4567066854595747`*^9}, 
   3.4567070087415743`*^9, {3.456707169648575*^9, 3.4567071987915745`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t", " ", "\[Zeta]"}], "-", 
      RowBox[{"t", " ", "\[Omega]"}], "-", 
      RowBox[{"t", " ", "\[CapitalOmega]"}], "+", 
      RowBox[{"Conjugate", "[", 
       RowBox[{"t", " ", 
        RowBox[{"(", 
         RowBox[{"\[Omega]", "+", "\[CapitalOmega]"}], ")"}]}], "]"}], "+", 
      RowBox[{"Conjugate", "[", 
       SubscriptBox["\[Phi]", "aux"], "]"}], "-", 
      SubscriptBox["\[Phi]", "green"]}], ")"}]}]], " ", "\[Eta]", " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    RowBox[{"Conjugate", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Zeta]"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Alpha]", "m"]}]}]], " ", 
       SubscriptBox["a", "m"]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"t", " ", "\[Zeta]"}], "+", 
           SubscriptBox["\[Alpha]", "p"]}], ")"}]}]], " ", 
       SubscriptBox["a", "p"]}]}], "]"}]}], ")"}], " ", 
  RowBox[{"Conjugate", "[", 
   SubscriptBox["A", "aux"], "]"}], " ", 
  SubscriptBox["A", "green"], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Zeta]"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Gamma]", "m"]}]], " ", 
     SubscriptBox["g", "m"]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "t", " ", "\[Zeta]"}], "+", 
         SubscriptBox["\[Gamma]", "p"]}], ")"}]}]], " ", 
     SubscriptBox["g", "p"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4567048513875747`*^9, 3.4567048544415746`*^9}, 
   3.456704908254575*^9, {3.4567049470265746`*^9, 3.4567050080255747`*^9}, {
   3.4567050417235746`*^9, 3.4567051408485746`*^9}, 3.456705181707575*^9, 
   3.4567053065795746`*^9, {3.4567053387385745`*^9, 3.4567053779195747`*^9}, {
   3.456705416221575*^9, 3.4567054227705746`*^9}, 3.4567066860675745`*^9, 
   3.4567070092655745`*^9, {3.4567071752555747`*^9, 3.456707199346575*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Zeta]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Alpha]", "m"]}]}]], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Zeta]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Alpha]", "p"]}]}]], " ", 
   SubscriptBox["a", "p"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Zeta]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Gamma]", "m"]}]}]], " ", 
   SubscriptBox["g", "m"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      SubscriptBox["\[Alpha]", "m"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Gamma]", "m"]}]}]], " ", 
   SubscriptBox["a", "m"], " ", 
   SubscriptBox["g", "m"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "t", " ", "\[Zeta]"}], 
     "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Alpha]", "p"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Gamma]", "m"]}]}]], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["g", "m"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Zeta]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Gamma]", "p"]}]}]], " ", 
   SubscriptBox["g", "p"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"2", " ", "\[ImaginaryI]", " ", "t", " ", "\[Zeta]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Alpha]", "m"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Gamma]", "p"]}]}]], " ", 
   SubscriptBox["a", "m"], " ", 
   SubscriptBox["g", "p"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      SubscriptBox["\[Alpha]", "p"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Gamma]", "p"]}]}]], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["g", "p"]}]}]], "Output",
 CellChangeTimes->{{3.4567048513875747`*^9, 3.4567048544415746`*^9}, 
   3.456704908254575*^9, {3.4567049470265746`*^9, 3.4567050080255747`*^9}, {
   3.4567050417235746`*^9, 3.4567051408485746`*^9}, 3.456705181707575*^9, 
   3.4567053065795746`*^9, {3.4567053387385745`*^9, 3.4567053779195747`*^9}, {
   3.456705416221575*^9, 3.4567054227705746`*^9}, 3.4567066860675745`*^9, 
   3.4567070092655745`*^9, {3.4567071752555747`*^9, 3.4567071994425745`*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Zeta]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Alpha]", "m"]}]}]], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Zeta]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Alpha]", "p"]}]}]], " ", 
   SubscriptBox["a", "p"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Zeta]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Gamma]", "m"]}]}]], " ", 
   SubscriptBox["g", "m"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Zeta]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Gamma]", "p"]}]}]], " ", 
   SubscriptBox["g", "p"]}]}]], "Output",
 CellChangeTimes->{{3.4567048513875747`*^9, 3.4567048544415746`*^9}, 
   3.456704908254575*^9, {3.4567049470265746`*^9, 3.4567050080255747`*^9}, {
   3.4567050417235746`*^9, 3.4567051408485746`*^9}, 3.456705181707575*^9, 
   3.4567053065795746`*^9, {3.4567053387385745`*^9, 3.4567053779195747`*^9}, {
   3.456705416221575*^9, 3.4567054227705746`*^9}, 3.4567066860675745`*^9, 
   3.4567070092655745`*^9, {3.4567071752555747`*^9, 3.4567071994555745`*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"t", " ", "\[Zeta]"}], "-", 
       SubscriptBox["\[Alpha]", "m"]}], ")"}]}]], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"t", " ", "\[Zeta]"}], "+", 
       SubscriptBox["\[Alpha]", "p"]}], ")"}]}]], " ", 
   SubscriptBox["a", "p"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Zeta]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Gamma]", "m"]}]}]], " ", 
   SubscriptBox["g", "m"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"t", " ", "\[Zeta]"}], "+", 
       SubscriptBox["\[Gamma]", "p"]}], ")"}]}]], " ", 
   SubscriptBox["g", "p"]}]}]], "Output",
 CellChangeTimes->{{3.4567048513875747`*^9, 3.4567048544415746`*^9}, 
   3.456704908254575*^9, {3.4567049470265746`*^9, 3.4567050080255747`*^9}, {
   3.4567050417235746`*^9, 3.4567051408485746`*^9}, 3.456705181707575*^9, 
   3.4567053065795746`*^9, {3.4567053387385745`*^9, 3.4567053779195747`*^9}, {
   3.456705416221575*^9, 3.4567054227705746`*^9}, 3.4567066860675745`*^9, 
   3.4567070092655745`*^9, {3.4567071752555747`*^9, 3.4567071995845747`*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Zeta]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Alpha]", "m"]}]}]], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Zeta]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Alpha]", "p"]}]}]], " ", 
   SubscriptBox["a", "p"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Zeta]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Gamma]", "m"]}]}]], " ", 
   SubscriptBox["g", "m"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Zeta]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Gamma]", "p"]}]}]], " ", 
   SubscriptBox["g", "p"]}]}]], "Output",
 CellChangeTimes->{{3.4567048513875747`*^9, 3.4567048544415746`*^9}, 
   3.456704908254575*^9, {3.4567049470265746`*^9, 3.4567050080255747`*^9}, {
   3.4567050417235746`*^9, 3.4567051408485746`*^9}, 3.456705181707575*^9, 
   3.4567053065795746`*^9, {3.4567053387385745`*^9, 3.4567053779195747`*^9}, {
   3.456705416221575*^9, 3.4567054227705746`*^9}, 3.4567066860675745`*^9, 
   3.4567070092655745`*^9, {3.4567071752555747`*^9, 3.4567071996005745`*^9}}]
}, Open  ]],

Cell[BoxData["Outer"], "Input",
 CellChangeTimes->{{3.4567103845625744`*^9, 3.456710385358575*^9}}],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Omega]", "S"], " ", "t"}], " ", "+", " ", 
   RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]}]]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["DC lock point", "Subsubsection",
 CellChangeTimes->{{3.4560792063364*^9, 3.4560792107511997`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"Conjugate", "[", "Esum", "]"}], "]"}], ".", "Esum"}], "/.", 
          RowBox[{
           SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], "/.", 
         RowBox[{
          SubscriptBox["\[CurlyPhi]", "green"], "\[Rule]", "0"}]}], "/.", 
        RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
       RowBox[{"\[Omega]", "\[Rule]", "0"}]}], ")"}], "]"}], "//", 
    "TrigToExp"}], "//", "Simplify"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "\[LeftDoubleBracket]", 
   RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"demod", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"2", "%", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Phi]M", "+", 
        RowBox[{"2", "t", " ", "\[Omega]M"}]}], "]"}]}], 
     RowBox[{"\[Pi]", "/", "\[Omega]M"}]], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      FractionBox["\[Pi]", "\[Omega]M"]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.456756006317294*^9, 3.4567560399462943`*^9}, {
  3.456757388258294*^9, 3.456757393836294*^9}, {3.4567574485072947`*^9, 
  3.4567574559302945`*^9}, {3.4567574963962946`*^9, 3.4567575623002944`*^9}, {
  3.4567577508632946`*^9, 3.4567577940762944`*^9}, {3.4567579072892942`*^9, 
  3.4567579182492943`*^9}, {3.4567590040912943`*^9, 3.456759040480294*^9}, {
  3.4567599556392946`*^9, 3.4567599565372944`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"Conjugate", "[", "Esum2", "]"}], "]"}], ".", "Esum2"}], "/.", 
          RowBox[{
           SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], "/.", 
         RowBox[{
          SubscriptBox["\[CurlyPhi]", "green"], "\[Rule]", "0"}]}], "/.", 
        RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
       RowBox[{"\[Omega]", "\[Rule]", "0"}]}], ")"}], "]"}], "//", 
    "TrigToExp"}], "//", "Simplify"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "\[LeftDoubleBracket]", 
   RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"demod", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"2", "%", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Phi]M", "+", 
        RowBox[{"2", "t", " ", "\[Omega]M"}]}], "]"}]}], 
     RowBox[{"\[Pi]", "/", "\[Omega]M"}]], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      FractionBox["\[Pi]", "\[Omega]M"]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.456756006317294*^9, 3.4567560399462943`*^9}, {
  3.456757388258294*^9, 3.456757393836294*^9}, {3.4567574485072947`*^9, 
  3.4567574559302945`*^9}, {3.4567574963962946`*^9, 3.4567575623002944`*^9}, {
  3.4567577508632946`*^9, 3.4567577940762944`*^9}, {3.4567579072892942`*^9, 
  3.4567579182492943`*^9}, {3.4567590040912943`*^9, 3.456759040480294*^9}, {
  3.4567599556392946`*^9, 3.4567599565372944`*^9}, {3.456765371310294*^9, 
  3.4567653722622943`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["\[Phi]", "aux"]}], "+", 
         SubscriptBox["\[Phi]", "green"]}], ")"}]}]], " ", "\[Eta]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubsuperscriptBox["r1", "r", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", "aux"]}]], "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", "green"]}]]}], ")"}], " ", 
           RowBox[{"Cos", "[", "\[Phi]M", "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", "aux"]}]], "-", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", "green"]}]]}], ")"}], " ", 
           RowBox[{"Sin", "[", "\[Phi]M", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Phi]", "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["\[Phi]", "aux"]}]}], ")"}]}]], "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", "green"]}]]}], ")"}], " ", 
           RowBox[{"Cos", "[", "\[Phi]M", "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Phi]", "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["\[Phi]", "aux"]}]}], ")"}]}]], "-", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", "green"]}]]}], ")"}], " ", 
           RowBox[{"Sin", "[", "\[Phi]M", "]"}]}]}], ")"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Phi]", "+", 
                 SubscriptBox["\[Phi]", "aux"]}], ")"}]}]], "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", "green"]}]]}], ")"}], " ", 
           RowBox[{"Cos", "[", "\[Phi]M", "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Phi]", "+", 
                 SubscriptBox["\[Phi]", "aux"]}], ")"}]}]], "-", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", "green"]}]]}], ")"}], " ", 
           RowBox[{"Sin", "[", "\[Phi]M", "]"}]}]}], ")"}], " ", 
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
     SubscriptBox["t1", "g"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SubscriptBox["r1", "g"], " ", 
        SubscriptBox["r2", "g"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], "-", 
        RowBox[{
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}]}], ")"}], "2"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.456765429824294*^9, 3.4567705279192944`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", "demod", "]"}], "]"}], "//", 
  "TrigFactor"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"%", "/.", 
      RowBox[{"\[Phi]M", "\[Rule]", 
       RowBox[{"\[Phi]M", "+", 
        RowBox[{"2", 
         SubscriptBox["\[Phi]", "aux"]}], "-", 
        SubscriptBox["\[Phi]", "green"]}]}]}], "]"}], "//", "TrigToExp"}], "//",
    "PowerExpand"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"TrigToExp", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%", "/.", 
     RowBox[{"\[Phi]M", "\[Rule]", 
      RowBox[{"-", "alt"}]}]}], "]"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.4567599418742943`*^9, 3.4567599894762945`*^9}, {
   3.4567601437942944`*^9, 3.4567601717082944`*^9}, {3.4567607231612945`*^9, 
   3.4567607647532945`*^9}, {3.4567641475562944`*^9, 
   3.4567641644912944`*^9}, {3.4567644370392942`*^9, 3.456764440329294*^9}, {
   3.4567644768862944`*^9, 3.4567644953992944`*^9}, {3.4567645843472943`*^9, 
   3.456764627579294*^9}, {3.4567650101702943`*^9, 3.4567650880492945`*^9}, {
   3.4567651584832945`*^9, 3.456765161171294*^9}, {3.4567653243052945`*^9, 
   3.4567653328022947`*^9}, 3.4567677091902943`*^9, 3.4567677568342943`*^9, {
   3.4567679110332947`*^9, 3.4567679542942944`*^9}, {3.4567680257382946`*^9, 
   3.4567680277972946`*^9}, 3.4567680584182944`*^9, {3.4567682108792944`*^9, 
   3.4567682595242944`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", " ", "\[Eta]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["r1", "r"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubscriptBox["r1", "r"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"\[Phi]M", "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Phi]", "aux"]}], "+", 
         SubscriptBox["\[Phi]", "green"]}], "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Phi]", "-", "\[Phi]M", "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Phi]", "aux"]}], "-", 
          SubscriptBox["\[Phi]", "green"]}], "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"2", " ", "\[Phi]"}], "-", "\[Phi]M", "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Phi]", "aux"]}], "-", 
          SubscriptBox["\[Phi]", "green"]}], "]"}], " ", 
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
     SubscriptBox["t1", "g"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SubscriptBox["r1", "g"], " ", 
        SubscriptBox["r2", "g"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Sin", "[", 
          FractionBox["\[Phi]", "2"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["r1", "r"], " ", 
            SubscriptBox["r2", "r"]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          FractionBox["\[Phi]", "2"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SubscriptBox["r1", "r"], " ", 
            SubscriptBox["r2", "r"]}]}], ")"}]}]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Sin", "[", 
          FractionBox["\[Phi]", "2"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[ImaginaryI]", "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["r1", "r"], " ", 
            SubscriptBox["r2", "r"]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          FractionBox["\[Phi]", "2"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SubscriptBox["r1", "r"], " ", 
            SubscriptBox["r2", "r"]}]}], ")"}]}]}], ")"}], "2"]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.4567599445502944`*^9, 3.4567599909762945`*^9, 3.4567601720772943`*^9, 
   3.4567606745042944`*^9, {3.4567607459782944`*^9, 3.456760765362294*^9}, 
   3.4567641650582943`*^9, 3.4567644408632946`*^9, {3.4567644778742943`*^9, 
   3.4567644960952945`*^9}, {3.4567645847092943`*^9, 3.456764628027294*^9}, {
   3.4567649830492945`*^9, 3.4567650113722944`*^9}, {3.4567650414602947`*^9, 
   3.456765105369294*^9}, 3.4567651620282946`*^9, {3.4567653254432945`*^9, 
   3.4567653335842943`*^9}, 3.4567654761062946`*^9, 3.4567677104632945`*^9, 
   3.456767758364294*^9, 3.4567679202152944`*^9, 3.456767954770294*^9, 
   3.456768028435294*^9, 3.4567680591882944`*^9, {3.4567682140172944`*^9, 
   3.4567682600492945`*^9}, 3.4567705388872943`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]M"}]], " ", "\[Eta]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["r1", "r"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubscriptBox["r1", "r"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]M"}]]}], ")"}]}], 
       "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]"}]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]M"}]]}], ")"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Phi]"}]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]M"}]]}], ")"}], " ", 
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], " ", 
     SubscriptBox["t1", "g"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SubscriptBox["r1", "g"], " ", 
        SubscriptBox["r2", "g"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]"}]]}], ")"}], " ", 
         SubscriptBox["r1", "r"], " ", 
         SubscriptBox["r2", "r"]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
         SubsuperscriptBox["r1", "r", "2"], " ", 
         SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], "2"]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.4567599445502944`*^9, 3.4567599909762945`*^9, 3.4567601720772943`*^9, 
   3.4567606745042944`*^9, {3.4567607459782944`*^9, 3.456760765362294*^9}, 
   3.4567641650582943`*^9, 3.4567644408632946`*^9, {3.4567644778742943`*^9, 
   3.4567644960952945`*^9}, {3.4567645847092943`*^9, 3.456764628027294*^9}, {
   3.4567649830492945`*^9, 3.4567650113722944`*^9}, {3.4567650414602947`*^9, 
   3.456765105369294*^9}, 3.4567651620282946`*^9, {3.4567653254432945`*^9, 
   3.4567653335842943`*^9}, 3.4567654761062946`*^9, 3.4567677104632945`*^9, 
   3.456767758364294*^9, 3.4567679202152944`*^9, 3.456767954770294*^9, 
   3.456768028435294*^9, 3.4567680591882944`*^9, {3.4567682140172944`*^9, 
   3.4567682600492945`*^9}, 3.4567705389732943`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.4567599445502944`*^9, 3.4567599909762945`*^9, 3.4567601720772943`*^9, 
   3.4567606745042944`*^9, {3.4567607459782944`*^9, 3.456760765362294*^9}, 
   3.4567641650582943`*^9, 3.4567644408632946`*^9, {3.4567644778742943`*^9, 
   3.4567644960952945`*^9}, {3.4567645847092943`*^9, 3.456764628027294*^9}, {
   3.4567649830492945`*^9, 3.4567650113722944`*^9}, {3.4567650414602947`*^9, 
   3.456765105369294*^9}, 3.4567651620282946`*^9, {3.4567653254432945`*^9, 
   3.4567653335842943`*^9}, 3.4567654761062946`*^9, 3.4567677104632945`*^9, 
   3.456767758364294*^9, 3.4567679202152944`*^9, 3.456767954770294*^9, 
   3.456768028435294*^9, 3.4567680591882944`*^9, {3.4567682140172944`*^9, 
   3.4567682600492945`*^9}, 3.456770539442294*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Conjugate", "[", "Esum", "]"}], "]"}], ".", "Esum"}], "/.", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "aux"], "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "green"], "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], ")"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "\[LeftDoubleBracket]", 
   RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "//", "ComplexExpand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Coefficient", "[", 
   RowBox[{"%", ",", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Phi]", "+", 
      RowBox[{"t", " ", 
       SubscriptBox["\[Omega]", "S"]}]}], "]"}]}], "]"}], "/.", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[CurlyPhi]", "aux"], " ", 
    SubscriptBox["\[CurlyPhi]", "green"]}], "\[Rule]", "0", " ", 
   RowBox[{"(*", " ", 
    RowBox[{"slope", " ", "of", " ", "error", " ", "signal"}], " ", 
    "*)"}]}]}]}], "Input",
 CellChangeTimes->{{3.4560771628768*^9, 3.4560772006288*^9}, {
   3.4560772401280003`*^9, 3.4560772429828*^9}, {3.4560773995444*^9, 
   3.4560774746272*^9}, {3.4560790070931997`*^9, 3.4560791953384*^9}, {
   3.4567087466445746`*^9, 3.456708748082575*^9}, {3.4567088453665743`*^9, 
   3.4567088922745743`*^9}, {3.4567089365125747`*^9, 
   3.4567089427575746`*^9}, {3.4567089804135747`*^9, 
   3.4567089806235743`*^9}, {3.4567465323382945`*^9, 
   3.4567465704522943`*^9}, {3.456755930048294*^9, 3.4567559484932947`*^9}, 
   3.4567574749622946`*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, 
   3.456149887112*^9, 3.4566641215008945`*^9, 3.4567087523405743`*^9, 
   3.4567088821665745`*^9, 3.4567467611082945`*^9, 3.4567559924312944`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, 
   3.456149887112*^9, 3.4566641215008945`*^9, 3.4567087523405743`*^9, 
   3.4567088821665745`*^9, 3.4567467611082945`*^9, 3.4567559924322944`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"newprm", "=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["r1", "r"], "\[Rule]", "r1r"}], ",", 
       RowBox[{
        SubscriptBox["r2", "r"], "\[Rule]", "r2r"}]}], "}"}], "/.", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"r1r", "\[Rule]", "r1"}], ",", 
         RowBox[{"r2r", "\[Rule]", "r2"}]}], "}"}], "/.", "redOPO"}], ")"}]}],
     ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["r1", "g"], "\[Rule]", "r1g"}], ",", 
       RowBox[{
        SubscriptBox["r2", "g"], "\[Rule]", "r2g"}]}], "}"}], "/.", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"r1g", "\[Rule]", "r1"}], ",", 
         RowBox[{"r2g", "\[Rule]", "r2"}]}], "}"}], "/.", "greenOPO"}], 
      ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4567663472172947`*^9, 3.4567665037522945`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["r1", "r"], "\[Rule]", "0.99498743710662`"}], ",", 
   RowBox[{
    SubscriptBox["r2", "r"], "\[Rule]", "0.9219544457292888`"}], ",", 
   RowBox[{
    SubscriptBox["r1", "g"], "\[Rule]", "0.8366600265340756`"}], ",", 
   RowBox[{
    SubscriptBox["r2", "g"], "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4567663986022944`*^9, {3.4567664388892946`*^9, 3.4567664487292943`*^9}, 
   3.4567665041812944`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Cos", "[", "\[Phi]M", "]"}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Phi]", "-", "\[Phi]M"}], "]"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"]}], "+", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"2", " ", "\[Phi]"}], "-", "\[Phi]M"}], "]"}], " ", 
    SubsuperscriptBox["r1", "r", "2"], " ", 
    SubsuperscriptBox["r2", "r", "2"]}]}], "//", 
  "TrigExpand"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Phi]M", "]"}], ",", 
     RowBox[{"Cos", "[", "\[Phi]M", "]"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4567671173702946`*^9, 3.4567671680172944`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", "\[Phi]M", "]"}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
   RowBox[{"Cos", "[", "\[Phi]M", "]"}], " ", 
   SubscriptBox["r1", "r"], " ", 
   SubscriptBox["r2", "r"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
   RowBox[{"Sin", "[", "\[Phi]M", "]"}], " ", 
   SubscriptBox["r1", "r"], " ", 
   SubscriptBox["r2", "r"]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Phi]", "]"}], "2"], " ", 
   RowBox[{"Cos", "[", "\[Phi]M", "]"}], " ", 
   SubsuperscriptBox["r1", "r", "2"], " ", 
   SubsuperscriptBox["r2", "r", "2"]}], "-", 
  RowBox[{
   RowBox[{"Cos", "[", "\[Phi]M", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Phi]", "]"}], "2"], " ", 
   SubsuperscriptBox["r1", "r", "2"], " ", 
   SubsuperscriptBox["r2", "r", "2"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
   RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
   RowBox[{"Sin", "[", "\[Phi]M", "]"}], " ", 
   SubsuperscriptBox["r1", "r", "2"], " ", 
   SubsuperscriptBox["r2", "r", "2"]}]}]], "Output",
 CellChangeTimes->{3.4567671210942945`*^9, 3.456767168567294*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sin", "[", "\[Phi]M", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", "\[Phi]M", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", "\[Phi]", "]"}], "2"], " ", 
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}], "-", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Phi]", "]"}], "2"], " ", 
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.4567671210942945`*^9, 3.4567671685702944`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  FractionBox[
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
      SubscriptBox["r1", "r"], " ", 
      SubscriptBox["r2", "r"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", "\[Phi]", "]"}], "2"], " ", 
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}], "-", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Phi]", "]"}], "2"], " ", 
      SubsuperscriptBox["r1", "r", "2"], " ", 
      SubsuperscriptBox["r2", "r", "2"]}]}], ")"}], 
   RowBox[{"-", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}]], "]"}]], "Input",
 CellChangeTimes->{{3.4567672563392944`*^9, 3.456767273579294*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"Csc", "[", "\[Phi]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "\[Phi]"}], "]"}], " ", 
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.4567672739432945`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alt", "=", 
  RowBox[{"ArcTan", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"Csc", "[", "\[Phi]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "\[Phi]"}], "]"}], " ", 
        SubsuperscriptBox["r1", "r", "2"], " ", 
        SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
    RowBox[{"2", " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
        SubscriptBox["r1", "r"], " ", 
        SubscriptBox["r2", "r"]}]}], ")"}]}]], "]"}]}]], "Input",
 CellChangeTimes->{{3.4567673201962943`*^9, 3.4567673387742944`*^9}}],

Cell[BoxData[
 RowBox[{"ArcTan", "[", 
  FractionBox[
   RowBox[{
    RowBox[{"Csc", "[", "\[Phi]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "\[Phi]"}], "]"}], " ", 
       SubsuperscriptBox["r1", "r", "2"], " ", 
       SubsuperscriptBox["r2", "r", "2"]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}], ")"}]}]], "]"}]], "Output",
 CellChangeTimes->{{3.4567673246042943`*^9, 3.4567673392462945`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "\[Phi]M", "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Phi]", "-", "\[Phi]M"}], "]"}], " ", 
           SubscriptBox["r1", "r"], " ", 
           SubscriptBox["r2", "r"]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"2", " ", "\[Phi]"}], "-", "\[Phi]M"}], "]"}], " ", 
           SubsuperscriptBox["r1", "r", "2"], " ", 
           SubsuperscriptBox["r2", "r", "2"]}]}], "\[Equal]", "0"}], ",", 
        "\[Phi]M"}], "]"}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PowerExpand", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"#", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
     "&"}], "[", 
    RowBox[{"\[Phi]M", "/.", "sol"}], "]"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"#", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
    "&"}], "[", 
   RowBox[{"\[Phi]M", "/.", "sol"}], "]"}], "/.", 
  "newprm"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"%", ",", 
     RowBox[{"alt", "/.", "newprm"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", 
     RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.456765560027294*^9, 3.4567655726832943`*^9}, {
   3.4567661010872946`*^9, 3.4567661091772947`*^9}, {3.456766179876294*^9, 
   3.4567662554332943`*^9}, {3.4567663327282944`*^9, 
   3.4567663331882944`*^9}, {3.4567665134252944`*^9, 
   3.4567665538932943`*^9}, {3.4567665923122945`*^9, 
   3.4567666329622946`*^9}, {3.4567666997902946`*^9, 3.456766700548294*^9}, {
   3.4567667335882945`*^9, 3.4567667864032946`*^9}, 3.4567668390302944`*^9, {
   3.4567669020452943`*^9, 3.4567669428772945`*^9}, {3.456766990364294*^9, 
   3.4567670440752945`*^9}, {3.4567673430762944`*^9, 3.456767385197294*^9}, 
   3.4567674888342943`*^9}],

Cell[BoxData[
 RowBox[{"ArcCos", "[", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"Sin", "[", "\[Phi]", "]"}], " ", 
    SubscriptBox["r1", "r"], " ", 
    SubscriptBox["r2", "r"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
       SubscriptBox["r1", "r"], " ", 
       SubscriptBox["r2", "r"]}]}], ")"}]}], 
   RowBox[{"1", "-", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], " ", 
     SubscriptBox["r1", "r"], " ", 
     SubscriptBox["r2", "r"]}], "+", 
    RowBox[{
     SubsuperscriptBox["r1", "r", "2"], " ", 
     SubsuperscriptBox["r2", "r", "2"]}]}]], "]"}]], "Output",
 CellChangeTimes->{{3.4567669987492943`*^9, 3.4567670449732943`*^9}, {
   3.4567673465392942`*^9, 3.4567673858612947`*^9}, 3.4567674895972943`*^9}],

Cell[BoxData[
 RowBox[{"ArcCos", "[", 
  FractionBox[
   RowBox[{"1.8346661821704788`", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"0.9173330910852394`", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
    RowBox[{"Sin", "[", "\[Phi]", "]"}]}], 
   RowBox[{"1.8415`", "\[InvisibleSpace]", "-", 
    RowBox[{"1.8346661821704788`", " ", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}]}]}]], "]"}]], "Output",
 CellChangeTimes->{{3.4567669987492943`*^9, 3.4567670449732943`*^9}, {
   3.4567673465392942`*^9, 3.4567673858612947`*^9}, 3.4567674895992947`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtmXk01P/3xzGDUSKET0QlkiUhZSnuqwUtitAmFYq0KREShaSSJGQNWUO2
smd52Zcs2Y19nxFSEmOsv/f3nN9fcx7n9X7Pufd5n/ee+zrv7Rb3DC3ZWFhY
JlhZWP73e+I4z5Gl7Vwlhw2N9y5tZ8KBbJc/FHGuEsuNWql3RZggv30yQkiE
qyTgmrL0ID8TeJjVC0r8XCWxWyxFK0lMaE50T7Nm4yr5LSXK8XZsAS5Q5jZ3
DFNKKsy4pyWSFuBGdc+fjFhKSe/oTsOTigvgqZ0UaSVFKTF2Wiz6qMUA27ZF
/gABzpJkj6LoH8pz8P2yyPioAEdJ8NP+HIETs7BSnJyhsZm9ZO7UejbH2zMw
8nXm3RkucomYb9TlA9+nYX80R9ub9aSS81+KfpeRJ+GgRIvC6wXWkuWU5dOG
MzTY8pjH1WeCpUSD33Oz/79haPqgdMGqbw2vptsor3Pvhx/WmfR9BSt4MkPT
Rt6zAxJkmtUMipZw1rGRswlqjaAY1nT/QS0T2+u2/toRj+GlngMbs4SJe5t/
B1btwjC4Khr4NI+JVV9p/7FJKYa3127k+nxiYo/asz1NmUUwLb+6kvCcicl3
amS7ywogBcu97jnExAoKcRyU4VzYNeYVf/TbAr7jIbVlRTID3ILlVeu+LODg
pvHiCsN0oB5vqTmTtIDDnyUc+3ApDV6kiU1dCVnAfxpvRzy4mwI0xyzlRw4L
WG4xqbPoXSLErRvGqcoLOA96ZXt6P8Jy4YszKrIL+CQzUIlZHwXG93aPfNu+
gO/tjxk9PxgBpDYnjpqNC9h8gufETc4wsIjgPTU8zcCTL1LuDZzzh2/62f3W
NAZ+e+emOfm2H/CzXbr/u4+BT6sbHfVZ9YEyq4SA5XoGtudJ3nrI4DmIbNaT
elbBwC8F3ZgPHrnDg7qZHK5CBu6Szx8u1n4M312Dj/llMrB7CvLbEGoH2xU1
u4U+M3CIvthyXNcN0DP8GaQQy8AcYiGhtXxG4GT/3kgnnIEnDpxZUthyBGKD
Dm28EsDA58p8f8gJXYPGvF/1D18z8IFvV3U0v94HZnfoqzfPGPiT6Q3fJaoj
SK5o68Q/ZuAtmZ6GBmtPwPlQJG67zcBSUhfrLsd7Qfy1Ey5T1xj4W2TIh3FV
b2h6Pq9GNmVgUx39Rs3vb0D6++mve/UY+IiYkvoOR39oM1yL85dn4DN1mUfG
QkNhzf6zebIkA/tOndt0xiIcZIPPi5dtYeDy5+GK0bIR4NaTHjzDzcC8Kvcm
HS5/hN3XzbwNfs1jp8i8RpFfseD1sPQeT9o87l50MPrK9Rkmvmmzc3yZw+St
IfvnkgtA9HaBuaPPLP7pZqotMF0Pq9/54//YzuDYAoUK1+R2sANu45uMafxP
0OZlmngv5O1tKJnLnsAT1pmhPReHQFH4zTH+hAn8w9fudrjlECQu6jUpBE3g
4oELMedshyCktH7ghsMEZq2oFMcvh8BRv361a/8Ezvmoa30+dwj23647WJz7
E4uUP0qJEBiGrJjaPK/8cZxqFzsPNcOQzleVIVxEw45C0ppuW0fB8ArficHP
NLyQe7M/XnYU5pNNRxLDaNiANbi6bN8oHDw6K6jhRMPh25Ylhk+OQo3Dtsem
e2mYGc2ozXIchcEeZ+3opDFcf9LkTnDDKPAl7OmWDRrF9usfBGXYjkHWX2e7
Wc9RbJS7cjDw8RhcgCruQrtRXFEkuffO8zGIpJrCqTOj2GlUMmwhZAxk13vH
3eMexeI/f250w2Nw+P6oTZbHCI50fHxEYR0N7DRCSVr3hvEOZeFkwfc0CAwU
7T13ZRhb3t/xn1gEDbKmI7LunRrG+jpWs5viaTAfE2MZLTeM34TXHWvPooHT
+pRq8vgQDvBWyQhopcGT3uLXdWZD2Jkv1WpgAx0i9x+6Pqo/hF9OUN9TN9EB
+5UfXNEawtusGo5iUTqwaNf8UhAbwhqcXKeNZejwLLVZ379rEIfN8gkGH6HD
yyejAhcNB/H0St+Enj0dEqlWU7aHBrHpbWdPkjMdapV/VngrDmLmRf+J2Kd0
WEf/9bCQZxBnyejxRHvTQSRqOh2CBrDZ3ntCz6PoYGo0a2ZrP4A3j7q5esTR
IYJzgS/WcABbkTOcbiTRYdt9VnsO3gHsnK7OpH2lg9ShTWoNL/qxZPAD18wK
OljN/fdz1bIfe/+3a3y0hognSSxM8Wg/7tugar5UTwdZfunlAJZ+rDucu72j
jQ53quRSK/v78O1AxdxQKh1SnRWvMAr7sOskCwP10kFxRL3E5FEftj3Nwao+
QgfbYC1bn/N9eMf3Oe5XNDp8PXlEonhfH1bAH3UKftJhX5ae5/a/vTg7yyWr
4jcdHKzP7DNq6sXizevEwv/SIW/LOZpnWi/ur18SNZyjg8bzq8fGb/Vio3ec
ymaLhF4LrvFXTvbijLXTRm+X6XDhzge2drlevDjzOTF6lQ60gW9XT3L34g8z
Ze1BLOPw0KirsHSqB2vd/OJiwzYO5GrGZrWGHlwYy661izwO/hpCjmmpPVgl
NCevnH0ctqeptEn69uDZl6LeiHMcMrYbKYXb9OBfV0ZORVLGAd7b+vLp92Du
kfWRvVzj0Ejxm3yxpwdv+0LlX1o3Dpdd0o6t8vbgC4zaw8z14zD1uz7e/k83
Nl/0L+vgHofH1ybZJpu68UfTjVIBG8ZhXSeXmfmXbpwqrbW0m2ccQk7sKup8
142T3+9uSyBYulhH5PQD4vmQxYMrBOcoWTpWGHbjIPHSEkXecTga/6xNY283
DuH1H0cEt/4Xo/RFoBubkK0P7CbYwqfEV/pfF678Kqo1R7w/s9Y/GdHWhZd4
LtiFEOxmt3JsU3YXzhbzvSREMC9dNMH7fRcOdxi3tyHiizTRILE6dOGrdloH
PhLx7268YOZ4rguXcnHu+kzkV3jIsejX/i6cfOrkV18i/xPZ70WuC3fhzyEh
p08Q+nTtynLsZlCxhfFfmz5CT+sPLW0GVCqmXS/30OUYh3neGaXqPCoWUvwx
/4Kox/NnvG81Q6lYHCT2RRL12sTYPZX5iIpFHNniXxH1jL2ld1zWhIo1x/qT
jxP1Vu6/lfBRg4qdRSGxb4kOpWdekYRFqfiqyNelo0w6GFR+Mnuz1InPVxSy
PJ2nw4BaVRGptxOnd1Tzvp6lg03KqIhzYSdOu77hifUfOrwO2N5u5dqJW6Gt
MJDwqwgnUu673Im3eyhLD48R/eJ85a2RVifeYmMquTpEhyrz8ONorQMXNXGP
RnbR4Wx7fkLOQAc+Ltq6Q6KdDqPHqKTdJR2YejD3z/0mOrApChZvdifO3UpY
baro8C52r6ifeQe2GUiPFSkl+lfY0InjcAc+nCXu+7aADpqrvsqzbB34o6Rc
bWM6HeptU9/eHGnHTaXTxsFEv5uM1U0NlLdjmcGjUZKxdHCqp3yq92zHHY3o
66v3dOBE0uQjlu2Yr7vz7VVfOgRlapvna7fjkT+xZ+e96JAV5iGawNGOC2Tj
vC0c6fDbevnt05dt2FlNlCl8lg5taUobT1u14SX2gXHuk3T49s/Kb8vRNlyn
9t+5VEQHT7dmv/y1VpwzcN1zQpYOt6o4+F72teKqMxOinlvpoM998N25AuL8
DvSVCRB6hiS8m3VoxdIt7WIySzRY6+vhKzNuxWac6jtOTdNgdAefv59yK571
4L/CO0SD9PTH/runW7DOtWqOG5U0OFptEHDDsgXftwt6Jf+KBjIbvAT2H2nB
Tyw4ptY/ogGPUUEAeXsL5sxxv/HImgZd/VKB0b3N+Mda6Ic5bRrYzC8G9hg1
49YeHUPFpTEwOqgomKzUjLUm1BW16GOg5mH53om3GV/JW7arahkDEk/Te8G6
Jjxsq8lzIHEMQqTig/QPN2EXjfcPLfTGwPV2t5D4tib8OKF4dGbvGFRabFXo
WvqBjZZP3BsRGQMT538KAnY/cN1eYd4B2ig8T4pUfGHeiJseq3m1OIyCwT4u
JUmxRrxDV+/xhoujIFJqp1RKbcBPOavO+miMQgb1mPKSfgPWTPRyP7o0At2c
s3vvadXjUJfeRXG7EYgLuKzCvViHPyb9VFg8PQL3ttaoJGXXYZJTutmszAiQ
VSP2jcjX4Qdau9ll+4ZBwUpX9bzod9yrLP6TQ20YFma+qP7rqMW/dhxNU+Ie
hnLXLWrv/Gvx8MNMpxMDQ3Dh/YxaHVctbjI5+FTWYwieVYRrwEI1vsn1PaUj
fxDGG9UDLPOqcWinwsz+l4Nwuqtz8rVTNW58FvXC7uwgiEwLRFAXqvC+9tq5
WuoAZAj7rNkyK/Etgz/jn4T6QUhC9kJIfiXuMLyq6xXVB4/lazKKH1Ximnrp
ikipPtA5RLZYv1iBQ67+c9on0wt9t1wq4hbL8edtwTv713fD4YciYnXfyrHS
DkfThy5dkPg07+GMcznefnmzVcJPKtgH/tuptVSGN9TXTD7K74R1xXdedS6V
Ylf7UHRAvh3u16wbXikoxR0S6ZsXn7RBe0uihqRLKT5hm/vrRUMrfKSPTt5f
LsENd6n2Hy63gI3Etw+bFjHm0GipCvNpBHXV+VPmzhi3mmmJmY7XA1lPeS11
sRjfazZ6XaxeB+EPk811l4rwuWiLBzqF1VBTE7bTebkAf/WOkBFRK4GAvo7O
KpcCrLF6e+SMbSFc+cv/SmDlGzbvlF1rvpAHspz6Gmau33CKmks5ZWcWzIm+
nkxZyceV/esFfTPSoUSx+gPTNR8Lj7JJZfclgI826bTOah7W8eXLVIsLh/Mm
sOb/JA8vImqqvpIHSNx7nDGwmottsg+euNb2DH49yzWXf5qLG/4eydG+EQF5
IbP8j9ZysP/dA5VVGYmgX3b7IT9LDv4Tkk6/m5MDLoKmGtqsWfhXWW9+6PMq
0JUNmXznnolHUkWVZl1qgR/aPvSzZuLBs1k90171kGStt+bI9hXfXa63E7nV
DB0FByuSSRk4zTHpoL8CFbY8suj/y52O1UtieI/+6QIf55MqfvxpeI71roBA
YQ/cdhUb/C6Wgt9nt9dYPRgA2WelqkglERfGJ2+oSB2BJF8uuqz5R+x373eo
4JspUN429sivIRJ/op4Ybiv+Bfw7cqXqqB+IferBVc65aWjedckV/Q7B8qYr
f7hy/4CBSqy83JZ32CS1ptNOZxaaslQyKWbncUZkdI/exwVos0/RUv4CcFXU
Yu7PKSZEOGr/NPhwDZ78En/9aom4P8fxCxnZP4IPvpsHh88uwe0Dj+SNzXwA
WbHJWrCtQkfYrVu/Jf3A+Ybats7kVZgPDinO2uwP66InnKfOrIGq/z8rIAVB
378f9KxTLCjPKyXXuCMCjCULM7f6sCLqs+71InVRsGpvdVOsixW5IHLG74GP
EEj102VKsqEITWVydlsMyKaant6Vz4b6VX1ToDgBZtzfPPncQkI2++PPxeR9
glCD0qEuQTJaVSlkYc9MBOypX1dwnozElSeMv39KBodA6a6gTjK6Kq+zYvwu
DVRMAqQKqtnRwZAE3/mP6VBX1fXAmJ0DcXuQNupdyADX/Yvqdoc40M9f16J/
3fgClSe1G42zOVBMpWSF4otMOME+vPm4DyfyW2rzYeXNArNJOufnYk70ROn5
2ZagLGAI3Fst+82JLkWM0ewSsuHrywZ3pdMUdKL1ffpRhRy41F3mHPSYgtS4
dJwECd+x+3sfbfxEQTthHtE0c6F1T+C2wRYK2vQwgSu3Mhckc68fb12mILbP
51penMoDNffdBbriXOjPIEf4hfY8sIy4/cRlnoL6hXKvyVzOB+ap6ahvPyio
Qe+G/OJoPhx9SFNYSqKgQg/hue93voHv7cCzqs8pKDmvuij83zd46lZyydqc
grwkd+lrkgtBLehipe8WCrI3oQrz+BRCa0yeqeMSJ7LweznYL1AEPKyjmgd6
OBEsj9u67SiGzVZ+TQcjONHyT+Pv5ttLAK8Mkl/IcqJZcqrCCcsSWGDbnp3I
y4kmtrIHKCeVQOomYbNHcxyIejb7EkmpFPY/EdLcVM6BsksFf8WhMphdukNP
t+RAKb13z7zxLIPfFus0a/Q5UByjMvthTRmUR6tq3NHgQP67HZ7oGJTDtuDR
CV0+DmQT2sE7frUCeHefqf1ZwY4ssxTsm2Ir4HpsyPbFr+zI9IcXNY9eAW8q
zd2do9nRSXbV6Ff3KqHpnfkj/JQd7bINVpZ7WgVu69QOcx9iR1t9fgcJlFfB
53U3xU4rsyOhT7pLSxzV8FLd7vnEDnZE7mOU1/tWA3dBeqkMhR0NHbtw1iay
BlqPNys9byMjrTEX84a+GvhYxJIlV0tGYe7Rd+XFakG2XeEDfzEZGX6beD4R
XgvPJISLwxPJqEzONccq9Dss5F+ysncj/FsTXVZJ/Q4s5N/0eQcycr5e1Sj5
Xx3ofjjKl36XjJQjeOnDQXUgZlmWVHCJjGJ4YoSvBtaDkUF9504Noh+Sq3YU
t9bD5fVCSFWZjEx0J/eICTSAX9p8tr0sGfG7qRzredcAydb6ZDtRMno2U+V0
/m0jpEjWbrm+RkKDbyY9cxobQeVMZmb5AgkdlN34TpDnB7h3KFkf/0tC/ywu
JrX6/IA7x2REK8ZISHlibkpauwnYIx8ZWjSSkJkaxa7zehMM0yxN+mtIyNdL
hOnl2QQmwY29zuUkNCEB7LTyJhCKEm/hzyehmEsvxeION8PK2+re1HgSakoK
izWyaAaaphtzSzQJrTJSZEgezdDeoD376QMJmQQ277MobYbA2y73eQNJSKBB
5PQ21AJmQ6/6hDxJ6LDo7rYfV1ugJuuN8Hk3Erp/E0yePm2BhAuaZukuJFTP
ft2qv7gFNrOdu5XwkIQ8tVKffNBshao3t9hirUnoqw8m611uBaftd1CIJaFH
d7P3kksrbBItvhZjQejhOB9kUtgKnAYHf8+aEnqkQ/p/B9qAjf9WqIch8f9y
B/jvX24DKb23asP6JBT7af/D6qdtIMwehs6fIiHDqN0HHCraIOqTLcXtGAnJ
ispENtDaQBGd5N6rQ0JswZKsUlzt0BtAZl08QkJffEWrW0+1Q6u0jGkZkNDL
dcKycvfbIRVzC5drEnp78b/x8G+HY5bxtzsOkNDGJ1xGSp3tQBt3itqrRszL
u4x+X7MOWE4glgIlEtL5+fcQzaMDWp7ta9BTJCExy+k4zfgOSCky2jyhQMRv
OnZr6mcHjGzruG4sT0Jx1MGGI9yd0OLxaHCbHAk9Nu5VDFfohG9j8u+XZYj4
9Vrnj9t1wpT+3i+D0kT8NY0Xo993wkijQ9T4ThLqOvK9cCG3E5rfh7WtSpFQ
Bq7catDdCXHOssI7CH55oNTj03In7FMbUDgrSeSTWzi2Kk6Fxl9Bo4E7SEht
b96xc4eoYNxxim1YgoTosuk87F5U6HYWio3dTkLFCcm2polU0AtwwsIEB0kk
tGV+p4Kw7V2HkG1E/pHRqut/UWGteHuwFME6IhFhFrxdsFyWN1O8lYTEg0JW
8pW6YOqOzvnrBM/xBZrxGXeBrl9tqCDB9W/ells7dIGq7k6fFnFCD67XO0tC
uoDryTa2cIJdnnu9Ei7oAs/4c002BBuxekzZ9HXBsPfB+lMEy7q66letdcEd
Y6F6VYLZmE5fxSS6wSB6NkGe4G57e8GHR7uhuy5Z5X/85c89p3qrbsjTazu1
n+CXd2737HjVDZ5aVXUnCDYbt9J6/LkbrFn8Xt4kWO26RXRLQzdMzM9d8SeY
d/AyWfZPN/DduitbSTDt0sUb7vw90PL0v2pWIp/iTuPvVJUe4DIs4ztGcJCR
wW7F8z0gsrWHHkywzY+Tfi8e9YBZoL30DME6J3Vn+8N7oERJK92I0E+s+vC5
/cU94FrpfgUT/O+wVv6bwR5IXdsqqELoX1+svmWMrReebXmT+YVglxzF4QDd
XlA5aidfTdTPWFlee/JmLxRlhn6/QtRXLk068bBPLzzJH+lcJbg7XtxmpqkX
cq6v1Z8n/JHDkWKY+LcXOj/xr99A+Cnghrrq1U19kHlDf7WWYD0ZY5aG833w
/Xp/pMkuIr+UV/6J/X1g3LhVpI3wa9gGYcerLP3QpCNrUEH42dEm7pKQRD9E
DWg/LthNQoqKWNLTsh+sw9ZfKN5DQtGZ/3KuTvUDnWbcKqBCQk82eYQL8QzA
zv2V59T3EfPnIa9bw54BuJDBL225n4T4VWWPH7AbgKMJD81+EP3m+e1qj9Di
AGx8XrRziujPLLOxNdqzQUgb6LZXPU5CEnzyD8oCB0E599eh/BMk5Ff6YDQi
fhA2hrtoIz0SuivBUmtcPQjuNjczLxPzY+eoiH/ZuiFgH3/h23aWhEJuGEhG
vhsCz5dRAgnXiH60KTh2NmoYDr/+2+HmQcw/mLvOkz4Me5ZfHb9DzMN1G/e4
VxcPg8+Puj8mXsT7X2Ly1fuHocR7e/Ehb0Lff69kxcVG4EXLkacq/iT01/kC
Nz1sBGy4dx5OjCGhWy/mfjgFjcKZK0Y3wipJ6MLHPec/vKFBY1Eipy0/Gf3j
7DdPiqSB1BWt8j3EPuZ3z+dOTjoNapN64/8Ik1Gt1k/3pmYarH7VanASIyON
vpgUshAdWN+MScTsIqMtIkJsdyPpsCDDynkWyGggYDlFM30cIhsv8W+1ISOr
F7VsA00TQN+l+MmtiYzKPeXkfOqmIVlENsr0PTu6wjdWtuniDLj409sPWHCg
WY1qrSGHWdDeVbc1/zgnSr+3gWlxfw68s8B1RJqCploVGX+d5qDjiszDL3IU
JKtmPOfhPgevdduKn+6hoDiW8JkY/zm4FjekLaZKQWHvdk0MZ82B5cTO/0x1
KMgz80iPBXMOxp5/fjR+nYJMGI+KLDzm4foZ9wz1GAoKvhRR8Nd7Hv5Rn8jx
JVBQGy7J9wiYh8w901PjxD6m/5IzJyZuHnIEew6FfqGgo5vfpw1XzUN3maDc
SgkF7TmQEWWxngFuJi3ZzQMUdCeqNeKvAAMSIr0fpI4Q+xuJEe6xhQFa8g33
X9EpSLJeMyRmNwOuF1QpHv5NQSKX6/yG9RkQe8k5J2eVgs6XTvs+uMCAT+H3
HQPZuFCgFP8bNnMGxMh/cnzAwYV4py+8knjAgJV1eSp7eLiQnqHLi6/ODEgp
JM9s4OdC3jlRzw8/Y8BeL4fJKUEuVC1S/qzlNQPC31fvqN/MhchPae4WgQz4
6vo19LMYF7KxI501/8AAPvPqiOPbuRD1xrZdZnEMODx3s5lnKxc6bKq5dCWF
AWs2lGv3RblQioFJ4+Us4rykFTcLcyEhbcdo00IGrP/HNq68iQu5qQfaX6pg
gPGP+p6AjVzIWKJR5GIbA15JrZM+y8WFioUmf53vZUBr6c8n2excaNd6Sum5
UQaEHT8YK0jkuzx76IbxPwacOsdr2L5IQbGV2Zn6mxZAvlH5tOEUBR3mfj52
MHABPmT13JL+SkHuoTuOCwcyoXDdOmtdTQo6SX4qU/FqCRI0J2xPnuNEacfv
UqeTVuCwxcE4z4scSC0MVzbGr4GGq0zon9vsKM2iBQnRWFCwRsFW7puEf7cZ
yx36x4qW99S559wk9osRzmydP2zoeaN7bKYzGzqxiX3na1YyetIkl9fqwIoc
TqjsT2ZhR1wXHpenPWNBtYl/DSsX2ZHhtXGJYZk1sLZfPLd1HScqstysp7Fj
BcK1VRaNOCko7VL800GtJUhOPR9cvJ6CFraS1e/uX4I8wccqMhspSGMiZ5q5
ewk6xkptVv+jIKF/xvoCYkuw0Ut/JFGWggJFN9O1lxbBq+pW/copwodTU67J
uYvwQDc68lMgodtkwRdbxUVwT684wB9K3FNmcvhXpRfBT3ic6hJBQdzvx2y9
ty5CKl1BwJDw/e/jm+VieRZh/EXhi+VcCkqQfuzdNsWEKzWd98/0UNDnXLl1
qklMuKu4tKGQ8Llt0cWz5R+Z4BIi/nnnKHEvQklR+iFMCLW2HFsi6uQhOq5k
/YIJbZTZiwmEr9WTPU+HWjJh5L4QYyOJC30RvRIodZkJf6nqgY85uZB70Y+u
L8ZM4E1yazQgfFM+lnPt+xEmiPPF3S4gfOUqeCLx3AEmyD+qpuwkfKxZkzE1
rMyEA0MT8X6Ej0+1MBXvyTLh/79Ho2lOlYf/+x79fwlAJIc=
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwtmXc41f/7x+29ZxFFWpKkjJD7VJKkSaVS4WO1SGRFQ0ZDsiNRZpSi7JLb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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  GridLines->Automatic,
  PlotRange->
   NCache[{{-Pi, Pi}, {-1.5707962040952599`, 
     3.1412536932440465`}}, {{-3.141592653589793, 
    3.141592653589793}, {-1.5707962040952599`, 3.1412536932440465`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.4567669987492943`*^9, 3.4567670449732943`*^9}, {
   3.4567673465392942`*^9, 3.4567673858612947`*^9}, 3.4567674896442947`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AC signal", "Subsubsection",
 CellChangeTimes->{{3.4560792063364*^9, 3.4560792508744*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"y0", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Y", "[", "0", "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Phi]", "aux"], "\[Rule]", "0"}], ",", 
        RowBox[{
         SubscriptBox["\[Phi]", "green"], "\[Rule]", "0"}]}], "}"}]}], "//", 
     "ComplexExpand"}], "//", "Simplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4567685799072943`*^9, 3.4567685852272944`*^9}, {
  3.4567686733262944`*^9, 3.456768682522294*^9}, {3.456768770897294*^9, 
  3.4567687832092943`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.456708732344575*^9, 3.456708732509575*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TP", "=", 
   RowBox[{"(", GridBox[{
      {"0", 
       FractionBox[
        RowBox[{"k", " ", "\[Delta]l"}], "2"], 
       FractionBox[
        RowBox[{"k", " ", "\[Delta]l"}], "2"]},
      {
       FractionBox[
        RowBox[{"k", " ", "\[Delta]l"}], "2"], 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Omega]", " ", "L"}], "c"]}], "0"},
      {
       FractionBox[
        RowBox[{"k", " ", "\[Delta]l"}], "2"], "0", 
       FractionBox[
        RowBox[{"\[Omega]", " ", "L"}], "c"]}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P", "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "k", " ", "\[CapitalDelta]"}]], 
    RowBox[{"MatrixExp", "[", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "TP"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PP", "=", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "k", " ", "\[CapitalDelta]"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "3", "]"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "TP"}]}], ")"}]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"small", " ", "\[Omega]", " ", "and", " ", "\[Delta]l"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RT", "=", 
   RowBox[{"r1", " ", "r2", " ", 
    RowBox[{"P", " ", ".", "P"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RTT", "=", 
    RowBox[{"r1", " ", "r2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], "\[ImaginaryI]", " ", "k", " ", 
       "\[CapitalDelta]"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "3", "]"}], "-", 
       RowBox[{"2", "\[ImaginaryI]", " ", "TP"}]}], ")"}]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"small", " ", "\[Omega]", " ", "and", " ", "\[Delta]l"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cav", "=", 
   RowBox[{"t1", " ", 
    RowBox[{"Inverse", "[", 
     RowBox[{
      RowBox[{"IdentityMatrix", "[", "3", "]"}], "-", "RT"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cavv", "=", 
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"Series", "[", 
      RowBox[{"cav", ",", 
       RowBox[{"{", 
        RowBox[{"\[Omega]", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Delta]l", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "//",
     "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"refl", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "r1"}], " ", 
     RowBox[{"IdentityMatrix", "[", "3", "]"}]}], "+", 
    RowBox[{"t1", " ", "cavv"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trans", "=", 
   RowBox[{"cavv", " ", "t2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"det", "[", 
    RowBox[{"+", "1"}], "]"}], "=", 
   RowBox[{"(", GridBox[{
      {"0", "1", "0"},
      {"0", "0", "0"},
      {"1", "0", "0"}
     }], ")"}]}], ";", 
  RowBox[{
   RowBox[{"det", "[", 
    RowBox[{"-", "1"}], "]"}], "=", 
   RowBox[{"(", GridBox[{
      {"0", "0", "1"},
      {"1", "0", "0"},
      {"0", "0", "0"}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LaserPN", "=", 
   RowBox[{"(", GridBox[{
      {"1", 
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[CurlyPhi]", "2"]}], 
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[CurlyPhi]", "2"]}]},
      {
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[CurlyPhi]", "2"]}], "1", "0"},
      {
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[CurlyPhi]", "2"]}], "0", "1"}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ein", "=", 
   RowBox[{"LaserPN", ".", 
    RowBox[{"(", GridBox[{
       {"1"},
       {"0"},
       {"0"}
      }], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Erefp", "=", 
   RowBox[{"\[ImaginaryI]", " ", "rSB", "  ", "Ein"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Erefm", "=", 
   RowBox[{"\[ImaginaryI]", " ", "rSB", "  ", "Ein"}]}], ";"}]}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Electric Field", "Section",
 CellChangeTimes->{{3.4559752043442*^9, 3.4559752102254*^9}, {
  3.455975241285*^9, 3.4559752428606*^9}, {3.4559975049938*^9, 
  3.4559975163662*^9}}],

Cell[CellGroupData[{

Cell["DC Fields", "Subsection",
 CellChangeTimes->{{3.456667038544894*^9, 3.456667040354494*^9}}],

Cell[CellGroupData[{

Cell["Input", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
  3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979139477997`*^9, 
  3.4559979145406*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dcin", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"#", "\[LeftDoubleBracket]", 
     RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "&"}], "[", "Ein", 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.456667090633294*^9, {3.4566782718592944`*^9, 3.4566782784922943`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.4566670595424943`*^9, 3.4566782790392942`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transmission", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
   3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979275042*^9, 
   3.4559979302497997`*^9}, {3.4559990796577997`*^9, 3.455999081561*^9}, 
   3.4566670801032944`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dctrans", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"#", "\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "&"}], "[", 
       RowBox[{"trans", ".", "Ein"}], "]"}], "/.", 
      RowBox[{"\[CapitalDelta]", "\[Rule]", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}], "/.", 
     RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[CurlyPhi]", "\[Rule]", "0"}]}]}], " "}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"\[Phi]", "\[Rule]", "0"}]}]}], "Input",
 CellChangeTimes->{{3.4566670886520944`*^9, 3.4566671200080943`*^9}, {
  3.456678282362294*^9, 3.4566782843332944`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"t1", " ", "t2"}], 
  RowBox[{"1", "-", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "r1", " ", 
    "r2"}]}]]], "Output",
 CellChangeTimes->{3.4566671178240943`*^9, 3.4566782850832944`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"t1", " ", "t2"}], 
  RowBox[{"1", "-", 
   RowBox[{"r1", " ", "r2"}]}]]], "Output",
 CellChangeTimes->{3.4566671178240943`*^9, 3.4566782850852947`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reflection", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
   3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979275042*^9, 
   3.4559979302497997`*^9}, {3.4559990796577997`*^9, 3.455999081561*^9}, 
   3.4566670801032944`*^9, {3.4566671271216946`*^9, 3.4566671318328943`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dcrefl", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"#", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "&"}], "[", 
           RowBox[{"refl", ".", "Ein"}], "]"}], "/.", 
          RowBox[{"\[CapitalDelta]", "\[Rule]", 
           RowBox[{
            FractionBox["1", 
             RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}], "/.", 
         RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
        RowBox[{"\[CurlyPhi]", "\[Rule]", "0"}]}], "//", "Together"}], "//", 
      "Simplify"}], ")"}], "/.", 
    RowBox[{
     SuperscriptBox["t1", "2"], "\[Rule]", 
     RowBox[{"1", "-", 
      SuperscriptBox["r1", "2"]}]}]}], "//", 
   "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"\[Phi]", "\[Rule]", "0"}]}]}], "Input",
 CellChangeTimes->{
  3.4566670925676947`*^9, {3.4566671366064944`*^9, 3.4566672126408944`*^9}, {
   3.456678288133294*^9, 3.4566782897742944`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "r1", "+", 
      SuperscriptBox["r1", "2"]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["r1", "2"], " ", "r2"}]}], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], "-", 
   RowBox[{"r1", " ", "r2"}]}]]], "Output",
 CellChangeTimes->{{3.4566671374020944`*^9, 3.4566672131244946`*^9}, 
   3.4566782905032945`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "-", "r1", "-", 
   SuperscriptBox["r1", "2"], "+", 
   RowBox[{
    SuperscriptBox["r1", "2"], " ", "r2"}]}], 
  RowBox[{"1", "-", 
   RowBox[{"r1", " ", "r2"}]}]]], "Output",
 CellChangeTimes->{{3.4566671374020944`*^9, 3.4566672131244946`*^9}, 
   3.4566782905052943`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inside cavity", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
   3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979275042*^9, 
   3.4559979302497997`*^9}, {3.4559990796577997`*^9, 3.455999081561*^9}, 
   3.4566670801032944`*^9, {3.4566671271216946`*^9, 3.4566671318328943`*^9}, {
   3.456667225604494*^9, 3.4566672297852945`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dccav", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "&"}], "[", 
      RowBox[{"cav", ".", "Ein"}], "]"}], "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"\[CurlyPhi]", "\[Rule]", "0"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"\[Phi]", "\[Rule]", "0"}]}]}], "Input",
 CellChangeTimes->{
  3.4566670925676947`*^9, {3.4566671366064944`*^9, 3.4566672578808947`*^9}, {
   3.4566783658382945`*^9, 3.4566783680882945`*^9}}],

Cell[BoxData[
 FractionBox["t1", 
  RowBox[{"1", "-", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "r1", " ", 
    "r2"}]}]]], "Output",
 CellChangeTimes->{{3.4566671374020944`*^9, 3.456667258426894*^9}, 
   3.4566783686822944`*^9}],

Cell[BoxData[
 FractionBox["t1", 
  RowBox[{"1", "-", 
   RowBox[{"r1", " ", "r2"}]}]]], "Output",
 CellChangeTimes->{{3.4566671374020944`*^9, 3.456667258426894*^9}, 
   3.4566783686842947`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field Equations", "Subsection",
 CellChangeTimes->{{3.4559752043442*^9, 3.4559752102254*^9}, {
  3.455975241285*^9, 3.4559752428606*^9}, {3.4559975049938*^9, 
  3.4559975163662*^9}, {3.4560752147332*^9, 3.4560752172448*^9}, {
  3.4560753171628*^9, 3.4560753229035997`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fieldTrans", "[", 
   RowBox[{"l_List", "?", "MatrixQ"}], "]"}], ":=", 
  RowBox[{"fieldTrans", "[", 
   RowBox[{"First", "/@", "l"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fieldTrans", "[", 
   RowBox[{"l_List", "?", "VectorQ"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"l", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "-", 
    RowBox[{
     RowBox[{"l", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
     "\[Conjugate]"}]}], 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
    "l", "\[LeftDoubleBracket]", "1", 
     "\[RightDoubleBracket]"}]}]]}]}], "Input",
 CellChangeTimes->{{3.4566801637262945`*^9, 3.456680163770294*^9}, {
   3.4566810147492943`*^9, 3.456681047645294*^9}, {3.456681149079294*^9, 
   3.456681264980294*^9}, {3.4566813035282946`*^9, 3.456681365107294*^9}, 
   3.4566814000872946`*^9, {3.4566814419812946`*^9, 3.4566814648822947`*^9}, {
   3.4566815268402944`*^9, 3.4566815472792945`*^9}, {3.4566821706692944`*^9, 
   3.4566821900842943`*^9}, {3.4566822252052946`*^9, 3.4566822717202945`*^9}}],

Cell[CellGroupData[{

Cell["Input", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
  3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979139477997`*^9, 
  3.4559979145406*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fieldTrans", "[", "Ein", "]"}], "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "//", "ComplexExpand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Abs", "[", 
    FractionBox["%", "\[CurlyPhi]"], "]"}], "//", "ComplexExpand"}], "//", 
  "PowerExpand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Arg", "[", 
   FractionBox["%%", "\[CurlyPhi]"], "]"}], "//", "ComplexExpand"}]}], "Input",
 CellChangeTimes->{{3.455996878061*^9, 3.4559971512482*^9}, {
   3.455997183275*^9, 3.455997314627*^9}, {3.455997421955*^9, 
   3.4559974363382*^9}, {3.4559975314514*^9, 3.455997538955*^9}, 
   3.4559976876542*^9, {3.455997745967*^9, 3.4559977469342003`*^9}, {
   3.4566646121364946`*^9, 3.4566646131816945`*^9}, {3.4566646939740944`*^9, 
   3.4566647013372946`*^9}, 3.4566670626000943`*^9, {3.4566815129412947`*^9, 
   3.4566815133592944`*^9}, {3.4566815591022944`*^9, 
   3.4566816053942947`*^9}, {3.4566819932952943`*^9, 3.4566820018152943`*^9}}],

Cell[BoxData["\[CurlyPhi]"], "Output",
 CellChangeTimes->{
  3.455997688091*^9, 3.455997747605*^9, 3.456149883758*^9, 
   3.4566641180220947`*^9, 3.4566646140708942`*^9, 3.4566647111028943`*^9, 
   3.456667063130494*^9, 3.456681514388294*^9, {3.4566815505312943`*^9, 
   3.4566816229082947`*^9}, {3.4566819957222943`*^9, 3.4566820022622943`*^9}, 
   3.4566821766492944`*^9, {3.4566822101252947`*^9, 3.4566822745522947`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.455997688091*^9, 3.455997747605*^9, 3.456149883758*^9, 
   3.4566641180220947`*^9, 3.4566646140708942`*^9, 3.4566647111028943`*^9, 
   3.456667063130494*^9, 3.456681514388294*^9, {3.4566815505312943`*^9, 
   3.4566816229082947`*^9}, {3.4566819957222943`*^9, 3.4566820022622943`*^9}, 
   3.4566821766492944`*^9, {3.4566822101252947`*^9, 3.456682274553294*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.455997688091*^9, 3.455997747605*^9, 3.456149883758*^9, 
   3.4566641180220947`*^9, 3.4566646140708942`*^9, 3.4566647111028943`*^9, 
   3.456667063130494*^9, 3.456681514388294*^9, {3.4566815505312943`*^9, 
   3.4566816229082947`*^9}, {3.4566819957222943`*^9, 3.4566820022622943`*^9}, 
   3.4566821766492944`*^9, {3.4566822101252947`*^9, 3.4566822745552945`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transmission (phase)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
  3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979275042*^9, 
  3.4559979302497997`*^9}, {3.4559990796577997`*^9, 3.455999081561*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fieldTrans", "[", 
      RowBox[{"trans", ".", "Ein"}], "]"}], "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "//", "ComplexExpand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   FractionBox["%", "\[CurlyPhi]"], ",", "\[Omega]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"(", 
      RowBox[{"%", "-", "1"}], ")"}], "\[ImaginaryI]"], 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.4566789051182947`*^9, 3.456678905699294*^9}, {
  3.456681646192294*^9, 3.4566816709312944`*^9}, {3.4566817820752945`*^9, 
  3.456681848022294*^9}, {3.4566818933612947`*^9, 3.4566819275622945`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[CurlyPhi]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], "+", 
     RowBox[{
     "2", " ", "\[ImaginaryI]", " ", "L", " ", "r1", " ", "r2", " ", 
      "\[Omega]"}]}], ")"}]}], 
  RowBox[{"c", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"r1", " ", "r2"}]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.4566789068892946`*^9, {3.4566816481112947`*^9, 3.456681671522294*^9}, {
   3.4566817855782948`*^9, 3.4566817942602944`*^9}, {3.4566818346802945`*^9, 
   3.4566818486772947`*^9}, {3.456681896015294*^9, 3.456681928034294*^9}, {
   3.4566822540382943`*^9, 3.4566822762712946`*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{
   "2", " ", "\[ImaginaryI]", " ", "L", " ", "r1", " ", "r2", " ", 
    "\[Omega]"}], 
   RowBox[{"c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.4566789068892946`*^9, {3.4566816481112947`*^9, 3.456681671522294*^9}, {
   3.4566817855782948`*^9, 3.4566817942602944`*^9}, {3.4566818346802945`*^9, 
   3.4566818486772947`*^9}, {3.456681896015294*^9, 3.456681928034294*^9}, {
   3.4566822540382943`*^9, 3.4566822762732944`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"F", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", "\[Omega]"}], 
   RowBox[{"FSR", " ", "\[Pi]"}]]}]], "Output",
 CellChangeTimes->{
  3.4566789068892946`*^9, {3.4566816481112947`*^9, 3.456681671522294*^9}, {
   3.4566817855782948`*^9, 3.4566817942602944`*^9}, {3.4566818346802945`*^9, 
   3.4566818486772947`*^9}, {3.456681896015294*^9, 3.456681928034294*^9}, {
   3.4566822540382943`*^9, 3.4566822762752943`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transmission (length)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
  3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979275042*^9, 
  3.4559979302497997`*^9}, {3.4559990796577997`*^9, 3.4559990897198*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fieldTrans", "[", 
      RowBox[{"trans", ".", "Ein"}], "]"}], "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[CurlyPhi]", "\[Rule]", "0"}]}], "//", "ComplexExpand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"F", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{"r1", " ", "r2"}]]}]], 
     FractionBox["%", "\[Delta]l"]}], "]"}], ",", "\[Omega]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{
        "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]], "&"}],
      "[", 
     RowBox[{"CoefficientList", "[", 
      RowBox[{"%", ",", "\[Omega]"}], "]"}], "]"}], 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.4559973759974003`*^9, 3.4559973945926*^9}, 
   3.4559974433894*^9, {3.4559975546174*^9, 3.4559975549294*^9}, {
   3.4559979409826*^9, 3.455997941435*^9}, 3.4559989117706003`*^9, {
   3.455998981097*^9, 3.4559989867286*^9}, {3.4559991120746*^9, 
   3.4559991209666*^9}, {3.4559991875474*^9, 3.4559991965174*^9}, {
   3.4566822925242944`*^9, 3.456682316784294*^9}, {3.4566824145642943`*^9, 
   3.4566824149222946`*^9}, {3.4566824928822947`*^9, 3.4566825168392944`*^9}, 
   3.4566825564572945`*^9, {3.4566826045522947`*^9, 3.4566827099982944`*^9}, 
   3.4566827675172944`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "k", " ", "r1", " ", "r2", " ", "\[Delta]l", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "L", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]"}]}], ")"}]}], 
  RowBox[{"c", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], "2"]}]]], "Output",
 CellChangeTimes->{{3.455997379913*^9, 3.4559973950917997`*^9}, 
   3.4559974439978*^9, 3.4559975558342*^9, 3.4559979425425997`*^9, 
   3.4559982851498003`*^9, 3.4559989130966*^9, {3.4559989820642*^9, 
   3.4559989872122*^9}, {3.4559991125894003`*^9, 3.4559991215906*^9}, 
   3.4559991972662*^9, 3.4561498840076*^9, 3.4566641182092943`*^9, {
   3.4566822787162943`*^9, 3.456682317522294*^9}, 3.4566824153422947`*^9, {
   3.4566824994372945`*^9, 3.4566825172972946`*^9}, {3.456682620013294*^9, 
   3.4566826250142946`*^9}, {3.4566826699982944`*^9, 3.456682712244294*^9}, 
   3.4566827681542945`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "F", " ", "k", " ", 
     SqrtBox[
      RowBox[{"r1", " ", "r2"}]]}], "\[Pi]"]}], "-", 
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "F", " ", "k", " ", "L", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]"}], 
   RowBox[{"c", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.455997379913*^9, 3.4559973950917997`*^9}, 
   3.4559974439978*^9, 3.4559975558342*^9, 3.4559979425425997`*^9, 
   3.4559982851498003`*^9, 3.4559989130966*^9, {3.4559989820642*^9, 
   3.4559989872122*^9}, {3.4559991125894003`*^9, 3.4559991215906*^9}, 
   3.4559991972662*^9, 3.4561498840076*^9, 3.4566641182092943`*^9, {
   3.4566822787162943`*^9, 3.456682317522294*^9}, 3.4566824153422947`*^9, {
   3.4566824994372945`*^9, 3.4566825172972946`*^9}, {3.456682620013294*^9, 
   3.4566826250142946`*^9}, {3.4566826699982944`*^9, 3.456682712244294*^9}, 
   3.4566827681562943`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]]}]]}]], "Output",
 CellChangeTimes->{{3.455997379913*^9, 3.4559973950917997`*^9}, 
   3.4559974439978*^9, 3.4559975558342*^9, 3.4559979425425997`*^9, 
   3.4559982851498003`*^9, 3.4559989130966*^9, {3.4559989820642*^9, 
   3.4559989872122*^9}, {3.4559991125894003`*^9, 3.4559991215906*^9}, 
   3.4559991972662*^9, 3.4561498840076*^9, 3.4566641182092943`*^9, {
   3.4566822787162943`*^9, 3.456682317522294*^9}, 3.4566824153422947`*^9, {
   3.4566824994372945`*^9, 3.4566825172972946`*^9}, {3.456682620013294*^9, 
   3.4566826250142946`*^9}, {3.4566826699982944`*^9, 3.456682712244294*^9}, 
   3.4566827681812944`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transmission (phase, off-resonant)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
  3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979275042*^9, 
  3.4559979302497997`*^9}, {3.4559990796577997`*^9, 3.455999081561*^9}, {
  3.4560004569505997`*^9, 3.4560004602265997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fieldTrans", "[", 
      RowBox[{"trans", ".", "Ein"}], "]"}], "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "//", "ComplexExpand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "/@", 
  RowBox[{"TrigToExp", "/@", 
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      FractionBox["%", "\[CurlyPhi]"], "]"}], ",", "\[Omega]"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"%", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"%", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]], 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{
  3.4566828027152944`*^9, {3.4566862134502945`*^9, 3.4566862218322945`*^9}, {
   3.4566862690902944`*^9, 3.456686319166294*^9}, {3.4566863950042944`*^9, 
   3.4566864076632943`*^9}, {3.4566864644192944`*^9, 3.4566864709382944`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"c", "+", 
      RowBox[{"2", " ", "c", " ", 
       SuperscriptBox["r1", "2"], " ", 
       SuperscriptBox["r2", "2"]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "L", " ", 
       SuperscriptBox["r1", "2"], " ", 
       SuperscriptBox["r2", "2"], " ", "\[Omega]"}], "-", 
      RowBox[{"r1", " ", "r2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "L", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"]}]}], ")"}], " ", "\[Omega]"}]}], ")"}],
        " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{"c", " ", 
       SuperscriptBox["r1", "2"], " ", 
       SuperscriptBox["r2", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "\[Phi]"}], "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[CurlyPhi]"}], " ", 
       RowBox[{"Cos", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[CurlyPhi]", " ", 
       RowBox[{"Sin", "[", 
        FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"c", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox["r1", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "-", 
       RowBox[{"2", " ", "r1", " ", "r2", " ", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}]}]}], ")"}], "2"]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.4566828034702945`*^9, 3.4566862221902943`*^9, {3.4566862705032945`*^9, 
   3.456686281237294*^9}, 3.4566863259952946`*^9, {3.456686399388294*^9, 
   3.4566864083002944`*^9}, 3.4566864722382946`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "r1", " ", 
       "r2"}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", "r2"}]}], 
     RowBox[{"2", "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", 
       "r2"}]}]]}], ",", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "L", " ", "r1", " ", "r2", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", "r2"}], 
       "+", 
       RowBox[{
        SuperscriptBox["r1", "2"], " ", 
        SuperscriptBox["r2", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SuperscriptBox["r1", "2"], " ", 
           SuperscriptBox["r2", "2"]}]}], ")"}]}]}], ")"}]}], 
    RowBox[{"c", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]]}], "+", 
       RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", "r2"}]}],
        ")"}], "2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4566828034702945`*^9, 3.4566862221902943`*^9, {3.4566862705032945`*^9, 
   3.456686281237294*^9}, 3.4566863259952946`*^9, {3.456686399388294*^9, 
   3.4566864083002944`*^9}, 3.4566864722602944`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "F", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", "r2"}], 
      "+", 
      RowBox[{
       SuperscriptBox["r1", "2"], " ", 
       SuperscriptBox["r2", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SuperscriptBox["r1", "2"], " ", 
          SuperscriptBox["r2", "2"]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"FSR", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]]}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", "r2"}]}], 
     ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]]}], "+", 
      RowBox[{"r1", " ", "r2"}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]"}]], " ", "r1", " ", 
       "r2"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.4566828034702945`*^9, 3.4566862221902943`*^9, {3.4566862705032945`*^9, 
   3.456686281237294*^9}, 3.4566863259952946`*^9, {3.456686399388294*^9, 
   3.4566864083002944`*^9}, 3.4566864723352947`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}], "+", 
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]]}]}], 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"#", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]], "&"}], "[", 
      RowBox[{"trans", ".", "Ein"}], "]"}], "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "//", "ComplexExpand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"t", "\[Rule]", "0"}]}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"%%", "/.", 
      RowBox[{"t", "\[Rule]", 
       FractionBox["\[Pi]", 
        RowBox[{"2", "\[Omega]"}]]}]}], "%"], 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.455996878061*^9, 3.4559971512482*^9}, {
   3.455997183275*^9, 3.455997314627*^9}, {3.455997421955*^9, 
   3.4559974363382*^9}, {3.4559975314514*^9, 3.455997538955*^9}, {
   3.4559979355538*^9, 3.4559979361154003`*^9}, {3.4559981681809998`*^9, 
   3.4559981734694*^9}, 3.4559982061514*^9, 3.4560004724102*^9, {
   3.4560005461826*^9, 3.4560005854322*^9}, {3.456664810084894*^9, 
   3.4566648157944946`*^9}, 3.456677854093294*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"t1", " ", "t2"}], 
  RowBox[{"1", "-", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "r1", " ", 
    "r2"}]}]]], "Output",
 CellChangeTimes->{
  3.455996897171*^9, {3.4559969660606003`*^9, 3.4559971518254004`*^9}, {
   3.4559971967534*^9, 3.4559972012306004`*^9}, {3.4559972332262*^9, 
   3.455997261743*^9}, {3.4559972977166*^9, 3.4559973151106*^9}, 
   3.4559974371806*^9, 3.4559975400313997`*^9, 3.4559979367394*^9, {
   3.4559981690702*^9, 3.4559981739842*^9}, 3.4559982067441998`*^9, 
   3.4560004752494*^9, {3.4560005472122*^9, 3.4560005865866003`*^9}, 
   3.4561498843196*^9, 3.4566641185368943`*^9, 3.4566648168084946`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[CurlyPhi]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"c", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", " ", "\[Omega]"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r1", " ", "r2"}], "-", 
        RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", "L", " ", "r1", " ", "r2", " ", "\[Omega]", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}], 
  RowBox[{"c", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r1", " ", "r2"}], "-", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.455996897171*^9, {3.4559969660606003`*^9, 3.4559971518254004`*^9}, {
   3.4559971967534*^9, 3.4559972012306004`*^9}, {3.4559972332262*^9, 
   3.455997261743*^9}, {3.4559972977166*^9, 3.4559973151106*^9}, 
   3.4559974371806*^9, 3.4559975400313997`*^9, 3.4559979367394*^9, {
   3.4559981690702*^9, 3.4559981739842*^9}, 3.4559982067441998`*^9, 
   3.4560004752494*^9, {3.4560005472122*^9, 3.4560005865866003`*^9}, 
   3.4561498843196*^9, 3.4566641185368943`*^9, 3.4566648168396945`*^9}],

Cell[BoxData["\[CurlyPhi]"], "Output",
 CellChangeTimes->{
  3.455996897171*^9, {3.4559969660606003`*^9, 3.4559971518254004`*^9}, {
   3.4559971967534*^9, 3.4559972012306004`*^9}, {3.4559972332262*^9, 
   3.455997261743*^9}, {3.4559972977166*^9, 3.4559973151106*^9}, 
   3.4559974371806*^9, 3.4559975400313997`*^9, 3.4559979367394*^9, {
   3.4559981690702*^9, 3.4559981739842*^9}, 3.4559982067441998`*^9, 
   3.4560004752494*^9, {3.4560005472122*^9, 3.4560005865866003`*^9}, 
   3.4561498843196*^9, 3.4566641185368943`*^9, 3.456664816855294*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"F", " ", 
   SqrtBox[
    RowBox[{"r1", " ", "r2"}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]"}], 
  RowBox[{"FSR", " ", "\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r1", " ", "r2"}], "-", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.455996897171*^9, {3.4559969660606003`*^9, 3.4559971518254004`*^9}, {
   3.4559971967534*^9, 3.4559972012306004`*^9}, {3.4559972332262*^9, 
   3.455997261743*^9}, {3.4559972977166*^9, 3.4559973151106*^9}, 
   3.4559974371806*^9, 3.4559975400313997`*^9, 3.4559979367394*^9, {
   3.4559981690702*^9, 3.4559981739842*^9}, 3.4559982067441998`*^9, 
   3.4560004752494*^9, {3.4560005472122*^9, 3.4560005865866003`*^9}, 
   3.4561498843196*^9, 3.4566641185368943`*^9, 3.4566648168864946`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transmission (length, off-resonant)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
  3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979275042*^9, 
  3.4559979302497997`*^9}, {3.4559990796577997`*^9, 3.4559990897198*^9}, {
  3.4560008786584*^9, 3.456000882808*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}], "+", 
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]]}]}], 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"#", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]], "&"}], "[", 
      RowBox[{"trans", ".", "Ein"}], "]"}], "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}], "/.", 
    RowBox[{"\[CurlyPhi]", "\[Rule]", "0"}]}], "//", "ComplexExpand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{"t", "\[Rule]", "0"}]}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"%%", "/.", 
      RowBox[{"t", "\[Rule]", 
       FractionBox["\[Pi]", 
        RowBox[{"2", "\[Omega]"}]]}]}], "%"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"F", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
       RowBox[{"\[Pi]", 
        SqrtBox[
         RowBox[{"r1", " ", "r2"}]]}]], ")"}], "2"]}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.4559973759974003`*^9, 3.4559973945926*^9}, 
   3.4559974433894*^9, {3.4559975546174*^9, 3.4559975549294*^9}, {
   3.4559979409826*^9, 3.455997941435*^9}, 3.4559989117706003`*^9, {
   3.455998981097*^9, 3.4559989867286*^9}, {3.4559991120746*^9, 
   3.4559991209666*^9}, {3.4559991875474*^9, 3.4559991965174*^9}, 
   3.4560008896408*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", "k", " ", "r1", " ", "r2", " ", "\[Delta]l", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r1", " ", "r2"}], "-", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"L", " ", "\[Omega]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r1", " ", "r2"}], "+", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"c", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "r1"}], " ", "r2"}], "+", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], "2"]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.455997379913*^9, 3.4559973950917997`*^9}, 
   3.4559974439978*^9, 3.4559975558342*^9, 3.4559979425425997`*^9, 
   3.4559982851498003`*^9, 3.4559989130966*^9, {3.4559989820642*^9, 
   3.4559989872122*^9}, {3.4559991125894003`*^9, 3.4559991215906*^9}, 
   3.4559991972662*^9, 3.4560008909667997`*^9, 3.4561498847876*^9, 
   3.4566641190048943`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "F", " ", "k", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Delta]l"}], 
   RowBox[{"\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r1", " ", "r2"}], "-", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.455997379913*^9, 3.4559973950917997`*^9}, 
   3.4559974439978*^9, 3.4559975558342*^9, 3.4559979425425997`*^9, 
   3.4559982851498003`*^9, 3.4559989130966*^9, {3.4559989820642*^9, 
   3.4559989872122*^9}, {3.4559991125894003`*^9, 3.4559991215906*^9}, 
   3.4559991972662*^9, 3.4560008909667997`*^9, 3.4561498847876*^9, 
   3.456664119067294*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r1", " ", "r2"}], "+", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], 
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r1", " ", "r2"}], "-", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.455997379913*^9, 3.4559973950917997`*^9}, 
   3.4559974439978*^9, 3.4559975558342*^9, 3.4559979425425997`*^9, 
   3.4559982851498003`*^9, 3.4559989130966*^9, {3.4559989820642*^9, 
   3.4559989872122*^9}, {3.4559991125894003`*^9, 3.4559991215906*^9}, 
   3.4559991972662*^9, 3.4560008909667997`*^9, 3.4561498847876*^9, 
   3.4566641190984945`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reflection (phase)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
  3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979275042*^9, 
  3.4559979302497997`*^9}, {3.4559990796577997`*^9, 3.455999081561*^9}, {
  3.456058559502*^9, 3.4560585610776*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "&"}], "[", 
      RowBox[{"refl", ".", "Ein"}], "]"}], "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"\[CurlyPhi]", "\[Rule]", "0"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"DC", " ", "field"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}], "+", 
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]]}]}], 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"#", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]], "&"}], "[", 
      RowBox[{"refl", ".", "Ein"}], "]"}], "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "//", "ComplexExpand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"%%", "/.", 
       RowBox[{"t", "\[Rule]", 
        FractionBox["\[Pi]", 
         RowBox[{"2", "\[Omega]"}]]}]}], "%"], 
     FractionBox[
      RowBox[{"F", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "/.", 
   RowBox[{
    SuperscriptBox["t1", "2"], "\[Rule]", 
    RowBox[{"1", "-", 
     SuperscriptBox["r1", "2"]}]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.455996878061*^9, 3.4559971512482*^9}, {
   3.455997183275*^9, 3.455997314627*^9}, {3.455997421955*^9, 
   3.4559974363382*^9}, {3.4559975314514*^9, 3.455997538955*^9}, {
   3.4559979355538*^9, 3.4559979361154003`*^9}, {3.4559981681809998`*^9, 
   3.4559981734694*^9}, 3.4559982061514*^9, {3.4560585677544003`*^9, 
   3.4560586530708*^9}, {3.4560590360508003`*^9, 3.4560590526336*^9}, {
   3.4566648264024944`*^9, 3.456664851986494*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "r1"}], "+", 
  FractionBox[
   SuperscriptBox["t1", "2"], 
   RowBox[{"1", "-", 
    RowBox[{"r1", " ", "r2"}]}]]}]], "Output",
 CellChangeTimes->{
  3.455996897171*^9, {3.4559969660606003`*^9, 3.4559971518254004`*^9}, {
   3.4559971967534*^9, 3.4559972012306004`*^9}, {3.4559972332262*^9, 
   3.455997261743*^9}, {3.4559972977166*^9, 3.4559973151106*^9}, 
   3.4559974371806*^9, 3.4559975400313997`*^9, 3.4559979367394*^9, {
   3.4559981690702*^9, 3.4559981739842*^9}, 3.4559982067441998`*^9, 
   3.4560585686436*^9, {3.4560586109820004`*^9, 3.4560586539444*^9}, {
   3.456059036784*^9, 3.456059058624*^9}, 3.4561498850528*^9, 
   3.4566641192700944`*^9, 3.4566648527664948`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[CurlyPhi]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "r1"}], "+", 
        RowBox[{
         SuperscriptBox["r1", "2"], " ", "r2"}], "+", 
        SuperscriptBox["t1", "2"]}], ")"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "+", 
     RowBox[{"2", " ", "L", " ", "r1", " ", "r2", " ", 
      SuperscriptBox["t1", "2"], " ", "\[Omega]", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}], 
  RowBox[{"c", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "r1"}], "+", 
     RowBox[{
      SuperscriptBox["r1", "2"], " ", "r2"}], "+", 
     SuperscriptBox["t1", "2"]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.455996897171*^9, {3.4559969660606003`*^9, 3.4559971518254004`*^9}, {
   3.4559971967534*^9, 3.4559972012306004`*^9}, {3.4559972332262*^9, 
   3.455997261743*^9}, {3.4559972977166*^9, 3.4559973151106*^9}, 
   3.4559974371806*^9, 3.4559975400313997`*^9, 3.4559979367394*^9, {
   3.4559981690702*^9, 3.4559981739842*^9}, 3.4559982067441998`*^9, 
   3.4560585686436*^9, {3.4560586109820004`*^9, 3.4560586539444*^9}, {
   3.456059036784*^9, 3.456059058624*^9}, 3.4561498850528*^9, 
   3.4566641192700944`*^9, 3.4566648527664948`*^9}],

Cell[BoxData["\[CurlyPhi]"], "Output",
 CellChangeTimes->{
  3.455996897171*^9, {3.4559969660606003`*^9, 3.4559971518254004`*^9}, {
   3.4559971967534*^9, 3.4559972012306004`*^9}, {3.4559972332262*^9, 
   3.455997261743*^9}, {3.4559972977166*^9, 3.4559973151106*^9}, 
   3.4559974371806*^9, 3.4559975400313997`*^9, 3.4559979367394*^9, {
   3.4559981690702*^9, 3.4559981739842*^9}, 3.4559982067441998`*^9, 
   3.4560585686436*^9, {3.4560586109820004`*^9, 3.4560586539444*^9}, {
   3.456059036784*^9, 3.456059058624*^9}, 3.4561498850528*^9, 
   3.4566641192700944`*^9, 3.4566648527664948`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"F", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["r1", "2"]}], ")"}], " ", 
   SqrtBox[
    RowBox[{"r1", " ", "r2"}]], " ", "\[Omega]"}], 
  RowBox[{"FSR", " ", "\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "r1", "+", 
     RowBox[{
      SuperscriptBox["r1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "r2"}], ")"}]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.455996897171*^9, {3.4559969660606003`*^9, 3.4559971518254004`*^9}, {
   3.4559971967534*^9, 3.4559972012306004`*^9}, {3.4559972332262*^9, 
   3.455997261743*^9}, {3.4559972977166*^9, 3.4559973151106*^9}, 
   3.4559974371806*^9, 3.4559975400313997`*^9, 3.4559979367394*^9, {
   3.4559981690702*^9, 3.4559981739842*^9}, 3.4559982067441998`*^9, 
   3.4560585686436*^9, {3.4560586109820004`*^9, 3.4560586539444*^9}, {
   3.456059036784*^9, 3.456059058624*^9}, 3.4561498850528*^9, 
   3.4566641192700944`*^9, 3.4566648527664948`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reflection (length)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
   3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979275042*^9, 
   3.4559979302497997`*^9}, {3.4559990796577997`*^9, 3.4559990897198*^9}, 
   3.4560597462096*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}], "+", 
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]]}]}], 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"#", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]], "&"}], "[", 
      RowBox[{"refl", ".", "Ein"}], "]"}], "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[CurlyPhi]", "\[Rule]", "0"}]}], "//", "ComplexExpand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", 
    FractionBox[
     RowBox[{"F", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
     RowBox[{"\[Pi]", 
      SqrtBox[
       RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
   RowBox[{"t", "\[Rule]", "0"}]}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"%%", "/.", 
      RowBox[{"t", "\[Rule]", 
       FractionBox["\[Pi]", 
        RowBox[{"2", "\[Omega]"}]]}]}], "%"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"F", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
       RowBox[{"\[Pi]", 
        SqrtBox[
         RowBox[{"r1", " ", "r2"}]]}]], ")"}], "2"]}], "/.", 
   RowBox[{"L", "\[Rule]", 
    FractionBox["c", 
     RowBox[{"2", " ", "FSR"}]]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.4559973759974003`*^9, 3.4559973945926*^9}, 
   3.4559974433894*^9, {3.4559975546174*^9, 3.4559975549294*^9}, {
   3.4559979409826*^9, 3.455997941435*^9}, 3.4559989117706003`*^9, {
   3.455998981097*^9, 3.4559989867286*^9}, {3.4559991120746*^9, 
   3.4559991209666*^9}, {3.4559991875474*^9, 3.4559991965174*^9}, {
   3.4560597224351997`*^9, 3.4560597227628*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "k", " ", "r1", " ", "r2", " ", 
   SuperscriptBox["t1", "2"], " ", "\[Delta]l", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "+", 
     RowBox[{"L", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}], 
  RowBox[{"c", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "r1"}], "+", 
     RowBox[{
      SuperscriptBox["r1", "2"], " ", "r2"}], "+", 
     SuperscriptBox["t1", "2"]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.455997379913*^9, 3.4559973950917997`*^9}, 
   3.4559974439978*^9, 3.4559975558342*^9, 3.4559979425425997`*^9, 
   3.4559982851498003`*^9, 3.4559989130966*^9, {3.4559989820642*^9, 
   3.4559989872122*^9}, {3.4559991125894003`*^9, 3.4559991215906*^9}, 
   3.4559991972662*^9, 3.456059723418*^9, 3.4561498852088003`*^9, 
   3.4566641194416943`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "F", " ", "k", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    SuperscriptBox["t1", "2"], " ", "\[Delta]l"}], 
   RowBox[{"\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "r1"}], "+", 
      RowBox[{
       SuperscriptBox["r1", "2"], " ", "r2"}], "+", 
      SuperscriptBox["t1", "2"]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.455997379913*^9, 3.4559973950917997`*^9}, 
   3.4559974439978*^9, 3.4559975558342*^9, 3.4559979425425997`*^9, 
   3.4559982851498003`*^9, 3.4559989130966*^9, {3.4559989820642*^9, 
   3.4559989872122*^9}, {3.4559991125894003`*^9, 3.4559991215906*^9}, 
   3.4559991972662*^9, 3.456059723418*^9, 3.4561498852088003`*^9, 
   3.4566641194728947`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]"}], 
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]]}]]}]], "Output",
 CellChangeTimes->{{3.455997379913*^9, 3.4559973950917997`*^9}, 
   3.4559974439978*^9, 3.4559975558342*^9, 3.4559979425425997`*^9, 
   3.4559982851498003`*^9, 3.4559989130966*^9, {3.4559989820642*^9, 
   3.4559989872122*^9}, {3.4559991125894003`*^9, 3.4559991215906*^9}, 
   3.4559991972662*^9, 3.456059723418*^9, 3.4561498852088003`*^9, 
   3.4566641195196943`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reflection (phase, off-resonant)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
   3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979275042*^9, 
   3.4559979302497997`*^9}, {3.4559990796577997`*^9, 3.455999081561*^9}, {
   3.4560004569505997`*^9, 3.4560004602265997`*^9}, 3.4560586751916*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}], "+", 
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]]}]}], 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"#", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]], "&"}], "[", 
      RowBox[{"refl", ".", "Ein"}], "]"}], "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}], "/.", 
    RowBox[{"\[Delta]l", "\[Rule]", "0"}]}], "//", "ComplexExpand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"t", "\[Rule]", "0"}]}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"%%", "/.", 
       RowBox[{"t", "\[Rule]", 
        FractionBox["\[Pi]", 
         RowBox[{"2", "\[Omega]"}]]}]}], "%"], 
     FractionBox[
      RowBox[{"F", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "/.", 
   RowBox[{
    SuperscriptBox["t1", "2"], "\[Rule]", 
    RowBox[{"1", "-", 
     SuperscriptBox["r1", "2"]}]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.455996878061*^9, 3.4559971512482*^9}, {
   3.455997183275*^9, 3.455997314627*^9}, {3.455997421955*^9, 
   3.4559974363382*^9}, {3.4559975314514*^9, 3.455997538955*^9}, {
   3.4559979355538*^9, 3.4559979361154003`*^9}, {3.4559981681809998`*^9, 
   3.4559981734694*^9}, 3.4559982061514*^9, 3.4560004724102*^9, {
   3.4560005461826*^9, 3.4560005854322*^9}, {3.4560586770324*^9, 
   3.4560586774379997`*^9}, 3.4560592870548*^9, {3.4566648628128943`*^9, 
   3.4566648635148945`*^9}, {3.4566670314936943`*^9, 3.4566670323360944`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "r1"}], "+", 
  FractionBox[
   SuperscriptBox["t1", "2"], 
   RowBox[{"1", "-", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "r1", " ", 
     "r2"}]}]]}]], "Output",
 CellChangeTimes->{
  3.455996897171*^9, {3.4559969660606003`*^9, 3.4559971518254004`*^9}, {
   3.4559971967534*^9, 3.4559972012306004`*^9}, {3.4559972332262*^9, 
   3.455997261743*^9}, {3.4559972977166*^9, 3.4559973151106*^9}, 
   3.4559974371806*^9, 3.4559975400313997`*^9, 3.4559979367394*^9, {
   3.4559981690702*^9, 3.4559981739842*^9}, 3.4559982067441998`*^9, 
   3.4560004752494*^9, {3.4560005472122*^9, 3.4560005865866003`*^9}, 
   3.4560586813691998`*^9, 3.4560592884588003`*^9, 3.456149885942*^9, 
   3.4566641202060947`*^9, 3.4566648663072944`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"\[CurlyPhi]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", 
          FractionBox["\[Phi]", "2"], "]"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"Sin", "[", 
           FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
           RowBox[{"Cos", "[", 
            FractionBox["\[Phi]", "2"], "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"r1", " ", "r2"}]}], ")"}], " ", 
           RowBox[{"Sin", "[", 
            FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "r1"}], "+", 
            RowBox[{
             SuperscriptBox["r1", "2"], " ", "r2"}], "+", 
            SuperscriptBox["t1", "2"]}], ")"}], " ", 
          RowBox[{"Cos", "[", 
           FractionBox["\[Phi]", "2"], "]"}]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"r1", "+", 
            RowBox[{
             SuperscriptBox["r1", "2"], " ", "r2"}], "-", 
            SuperscriptBox["t1", "2"]}], ")"}], " ", 
          RowBox[{"Sin", "[", 
           FractionBox["\[Phi]", "2"], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", "L", " ", "r1", " ", "r2", " ", 
       SuperscriptBox["t1", "2"], " ", "\[Omega]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r1", " ", "r2"}], "-", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"c", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "r1"}], " ", "r2"}], "+", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "r1"}], "+", 
      SuperscriptBox["t1", "2"], "+", 
      RowBox[{
       SuperscriptBox["r1", "2"], " ", "r2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["r1", "2"], " ", "r2", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.455996897171*^9, {3.4559969660606003`*^9, 3.4559971518254004`*^9}, {
   3.4559971967534*^9, 3.4559972012306004`*^9}, {3.4559972332262*^9, 
   3.455997261743*^9}, {3.4559972977166*^9, 3.4559973151106*^9}, 
   3.4559974371806*^9, 3.4559975400313997`*^9, 3.4559979367394*^9, {
   3.4559981690702*^9, 3.4559981739842*^9}, 3.4559982067441998`*^9, 
   3.4560004752494*^9, {3.4560005472122*^9, 3.4560005865866003`*^9}, 
   3.4560586813691998`*^9, 3.4560592884588003`*^9, 3.456149885942*^9, 
   3.4566641202060947`*^9, 3.4566648663540945`*^9}],

Cell[BoxData["\[CurlyPhi]"], "Output",
 CellChangeTimes->{
  3.455996897171*^9, {3.4559969660606003`*^9, 3.4559971518254004`*^9}, {
   3.4559971967534*^9, 3.4559972012306004`*^9}, {3.4559972332262*^9, 
   3.455997261743*^9}, {3.4559972977166*^9, 3.4559973151106*^9}, 
   3.4559974371806*^9, 3.4559975400313997`*^9, 3.4559979367394*^9, {
   3.4559981690702*^9, 3.4559981739842*^9}, 3.4559982067441998`*^9, 
   3.4560004752494*^9, {3.4560005472122*^9, 3.4560005865866003`*^9}, 
   3.4560586813691998`*^9, 3.4560592884588003`*^9, 3.456149885942*^9, 
   3.4566641202060947`*^9, 3.4566648663540945`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["r1", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]"}], 
   RowBox[{"FSR", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r1", " ", "r2"}], "-", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "r1", "+", 
      SuperscriptBox["r1", "2"], "-", 
      RowBox[{
       SuperscriptBox["r1", "2"], " ", "r2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["r1", "2"], " ", "r2", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.455996897171*^9, {3.4559969660606003`*^9, 3.4559971518254004`*^9}, {
   3.4559971967534*^9, 3.4559972012306004`*^9}, {3.4559972332262*^9, 
   3.455997261743*^9}, {3.4559972977166*^9, 3.4559973151106*^9}, 
   3.4559974371806*^9, 3.4559975400313997`*^9, 3.4559979367394*^9, {
   3.4559981690702*^9, 3.4559981739842*^9}, 3.4559982067441998`*^9, 
   3.4560004752494*^9, {3.4560005472122*^9, 3.4560005865866003`*^9}, 
   3.4560586813691998`*^9, 3.4560592884588003`*^9, 3.456149885942*^9, 
   3.4566641202060947`*^9, 3.4566648663540945`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reflection (length, off-resonant)", "Subsubsection",
 CellChangeTimes->{{3.4559753308445997`*^9, 3.4559753457738*^9}, {
   3.4559753770986*^9, 3.4559753791734*^9}, {3.4559979275042*^9, 
   3.4559979302497997`*^9}, {3.4559990796577997`*^9, 3.4559990897198*^9}, {
   3.4560008786584*^9, 3.456000882808*^9}, 3.4560597513732*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}], "+", 
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]]}]}], 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"#", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]], "&"}], "[", 
      RowBox[{"refl", ".", "Ein"}], "]"}], "/.", 
     RowBox[{"\[CapitalDelta]", "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", "k"}]], "\[Phi]"}]}]}], "/.", 
    RowBox[{"\[CurlyPhi]", "\[Rule]", "0"}]}], "//", "ComplexExpand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", 
     FractionBox[
      RowBox[{"F", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
      RowBox[{"\[Pi]", 
       SqrtBox[
        RowBox[{"r1", " ", "r2"}]]}]]}], "/.", 
    RowBox[{"t", "\[Rule]", "0"}]}], "/.", 
   RowBox[{
    SuperscriptBox["t1", "2"], "\[Rule]", 
    RowBox[{"1", "-", 
     SuperscriptBox["r1", "2"]}]}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"%%", "/.", 
       RowBox[{"t", "\[Rule]", 
        FractionBox["\[Pi]", 
         RowBox[{"2", "\[Omega]"}]]}]}], "%"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"F", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"r1", " ", "r2"}]}], ")"}]}], 
        RowBox[{"\[Pi]", 
         SqrtBox[
          RowBox[{"r1", " ", "r2"}]]}]], ")"}], "2"]}], "/.", 
    RowBox[{"L", "\[Rule]", 
     FractionBox["c", 
      RowBox[{"2", " ", "FSR"}]]}]}], "/.", 
   RowBox[{
    SuperscriptBox["t1", "2"], "\[Rule]", 
    RowBox[{"1", "-", 
     SuperscriptBox["r1", "2"]}]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.4559973759974003`*^9, 3.4559973945926*^9}, 
   3.4559974433894*^9, {3.4559975546174*^9, 3.4559975549294*^9}, {
   3.4559979409826*^9, 3.455997941435*^9}, 3.4559989117706003`*^9, {
   3.455998981097*^9, 3.4559989867286*^9}, {3.4559991120746*^9, 
   3.4559991209666*^9}, {3.4559991875474*^9, 3.4559991965174*^9}, 
   3.4560008896408*^9, {3.456059753526*^9, 3.4560597540408*^9}, 
   3.4560599232384*^9, 3.4560600967416*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", "k", " ", "r1", " ", "r2", " ", 
    SuperscriptBox["t1", "2"], " ", "\[Delta]l", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r1", " ", "r2"}], "-", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"L", " ", "\[Omega]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r1", " ", "r2"}], "+", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"c", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "r1"}], " ", "r2"}], "+", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "r1"}], "+", 
      SuperscriptBox["t1", "2"], "+", 
      RowBox[{
       SuperscriptBox["r1", "2"], " ", "r2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["r1", "2"], " ", "r2", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.455997379913*^9, 3.4559973950917997`*^9}, 
   3.4559974439978*^9, 3.4559975558342*^9, 3.4559979425425997`*^9, 
   3.4559982851498003`*^9, 3.4559989130966*^9, {3.4559989820642*^9, 
   3.4559989872122*^9}, {3.4559991125894003`*^9, 3.4559991215906*^9}, 
   3.4559991972662*^9, 3.4560008909667997`*^9, 3.45605975571*^9, 
   3.4560599243616*^9, 3.4560600980364*^9, 3.4561498868936*^9, 
   3.4566641211576943`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "F", " ", "k", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["r1", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Delta]l"}], 
   RowBox[{"\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r1", " ", "r2"}], "-", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "r1", "+", 
      SuperscriptBox["r1", "2"], "-", 
      RowBox[{
       SuperscriptBox["r1", "2"], " ", "r2", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["r1", "2"], " ", "r2", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.455997379913*^9, 3.4559973950917997`*^9}, 
   3.4559974439978*^9, 3.4559975558342*^9, 3.4559979425425997`*^9, 
   3.4559982851498003`*^9, 3.4559989130966*^9, {3.4559989820642*^9, 
   3.4559989872122*^9}, {3.4559991125894003`*^9, 3.4559991215906*^9}, 
   3.4559991972662*^9, 3.4560008909667997`*^9, 3.45605975571*^9, 
   3.4560599243616*^9, 3.4560600980364*^9, 3.4561498868936*^9, 
   3.4566641212824945`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"F", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"r1", " ", "r2"}]}], ")"}], " ", "\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r1", " ", "r2"}], "+", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}], 
   RowBox[{"2", " ", "FSR", " ", "\[Pi]", " ", 
    SqrtBox[
     RowBox[{"r1", " ", "r2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r1", " ", "r2"}], "-", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.455997379913*^9, 3.4559973950917997`*^9}, 
   3.4559974439978*^9, 3.4559975558342*^9, 3.4559979425425997`*^9, 
   3.4559982851498003`*^9, 3.4559989130966*^9, {3.4559989820642*^9, 
   3.4559989872122*^9}, {3.4559991125894003`*^9, 3.4559991215906*^9}, 
   3.4559991972662*^9, 3.4560008909667997`*^9, 3.45605975571*^9, 
   3.4560599243616*^9, 3.4560600980364*^9, 3.4561498868936*^9, 
   3.4566641213136945`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ee", "=", 
  RowBox[{
   RowBox[{"Eaux", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]}]]}], "+", 
   RowBox[{"Eaux2", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}], " ", "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", "2"]}]}]]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"ComplexExpand", "[", 
  RowBox[{"ee", " ", 
   RowBox[{"Conjugate", "[", "ee", "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"%", 
    FractionBox["\[Omega]", "\[Pi]"], 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"2", "\[Omega]", " ", "t"}], "+", 
      SubscriptBox["\[Phi]", "M"], "+", 
      FractionBox["\[Pi]", "2"]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     FractionBox["\[Pi]", "\[Omega]"]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4571329394815745`*^9, 3.457133110495575*^9}, {
  3.457133332773575*^9, 3.457133336601575*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Omega]"}]}]], " ", "Eaux"}], 
  "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "2"]}]}]], " ", "Eaux2"}]}]], "Output",
 CellChangeTimes->{{3.4571330014485745`*^9, 3.4571330261315746`*^9}, {
   3.4571331084115744`*^9, 3.457133111035575*^9}, 3.4571333371445746`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["Eaux", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", 
     RowBox[{"\[Phi]", "+", 
      RowBox[{"t", " ", "\[Omega]"}]}], "]"}], "2"]}], "+", 
  RowBox[{"2", " ", "Eaux", " ", "Eaux2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Phi]", "+", 
     RowBox[{"t", " ", "\[Omega]"}]}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"t", " ", "\[Omega]"}], "+", 
     SubscriptBox["\[Phi]", "2"]}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["Eaux2", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"t", " ", "\[Omega]"}], "+", 
      SubscriptBox["\[Phi]", "2"]}], "]"}], "2"]}], "+", 
  RowBox[{
   SuperscriptBox["Eaux", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", 
     RowBox[{"\[Phi]", "+", 
      RowBox[{"t", " ", "\[Omega]"}]}], "]"}], "2"]}], "-", 
  RowBox[{"2", " ", "Eaux", " ", "Eaux2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Phi]", "+", 
     RowBox[{"t", " ", "\[Omega]"}]}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"t", " ", "\[Omega]"}], "+", 
     SubscriptBox["\[Phi]", "2"]}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["Eaux2", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"t", " ", "\[Omega]"}], "+", 
      SubscriptBox["\[Phi]", "2"]}], "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{{3.4571330014485745`*^9, 3.4571330261315746`*^9}, {
   3.4571331084115744`*^9, 3.457133111035575*^9}, 3.4571333371475744`*^9}],

Cell[BoxData[
 RowBox[{"Eaux", " ", "Eaux2", " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"\[Phi]", "+", 
    SubscriptBox["\[Phi]", "2"], "-", 
    SubscriptBox["\[Phi]", "M"]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.4571330014485745`*^9, 3.4571330261315746`*^9}, {
   3.4571331084115744`*^9, 3.457133111035575*^9}, 3.4571333377625747`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Offset Locking", "Subsection",
 CellChangeTimes->{{3.4559752043442*^9, 3.4559752102254*^9}, {
  3.455975241285*^9, 3.4559752428606*^9}, {3.4559975049938*^9, 
  3.4559975163662*^9}, {3.4560752147332*^9, 3.4560752172448*^9}, {
  3.45607534075*^9, 3.456075342388*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fShift", "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Omega]", "S"], " ", "t"}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eshift", "=", 
   RowBox[{
    RowBox[{"fShift", " ", "Ein"}], "/.", 
    RowBox[{"\[CurlyPhi]", "\[Rule]", "\[Kappa]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Esum", "=", 
  RowBox[{
   RowBox[{"a0", " ", "Ein"}], "+", 
   RowBox[{"a1", " ", "Eshift"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "n_", "]"}], "=", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"Conjugate", "[", "Esum", "]"}], "]"}], ".", 
    RowBox[{"det", "[", "n", "]"}], ".", "Esum"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"X", "[", 
       RowBox[{"+", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"X", "[", 
       RowBox[{"-", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4560753458512*^9, 3.4560753963171997`*^9}, {
   3.4560755078416*^9, 3.4560755268736*^9}, {3.456075881914*^9, 
   3.4560759482764*^9}, 3.456076177144*^9, {3.4560767824863997`*^9, 
   3.4560767897092*^9}, {3.4560773800288*^9, 3.4560773840692*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a0", "+", 
     RowBox[{"a1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "t", " ", 
         SubscriptBox["\[Omega]", "S"]}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "a1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "t", " ", 
         SubscriptBox["\[Omega]", "S"]}]}]], " ", "\[Kappa]"}], "+", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "a0", " ", "\[CurlyPhi]"}], "2"]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "a1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "t", " ", 
         SubscriptBox["\[Omega]", "S"]}]}]], " ", "\[Kappa]"}], "+", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "a0", " ", "\[CurlyPhi]"}], "2"]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4560761773624*^9, 3.4560767901772003`*^9, 
  3.4560772339348*^9, 3.4560773848024*^9, 3.456080325808*^9, 
  3.4560811786288*^9, 3.4561498870808*^9, 3.4566641213604946`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["DC lock point", "Subsubsection",
 CellChangeTimes->{{3.4560792063364*^9, 3.4560792107511997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"(", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Conjugate", "[", "Esum", "]"}], "]"}], ".", "Esum"}], 
  ")"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "\[LeftDoubleBracket]", 
    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "//", 
   "ComplexExpand"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Coefficient", "[", 
   RowBox[{"%", ",", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Phi]", "+", 
      RowBox[{"t", " ", 
       SubscriptBox["\[Omega]", "S"]}]}], "]"}]}], "]"}], "/.", 
  RowBox[{
   RowBox[{"\[Kappa]", " ", "\[CurlyPhi]"}], "\[Rule]", "0", " ", 
   RowBox[{"(*", " ", 
    RowBox[{"slope", " ", "of", " ", "error", " ", "signal"}], " ", 
    "*)"}]}]}]}], "Input",
 CellChangeTimes->{{3.4560771628768*^9, 3.4560772006288*^9}, {
  3.4560772401280003`*^9, 3.4560772429828*^9}, {3.4560773995444*^9, 
  3.4560774746272*^9}, {3.4560790070931997`*^9, 3.4560791953384*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a0", "+", 
       RowBox[{"a1", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]]}]}], ")"}], " ", 
     RowBox[{"Conjugate", "[", 
      RowBox[{"a0", "+", 
       RowBox[{"a1", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]]}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "a1", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", "\[Kappa]"}], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "a0", " ", "\[CurlyPhi]"}], "2"]}], 
      ")"}], " ", 
     RowBox[{"Conjugate", "[", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "a1", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", "\[Kappa]"}], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "a0", " ", "\[CurlyPhi]"}], "2"]}], 
      "]"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, 
   3.456149887112*^9, 3.4566641215008945`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SuperscriptBox["\[Kappa]", "2"]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["a0", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SuperscriptBox["\[CurlyPhi]", "2"]}], ")"}]}]}], ")"}]}], "+", 
  RowBox[{"a0", " ", "a1", " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", 
     RowBox[{"\[Kappa]", " ", "\[CurlyPhi]"}]}], ")"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Phi]", "+", 
     RowBox[{"t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, 
   3.456149887112*^9, 3.4566641215632944`*^9}],

Cell[BoxData[
 RowBox[{"2", " ", "a0", " ", "a1"}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, 
   3.456149887112*^9, 3.4566641215632944`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AC signal", "Subsubsection",
 CellChangeTimes->{{3.4560792063364*^9, 3.4560792508744*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "0", "]"}], "//", "ComplexExpand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{
   RowBox[{"\[Phi]", "+", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}]}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", "\[Pi]"}], "/", "2"}]}]}]}], "Input",
 CellChangeTimes->{{3.4560754053808002`*^9, 3.4560754056148*^9}, {
  3.4560754563772*^9, 3.456075583876*^9}, {3.4560759722848*^9, 
  3.456075973174*^9}, {3.456076008898*^9, 3.4560760134688*^9}, {
  3.4560792602656*^9, 3.4560792876748*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", "a0", " ", "a1", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "\[Kappa]"}], "+", "\[CurlyPhi]"}], ")"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"t", " ", "\[Omega]"}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"\[Phi]", "+", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.4560754456132*^9, 3.4560754586703997`*^9}, 
   3.4560754983255997`*^9, {3.4560755531284*^9, 3.4560755847184*^9}, 
   3.4560759736264*^9, {3.4560760109572*^9, 3.456076014748*^9}, 
   3.4560767929228*^9, {3.4560792631204*^9, 3.4560792880804*^9}, 
   3.4561498872836*^9, 3.4566641216412945`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", "a0", " ", "a1", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "\[Kappa]"}], "+", "\[CurlyPhi]"}], ")"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"t", " ", "\[Omega]"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.4560754456132*^9, 3.4560754586703997`*^9}, 
   3.4560754983255997`*^9, {3.4560755531284*^9, 3.4560755847184*^9}, 
   3.4560759736264*^9, {3.4560760109572*^9, 3.456076014748*^9}, 
   3.4560767929228*^9, {3.4560792631204*^9, 3.4560792880804*^9}, 
   3.4561498872836*^9, 3.4566641216412945`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Double Offset Locking", "Subsection",
 CellChangeTimes->{{3.4559752043442*^9, 3.4559752102254*^9}, {
  3.455975241285*^9, 3.4559752428606*^9}, {3.4559975049938*^9, 
  3.4559975163662*^9}, {3.4560752147332*^9, 3.4560752172448*^9}, {
  3.45607534075*^9, 3.456075342388*^9}, {3.456080099842*^9, 
  3.4560801009028*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fShiftP", "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Omega]", "S"], " ", "t"}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "p"]}]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fShiftM", "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      SubscriptBox["\[Omega]", "S"], " ", "t"}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "m"]}]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EshiftP", "=", 
   RowBox[{
    RowBox[{"fShiftP", " ", "Ein"}], "/.", 
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     SubscriptBox["\[CurlyPhi]", "p"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EshiftM", "=", 
   RowBox[{
    RowBox[{"fShiftM", " ", "Ein"}], "/.", 
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     SubscriptBox["\[CurlyPhi]", "m"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Esum", "=", 
  RowBox[{
   RowBox[{
    SubscriptBox["a", "0"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "0"]}]], "Ein"}], "/.", 
      RowBox[{"\[CurlyPhi]", "\[Rule]", 
       SubscriptBox["\[CurlyPhi]", "o"]}]}], ")"}]}], "+", 
   RowBox[{
    SubscriptBox["a", "p"], " ", "EshiftP"}], "+", 
   RowBox[{
    SubscriptBox["a", "m"], "EshiftM"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Y", "[", "n_", "]"}], "=", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"Conjugate", "[", "Esum", "]"}], "]"}], ".", 
    RowBox[{"det", "[", "n", "]"}], ".", "Esum"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Y", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"Y", "[", 
       RowBox[{"+", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{
      RowBox[{"Y", "[", 
       RowBox[{"-", "1"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4560753458512*^9, 3.4560753963171997`*^9}, {
   3.4560755078416*^9, 3.4560755268736*^9}, {3.456075881914*^9, 
   3.4560759482764*^9}, 3.456076177144*^9, {3.4560767824863997`*^9, 
   3.4560767897092*^9}, {3.4560773800288*^9, 3.4560773840692*^9}, {
   3.4560801266896*^9, 3.4560802784308*^9}, {3.4560803462595997`*^9, 
   3.4560803831535997`*^9}, {3.4560804245559998`*^9, 3.4560804527296*^9}, {
   3.456080485552*^9, 3.4560805057539997`*^9}, {3.4560821940327997`*^9, 
   3.456082207558*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Phi]", "0"]}]], " ", 
      SubscriptBox["a", "0"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "m"]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", "t", " ", 
         SubscriptBox["\[Omega]", "S"]}]}]], " ", 
      SubscriptBox["a", "m"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "p"]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "t", " ", 
         SubscriptBox["\[Omega]", "S"]}]}]], " ", 
      SubscriptBox["a", "p"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "m"]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", "t", " ", 
         SubscriptBox["\[Omega]", "S"]}]}]], " ", 
      SubscriptBox["a", "m"], " ", 
      SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Phi]", "0"]}]], " ", 
      SubscriptBox["a", "0"], " ", 
      SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "p"]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "t", " ", 
         SubscriptBox["\[Omega]", "S"]}]}]], " ", 
      SubscriptBox["a", "p"], " ", 
      SubscriptBox["\[CurlyPhi]", "p"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "m"]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", "t", " ", 
         SubscriptBox["\[Omega]", "S"]}]}]], " ", 
      SubscriptBox["a", "m"], " ", 
      SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Phi]", "0"]}]], " ", 
      SubscriptBox["a", "0"], " ", 
      SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Phi]", "p"]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "t", " ", 
         SubscriptBox["\[Omega]", "S"]}]}]], " ", 
      SubscriptBox["a", "p"], " ", 
      SubscriptBox["\[CurlyPhi]", "p"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4560801737860003`*^9, 3.4560802308196*^9, {3.4560802736572*^9, 
   3.4560802935628*^9}, {3.456080360674*^9, 3.456080432668*^9}, 
   3.4560804630256*^9, {3.4560804960039997`*^9, 3.4560805065028*^9}, 
   3.4560812943652*^9, 3.4560822091647997`*^9, 3.4561498873148003`*^9, 
   3.4566641216724944`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["DC lock point", "Subsubsection",
 CellChangeTimes->{{3.4560792063364*^9, 3.4560792107511997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"(", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Conjugate", "[", "Esum", "]"}], "]"}], ".", "Esum"}], 
  ")"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "\[LeftDoubleBracket]", 
    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "//", 
   "ComplexExpand"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["a", "m", "2"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubsuperscriptBox["a", "0", "2"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubsuperscriptBox["a", "p", "2"], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "m"], " ", 
       SubscriptBox["\[CurlyPhi]", "p"]}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "m"], " ", 
       SubscriptBox["\[CurlyPhi]", "o"]}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "o"], " ", 
       SubscriptBox["\[CurlyPhi]", "p"]}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "m"], " ", 
       SubscriptBox["a", "p"]}], "\[Rule]", "0"}]}], "}"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"error", " ", "signal"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"TrigExpand", "[", "%", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%%", "/.", 
    RowBox[{
     SubscriptBox["a", "m"], "\[Rule]", 
     SubscriptBox["a", "p"]}]}], "]"}], "//", "TrigFactor"}]}], "Input",
 CellChangeTimes->{{3.4560771628768*^9, 3.4560772006288*^9}, {
   3.4560772401280003`*^9, 3.4560772429828*^9}, {3.4560773995444*^9, 
   3.4560774746272*^9}, {3.4560790070931997`*^9, 3.4560791953384*^9}, {
   3.4560805283896*^9, 3.4560805318059998`*^9}, {3.4560805694332*^9, 
   3.4560806791948*^9}, {3.4560807362752*^9, 3.4560807390676003`*^9}, {
   3.456080782108*^9, 3.4560808268332*^9}, {3.4560808631656*^9, 
   3.4560809325076*^9}, {3.4560810928912*^9, 3.4560811240912*^9}, {
   3.456081254164*^9, 3.4560812708872004`*^9}, 3.456081302992*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Conjugate", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Phi]", "0"]}]], " ", 
        SubscriptBox["a", "0"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "m"]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "m"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "p"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "p"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Phi]", "0"]}]], " ", 
        SubscriptBox["a", "0"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "m"]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "m"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "p"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "p"]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Conjugate", "[", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "m"]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Phi]", "0"]}]], " ", 
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "p"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "m"]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Phi]", "0"]}]], " ", 
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "p"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4566641217192945`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["a", "m", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubsuperscriptBox["\[CurlyPhi]", "m", "2"]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["a", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubsuperscriptBox["\[CurlyPhi]", "o", "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "m"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"2", " ", "t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "m"], " ", 
     SubscriptBox["a", "p"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{
        SubscriptBox["\[CurlyPhi]", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["a", "p", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubsuperscriptBox["\[CurlyPhi]", "p", "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["a", "0"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          SubscriptBox["\[Phi]", "0"], "-", 
          SubscriptBox["\[Phi]", "m"], "+", 
          RowBox[{"t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
        SubscriptBox["a", "m"], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{
           SubscriptBox["\[CurlyPhi]", "m"], " ", 
           SubscriptBox["\[CurlyPhi]", "o"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          SubscriptBox["\[Phi]", "0"], "-", 
          SubscriptBox["\[Phi]", "p"], "-", 
          RowBox[{"t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
        SubscriptBox["a", "p"], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{
           SubscriptBox["\[CurlyPhi]", "o"], " ", 
           SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4566641221872945`*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["a", "0"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "m"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "m"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "p"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4566641221872945`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "m"], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "m"], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "m"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "m"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "p"], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "p"], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "p"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "p"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"]}]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.456664122202894*^9}],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "0"], "-", 
    FractionBox[
     SubscriptBox["\[Phi]", "m"], "2"], "-", 
    FractionBox[
     SubscriptBox["\[Phi]", "p"], "2"]}], "]"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    FractionBox[
     SubscriptBox["\[Phi]", "m"], "2"], "-", 
    FractionBox[
     SubscriptBox["\[Phi]", "p"], "2"], "-", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
  SubscriptBox["a", "0"], " ", 
  SubscriptBox["a", "p"]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4566641222184944`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AC signal", "Subsubsection",
 CellChangeTimes->{{3.4560792063364*^9, 3.4560792508744*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Y", "[", "0", "]"}], "//", "ComplexExpand"}], "//", "Simplify"}],
   "//", "TrigFactor"}]], "Input",
 CellChangeTimes->{{3.4560754053808002`*^9, 3.4560754056148*^9}, {
  3.4560754563772*^9, 3.456075583876*^9}, {3.4560759722848*^9, 
  3.456075973174*^9}, {3.456076008898*^9, 3.4560760134688*^9}, {
  3.4560792602656*^9, 3.4560792876748*^9}, {3.4560811593004*^9, 
  3.4560811700643997`*^9}, {3.4560824376424*^9, 3.4560824400916*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"t", " ", "\[Omega]"}], "]"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "m"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["a", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "m"]}], "-", 
       RowBox[{
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["a", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "0"]}], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
       RowBox[{
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "m"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"2", " ", "t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "m"]}], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
       RowBox[{
        SubscriptBox["a", "m"], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4560754456132*^9, 3.4560754586703997`*^9}, 
   3.4560754983255997`*^9, {3.4560755531284*^9, 3.4560755847184*^9}, 
   3.4560759736264*^9, {3.4560760109572*^9, 3.456076014748*^9}, 
   3.4560767929228*^9, {3.4560792631204*^9, 3.4560792880804*^9}, {
   3.4560811461963997`*^9, 3.4560811836675997`*^9}, 3.456082440934*^9, 
   3.4561498883132*^9, 3.4561615960692*^9, 3.456664122639694*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{
          SubscriptBox["\[Phi]", "0"], "-", 
          SubscriptBox["\[Phi]", "m"], "+", 
          RowBox[{"t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["a", "0"], " ", 
           SubscriptBox["a", "m"], " ", 
           SubscriptBox["\[CurlyPhi]", "m"]}], "-", 
          RowBox[{
           SubscriptBox["a", "0"], " ", 
           SubscriptBox["a", "m"], " ", 
           SubscriptBox["\[CurlyPhi]", "o"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{
          SubscriptBox["\[Phi]", "0"], "-", 
          SubscriptBox["\[Phi]", "p"], "-", 
          RowBox[{"t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "0"]}], " ", 
           SubscriptBox["a", "p"], " ", 
           SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
          RowBox[{
           SubscriptBox["a", "0"], " ", 
           SubscriptBox["a", "p"], " ", 
           SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}]}], ")"}]}], "/.", 
    RowBox[{
     SubscriptBox["a", "m"], "\[Rule]", 
     SubscriptBox["a", "p"]}]}], "//", "TrigReduce"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"%", 
    RowBox[{"Sin", "[", 
     RowBox[{
      FractionBox[
       SubscriptBox["\[Phi]", "m"], "2"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "p"], "2"], "-", 
      RowBox[{"t", " ", 
       SubscriptBox["\[Omega]", "S"]}]}], "]"}]}], ")"}], "//", 
  "TrigReduce"}]}], "Input",
 CellChangeTimes->{{3.456082851604*^9, 3.456082860574*^9}, {
  3.4560838137964*^9, 3.4560838284292*^9}, {3.4560840436312*^9, 
  3.4560840570004*^9}, {3.456084095158*^9, 3.456084131974*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  SubscriptBox["a", "0"], " ", 
  SubscriptBox["a", "p"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "m"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["\[CurlyPhi]", "m"]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{
         SubscriptBox["\[Phi]", "0"], "-", 
         SubscriptBox["\[Phi]", "p"], "-", 
         RowBox[{"t", " ", 
          SubscriptBox["\[Omega]", "S"]}]}], "]"}], "+", 
       RowBox[{"Sin", "[", 
        RowBox[{
         SubscriptBox["\[Phi]", "0"], "-", 
         SubscriptBox["\[Phi]", "m"], "+", 
         RowBox[{"t", " ", 
          SubscriptBox["\[Omega]", "S"]}]}], "]"}]}], ")"}], " ", 
     SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4560828550360003`*^9, 3.456082861042*^9}, {
   3.4560838200364*^9, 3.4560838290376*^9}, 3.4560840576244*^9, {
   3.4560840967335997`*^9, 3.4560841321924*^9}, 3.4561498885004*^9, 
   3.4566641229672947`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Cos", "[", 
     RowBox[{
      SubscriptBox["\[Phi]", "0"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "m"], "2"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "p"], "2"]}], "]"}]}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", "m"]}], "2"], "+", 
     FractionBox[
      SubscriptBox["\[Phi]", "p"], "2"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "+", 
     FractionBox[
      SubscriptBox["\[Phi]", "m"], "2"], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", "p"]}], "2"], "-", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "-", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", "m"]}], "2"], "+", 
     FractionBox[
      SubscriptBox["\[Phi]", "p"], "2"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     FractionBox[
      SubscriptBox["\[Phi]", "m"], "2"], "-", 
     FractionBox[
      SubscriptBox["\[Phi]", "p"], "2"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "p"]}], "-", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "+", 
     FractionBox[
      SubscriptBox["\[Phi]", "m"], "2"], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", "p"]}], "2"], "-", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "p"]}]}]], "Output",
 CellChangeTimes->{{3.4560828550360003`*^9, 3.456082861042*^9}, {
   3.4560838200364*^9, 3.4560838290376*^9}, 3.4560840576244*^9, {
   3.4560840967335997`*^9, 3.4560841321924*^9}, 3.4561498885004*^9, 
   3.4566641229672947`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       FractionBox[
        SubscriptBox["\[Phi]", "m"], "2"], "-", 
       FractionBox[
        SubscriptBox["\[Phi]", "p"], "2"]}], "]"}]}], " ", 
    SubscriptBox["a", "0"], " ", 
    SubscriptBox["a", "p"], " ", 
    SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{
      SubscriptBox["\[Phi]", "0"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "m"], "2"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "p"], "2"]}], "]"}], " ", 
    SubscriptBox["a", "0"], " ", 
    SubscriptBox["a", "p"], " ", 
    SubscriptBox["\[CurlyPhi]", "p"]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.4560839376136*^9, 3.4560839380192003`*^9}, {
  3.4560841545783997`*^9, 3.4560841894132*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "0"], "-", 
    FractionBox[
     SubscriptBox["\[Phi]", "m"], "2"], "-", 
    FractionBox[
     SubscriptBox["\[Phi]", "p"], "2"]}], "]"}], " ", 
  SubscriptBox["a", "0"], " ", 
  SubscriptBox["a", "p"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
    SubscriptBox["\[CurlyPhi]", "p"]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.4560839385184*^9, {3.4560841676668*^9, 3.4560841899748*^9}, 
   3.4561498885472*^9, 3.4566641230140944`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{
          SubscriptBox["\[Phi]", "0"], "-", 
          SubscriptBox["\[Phi]", "m"], "+", 
          RowBox[{"t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["a", "0"], " ", 
           SubscriptBox["a", "m"], " ", 
           SubscriptBox["\[CurlyPhi]", "m"]}], "-", 
          RowBox[{
           SubscriptBox["a", "0"], " ", 
           SubscriptBox["a", "m"], " ", 
           SubscriptBox["\[CurlyPhi]", "o"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{
          SubscriptBox["\[Phi]", "0"], "-", 
          SubscriptBox["\[Phi]", "p"], "-", 
          RowBox[{"t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "0"]}], " ", 
           SubscriptBox["a", "p"], " ", 
           SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
          RowBox[{
           SubscriptBox["a", "0"], " ", 
           SubscriptBox["a", "p"], " ", 
           SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}]}], ")"}]}], "/.", 
    RowBox[{
     SubscriptBox["a", "m"], "\[Rule]", 
     SubscriptBox["a", "p"]}]}], "//", "TrigReduce"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"%", 
    RowBox[{"Cos", "[", 
     RowBox[{
      FractionBox[
       SubscriptBox["\[Phi]", "m"], "2"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "p"], "2"], "-", 
      RowBox[{"t", " ", 
       SubscriptBox["\[Omega]", "S"]}]}], "]"}]}], ")"}], "//", 
  "TrigReduce"}]}], "Input",
 CellChangeTimes->{{3.456082851604*^9, 3.456082860574*^9}, {
  3.4560838137964*^9, 3.4560838284292*^9}, {3.4560840436312*^9, 
  3.4560840570004*^9}, {3.456084095158*^9, 3.456084131974*^9}, {
  3.4561499390444*^9, 3.4561499393564*^9}, {3.4561549661084003`*^9, 
  3.456154973066*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  SubscriptBox["a", "0"], " ", 
  SubscriptBox["a", "p"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "m"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["\[CurlyPhi]", "m"]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{
         SubscriptBox["\[Phi]", "0"], "-", 
         SubscriptBox["\[Phi]", "p"], "-", 
         RowBox[{"t", " ", 
          SubscriptBox["\[Omega]", "S"]}]}], "]"}], "+", 
       RowBox[{"Sin", "[", 
        RowBox[{
         SubscriptBox["\[Phi]", "0"], "-", 
         SubscriptBox["\[Phi]", "m"], "+", 
         RowBox[{"t", " ", 
          SubscriptBox["\[Omega]", "S"]}]}], "]"}]}], ")"}], " ", 
     SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.4561499397776003`*^9, {3.4561549692284*^9, 3.4561549751408*^9}, 
   3.4566641230608945`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     FractionBox[
      SubscriptBox["\[Phi]", "m"], "2"], "-", 
     FractionBox[
      SubscriptBox["\[Phi]", "p"], "2"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", "m"]}], "2"], "+", 
     FractionBox[
      SubscriptBox["\[Phi]", "p"], "2"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "m"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     FractionBox[
      SubscriptBox["\[Phi]", "m"], "2"], "-", 
     FractionBox[
      SubscriptBox["\[Phi]", "p"], "2"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "-", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "+", 
     FractionBox[
      SubscriptBox["\[Phi]", "m"], "2"], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", "p"]}], "2"], "-", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "-", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", "m"]}], "2"], "+", 
     FractionBox[
      SubscriptBox["\[Phi]", "p"], "2"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     FractionBox[
      SubscriptBox["\[Phi]", "m"], "2"], "-", 
     FractionBox[
      SubscriptBox["\[Phi]", "p"], "2"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "p"]}], "+", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "+", 
     FractionBox[
      SubscriptBox["\[Phi]", "m"], "2"], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", "p"]}], "2"], "-", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "p"]}]}]], "Output",
 CellChangeTimes->{
  3.4561499397776003`*^9, {3.4561549692284*^9, 3.4561549751408*^9}, 
   3.4566641230608945`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{
      SubscriptBox["\[Phi]", "0"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "m"], "2"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "p"], "2"]}], "]"}], " ", 
    SubscriptBox["a", "0"], " ", 
    SubscriptBox["a", "p"], " ", 
    SubscriptBox["\[CurlyPhi]", "m"]}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      SubscriptBox["\[Phi]", "0"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "m"], "2"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "p"], "2"]}], "]"}], " ", 
    SubscriptBox["a", "0"], " ", 
    SubscriptBox["a", "p"], " ", 
    SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{
      SubscriptBox["\[Phi]", "0"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "m"], "2"], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", "p"], "2"]}], "]"}], " ", 
    SubscriptBox["a", "0"], " ", 
    SubscriptBox["a", "p"], " ", 
    SubscriptBox["\[CurlyPhi]", "p"]}]}], " ", "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.456149978138*^9, 3.4561500097436*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sin", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "0"], "-", 
    FractionBox[
     SubscriptBox["\[Phi]", "m"], "2"], "-", 
    FractionBox[
     SubscriptBox["\[Phi]", "p"], "2"]}], "]"}], " ", 
  SubscriptBox["a", "0"], " ", 
  SubscriptBox["a", "p"], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[CurlyPhi]", "m"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
    SubscriptBox["\[CurlyPhi]", "p"]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4561499991512003`*^9, 3.4561500102272*^9}, 
   3.4566641231232944`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DC lock point", "Subsubsection",
 CellChangeTimes->{{3.4560792063364*^9, 3.4560792107511997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"apm", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["a", "m"], "\[Rule]", 
      RowBox[{
       SubscriptBox["a", "+"], "-", 
       SubscriptBox["a", "-"]}]}], ",", 
     RowBox[{
      SubscriptBox["a", "p"], "\[Rule]", 
      RowBox[{
       SubscriptBox["a", "+"], "+", 
       SubscriptBox["a", "-"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", "m"], "\[Rule]", 
      RowBox[{
       SubscriptBox["\[Phi]", "+"], "-", 
       SubscriptBox["\[Phi]", "-"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", "p"], "\[Rule]", 
      RowBox[{
       SubscriptBox["\[Phi]", "+"], "+", 
       SubscriptBox["\[Phi]", "-"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "m"], "\[Rule]", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "+"], "-", 
       SubscriptBox["\[CurlyPhi]", "-"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[CurlyPhi]", "p"], "\[Rule]", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "+"], "+", 
       SubscriptBox["\[CurlyPhi]", "-"]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4561620346632*^9, 3.4561620590772*^9}, {
  3.4561621658904*^9, 3.4561622029248*^9}, {3.456162717756*^9, 
  3.4561627254468*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"(", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Conjugate", "[", "Esum", "]"}], "]"}], ".", "Esum"}], 
  ")"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "\[LeftDoubleBracket]", 
    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "//", 
   "ComplexExpand"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["a", "m", "2"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubsuperscriptBox["a", "0", "2"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubsuperscriptBox["a", "p", "2"], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "m"], " ", 
       SubscriptBox["\[CurlyPhi]", "p"]}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "m"], " ", 
       SubscriptBox["\[CurlyPhi]", "o"]}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "o"], " ", 
       SubscriptBox["\[CurlyPhi]", "p"]}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "m"], " ", 
       SubscriptBox["a", "p"]}], "\[Rule]", "0"}]}], "}"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"error", " ", "signal"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"TrigExpand", "[", "%", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"%%", "/.", "apm"}], "]"}], "//", "Expand"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"TrigFactor", "[", 
  RowBox[{"%", "/.", 
   RowBox[{
    SubscriptBox["a", "-"], "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TrigFactor", "[", 
  RowBox[{"%%", "/.", 
   RowBox[{
    SubscriptBox["a", "+"], "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4560771628768*^9, 3.4560772006288*^9}, {
   3.4560772401280003`*^9, 3.4560772429828*^9}, {3.4560773995444*^9, 
   3.4560774746272*^9}, {3.4560790070931997`*^9, 3.4560791953384*^9}, {
   3.4560805283896*^9, 3.4560805318059998`*^9}, {3.4560805694332*^9, 
   3.4560806791948*^9}, {3.4560807362752*^9, 3.4560807390676003`*^9}, {
   3.456080782108*^9, 3.4560808268332*^9}, {3.4560808631656*^9, 
   3.4560809325076*^9}, {3.4560810928912*^9, 3.4560811240912*^9}, {
   3.456081254164*^9, 3.4560812708872004`*^9}, 3.456081302992*^9, {
   3.4561617024456*^9, 3.4561617434424*^9}, {3.4561618007412*^9, 
   3.4561618721268*^9}, {3.4561619200188*^9, 3.456161965758*^9}, 
   3.4561620299832*^9, {3.4561620689208*^9, 3.456162069498*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Conjugate", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Phi]", "0"]}]], " ", 
        SubscriptBox["a", "0"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "m"]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "m"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "p"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "p"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Phi]", "0"]}]], " ", 
        SubscriptBox["a", "0"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "m"]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "m"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "p"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "p"]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Conjugate", "[", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "m"]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Phi]", "0"]}]], " ", 
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "p"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "m"]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Phi]", "0"]}]], " ", 
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "p"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, 
   3.4566641232012944`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["a", "m", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubsuperscriptBox["\[CurlyPhi]", "m", "2"]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["a", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubsuperscriptBox["\[CurlyPhi]", "o", "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "m"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"2", " ", "t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "m"], " ", 
     SubscriptBox["a", "p"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{
        SubscriptBox["\[CurlyPhi]", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["a", "p", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubsuperscriptBox["\[CurlyPhi]", "p", "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["a", "0"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          SubscriptBox["\[Phi]", "0"], "-", 
          SubscriptBox["\[Phi]", "m"], "+", 
          RowBox[{"t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
        SubscriptBox["a", "m"], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{
           SubscriptBox["\[CurlyPhi]", "m"], " ", 
           SubscriptBox["\[CurlyPhi]", "o"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          SubscriptBox["\[Phi]", "0"], "-", 
          SubscriptBox["\[Phi]", "p"], "-", 
          RowBox[{"t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
        SubscriptBox["a", "p"], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{
           SubscriptBox["\[CurlyPhi]", "o"], " ", 
           SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, 
   3.4566641232012944`*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["a", "0"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "m"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "m"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "p"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, 
   3.4566641232012944`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "m"], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "m"], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "m"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "m"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "p"], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "p"], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "p"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "p"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"]}]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, 
   3.4566641232012944`*^9}],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sin", "[", 
       RowBox[{
        SubscriptBox["\[Phi]", "+"], "-", 
        SubscriptBox["\[Phi]", "0"]}], "]"}]}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "-"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "-"]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "+"], "-", 
       SubscriptBox["\[Phi]", "0"]}], "]"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "-"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "+"]}]}], ")"}], " ", 
  SubscriptBox["a", "0"]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, 
   3.456664123435294*^9}],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "+"], "-", 
    SubscriptBox["\[Phi]", "0"]}], "]"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "-"], "+", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
  SubscriptBox["a", "+"], " ", 
  SubscriptBox["a", "0"]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, 
   3.456664123435294*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "4"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "+"], "-", 
    SubscriptBox["\[Phi]", "0"]}], "]"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "-"], "+", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
  SubscriptBox["a", "-"], " ", 
  SubscriptBox["a", "0"]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, 
   3.456664123435294*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AC signal", "Subsubsection",
 CellChangeTimes->{{3.4560792063364*^9, 3.4560792508744*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"y0", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "0", "]"}], "/.", "apm"}], ")"}], "//", 
     "ComplexExpand"}], "//", "Simplify"}], "//", 
   "TrigFactor"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"2", "y0"}], 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Omega]", " ", "t"}], "]"}]], 
    RowBox[{"Cos", "[", 
     RowBox[{
      SubscriptBox["\[Phi]", "-"], "+", 
      RowBox[{"t", " ", 
       SubscriptBox["\[Omega]", "S"]}]}], "]"}]}], "//", "Simplify"}], "//", 
  "TrigReduce"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      SubscriptBox["\[Omega]", "S"], 
      RowBox[{"2", "\[Pi]"}]], "%"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      FractionBox[
       RowBox[{"2", "\[Pi]"}], 
       SubscriptBox["\[Omega]", "S"]]}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"TrigFactor", "[", 
  RowBox[{"%", "/.", 
   RowBox[{
    SubscriptBox["a", "+"], "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TrigFactor", "[", 
  RowBox[{"%%", "/.", 
   RowBox[{
    SubscriptBox["a", "-"], "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4560754053808002`*^9, 3.4560754056148*^9}, {
  3.4560754563772*^9, 3.456075583876*^9}, {3.4560759722848*^9, 
  3.456075973174*^9}, {3.456076008898*^9, 3.4560760134688*^9}, {
  3.4560792602656*^9, 3.4560792876748*^9}, {3.4560811593004*^9, 
  3.4560811700643997`*^9}, {3.4560824376424*^9, 3.4560824400916*^9}, {
  3.4561621027416*^9, 3.45616212558*^9}, {3.456163520922*^9, 
  3.456163521546*^9}, {3.456163588158*^9, 3.456163629576*^9}, {
  3.4561636612128*^9, 3.456163681602*^9}, {3.4561637254224*^9, 
  3.4561637325984*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"t", " ", "\[Omega]"}], "]"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", 
        SubscriptBox["\[Phi]", "-"]}], "+", 
       RowBox[{"2", " ", "t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SubsuperscriptBox["a", "-", "2"], " ", 
        SubscriptBox["\[CurlyPhi]", "-"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[CurlyPhi]", "-"], " ", 
        SubsuperscriptBox["a", "+", "2"]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "-"], "-", 
       SubscriptBox["\[Phi]", "+"], "+", 
       SubscriptBox["\[Phi]", "0"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "-"], " ", 
        SubscriptBox["\[CurlyPhi]", "-"], " ", 
        SubscriptBox["a", "0"]}], "-", 
       RowBox[{
        SubscriptBox["\[CurlyPhi]", "-"], " ", 
        SubscriptBox["a", "+"], " ", 
        SubscriptBox["a", "0"]}], "-", 
       RowBox[{
        SubscriptBox["a", "-"], " ", 
        SubscriptBox["\[CurlyPhi]", "+"], " ", 
        SubscriptBox["a", "0"]}], "+", 
       RowBox[{
        SubscriptBox["a", "+"], " ", 
        SubscriptBox["\[CurlyPhi]", "+"], " ", 
        SubscriptBox["a", "0"]}], "+", 
       RowBox[{
        SubscriptBox["a", "-"], " ", 
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}], "-", 
       RowBox[{
        SubscriptBox["a", "+"], " ", 
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "-"], "+", 
       SubscriptBox["\[Phi]", "+"], "-", 
       SubscriptBox["\[Phi]", "0"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "-"]}], " ", 
        SubscriptBox["\[CurlyPhi]", "-"], " ", 
        SubscriptBox["a", "0"]}], "-", 
       RowBox[{
        SubscriptBox["\[CurlyPhi]", "-"], " ", 
        SubscriptBox["a", "+"], " ", 
        SubscriptBox["a", "0"]}], "-", 
       RowBox[{
        SubscriptBox["a", "-"], " ", 
        SubscriptBox["\[CurlyPhi]", "+"], " ", 
        SubscriptBox["a", "0"]}], "-", 
       RowBox[{
        SubscriptBox["a", "+"], " ", 
        SubscriptBox["\[CurlyPhi]", "+"], " ", 
        SubscriptBox["a", "0"]}], "+", 
       RowBox[{
        SubscriptBox["a", "-"], " ", 
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
       RowBox[{
        SubscriptBox["a", "+"], " ", 
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4560754456132*^9, 3.4560754586703997`*^9}, 
   3.4560754983255997`*^9, {3.4560755531284*^9, 3.4560755847184*^9}, 
   3.4560759736264*^9, {3.4560760109572*^9, 3.456076014748*^9}, 
   3.4560767929228*^9, {3.4560792631204*^9, 3.4560792880804*^9}, {
   3.4560811461963997`*^9, 3.4560811836675997`*^9}, 3.456082440934*^9, 
   3.4561498883132*^9, 3.4561615960692*^9, {3.4561620902928*^9, 
   3.4561621275924*^9}, 3.4561627319676*^9, 3.4561635241512003`*^9, 
   3.4561635913248*^9, {3.4561636360188*^9, 3.4561636823508*^9}, 
   3.4561637297748003`*^9, 3.4566641251512947`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "-"], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubsuperscriptBox["a", "-", "2"], " ", 
   SubscriptBox["\[CurlyPhi]", "-"]}], "+", 
  RowBox[{"4", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"3", " ", 
      SubscriptBox["\[Phi]", "-"]}], "+", 
     RowBox[{"3", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubsuperscriptBox["a", "-", "2"], " ", 
   SubscriptBox["\[CurlyPhi]", "-"]}], "-", 
  RowBox[{"4", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "-"], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["\[CurlyPhi]", "-"], " ", 
   SubsuperscriptBox["a", "+", "2"]}], "-", 
  RowBox[{"4", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"3", " ", 
      SubscriptBox["\[Phi]", "-"]}], "+", 
     RowBox[{"3", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["\[CurlyPhi]", "-"], " ", 
   SubsuperscriptBox["a", "+", "2"]}], "-", 
  RowBox[{"4", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "+"], "-", 
     SubscriptBox["\[Phi]", "0"]}], "]"}], " ", 
   SubscriptBox["a", "-"], " ", 
   SubscriptBox["\[CurlyPhi]", "-"], " ", 
   SubscriptBox["a", "0"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "-"]}], "+", 
     SubscriptBox["\[Phi]", "+"], "-", 
     SubscriptBox["\[Phi]", "0"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "-"], " ", 
   SubscriptBox["\[CurlyPhi]", "-"], " ", 
   SubscriptBox["a", "0"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "-"]}], "-", 
     SubscriptBox["\[Phi]", "+"], "+", 
     SubscriptBox["\[Phi]", "0"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "-"], " ", 
   SubscriptBox["\[CurlyPhi]", "-"], " ", 
   SubscriptBox["a", "0"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "-"]}], "+", 
     SubscriptBox["\[Phi]", "+"], "-", 
     SubscriptBox["\[Phi]", "0"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["\[CurlyPhi]", "-"], " ", 
   SubscriptBox["a", "+"], " ", 
   SubscriptBox["a", "0"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "-"]}], "-", 
     SubscriptBox["\[Phi]", "+"], "+", 
     SubscriptBox["\[Phi]", "0"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["\[CurlyPhi]", "-"], " ", 
   SubscriptBox["a", "+"], " ", 
   SubscriptBox["a", "0"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "-"]}], "+", 
     SubscriptBox["\[Phi]", "+"], "-", 
     SubscriptBox["\[Phi]", "0"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "-"], " ", 
   SubscriptBox["\[CurlyPhi]", "+"], " ", 
   SubscriptBox["a", "0"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "-"]}], "-", 
     SubscriptBox["\[Phi]", "+"], "+", 
     SubscriptBox["\[Phi]", "0"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "-"], " ", 
   SubscriptBox["\[CurlyPhi]", "+"], " ", 
   SubscriptBox["a", "0"]}], "-", 
  RowBox[{"4", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "+"], "-", 
     SubscriptBox["\[Phi]", "0"]}], "]"}], " ", 
   SubscriptBox["a", "+"], " ", 
   SubscriptBox["\[CurlyPhi]", "+"], " ", 
   SubscriptBox["a", "0"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "-"]}], "+", 
     SubscriptBox["\[Phi]", "+"], "-", 
     SubscriptBox["\[Phi]", "0"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "+"], " ", 
   SubscriptBox["\[CurlyPhi]", "+"], " ", 
   SubscriptBox["a", "0"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "-"]}], "-", 
     SubscriptBox["\[Phi]", "+"], "+", 
     SubscriptBox["\[Phi]", "0"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "+"], " ", 
   SubscriptBox["\[CurlyPhi]", "+"], " ", 
   SubscriptBox["a", "0"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "-"]}], "+", 
     SubscriptBox["\[Phi]", "+"], "-", 
     SubscriptBox["\[Phi]", "0"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "-"], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "-"]}], "-", 
     SubscriptBox["\[Phi]", "+"], "+", 
     SubscriptBox["\[Phi]", "0"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "-"], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
  RowBox[{"4", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "+"], "-", 
     SubscriptBox["\[Phi]", "0"]}], "]"}], " ", 
   SubscriptBox["a", "+"], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "-"]}], "+", 
     SubscriptBox["\[Phi]", "+"], "-", 
     SubscriptBox["\[Phi]", "0"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "+"], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["\[Phi]", "-"]}], "-", 
     SubscriptBox["\[Phi]", "+"], "+", 
     SubscriptBox["\[Phi]", "0"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "+"], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}]}]], "Output",
 CellChangeTimes->{{3.4560754456132*^9, 3.4560754586703997`*^9}, 
   3.4560754983255997`*^9, {3.4560755531284*^9, 3.4560755847184*^9}, 
   3.4560759736264*^9, {3.4560760109572*^9, 3.456076014748*^9}, 
   3.4560767929228*^9, {3.4560792631204*^9, 3.4560792880804*^9}, {
   3.4560811461963997`*^9, 3.4560811836675997`*^9}, 3.456082440934*^9, 
   3.4561498883132*^9, 3.4561615960692*^9, {3.4561620902928*^9, 
   3.4561621275924*^9}, 3.4561627319676*^9, 3.4561635241512003`*^9, 
   3.4561635913248*^9, {3.4561636360188*^9, 3.4561636823508*^9}, 
   3.4561637297748003`*^9, 3.456664125478894*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "4"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "+"], "-", 
    SubscriptBox["\[Phi]", "0"]}], "]"}], " ", 
  SubscriptBox["a", "0"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "-"], " ", 
     SubscriptBox["\[CurlyPhi]", "-"]}], "+", 
    RowBox[{
     SubscriptBox["a", "+"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "+"], "-", 
       SubscriptBox["\[CurlyPhi]", "o"]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4560754456132*^9, 3.4560754586703997`*^9}, 
   3.4560754983255997`*^9, {3.4560755531284*^9, 3.4560755847184*^9}, 
   3.4560759736264*^9, {3.4560760109572*^9, 3.456076014748*^9}, 
   3.4560767929228*^9, {3.4560792631204*^9, 3.4560792880804*^9}, {
   3.4560811461963997`*^9, 3.4560811836675997`*^9}, 3.456082440934*^9, 
   3.4561498883132*^9, 3.4561615960692*^9, {3.4561620902928*^9, 
   3.4561621275924*^9}, 3.4561627319676*^9, 3.4561635241512003`*^9, 
   3.4561635913248*^9, {3.4561636360188*^9, 3.4561636823508*^9}, 
   3.4561637297748003`*^9, 3.4566641393472943`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "4"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "+"], "-", 
    SubscriptBox["\[Phi]", "0"]}], "]"}], " ", 
  SubscriptBox["a", "-"], " ", 
  SubscriptBox["\[CurlyPhi]", "-"], " ", 
  SubscriptBox["a", "0"]}]], "Output",
 CellChangeTimes->{{3.4560754456132*^9, 3.4560754586703997`*^9}, 
   3.4560754983255997`*^9, {3.4560755531284*^9, 3.4560755847184*^9}, 
   3.4560759736264*^9, {3.4560760109572*^9, 3.456076014748*^9}, 
   3.4560767929228*^9, {3.4560792631204*^9, 3.4560792880804*^9}, {
   3.4560811461963997`*^9, 3.4560811836675997`*^9}, 3.456082440934*^9, 
   3.4561498883132*^9, 3.4561615960692*^9, {3.4561620902928*^9, 
   3.4561621275924*^9}, 3.4561627319676*^9, 3.4561635241512003`*^9, 
   3.4561635913248*^9, {3.4561636360188*^9, 3.4561636823508*^9}, 
   3.4561637297748003`*^9, 3.4566641393472943`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "4"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "+"], "-", 
    SubscriptBox["\[Phi]", "0"]}], "]"}], " ", 
  SubscriptBox["a", "+"], " ", 
  SubscriptBox["a", "0"], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[CurlyPhi]", "+"], "-", 
    SubscriptBox["\[CurlyPhi]", "o"]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4560754456132*^9, 3.4560754586703997`*^9}, 
   3.4560754983255997`*^9, {3.4560755531284*^9, 3.4560755847184*^9}, 
   3.4560759736264*^9, {3.4560760109572*^9, 3.456076014748*^9}, 
   3.4560767929228*^9, {3.4560792631204*^9, 3.4560792880804*^9}, {
   3.4560811461963997`*^9, 3.4560811836675997`*^9}, 3.456082440934*^9, 
   3.4561498883132*^9, 3.4561615960692*^9, {3.4561620902928*^9, 
   3.4561621275924*^9}, 3.4561627319676*^9, 3.4561635241512003`*^9, 
   3.4561635913248*^9, {3.4561636360188*^9, 3.4561636823508*^9}, 
   3.4561637297748003`*^9, 3.456664139362894*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DC lock point", "Subsubsection",
 CellChangeTimes->{{3.4560792063364*^9, 3.4560792107511997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"(", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Conjugate", "[", "Esum", "]"}], "]"}], ".", "Esum"}], 
  ")"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "\[LeftDoubleBracket]", 
    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "//", 
   "ComplexExpand"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["a", "m", "2"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubsuperscriptBox["a", "0", "2"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubsuperscriptBox["a", "p", "2"], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "m"], " ", 
       SubscriptBox["\[CurlyPhi]", "p"]}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "m"], " ", 
       SubscriptBox["\[CurlyPhi]", "o"]}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "o"], " ", 
       SubscriptBox["\[CurlyPhi]", "p"]}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "m"], " ", 
       SubscriptBox["a", "p"]}], "\[Rule]", "0"}]}], "}"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"error", " ", "signal"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"TrigExpand", "[", "%", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"2", "%%", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "M"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}]}], "]"}], "//", "Expand"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      SubscriptBox["\[Omega]", "S"], 
      RowBox[{"2", "\[Pi]"}]], "%"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      FractionBox[
       RowBox[{"2", "\[Pi]"}], 
       SubscriptBox["\[Omega]", "S"]]}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"TrigFactor", "[", 
  RowBox[{"%", "/.", 
   RowBox[{
    SubscriptBox["a", "m"], "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TrigFactor", "[", 
  RowBox[{"%%", "/.", 
   RowBox[{
    SubscriptBox["a", "p"], "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4560771628768*^9, 3.4560772006288*^9}, {
   3.4560772401280003`*^9, 3.4560772429828*^9}, {3.4560773995444*^9, 
   3.4560774746272*^9}, {3.4560790070931997`*^9, 3.4560791953384*^9}, {
   3.4560805283896*^9, 3.4560805318059998`*^9}, {3.4560805694332*^9, 
   3.4560806791948*^9}, {3.4560807362752*^9, 3.4560807390676003`*^9}, {
   3.456080782108*^9, 3.4560808268332*^9}, {3.4560808631656*^9, 
   3.4560809325076*^9}, {3.4560810928912*^9, 3.4560811240912*^9}, {
   3.456081254164*^9, 3.4560812708872004`*^9}, 3.456081302992*^9, {
   3.4561617024456*^9, 3.4561617434424*^9}, {3.4561618007412*^9, 
   3.4561618721268*^9}, {3.4561619200188*^9, 3.456161965758*^9}, 
   3.4561620299832*^9, {3.4561620689208*^9, 3.456162069498*^9}, {
   3.4561701484421997`*^9, 3.4561702079406*^9}, {3.4561702384386*^9, 
   3.4561703317734003`*^9}, {3.4561715898042*^9, 3.4561716018162003`*^9}, {
   3.456172457289*^9, 3.4561724576166*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Conjugate", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Phi]", "0"]}]], " ", 
        SubscriptBox["a", "0"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "m"]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "m"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "p"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "p"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Phi]", "0"]}]], " ", 
        SubscriptBox["a", "0"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "m"]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "m"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "p"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "p"]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Conjugate", "[", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "m"]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Phi]", "0"]}]], " ", 
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "p"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "m"]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Phi]", "0"]}]], " ", 
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "p"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}]], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, {
   3.4561701494094*^9, 3.4561702085958*^9}, {3.4561702394526*^9, 
   3.4561702855038*^9}, 3.4561714902762003`*^9, 3.4561716025806*^9, 
   3.4566641394096947`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["a", "m", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubsuperscriptBox["\[CurlyPhi]", "m", "2"]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["a", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubsuperscriptBox["\[CurlyPhi]", "o", "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "m"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"2", " ", "t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "m"], " ", 
     SubscriptBox["a", "p"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{
        SubscriptBox["\[CurlyPhi]", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["a", "p", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubsuperscriptBox["\[CurlyPhi]", "p", "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["a", "0"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          SubscriptBox["\[Phi]", "0"], "-", 
          SubscriptBox["\[Phi]", "m"], "+", 
          RowBox[{"t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
        SubscriptBox["a", "m"], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{
           SubscriptBox["\[CurlyPhi]", "m"], " ", 
           SubscriptBox["\[CurlyPhi]", "o"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          SubscriptBox["\[Phi]", "0"], "-", 
          SubscriptBox["\[Phi]", "p"], "-", 
          RowBox[{"t", " ", 
           SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
        SubscriptBox["a", "p"], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{
           SubscriptBox["\[CurlyPhi]", "o"], " ", 
           SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, {
   3.4561701494094*^9, 3.4561702085958*^9}, {3.4561702394526*^9, 
   3.4561702855038*^9}, 3.4561714902762003`*^9, 3.4561716025806*^9, 
   3.4566641394252944`*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["a", "0"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "m"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "m"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "p"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, {
   3.4561701494094*^9, 3.4561702085958*^9}, {3.4561702394526*^9, 
   3.4561702855038*^9}, 3.4561714902762003`*^9, 3.4561716025806*^9, 
   3.456664139440894*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "m"], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "m"], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "m"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "m"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "p"], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "p"], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "p"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    SubscriptBox["\[Phi]", "0"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    SubscriptBox["\[Phi]", "p"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"]}]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, {
   3.4561701494094*^9, 3.4561702085958*^9}, {3.4561702394526*^9, 
   3.4561702855038*^9}, 3.4561714902762003`*^9, 3.4561716025806*^9, 
   3.4566641394564943`*^9}],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "M"], "+", 
    RowBox[{"t", " ", 
     SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
  SubscriptBox["a", "0"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "m"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "m"]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     SubscriptBox["a", "p"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, {
   3.4561701494094*^9, 3.4561702085958*^9}, {3.4561702394526*^9, 
   3.4561702855038*^9}, 3.4561714902762003`*^9, 3.4561716025806*^9, 
   3.4566641394876947`*^9}],

Cell[BoxData[
 RowBox[{"2", " ", 
  SubscriptBox["a", "0"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "m"], "-", 
       SubscriptBox["\[Phi]", "M"]}], "]"}], " ", 
     SubscriptBox["a", "m"]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "+", 
       SubscriptBox["\[Phi]", "M"], "-", 
       SubscriptBox["\[Phi]", "p"]}], "]"}], " ", 
     SubscriptBox["a", "p"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, {
   3.4561701494094*^9, 3.4561702085958*^9}, {3.4561702394526*^9, 
   3.4561702855038*^9}, 3.4561714902762003`*^9, 3.4561716025806*^9, 
   3.4566641407356944`*^9}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "0"], "+", 
    SubscriptBox["\[Phi]", "M"], "-", 
    SubscriptBox["\[Phi]", "p"]}], "]"}], " ", 
  SubscriptBox["a", "0"], " ", 
  SubscriptBox["a", "p"]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, {
   3.4561701494094*^9, 3.4561702085958*^9}, {3.4561702394526*^9, 
   3.4561702855038*^9}, 3.4561714902762003`*^9, 3.4561716025806*^9, 
   3.456664140751294*^9}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "0"], "-", 
    SubscriptBox["\[Phi]", "m"], "-", 
    SubscriptBox["\[Phi]", "M"]}], "]"}], " ", 
  SubscriptBox["a", "0"], " ", 
  SubscriptBox["a", "m"]}]], "Output",
 CellChangeTimes->{{3.4560771665896*^9, 3.4560772011748*^9}, {
   3.4560772353388*^9, 3.45607724356*^9}, {3.4560773871892*^9, 
   3.4560774752824*^9}, {3.4560790184968*^9, 3.4560790411012*^9}, {
   3.4560791546848*^9, 3.4560791751208*^9}, 3.456080326822*^9, {
   3.4560805217595997`*^9, 3.4560805345048*^9}, {3.4560805898224*^9, 
   3.4560806797251997`*^9}, 3.45608073952*^9, {3.4560807864604*^9, 
   3.4560808272855997`*^9}, {3.4560808669407997`*^9, 3.4560809330848*^9}, {
   3.4560810937024*^9, 3.4560811255108*^9}, {3.4560812624944*^9, 
   3.4560813032728*^9}, 3.456082214656*^9, 3.4561498873459997`*^9, 
   3.4561617447216*^9, {3.4561618017864*^9, 3.4561618731408*^9}, 
   3.4561619255411997`*^9, 3.4561619665224*^9, 3.4561620701532*^9, {
   3.4561701494094*^9, 3.4561702085958*^9}, {3.4561702394526*^9, 
   3.4561702855038*^9}, 3.4561714902762003`*^9, 3.4561716025806*^9, 
   3.4566641407668943`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AC signal", "Subsubsection",
 CellChangeTimes->{{3.4560792063364*^9, 3.4560792508744*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"y0", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Y", "[", "0", "]"}], ")"}], "//", "ComplexExpand"}], "//", 
    "Simplify"}], "//", "TrigFactor"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"2", "y0"}], 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Omega]", " ", "t"}], "]"}]], 
    RowBox[{"Cos", "[", 
     RowBox[{
      SubscriptBox["\[Phi]", "M"], "+", 
      RowBox[{"t", " ", 
       SubscriptBox["\[Omega]", "S"]}]}], "]"}]}], "//", "Simplify"}], "//", 
  "TrigReduce"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      SubscriptBox["\[Omega]", "S"], 
      RowBox[{"2", "\[Pi]"}]], "%"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      FractionBox[
       RowBox[{"2", "\[Pi]"}], 
       SubscriptBox["\[Omega]", "S"]]}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"TrigFactor", "[", 
  RowBox[{"%", "/.", 
   RowBox[{
    SubscriptBox["a", "m"], "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TrigFactor", "[", 
  RowBox[{"%%", "/.", 
   RowBox[{
    SubscriptBox["a", "p"], "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4561637435808*^9, 3.4561637438616*^9}, {
  3.4561699151754*^9, 3.4561699258613997`*^9}, {3.4561699993374*^9, 
  3.4561700216610003`*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"t", " ", "\[Omega]"}], "]"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "m"], "+", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["a", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "m"]}], "-", 
       RowBox[{
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["a", "m"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "0"]}], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
       RowBox[{
        SubscriptBox["a", "0"], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "m"], "-", 
       SubscriptBox["\[Phi]", "p"], "-", 
       RowBox[{"2", " ", "t", " ", 
        SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "m"]}], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
       RowBox[{
        SubscriptBox["a", "m"], " ", 
        SubscriptBox["a", "p"], " ", 
        SubscriptBox["\[CurlyPhi]", "p"]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.4561637466540003`*^9, {3.456169919949*^9, 3.4561699300889997`*^9}, {
   3.4561700054681997`*^9, 3.4561700222538*^9}, 3.456664140829294*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     SubscriptBox["\[Phi]", "m"], "-", 
     SubscriptBox["\[Phi]", "M"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"], " ", 
   SubscriptBox["\[CurlyPhi]", "m"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     SubscriptBox["\[Phi]", "m"], "+", 
     SubscriptBox["\[Phi]", "M"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"], " ", 
   SubscriptBox["\[CurlyPhi]", "m"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "m"], "-", 
     SubscriptBox["\[Phi]", "M"], "-", 
     SubscriptBox["\[Phi]", "p"], "-", 
     RowBox[{"3", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "m"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "m"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "m"], "+", 
     SubscriptBox["\[Phi]", "M"], "-", 
     SubscriptBox["\[Phi]", "p"], "-", 
     RowBox[{"t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "m"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "m"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     SubscriptBox["\[Phi]", "m"], "-", 
     SubscriptBox["\[Phi]", "M"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     SubscriptBox["\[Phi]", "m"], "+", 
     SubscriptBox["\[Phi]", "M"], "+", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "m"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "+", 
     SubscriptBox["\[Phi]", "M"], "-", 
     SubscriptBox["\[Phi]", "p"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     SubscriptBox["\[Phi]", "M"], "-", 
     SubscriptBox["\[Phi]", "p"], "-", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "+", 
     SubscriptBox["\[Phi]", "M"], "-", 
     SubscriptBox["\[Phi]", "p"]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "p"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "-", 
     SubscriptBox["\[Phi]", "M"], "-", 
     SubscriptBox["\[Phi]", "p"], "-", 
     RowBox[{"2", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "0"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "p"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "m"], "-", 
     SubscriptBox["\[Phi]", "M"], "-", 
     SubscriptBox["\[Phi]", "p"], "-", 
     RowBox[{"3", " ", "t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "m"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "p"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Phi]", "m"], "+", 
     SubscriptBox["\[Phi]", "M"], "-", 
     SubscriptBox["\[Phi]", "p"], "-", 
     RowBox[{"t", " ", 
      SubscriptBox["\[Omega]", "S"]}]}], "]"}], " ", 
   SubscriptBox["a", "m"], " ", 
   SubscriptBox["a", "p"], " ", 
   SubscriptBox["\[CurlyPhi]", "p"]}]}]], "Output",
 CellChangeTimes->{
  3.4561637466540003`*^9, {3.456169919949*^9, 3.4561699300889997`*^9}, {
   3.4561700054681997`*^9, 3.4561700222538*^9}, 3.4566641409852943`*^9}],

Cell[BoxData[
 RowBox[{"2", " ", 
  SubscriptBox["a", "0"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "-", 
       SubscriptBox["\[Phi]", "m"], "-", 
       SubscriptBox["\[Phi]", "M"]}], "]"}], " ", 
     SubscriptBox["a", "m"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[CurlyPhi]", "m"], "-", 
       SubscriptBox["\[CurlyPhi]", "o"]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Phi]", "0"], "+", 
       SubscriptBox["\[Phi]", "M"], "-", 
       SubscriptBox["\[Phi]", "p"]}], "]"}], " ", 
     SubscriptBox["a", "p"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[CurlyPhi]", "o"]}], "+", 
       SubscriptBox["\[CurlyPhi]", "p"]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.4561637466540003`*^9, {3.456169919949*^9, 3.4561699300889997`*^9}, {
   3.4561700054681997`*^9, 3.4561700222538*^9}, 3.4566641502360945`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "0"], "+", 
    SubscriptBox["\[Phi]", "M"], "-", 
    SubscriptBox["\[Phi]", "p"]}], "]"}], " ", 
  SubscriptBox["a", "0"], " ", 
  SubscriptBox["a", "p"], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[CurlyPhi]", "o"], "-", 
    SubscriptBox["\[CurlyPhi]", "p"]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.4561637466540003`*^9, {3.456169919949*^9, 3.4561699300889997`*^9}, {
   3.4561700054681997`*^9, 3.4561700222538*^9}, 3.4566641502360945`*^9}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"Sin", "[", 
   RowBox[{
    SubscriptBox["\[Phi]", "0"], "-", 
    SubscriptBox["\[Phi]", "m"], "-", 
    SubscriptBox["\[Phi]", "M"]}], "]"}], " ", 
  SubscriptBox["a", "0"], " ", 
  SubscriptBox["a", "m"], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[CurlyPhi]", "m"], "-", 
    SubscriptBox["\[CurlyPhi]", "o"]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.4561637466540003`*^9, {3.456169919949*^9, 3.4561699300889997`*^9}, {
   3.4561700054681997`*^9, 3.4561700222538*^9}, 3.4566641502360945`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{842, 1077},
WindowMargins->{{165, Automatic}, {Automatic, -12}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 101, 1, 103, "Title"],
Cell[CellGroupData[{
Cell[693, 27, 24, 0, 88, "Section"],
Cell[720, 29, 150, 2, 35, "Input"],
Cell[873, 33, 222, 6, 35, "Input"],
Cell[1098, 41, 1452, 39, 146, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2587, 85, 96, 1, 88, "Section"],
Cell[CellGroupData[{
Cell[2708, 90, 93, 1, 46, "Subsection"],
Cell[2804, 93, 546, 16, 80, "Input"],
Cell[CellGroupData[{
Cell[3375, 113, 113, 1, 32, "Subsubsection"],
Cell[3491, 116, 354, 7, 76, "Text"],
Cell[3848, 125, 513, 15, 65, "Input"],
Cell[CellGroupData[{
Cell[4386, 144, 764, 17, 102, "Input"],
Cell[5153, 163, 681, 9, 35, "Output"],
Cell[5837, 174, 681, 9, 35, "Output"],
Cell[6521, 185, 677, 9, 35, "Output"],
Cell[7201, 196, 681, 9, 35, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7943, 212, 91, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[8059, 217, 5870, 165, 556, "Input"],
Cell[13932, 384, 2789, 59, 152, "Output"],
Cell[16724, 445, 1579, 22, 35, "Output"],
Cell[18306, 469, 1577, 22, 35, "Output"],
Cell[19886, 493, 1580, 22, 35, "Output"],
Cell[21469, 517, 1580, 22, 35, "Output"],
Cell[23052, 541, 1580, 22, 35, "Output"],
Cell[24635, 565, 1580, 22, 35, "Output"],
Cell[26218, 589, 1576, 22, 35, "Output"],
Cell[27797, 613, 1578, 22, 35, "Output"],
Cell[29378, 637, 1578, 22, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30993, 664, 1947, 52, 210, "Input"],
Cell[32943, 718, 1745, 42, 100, "Output"],
Cell[34691, 762, 791, 11, 35, "Output"],
Cell[35485, 775, 794, 11, 35, "Output"],
Cell[36282, 788, 794, 11, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37125, 805, 89, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[37239, 810, 1520, 42, 210, "Input"],
Cell[38762, 854, 1449, 38, 100, "Output"],
Cell[40214, 894, 498, 7, 35, "Output"],
Cell[40715, 903, 501, 7, 35, "Output"],
Cell[41219, 912, 498, 7, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41754, 924, 1663, 44, 208, "Input"],
Cell[43420, 970, 1651, 41, 139, "Output"],
Cell[45074, 1013, 682, 10, 35, "Output"],
Cell[45759, 1025, 686, 10, 35, "Output"],
Cell[46448, 1037, 683, 10, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47180, 1053, 104, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[47309, 1058, 4804, 130, 517, "Input"],
Cell[52116, 1190, 393, 6, 29, "Print"],
Cell[52512, 1198, 594, 8, 35, "Output"],
Cell[53109, 1208, 397, 6, 29, "Print"],
Cell[53509, 1216, 592, 8, 35, "Output"],
Cell[54104, 1226, 592, 8, 35, "Output"],
Cell[54699, 1236, 618, 9, 35, "Output"],
Cell[55320, 1247, 346, 5, 27, "Print"],
Cell[55669, 1254, 811, 13, 55, "Output"],
Cell[56483, 1269, 2718, 50, 295, "Output"],
Cell[59204, 1321, 649, 10, 35, "Output"],
Cell[59856, 1333, 395, 6, 29, "Print"],
Cell[60254, 1341, 593, 8, 35, "Output"],
Cell[60850, 1351, 393, 6, 29, "Print"],
Cell[61246, 1359, 619, 9, 35, "Output"],
Cell[61868, 1370, 592, 8, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62497, 1383, 1354, 42, 180, "Input"],
Cell[63854, 1427, 455, 13, 57, "Output"],
Cell[64312, 1442, 414, 12, 57, "Output"],
Cell[64729, 1456, 455, 13, 57, "Output"],
Cell[65187, 1471, 411, 12, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[65647, 1489, 87, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[65759, 1494, 1381, 37, 206, "Input"],
Cell[67143, 1533, 511, 8, 35, "Output"],
Cell[67657, 1543, 503, 8, 35, "Output"],
Cell[68163, 1553, 510, 8, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68710, 1566, 111, 1, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[68846, 1571, 613, 16, 80, "Input"],
Cell[69462, 1589, 659, 10, 35, "Output"],
Cell[70124, 1601, 565, 8, 35, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[70762, 1617, 100, 1, 88, "Section"],
Cell[CellGroupData[{
Cell[70887, 1622, 101, 1, 46, "Subsection"],
Cell[70991, 1625, 14832, 410, 1157, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85860, 2040, 186, 3, 57, "Subsection"],
Cell[CellGroupData[{
Cell[86071, 2047, 148, 2, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[86244, 2053, 489, 11, 72, "Input"],
Cell[86736, 2066, 395, 10, 71, "Output"],
Cell[87134, 2078, 395, 10, 71, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[87578, 2094, 192, 3, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[87795, 2101, 539, 12, 72, "Input"],
Cell[88337, 2115, 257, 6, 67, "Output"],
Cell[88597, 2123, 257, 6, 67, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[88903, 2135, 165, 2, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[89093, 2141, 1786, 53, 200, "Input"],
Cell[90882, 2196, 1525, 36, 73, "Output"],
Cell[92410, 2234, 1652, 41, 77, "Output"],
Cell[94065, 2277, 1117, 25, 77, "Output"],
Cell[95185, 2304, 972, 20, 73, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[96206, 2330, 215, 3, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[96446, 2337, 1602, 44, 180, "Input"],
Cell[98051, 2383, 614, 16, 73, "Output"],
Cell[98668, 2401, 716, 21, 77, "Output"],
Cell[99387, 2424, 211, 4, 43, "Output"],
Cell[99601, 2430, 635, 19, 77, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[100285, 2455, 216, 3, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[100526, 2462, 2182, 64, 201, "Input"],
Cell[102711, 2528, 1107, 31, 71, "Output"],
Cell[103821, 2561, 1264, 37, 100, "Output"],
Cell[105088, 2600, 690, 18, 75, "Output"],
Cell[105781, 2620, 560, 14, 73, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[106390, 2640, 263, 3, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[106678, 2647, 1779, 50, 181, "Input"],
Cell[108460, 2699, 650, 17, 71, "Output"],
Cell[109113, 2718, 755, 21, 75, "Output"],
Cell[109871, 2741, 255, 4, 43, "Output"],
Cell[110129, 2747, 689, 19, 75, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[110879, 2773, 190, 3, 57, "Subsection"],
Cell[CellGroupData[{
Cell[111094, 2780, 148, 2, 40, "Subsubsection"],
Cell[111245, 2784, 253, 7, 66, "Input"],
Cell[CellGroupData[{
Cell[111523, 2795, 1066, 27, 118, "Input"],
Cell[112592, 2824, 402, 12, 71, "Output"],
Cell[112997, 2838, 379, 11, 71, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[113425, 2855, 192, 3, 40, "Subsubsection"],
Cell[113620, 2860, 253, 7, 66, "Input"],
Cell[CellGroupData[{
Cell[113898, 2871, 1116, 28, 118, "Input"],
Cell[115017, 2901, 353, 10, 67, "Output"],
Cell[115373, 2913, 329, 9, 67, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[115751, 2928, 165, 2, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[115941, 2934, 1395, 47, 200, "Input"],
Cell[117339, 2983, 2256, 58, 107, "Output"],
Cell[119598, 3043, 2495, 67, 141, "Output"],
Cell[122096, 3112, 1211, 33, 77, "Output"],
Cell[123310, 3147, 1388, 37, 75, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[124759, 3191, 231, 3, 57, "Subsection"],
Cell[CellGroupData[{
Cell[125015, 3198, 161, 2, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[125201, 3204, 1726, 56, 233, "Input"],
Cell[126930, 3262, 3363, 96, 201, "Output"],
Cell[130296, 3360, 3440, 99, 228, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133773, 3464, 2635, 59, 217, "Input"],
Cell[136411, 3525, 2868, 64, 201, "Output"],
Cell[139282, 3591, 1088, 15, 43, "Output"],
Cell[140373, 3608, 10186, 171, 623, "Output"],
Cell[150562, 3781, 9160, 155, 362, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[159759, 3941, 1532, 42, 155, "Input"],
Cell[161294, 3985, 1863, 45, 105, "Output"],
Cell[163160, 4032, 442, 7, 43, "Output"],
Cell[163605, 4041, 32775, 545, 660, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[196429, 4592, 216, 3, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[196670, 4599, 2369, 70, 235, "Input"],
Cell[199042, 4671, 1679, 50, 93, "Output"],
Cell[200724, 4723, 2991, 85, 353, "Output"],
Cell[203718, 4810, 1644, 46, 141, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[205399, 4861, 4574, 113, 652, "Input"],
Cell[209976, 4976, 692, 14, 103, "Output"],
Cell[210671, 4992, 1162, 28, 143, "Output"],
Cell[211836, 5022, 21985, 367, 835, "Output"],
Cell[233824, 5391, 6049, 105, 362, "Output"],
Cell[239876, 5498, 21242, 354, 662, "Output"],
Cell[261121, 5854, 4190, 76, 380, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[265384, 5938, 232, 3, 110, "Section"],
Cell[265619, 5943, 2104, 63, 101, "Text"],
Cell[267726, 6008, 14197, 418, 1042, "Input"],
Cell[281926, 6428, 5634, 148, 511, "Input"],
Cell[287563, 6578, 148, 2, 100, "Input"],
Cell[CellGroupData[{
Cell[287736, 6584, 1490, 46, 182, "Input"],
Cell[289229, 6632, 191, 4, 43, "Output"],
Cell[289423, 6638, 494, 12, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[289954, 6655, 2568, 73, 162, "Input"],
Cell[292525, 6730, 299, 7, 47, "Output"]
}, Open  ]],
Cell[292839, 6740, 2557, 78, 136, "Input"],
Cell[CellGroupData[{
Cell[295421, 6822, 3458, 88, 332, "Input"],
Cell[298882, 6912, 24185, 405, 635, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[323104, 7322, 1677, 46, 182, "Input"],
Cell[324784, 7370, 380, 11, 108, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[325201, 7386, 1958, 53, 171, "Input"],
Cell[327162, 7441, 273, 3, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[327472, 7449, 246, 6, 103, "Input"],
Cell[327721, 7457, 167, 2, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[327925, 7464, 5306, 137, 566, "Input"],
Cell[333234, 7603, 23742, 396, 612, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[357013, 8004, 6396, 165, 722, "Input"],
Cell[363412, 8171, 19999, 337, 597, "Output"]
}, Open  ]],
Cell[383426, 8511, 70, 1, 66, "Input"],
Cell[CellGroupData[{
Cell[383521, 8516, 6392, 190, 845, "Input"],
Cell[389916, 8708, 1661, 44, 116, "Output"],
Cell[391580, 8754, 757, 18, 120, "Output"],
Cell[392340, 8774, 546, 10, 102, "Output"],
Cell[392889, 8786, 1078, 28, 113, "Output"],
Cell[393970, 8816, 651, 15, 112, "Output"],
Cell[394624, 8833, 547, 10, 102, "Output"],
Cell[395174, 8845, 1107, 27, 116, "Output"],
Cell[396284, 8874, 768, 18, 120, "Output"],
Cell[397055, 8894, 546, 10, 102, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[397638, 8909, 238, 5, 65, "Subsubsection"],
Cell[CellGroupData[{
Cell[397901, 8918, 12032, 322, 2360, "Input"],
Cell[409936, 9242, 1026, 15, 51, "Print"],
Cell[410965, 9259, 1812, 33, 113, "Output"],
Cell[412780, 9294, 1028, 15, 51, "Print"],
Cell[413811, 9311, 2013, 38, 112, "Output"],
Cell[415827, 9351, 2789, 59, 116, "Output"],
Cell[418619, 9412, 1032, 15, 51, "Print"],
Cell[419654, 9429, 1863, 33, 112, "Output"],
Cell[421520, 9464, 2181, 42, 116, "Output"],
Cell[423704, 9508, 1027, 15, 51, "Print"],
Cell[424734, 9525, 1456, 21, 43, "Output"],
Cell[426193, 9548, 2098, 41, 72, "Output"],
Cell[428294, 9591, 1075, 16, 33, "Print"],
Cell[429372, 9609, 1863, 33, 72, "Output"],
Cell[431238, 9644, 2186, 42, 75, "Output"],
Cell[433427, 9688, 1079, 16, 33, "Print"],
Cell[434509, 9706, 1905, 34, 72, "Output"],
Cell[436417, 9742, 2181, 42, 75, "Output"],
Cell[438601, 9786, 1031, 15, 33, "Print"],
Cell[439635, 9803, 1401, 19, 43, "Output"],
Cell[441039, 9824, 2098, 41, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[443186, 9871, 297, 5, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[443508, 9880, 12142, 325, 1511, "Input"],
Cell[455653, 10207, 1081, 16, 33, "Print"],
Cell[456737, 10225, 1953, 37, 85, "Output"],
Cell[458693, 10264, 1085, 16, 33, "Print"],
Cell[459781, 10282, 2004, 38, 75, "Output"],
Cell[461788, 10322, 2815, 60, 75, "Output"],
Cell[464606, 10384, 1085, 16, 33, "Print"],
Cell[465694, 10402, 1903, 34, 72, "Output"],
Cell[467600, 10438, 1938, 34, 75, "Output"],
Cell[469541, 10474, 1084, 16, 33, "Print"],
Cell[470628, 10492, 1492, 22, 43, "Output"],
Cell[472123, 10516, 2037, 39, 75, "Output"],
Cell[474163, 10557, 1136, 17, 33, "Print"],
Cell[475302, 10576, 1900, 34, 72, "Output"],
Cell[477205, 10612, 1939, 34, 75, "Output"],
Cell[479147, 10648, 1140, 17, 33, "Print"],
Cell[480290, 10667, 1937, 35, 72, "Output"],
Cell[482230, 10704, 1943, 34, 75, "Output"],
Cell[484176, 10740, 1088, 16, 33, "Print"],
Cell[485267, 10758, 1437, 20, 43, "Output"],
Cell[486707, 10780, 2041, 39, 75, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[488785, 10824, 5049, 145, 601, "Input"],
Cell[493837, 10971, 1294, 37, 75, "Output"],
Cell[495134, 11010, 675, 22, 78, "Output"],
Cell[495812, 11034, 551, 17, 75, "Output"],
Cell[496366, 11053, 398, 14, 77, "Output"],
Cell[496767, 11069, 561, 17, 75, "Output"],
Cell[497331, 11088, 408, 14, 77, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[497788, 11108, 355, 6, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[498168, 11118, 12086, 324, 1511, "Input"],
Cell[510257, 11444, 1033, 15, 33, "Print"],
Cell[511293, 11461, 1786, 32, 73, "Output"],
Cell[513082, 11495, 1031, 15, 33, "Print"],
Cell[514116, 11512, 2000, 38, 72, "Output"],
Cell[516119, 11552, 2726, 57, 75, "Output"],
Cell[518848, 11611, 1031, 15, 33, "Print"],
Cell[519882, 11628, 1858, 33, 72, "Output"],
Cell[521743, 11663, 2145, 42, 75, "Output"],
Cell[523891, 11707, 1034, 15, 33, "Print"],
Cell[524928, 11724, 1447, 21, 43, "Output"],
Cell[526378, 11747, 1922, 34, 72, "Output"],
Cell[528303, 11783, 1082, 16, 33, "Print"],
Cell[529388, 11801, 1855, 33, 72, "Output"],
Cell[531246, 11836, 2145, 42, 75, "Output"],
Cell[533394, 11880, 1082, 16, 33, "Print"],
Cell[534479, 11898, 1896, 34, 72, "Output"],
Cell[536378, 11934, 2145, 42, 75, "Output"],
Cell[538526, 11978, 1038, 15, 33, "Print"],
Cell[539567, 11995, 1392, 19, 43, "Output"],
Cell[540962, 12016, 1921, 34, 72, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[542920, 12055, 5145, 147, 520, "Input"],
Cell[548068, 12204, 1523, 42, 75, "Output"],
Cell[549594, 12248, 613, 18, 77, "Output"],
Cell[550210, 12268, 740, 20, 73, "Output"],
Cell[550953, 12290, 445, 12, 73, "Output"],
Cell[551401, 12304, 903, 25, 75, "Output"],
Cell[552307, 12331, 613, 18, 77, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[552969, 12355, 431, 7, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[553425, 12366, 16950, 487, 1545, "Input"],
Cell[CellGroupData[{
Cell[570400, 12857, 334, 5, 33, "Print"],
Cell[570737, 12864, 336, 5, 33, "Print"]
}, Open  ]],
Cell[571088, 12872, 1499, 40, 75, "Output"],
Cell[572590, 12914, 2326, 63, 107, "Output"],
Cell[574919, 12979, 332, 5, 33, "Print"],
Cell[575254, 12986, 1212, 31, 75, "Output"],
Cell[576469, 13019, 1462, 38, 75, "Output"],
Cell[577934, 13059, 335, 5, 33, "Print"],
Cell[578272, 13066, 403, 8, 43, "Output"],
Cell[578678, 13076, 1543, 41, 75, "Output"],
Cell[580224, 13119, 383, 6, 33, "Print"],
Cell[580610, 13127, 1292, 33, 75, "Output"],
Cell[581905, 13162, 1465, 38, 75, "Output"],
Cell[583373, 13202, 383, 6, 33, "Print"],
Cell[583759, 13210, 1253, 32, 75, "Output"],
Cell[585015, 13244, 1465, 38, 75, "Output"],
Cell[586483, 13284, 335, 5, 33, "Print"],
Cell[586821, 13291, 348, 6, 43, "Output"],
Cell[587172, 13299, 1542, 41, 75, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[588751, 13345, 1791, 50, 148, "Input"],
Cell[590545, 13397, 558, 18, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[591140, 13420, 567, 18, 106, "Input"],
Cell[591710, 13440, 108, 1, 43, "Output"],
Cell[591821, 13443, 106, 1, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[591964, 13449, 5729, 167, 476, "Input"],
Cell[597696, 13618, 1686, 46, 75, "Output"],
Cell[599385, 13666, 480, 8, 43, "Output"],
Cell[599868, 13676, 816, 19, 75, "Output"],
Cell[600687, 13697, 479, 8, 43, "Output"],
Cell[601169, 13707, 14440, 244, 372, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[615646, 13956, 7387, 206, 728, "Input"],
Cell[623036, 14164, 2182, 62, 107, "Output"],
Cell[625221, 14228, 1563, 45, 78, "Output"],
Cell[626787, 14275, 1366, 38, 75, "Output"],
Cell[628156, 14315, 654, 18, 78, "Output"],
Cell[628813, 14335, 1291, 35, 75, "Output"],
Cell[630107, 14372, 877, 24, 78, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[631033, 14402, 187, 4, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[631245, 14410, 11016, 313, 1521, "Input"],
Cell[642264, 14725, 286, 4, 33, "Print"],
Cell[642553, 14731, 1434, 26, 78, "Output"],
Cell[643990, 14759, 288, 4, 33, "Print"],
Cell[644281, 14765, 1427, 25, 73, "Output"],
Cell[645711, 14792, 1594, 31, 73, "Output"],
Cell[647308, 14825, 288, 4, 33, "Print"],
Cell[647599, 14831, 1150, 16, 43, "Output"],
Cell[648752, 14849, 1155, 16, 43, "Output"],
Cell[649910, 14867, 1151, 16, 43, "Output"],
Cell[651064, 14885, 291, 4, 33, "Print"],
Cell[651358, 14891, 1223, 18, 46, "Output"],
Cell[652584, 14911, 1399, 24, 73, "Output"],
Cell[653986, 14937, 334, 5, 33, "Print"],
Cell[654323, 14944, 1151, 16, 43, "Output"],
Cell[655477, 14962, 1151, 16, 43, "Output"],
Cell[656631, 14980, 339, 5, 33, "Print"],
Cell[656973, 14987, 1151, 16, 43, "Output"],
Cell[658127, 15005, 1149, 16, 43, "Output"],
Cell[659279, 15023, 291, 4, 33, "Print"],
Cell[659573, 15029, 1166, 16, 43, "Output"],
Cell[660742, 15047, 1404, 24, 73, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[662195, 15077, 258, 5, 42, "Subsubsection"],
Cell[662456, 15084, 156, 3, 42, "Text"],
Cell[CellGroupData[{
Cell[662637, 15091, 762, 21, 76, "Input"],
Cell[663402, 15114, 617, 18, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[664056, 15137, 650, 18, 47, "Input"],
Cell[664709, 15157, 420, 10, 55, "Output"]
}, Open  ]],
Cell[665144, 15170, 157, 3, 42, "Text"],
Cell[CellGroupData[{
Cell[665326, 15177, 2036, 55, 80, "Input"],
Cell[667365, 15234, 1231, 36, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[668633, 15275, 846, 24, 48, "Input"],
Cell[669482, 15301, 554, 14, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[670073, 15320, 811, 24, 80, "Input"],
Cell[670887, 15346, 363, 10, 43, "Output"]
}, Open  ]],
Cell[671265, 15359, 166, 3, 42, "Text"],
Cell[CellGroupData[{
Cell[671456, 15366, 217, 5, 47, "Input"],
Cell[671676, 15373, 197, 4, 43, "Output"]
}, Open  ]],
Cell[671888, 15380, 187, 3, 42, "Text"],
Cell[CellGroupData[{
Cell[672100, 15387, 207, 4, 43, "Input"],
Cell[672310, 15393, 1066, 28, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[673413, 15426, 2851, 77, 338, "Input"],
Cell[676267, 15505, 596, 12, 88, "Output"],
Cell[676866, 15519, 618, 13, 88, "Output"],
Cell[677487, 15534, 410, 7, 82, "Output"],
Cell[677900, 15543, 1058, 25, 88, "Output"],
Cell[678961, 15570, 1121, 27, 141, "Output"],
Cell[680085, 15599, 861, 21, 88, "Output"],
Cell[680949, 15622, 730, 18, 127, "Output"],
Cell[681682, 15642, 730, 18, 127, "Output"],
Cell[682415, 15662, 637, 13, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[683089, 15680, 660, 18, 82, "Input"],
Cell[683752, 15700, 1803, 50, 207, "Output"]
}, Open  ]],
Cell[685570, 15753, 185, 3, 81, "Text"],
Cell[685758, 15758, 803, 21, 127, "Input"],
Cell[686564, 15781, 636, 19, 127, "Input"],
Cell[CellGroupData[{
Cell[687225, 15804, 675, 18, 82, "Input"],
Cell[687903, 15824, 543, 16, 127, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[688483, 15845, 1206, 32, 238, "Input"],
Cell[689692, 15879, 1289, 33, 183, "Output"],
Cell[690984, 15914, 619, 15, 127, "Output"],
Cell[691606, 15931, 623, 15, 127, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[692278, 15952, 97, 1, 77, "Subsubsection"],
Cell[CellGroupData[{
Cell[692400, 15957, 349, 6, 478, "Input"],
Cell[692752, 15965, 204, 4, 478, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[692993, 15974, 992, 26, 571, "Input"],
Cell[693988, 16002, 891, 23, 566, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[694916, 16030, 346, 8, 828, "Input"],
Cell[695265, 16040, 755, 18, 596, "Output"],
Cell[696023, 16060, 591, 15, 596, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[696651, 16080, 2354, 60, 977, "Input"],
Cell[699008, 16142, 2149, 57, 931, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[701194, 16204, 1914, 51, 2503, "Input"],
Cell[703111, 16257, 2443, 62, 1526, "Output"],
Cell[705557, 16321, 2918, 79, 891, "Output"],
Cell[708478, 16402, 1518, 37, 550, "Output"],
Cell[709999, 16441, 1541, 40, 596, "Output"],
Cell[711543, 16483, 1518, 37, 550, "Output"]
}, Open  ]],
Cell[713076, 16523, 99, 1, 478, "Input"],
Cell[713178, 16526, 215, 5, 531, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[713430, 16536, 104, 1, 53, "Subsubsection"],
Cell[713537, 16539, 1648, 41, 345, "Input"],
Cell[CellGroupData[{
Cell[715210, 16584, 1701, 42, 345, "Input"],
Cell[716914, 16628, 5194, 132, 438, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[722145, 16765, 1515, 32, 195, "Input"],
Cell[723663, 16799, 3616, 97, 450, "Output"],
Cell[727282, 16898, 3345, 82, 210, "Output"],
Cell[730630, 16982, 783, 11, 82, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[731450, 16998, 1707, 44, 246, "Input"],
Cell[733160, 17044, 441, 6, 82, "Output"],
Cell[733604, 17052, 434, 6, 82, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[734075, 17063, 999, 32, 140, "Input"],
Cell[735077, 17097, 490, 13, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[735604, 17115, 778, 22, 145, "Input"],
Cell[736385, 17139, 1200, 31, 140, "Output"],
Cell[737588, 17172, 1220, 34, 150, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[738845, 17211, 1168, 32, 145, "Input"],
Cell[740016, 17245, 857, 26, 176, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[740910, 17276, 946, 27, 176, "Input"],
Cell[741859, 17305, 898, 26, 176, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[742794, 17336, 2306, 58, 601, "Input"],
Cell[745103, 17396, 842, 23, 175, "Output"],
Cell[745948, 17421, 608, 14, 171, "Output"],
Cell[746559, 17437, 19727, 332, 926, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[766335, 17775, 96, 1, 96, "Subsubsection"],
Cell[766434, 17778, 574, 16, 102, "Input"],
Cell[767011, 17796, 146, 2, 243, "Input"],
Cell[767160, 17800, 4225, 138, 1672, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[771434, 17944, 184, 3, 266, "Section"],
Cell[CellGroupData[{
Cell[771643, 17951, 97, 1, 137, "Subsection"],
Cell[CellGroupData[{
Cell[771765, 17956, 190, 3, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[771980, 17963, 295, 8, 102, "Input"],
Cell[772278, 17973, 96, 1, 102, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[772423, 17980, 272, 4, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[772720, 17988, 764, 20, 233, "Input"],
Cell[773487, 18010, 310, 9, 160, "Output"],
Cell[773800, 18021, 190, 5, 160, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[774039, 18032, 320, 4, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[774384, 18040, 1103, 31, 370, "Input"],
Cell[775490, 18073, 593, 18, 171, "Output"],
Cell[776086, 18093, 317, 9, 171, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[776452, 18108, 375, 5, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[776852, 18117, 758, 20, 233, "Input"],
Cell[777613, 18139, 314, 9, 160, "Output"],
Cell[777930, 18150, 194, 5, 160, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[778185, 18162, 279, 4, 137, "Subsection"],
Cell[778467, 18168, 1104, 24, 243, "Input"],
Cell[CellGroupData[{
Cell[779596, 18196, 190, 3, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[779811, 18203, 1116, 24, 360, "Input"],
Cell[780930, 18229, 424, 6, 102, "Output"],
Cell[781357, 18237, 412, 6, 102, "Output"],
Cell[781772, 18245, 414, 6, 102, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[782235, 18257, 250, 3, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[782510, 18264, 1129, 33, 371, "Input"],
Cell[783642, 18299, 790, 22, 171, "Output"],
Cell[784435, 18323, 594, 15, 171, "Output"],
Cell[785032, 18340, 482, 11, 181, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[785563, 18357, 252, 3, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[785840, 18364, 2044, 56, 391, "Input"],
Cell[787887, 18422, 1206, 28, 171, "Output"],
Cell[789096, 18452, 1168, 27, 187, "Output"],
Cell[790267, 18481, 861, 18, 176, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[791177, 18505, 317, 4, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[791519, 18513, 1468, 41, 431, "Input"],
Cell[792990, 18556, 2528, 72, 438, "Output"],
Cell[795521, 18630, 2027, 57, 321, "Output"],
Cell[797551, 18689, 1985, 57, 187, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[799573, 18751, 2200, 58, 487, "Input"],
Cell[801776, 18811, 751, 16, 160, "Output"],
Cell[802530, 18829, 1333, 31, 171, "Output"],
Cell[803866, 18862, 545, 8, 102, "Output"],
Cell[804414, 18872, 965, 22, 187, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[805428, 18900, 310, 4, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[805763, 18908, 2402, 68, 565, "Input"],
Cell[808168, 18978, 1567, 40, 181, "Output"],
Cell[809738, 19020, 885, 22, 187, "Output"],
Cell[810626, 19044, 1106, 28, 181, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[811781, 19078, 292, 4, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[812098, 19086, 2745, 73, 551, "Input"],
Cell[814846, 19161, 720, 15, 171, "Output"],
Cell[815569, 19178, 1570, 41, 176, "Output"],
Cell[817142, 19221, 591, 9, 102, "Output"],
Cell[817736, 19232, 1023, 25, 187, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[818808, 19263, 276, 4, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[819109, 19271, 2345, 65, 565, "Input"],
Cell[821457, 19338, 1322, 36, 176, "Output"],
Cell[822782, 19376, 774, 19, 187, "Output"],
Cell[823559, 19397, 647, 15, 176, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[824255, 19418, 338, 4, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[824618, 19426, 2451, 64, 487, "Input"],
Cell[827072, 19492, 851, 19, 171, "Output"],
Cell[827926, 19513, 3418, 89, 488, "Output"],
Cell[831347, 19604, 598, 9, 102, "Output"],
Cell[831948, 19615, 1562, 39, 187, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[833559, 19660, 331, 4, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[833915, 19668, 2788, 80, 565, "Input"],
Cell[836706, 19750, 2033, 51, 258, "Output"],
Cell[838742, 19803, 1442, 37, 187, "Output"],
Cell[840187, 19842, 1168, 29, 181, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[841392, 19876, 1168, 31, 291, "Input"],
Cell[842563, 19909, 624, 16, 102, "Output"],
Cell[843190, 19927, 1528, 45, 175, "Output"],
Cell[844721, 19974, 340, 7, 102, "Output"]
}, Open  ]],
Cell[845076, 19984, 26, 0, 102, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[845151, 19990, 271, 4, 137, "Subsection"],
Cell[CellGroupData[{
Cell[845447, 19998, 1792, 50, 391, "Input"],
Cell[847242, 20050, 1439, 37, 160, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[848718, 20092, 104, 1, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[848847, 20097, 968, 25, 243, "Input"],
Cell[849818, 20124, 2013, 50, 237, "Output"],
Cell[851834, 20176, 1004, 28, 158, "Output"],
Cell[852841, 20206, 368, 6, 102, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[853258, 20218, 96, 1, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[853379, 20223, 581, 15, 175, "Input"],
Cell[853963, 20240, 668, 15, 102, "Output"],
Cell[854634, 20257, 560, 12, 102, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[855255, 20276, 322, 5, 137, "Subsection"],
Cell[CellGroupData[{
Cell[855602, 20285, 2993, 81, 541, "Input"],
Cell[858598, 20368, 3406, 89, 356, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[862041, 20462, 104, 1, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[862170, 20467, 2119, 53, 450, "Input"],
Cell[864292, 20522, 4824, 120, 432, "Output"],
Cell[869119, 20644, 2756, 74, 235, "Output"],
Cell[871878, 20720, 1269, 30, 110, "Output"],
Cell[873150, 20752, 3280, 91, 315, "Output"],
Cell[876433, 20845, 1186, 28, 158, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[877668, 20879, 96, 1, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[877789, 20884, 491, 10, 102, "Input"],
Cell[878283, 20896, 2261, 64, 246, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[880581, 20965, 2020, 60, 366, "Input"],
Cell[882604, 21027, 1445, 41, 181, "Output"],
Cell[884052, 21070, 2741, 84, 408, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[886830, 21159, 900, 27, 158, "Input"],
Cell[887733, 21188, 582, 18, 158, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[888352, 21211, 2113, 62, 366, "Input"],
Cell[890468, 21275, 1333, 40, 181, "Output"],
Cell[891804, 21317, 2951, 93, 535, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[894792, 21415, 1183, 36, 283, "Input"],
Cell[895978, 21453, 592, 18, 158, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[896619, 21477, 104, 1, 96, "Subsubsection"],
Cell[896726, 21480, 1233, 37, 102, "Input"],
Cell[CellGroupData[{
Cell[897984, 21521, 2555, 63, 585, "Input"],
Cell[900542, 21586, 4958, 122, 432, "Output"],
Cell[905503, 21710, 2890, 76, 235, "Output"],
Cell[908396, 21788, 1403, 32, 110, "Output"],
Cell[909802, 21822, 3416, 93, 315, "Output"],
Cell[913221, 21917, 1600, 39, 102, "Output"],
Cell[914824, 21958, 1144, 24, 102, "Output"],
Cell[915971, 21984, 1162, 25, 102, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[917182, 22015, 96, 1, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[917303, 22020, 1831, 52, 502, "Input"],
Cell[919137, 22074, 3593, 98, 321, "Output"],
Cell[922733, 22174, 7372, 212, 645, "Output"],
Cell[930108, 22388, 1123, 27, 102, "Output"],
Cell[931234, 22417, 878, 18, 102, "Output"],
Cell[932115, 22437, 959, 21, 102, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[933123, 22464, 104, 1, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[933252, 22469, 3274, 84, 713, "Input"],
Cell[936529, 22555, 5094, 124, 432, "Output"],
Cell[941626, 22681, 3026, 78, 235, "Output"],
Cell[944655, 22761, 1537, 34, 110, "Output"],
Cell[946195, 22797, 3552, 95, 315, "Output"],
Cell[949750, 22894, 1679, 39, 110, "Output"],
Cell[951432, 22935, 1467, 32, 110, "Output"],
Cell[952902, 22969, 1169, 22, 110, "Output"],
Cell[954074, 22993, 1171, 22, 102, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[955294, 23021, 96, 1, 96, "Subsubsection"],
Cell[CellGroupData[{
Cell[955415, 23026, 1409, 44, 502, "Input"],
Cell[956827, 23072, 2019, 61, 246, "Output"],
Cell[958849, 23135, 4384, 128, 453, "Output"],
Cell[963236, 23265, 1025, 30, 110, "Output"],
Cell[964264, 23297, 574, 16, 110, "Output"],
Cell[964841, 23315, 556, 15, 102, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
